@@ -3,7 +3,7 @@
  * Copyright (C) 2005       Thomas Denk
  * Copyright (C) 2008       Paul Wise
  * Copyright (C) 2007-2008  Giel van Schijndel
- * Copyright (C) 2007-2009  Warzone Resurrection Project
+ * Copyright (C) 2007-2010  Warzone 2100 Project
  *
  * This program is distributed under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
@@ -13,9 +13,9 @@
  * Id: autorevision.cpp 3543 2007-01-27 00:25:43Z daniel2000
  * HeadURL: http://svn.berlios.de/svnroot/repos/codeblocks/trunk/src/build_tools/autorevision/autorevision.cpp
  *
- * $Revision: 8162 $
- * $Id: autorevision.cpp 8162 2009-09-19 16:07:19Z the_cybersphinx $
- * $HeadURL: https://warzone2100.svn.sourceforge.net/svnroot/warzone2100/tags/2.2.4/build_tools/autorevision/autorevision.cpp $
+ * $Revision$
+ * $Id$
+ * $HeadURL$
  */
 
 #include <iostream>
@@ -25,6 +25,10 @@
 
 #include <cstring>
 #include <cstdlib>
+#ifndef PATH_MAX
+#define PATH_MAX 4096
+#endif
+
 
 using namespace std;
 
