@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -172,11 +172,11 @@ static void registry_set_key( const char *k, const char *v )
 // =======================================================================================================================
 // =======================================================================================================================
 //
-static BOOL registry_load( const char *filename )
+static bool registry_load( const char *filename )
 {
-	char buffer[MAXLINESIZE];
+	char buffer[MAXLINESIZE + 1];
 	char *bptr = NULL, *bufstart = NULL;
-	char key[32];
+	char key[MAXLINESIZE];
 	int l; // sscanf expects an int to receive %n, not an unsigned int
 	UDWORD filesize;
 
@@ -201,7 +201,8 @@ static BOOL registry_load( const char *filename )
 		int count = 0;
 
 		/* Put a line into buffer */
-		while (*bptr != '\0' && *bptr != '\n' && count < MAXLINESIZE) {
+		while (*bptr != '\0' && *bptr != '\n' && count < MAXLINESIZE)
+		{
 			buffer[count] = *bptr;
 			bptr++;
 			count++;
@@ -232,7 +233,7 @@ static BOOL registry_load( const char *filename )
 // =======================================================================================================================
 // =======================================================================================================================
 //
-static BOOL registry_save( const char *filename )
+static bool registry_save( const char *filename )
 {
 	char buffer[MAXLINESIZE * REGISTRY_HASH_SIZE];
 	unsigned int i;
@@ -247,9 +248,9 @@ static BOOL registry_save( const char *filename )
 
 			snprintf(linebuf, sizeof(linebuf), "%s=%s\n", j->key, j->value);
 			assert(strlen(linebuf) > 0 && strlen(linebuf) < MAXLINESIZE);
+			assert(count + strlen(linebuf) < MAXLINESIZE * REGISTRY_HASH_SIZE);
 			memcpy(buffer + count, linebuf, strlen(linebuf));
 			count += strlen(linebuf);
-			assert(count < MAXLINESIZE * REGISTRY_HASH_SIZE);
 		}
 	}
 
@@ -268,10 +269,10 @@ void setRegistryFilePath(const char* fileName)
 // =======================================================================================================================
 // =======================================================================================================================
 //
-BOOL openWarzoneKey( void )
+bool openWarzoneKey( void )
 {
 	//~~~~~~~~~~~~~~~~~~~~~
-	static BOOL done = false;
+	static bool done = false;
 	//~~~~~~~~~~~~~~~~~~~~~
 
 	if ( done == false )
@@ -287,7 +288,7 @@ BOOL openWarzoneKey( void )
 // =======================================================================================================================
 // =======================================================================================================================
 //
-BOOL closeWarzoneKey( void )
+bool closeWarzoneKey( void )
 {
 	registry_save( RegFilePath );
 	return true;
@@ -299,7 +300,7 @@ BOOL closeWarzoneKey( void )
  * \param	*val	Place where to store the setting
  * \return	Whether we succeed to find the setting
  */
-BOOL getWarzoneKeyNumeric( const char *pName, SDWORD *val )
+bool getWarzoneKeyNumeric( const char *pName, SDWORD *val )
 {
 	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 	char	*value = registry_get_key( pName );
@@ -319,7 +320,7 @@ BOOL getWarzoneKeyNumeric( const char *pName, SDWORD *val )
 // =======================================================================================================================
 // =======================================================================================================================
 //
-BOOL getWarzoneKeyString( const char *pName, char *pString )
+bool getWarzoneKeyString( const char *pName, char *pString )
 {
 	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 	char	*value = registry_get_key( pName );
@@ -341,7 +342,7 @@ BOOL getWarzoneKeyString( const char *pName, char *pString )
 // =======================================================================================================================
 // =======================================================================================================================
 //
-BOOL setWarzoneKeyNumeric( const char *pName, SDWORD val )
+bool setWarzoneKeyNumeric( const char *pName, SDWORD val )
 {
 	//~~~~~~~~~~~~
 	char	buf[32];
@@ -357,7 +358,7 @@ BOOL setWarzoneKeyNumeric( const char *pName, SDWORD val )
 // =======================================================================================================================
 // =======================================================================================================================
 //
-BOOL setWarzoneKeyString( const char *pName, const char *pString )
+bool setWarzoneKeyString( const char *pName, const char *pString )
 {
 	registry_set_key( pName, pString );
 	return true;
