@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -25,12 +25,12 @@
 #define _INCLUDE_LIB_FRAMEWORK_CONFIGFILE_H_
 
 extern void registry_clear(void);
-extern BOOL openWarzoneKey(void);
-extern BOOL closeWarzoneKey(void);
-extern BOOL getWarzoneKeyNumeric(const char *pName, SDWORD *val);
-extern BOOL setWarzoneKeyNumeric(const char *pName, SDWORD val);
-extern BOOL getWarzoneKeyString(const char *pName, char *pString);
-extern BOOL setWarzoneKeyString(const char *pName, const char *pString);
+extern bool openWarzoneKey(void);
+extern bool closeWarzoneKey(void);
+extern bool getWarzoneKeyNumeric(const char *pName, SDWORD *val);
+extern bool setWarzoneKeyNumeric(const char *pName, SDWORD val);
+extern bool getWarzoneKeyString(const char *pName, char *pString);
+extern bool setWarzoneKeyString(const char *pName, const char *pString);
 extern void setRegistryFilePath(const char* fileName);
 
 #endif // _INCLUDE_LIB_FRAMEWORK_CONFIGFILE_H_
