@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -670,6 +670,49 @@ static const char *cursor_embark[] = {
   "16,22"
 };
 
+static const char *cursor_disembark[] = {
+	/* width height num_colors chars_per_pixel */
+	"    32    32        3            1",
+	/* colors */
+	"X c #000000",
+	". c #ffffff",
+	"  c None",
+	/* pixels */
+	"                                ",
+	"                                ",
+	"                                ",
+	"                                ",
+	"                                ",
+	"           ...........X         ",
+	"           ...........X         ",
+	"           ...........X         ",
+	"           ...........X         ",
+	"        .................X      ",
+	"         ...............XX      ",
+	"          .............X        ",
+	"           ...........X         ",
+	"           X.........X          ",
+	"        ...XX.......XX...X      ",
+	"         ...XX.....XX...X       ",
+	"          ...XX...XX...X        ",
+	"           ...XX.XX...X         ",
+	"            ...XXX...X          ",
+	"             ...X...X           ",
+	"              .....X            ",
+	"               ...X             ",
+	"                .X              ",
+	"                                ",
+	"                                ",
+	"                                ",
+	"                                ",
+	"                                ",
+	"                                ",
+	"                                ",
+	"                                ",
+	"                                ",
+	"16,22"
+};
+
 static const char *cursor_fix[] = {
   /* width height num_colors chars_per_pixel */
   "    32    32        3            1",
@@ -842,6 +885,49 @@ static const char *cursor_lockon[] = {
   "15,15"
 };
 
+static const char *cursor_scout[] = {
+	/* width height num_colors chars_per_pixel */
+	"    32    32        3            1",
+	/* colors */
+	"X c #000000",
+	". c #ffffff",
+	"  c None",
+	/* pixels */
+	"                                ",
+	"                                ",
+	"                                ",
+	"                                ",
+	"                                ",
+	"                                ",
+	"             .....X             ",
+	"           ...XXX...X           ",
+	"          ..XX   XX..X          ",
+	"         ..X       X..X         ",
+	"         .X   ...X  X.X         ",
+	"        ..X  .X  .X  ..X        ",
+	"        .X  .X    .X  .X        ",
+	"        .X  .X .X .X  .X        ",
+	"        .X  .XX.XX.X  .X        ",
+	"        ..X  X...XX  ..X        ",
+	"         .X   ...X   .X         ",
+	"         ..X .....X ..X         ",
+	"          .XX.....XX.X          ",
+	"           X.......XX           ",
+	"            .......X            ",
+	"           .........X           ",
+	"           .........X           ",
+	"            XXXXXXXXX           ",
+	"                                ",
+	"                                ",
+	"                                ",
+	"                                ",
+	"                                ",
+	"                                ",
+	"                                ",
+	"                                ",
+	"15,15"
+};
+
 static const char *cursor_menu[] = {
   /* width height num_colors chars_per_pixel */
   "    32    32        3            1",
@@ -1122,10 +1208,12 @@ static const struct
 	{ cursor_bridge,        CURSOR_BRIDGE },
 	{ cursor_build,         CURSOR_BUILD },
 	{ cursor_embark,        CURSOR_EMBARK },
+	{ cursor_disembark,     CURSOR_DISEMBARK },
 	{ cursor_fix,           CURSOR_FIX },
 	{ cursor_guard,         CURSOR_GUARD },
 	{ cursor_jam,           CURSOR_JAM },
 	{ cursor_lockon,        CURSOR_LOCKON },
+	{ cursor_scout,         CURSOR_SCOUT },
 	{ cursor_menu,          CURSOR_MENU },
 	{ cursor_move,          CURSOR_MOVE },
 	{ cursor_notpossible,   CURSOR_NOTPOSSIBLE },
