@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -32,7 +32,12 @@
 #include "frameint.h"
 #include "string_ext.h"
 
+#if defined(WZ_HAVE_MOTIF)
+# include "x-motif-messagebox.h"
+#endif
+
 #include "lib/gamelib/gtime.h"
+#include "src/warzoneconfig.h"	// to determine if we are in full screen mode or not for the system dialogs
 
 #define MAX_LEN_LOG_LINE 512
 
@@ -41,8 +46,14 @@ UDWORD traceID = -1;
 
 static debug_callback * callbackRegistry = NULL;
 bool enabled_debug[LOG_LAST]; // global
+#ifdef DEBUG
 bool assertEnabled = true;
-
+#else
+bool assertEnabled = false;
+#endif
+#if defined(WZ_OS_MAC)
+#include <Carbon/Carbon.h>
+#endif
 /*
  * This list _must_ match the enum in debug.h!
  * Names must be 8 chars long at max!
@@ -74,6 +85,12 @@ static const char *code_part_names[] = {
 	"gateway",
 	"message",
 	"info",
+	"terrain",
+	"feature",
+	"fatal",
+	"input",
+	"popup",
+	"console",
 	"last"
 };
 
@@ -206,6 +223,29 @@ void debugFlushStderr()
 {
 	debug_flush_stderr = true;
 }
+// MSVC specific rotuines to set/clear allocation tracking
+#if defined(WZ_CC_MSVC) && defined(DEBUG)
+void debug_MEMCHKOFF(void)
+{
+	// Disable allocation tracking
+	int flags = _CrtSetDbgFlag(_CRTDBG_REPORT_FLAG);
+	flags &= ~_CRTDBG_ALLOC_MEM_DF;
+	_CrtSetDbgFlag(flags);
+}
+void debug_MEMCHKON(void)
+{
+	// Enable allocation tracking
+	int flags = _CrtSetDbgFlag(_CRTDBG_REPORT_FLAG);
+	flags |= _CRTDBG_ALLOC_MEM_DF;
+	_CrtSetDbgFlag(flags);
+}
+void debug_MEMSTATS(void)
+{
+	_CrtMemState state;
+	_CrtMemCheckpoint(&state);
+	_CrtMemDumpStatistics(&state);
+}
+#endif
 
 void debug_init(void)
 {
@@ -228,6 +268,8 @@ void debug_init(void)
 	memset( enabled_debug, false, sizeof(enabled_debug) );
 	enabled_debug[LOG_ERROR] = true;
 	enabled_debug[LOG_INFO] = true;
+	enabled_debug[LOG_FATAL] = true;
+	enabled_debug[LOG_POPUP] = true;
 	inputBuffer[0][0] = '\0';
 	inputBuffer[1][0] = '\0';
 #ifdef DEBUG
@@ -386,6 +428,79 @@ void _debug( code_part part, const char *function, const char *str, ... )
 		ssprintf(outputBuffer, "%-8s|%s: %s", code_part_names[part], ourtime, useInputBuffer1 ? inputBuffer[1] : inputBuffer[0]);
 
 		printToDebugCallbacks(outputBuffer);
+
+		// Throw up a dialog box for windows users since most don't have a clue to check the stderr.txt file for information
+		// Use for (duh) Fatal errors, that force us to terminate the game.
+		// FIXME: This only works for windowed mode now, screenToggleMode() doesn't seem to toggle us back and forth for some reason.
+		if (part == LOG_FATAL && !war_getFullscreen())
+		{
+#if defined(WZ_OS_WIN)
+			char* popupBuf;
+			sasprintf(&popupBuf, "%s\n\nPlease check your WZlog file in your <config dir>/logs directory for more details. \
+				\nDo not forget to upload both the WZlog<date><time>.txt file and the warzone2100.rpt file in your bug reports!", useInputBuffer1 ? inputBuffer[1] : inputBuffer[0]);
+
+			MessageBoxA(NULL, popupBuf, "Warzone has terminated unexpectedly", MB_OK|MB_ICONERROR);
+#elif defined(WZ_HAVE_MOTIF)
+			const char* popupBuf = useInputBuffer1 ? inputBuffer[1] : inputBuffer[0];
+			XmMessageBox(part, code_part_names[part], popupBuf);
+#elif defined(WZ_OS_MAC)
+			AlertStdCFStringAlertParamRec	param;
+			DialogRef						dialog;
+			OSStatus						err;
+			DialogItemIndex					itemHit;
+			char aBuffer[512];
+
+			GetStandardAlertDefaultParams( &param, kStdCFStringAlertVersionOne );
+			param.movable = true;
+			
+			ssprintf(aBuffer, "%s\n\nPlease check your <config dir>/logs/WZlog file for more details.\n", useInputBuffer1 ? inputBuffer[1] : inputBuffer[0] );
+			
+			err = CreateStandardAlert( kAlertStopAlert, CFStringCreateWithCString( nil, aBuffer, kCFStringEncodingMacRoman),
+				CFSTR( "Run Console.app and search for wz2100 and copy that to a file.\
+					  \n\nFor the Crash report on 10.4/10.5 check\
+					  \n~/Library/Logs/CrashReporter,\
+					  \non 10.6 check ~/Library/Logs/DiagnosticReports\
+					  \nDo not forget to upload and attach those to a bug report at http://developer.wz2100.net/newticket\
+					  \nThanks!" ), &param, &dialog );
+			SetWindowTitleWithCFString( GetDialogWindow( dialog ), CFSTR( "Warzone has terminated unexpectedly" ) );
+			
+			RunStandardAlert( dialog, NULL, &itemHit );
+#endif
+		}
+
+		// Throw up a dialog box for windows users since most don't have a clue to check the stderr.txt file for information
+		// This is a popup dialog used for times when the error isn't fatal, but we still need to notify user what is going on.
+		// FIXME: This only works for windowed mode now
+		if (part == LOG_POPUP && !war_getFullscreen())
+		{
+#if defined(WZ_OS_WIN) || defined(WZ_HAVE_MOTIF)
+			char* popupBuf;
+			sasprintf(&popupBuf, "A non fatal error has occurred.\n\n%s.\n\nCheck your <config dir>/logs/WZlog file for more details.", useInputBuffer1 ? inputBuffer[1] : inputBuffer[0]);
+
+# if defined(WZ_OS_WIN)
+			MessageBoxA(NULL, popupBuf, "Warzone has detected a problem.", MB_OK|MB_ICONINFORMATION);
+# elif defined(WZ_HAVE_MOTIF)
+			XmMessageBox(part, code_part_names[part], popupBuf);
+# endif
+#elif defined (WZ_OS_MAC)
+			AlertStdCFStringAlertParamRec	param;
+			DialogRef						dialog;
+			OSStatus						err;
+			DialogItemIndex					itemHit;
+			char aBuffer[512];
+			
+			GetStandardAlertDefaultParams( &param, kStdCFStringAlertVersionOne );
+			param.movable = true;
+			
+			ssprintf(aBuffer, "A non fatal error has occurred.\n\n%s\n\nCheck your <config dir>/logs/WZlog file for more details.", useInputBuffer1 ? inputBuffer[1] : inputBuffer[0] );
+			
+			err = CreateStandardAlert( kAlertNoteAlert, CFStringCreateWithCString( nil, aBuffer, kCFStringEncodingMacRoman), NULL, &param, &dialog );
+			SetWindowTitleWithCFString( GetDialogWindow( dialog ), CFSTR( "Warzone has detected a problem" ) );
+			
+			RunStandardAlert( dialog, NULL, &itemHit );
+#endif
+		}
+
 	}
 	useInputBuffer1 = !useInputBuffer1; // Swap buffers
 }
