@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -31,7 +31,12 @@
 # error Framework header files MUST be included from Frame.h ONLY.
 #endif
 
+#include "wzglobal.h"
+
 #include <assert.h>
+#if !defined(WZ_OS_WIN)
+#include <signal.h>
+#endif
 #include "macros.h"
 #include "types.h"
 
@@ -54,13 +59,22 @@ extern char last_called_script_event[MAX_EVENT_NAME_LEN];
 /** Whether asserts are currently enabled. */
 extern bool assertEnabled;
 
+
+/* Do the correct assert call for each compiler */
+#if defined(WZ_OS_WIN)
+#define wz_assert(expr) assert(expr)
+#else
+#define wz_assert(expr) raise(SIGTRAP)
+#endif
+
+
 /** Deals with failure in an assert. Expression is (re-)evaluated for output in the assert() call. */
 #define ASSERT_FAILURE(expr, expr_string, location_description, function, ...) \
 	( \
 		(void)_debug(LOG_ERROR, function, __VA_ARGS__), \
 		(void)_debug(LOG_ERROR, function, "Assert in Warzone: %s (%s), last script event: '%s'", \
 	                                  location_description, expr_string, last_called_script_event), \
-		( assertEnabled ? assert(expr) : (void)0 )\
+		( assertEnabled ? (void)wz_assert(expr) : (void)0 )\
 	)
 
 /**
@@ -106,13 +120,36 @@ extern bool assertEnabled;
 	do { bool _wzeval = (expr); if (!_wzeval) { ASSERT_FAILURE(expr, #expr, AT_MACRO, __FUNCTION__, __VA_ARGS__); return retval; } } while (0)
 
 
+/**
+ * Compile time assert
+ *
+ * Forces a compilation error if condition is true, but also produce a result
+ * (of value 0 and type size_t), so the expression can be used anywhere that
+ * a comma expression isn't permitted.
+ *
+ * \param expr Expression to evaluate
+ *
+ * \note BUILD_BUG_ON_ZERO from <linux/kernel.h>
+ */
+#ifndef __cplusplus
+#define STATIC_ASSERT_EXPR( expr ) \
+	(sizeof(struct { int:-!(expr); }))
+#else //cplusplus
+}
+template<bool> class StaticAssert;
+template<> class StaticAssert<true>{};
+#define STATIC_ASSERT_EXPR(expr) \
+	(sizeof(StaticAssert<(expr)>))
+extern "C"
+{
+#endif //cplusplus
 /**
  * Compile time assert
  * Not to be used in global context!
  * \param expr Expression to evaluate
  */
 #define STATIC_ASSERT( expr ) \
-	do { enum { assert_static__ = 1/(expr) }; } while(0)
+	(void)STATIC_ASSERT_EXPR(expr)
 
 
 /***
@@ -150,6 +187,12 @@ typedef enum {
   LOG_GATEWAY,
   LOG_MSG,
   LOG_INFO,	/**< special; on by default, for both debug & release builds  */
+  LOG_TERRAIN,
+  LOG_FEATURE,
+  LOG_FATAL,	/**< special; on by default, for both debug & release builds  */
+  LOG_INPUT,	// mouse / keyboard events
+  LOG_POPUP,	// special, on by default, for both debug & release builds (used for OS dependent popup code)
+  LOG_CONSOLE,	// send console messages to file
   LOG_LAST /**< _must_ be last! */
 } code_part;
 
@@ -236,6 +279,13 @@ void _realObjTrace(int id, const char *function, const char *str, ...) WZ_DECL_F
 static inline void objTraceEnable(UDWORD id) { traceID = id; }
 static inline void objTraceDisable(void) { traceID = (UDWORD)-1; }
 
+// MSVC specific rotuines to set/clear allocation tracking
+#if defined(WZ_CC_MSVC) && defined(DEBUG)
+void debug_MEMCHKOFF(void);
+void debug_MEMCHKON(void);
+void debug_MEMSTATS(void);
+#endif
+
 #if defined(__cplusplus)
 }
 #endif
