@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -59,7 +59,7 @@ extern UDWORD selectedPlayer;
  *  @return true when the framework library is successfully initialised, false
  *          when a part of the initialisation failed.
  */
-extern BOOL frameInitialise(const char* pWindowName, UDWORD width, UDWORD height, UDWORD bitDepth, BOOL fullScreen, BOOL vsync);
+extern bool frameInitialise(const char* pWindowName, UDWORD width, UDWORD height, UDWORD bitDepth, bool fullScreen, bool vsync);
 
 extern bool selfTest;
 
@@ -106,11 +106,7 @@ extern UDWORD HashString( const char *String );
 extern UDWORD HashStringIgnoreCase( const char *String );
 
 #if defined(WZ_OS_WIN)
-struct timeval
-{
-	long tv_sec;
-	long tv_usec;
-};
+# include <winsock2.h> /* for struct timeval */
 
 struct timezone;
 extern int gettimeofday(struct timeval* tv, struct timezone* tz);
