@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -78,12 +78,13 @@ static INPUT_STATE aMouseState[6];
 #define INPUT_MAXSTR	512
 
 /* The input string buffer */
-static UDWORD	pInputBuffer[INPUT_MAXSTR];
-static UDWORD	*pStartBuffer, *pEndBuffer;
-
-static char	pCharInputBuffer[INPUT_MAXSTR];
-static char	*pCharStartBuffer, *pCharEndBuffer;
-static char	currentChar;
+typedef struct _InputKey
+{
+	UDWORD key;
+	utf_32_char unicode;
+} InputKey;
+static InputKey	pInputBuffer[INPUT_MAXSTR];
+static InputKey	*pStartBuffer, *pEndBuffer;
 
 
 static KEY_CODE sdlKeyToKeyCode(SDLKey key)
@@ -104,8 +105,41 @@ void keyScanToString(KEY_CODE code, char *ascii, UDWORD maxStringSize)
 		strcpy(ascii,"???");
 		return;
 	}
+	else if (code == KEY_LCTRL)
+	{
+		// shortcuts with modifier keys work with either key.
+		strcpy(ascii, "Ctrl");
+		return;
+	}
+	else if (code == KEY_LSHIFT)
+	{
+		// shortcuts with modifier keys work with either key.
+		strcpy(ascii, "Shift");
+		return;
+	}
+	else if (code == KEY_LALT)
+	{
+		// shortcuts with modifier keys work with either key.
+		strcpy(ascii, "Alt");
+		return;
+	}
+	else if (code == KEY_LMETA)
+	{
+		// shortcuts with modifier keys work with either key.
+#ifdef WZ_OS_MAC
+		strcpy(ascii, "Cmd");
+#else
+		strcpy(ascii, "Meta");
+#endif
+		return;
+	}
 	ASSERT( keyCodeToSDLKey(code) < KEY_MAXSCAN, "Invalid key code: %d", code );
 	snprintf(ascii, maxStringSize, "%s", SDL_GetKeyName(keyCodeToSDLKey(code)));
+	if (ascii[0] >= 'a' && ascii[0] <= 'z' && ascii[1] != 0)
+	{
+		// capitalize
+		ascii[0] += 'A'-'a';
+	}
 }
 
 
@@ -126,8 +160,6 @@ void inputInitialise(void)
 
 	pStartBuffer = pInputBuffer;
 	pEndBuffer = pInputBuffer;
-	pCharStartBuffer = pCharInputBuffer;
-	pCharEndBuffer = pCharInputBuffer;
 
 	dragX = mouseXPos = screenWidth/2;
 	dragY = mouseYPos = screenHeight/2;
@@ -137,39 +169,27 @@ void inputInitialise(void)
 	SDL_EnableKeyRepeat(SDL_DEFAULT_REPEAT_DELAY, SDL_DEFAULT_REPEAT_INTERVAL);
 }
 
-/* add count copies of the characater code to the input buffer */
-void inputAddBuffer(UDWORD code, char char_code, UDWORD count)
+// Cyclic increment.
+static InputKey *inputPointerNext(InputKey *p)
 {
-	UDWORD	*pNext;
-	char	*pCharNext;
+    return p + 1 == pInputBuffer + INPUT_MAXSTR ? pInputBuffer : p + 1;
+}
 
+/* add count copies of the characater code to the input buffer */
+static void inputAddBuffer(UDWORD key, utf_32_char unicode)
+{
 	/* Calculate what pEndBuffer will be set to next */
-	pNext = pEndBuffer + 1;
-	pCharNext = pCharEndBuffer + 1;
-	if (pNext >= pInputBuffer + INPUT_MAXSTR)
+	InputKey	*pNext = inputPointerNext(pEndBuffer);
+
+	if (pNext == pStartBuffer)
 	{
-		pNext = pInputBuffer;
-		pCharNext = pCharInputBuffer;
+		return;  // Buffer full.
 	}
 
-	while (pNext != pStartBuffer && count > 0)
-	{
-		/* Store the character */
-		*pEndBuffer = code;
-		*pCharEndBuffer = char_code;
-		pEndBuffer = pNext;
-		pCharEndBuffer = pCharNext;
-		count -= 1;
-
-		/* Calculate what pEndBuffer will be set to next */
-		pNext = pEndBuffer + 1;
-		pCharNext = pCharEndBuffer + 1;
-		if (pNext >= pInputBuffer + INPUT_MAXSTR)
-		{
-			pNext = pInputBuffer;
-			pCharNext = pCharInputBuffer;
-		}
-	}
+	// Add key to buffer.
+	pEndBuffer->key = key;
+	pEndBuffer->unicode = unicode;
+	pEndBuffer = pNext;
 }
 
 
@@ -178,8 +198,6 @@ void inputClearBuffer(void)
 {
 	pStartBuffer = pInputBuffer;
 	pEndBuffer = pInputBuffer;
-	pCharStartBuffer = pCharInputBuffer;
-	pCharEndBuffer = pCharInputBuffer;
 }
 
 
@@ -188,35 +206,29 @@ void inputClearBuffer(void)
  * windows key map.
  * All key presses are buffered up (including windows auto repeat).
  */
-UDWORD inputGetKey(void)
+UDWORD inputGetKey(utf_32_char *unicode)
 {
 	UDWORD	retVal;
 
-	if (pStartBuffer != pEndBuffer)
+	if (pStartBuffer == pEndBuffer)
 	{
-		retVal = *pStartBuffer;
-		currentChar = *pCharStartBuffer;
-		pStartBuffer += 1;
-		pCharStartBuffer += 1;
+	    return 0;  // Buffer empty.
+	}
 
-		if (pStartBuffer >= pInputBuffer + INPUT_MAXSTR)
-		{
-			pStartBuffer = pInputBuffer;
-			pCharStartBuffer = pCharInputBuffer;
-		}
-	}
-	else
+	retVal = pStartBuffer->key;
+	if (unicode)
 	{
-		retVal = 0;
+	    *unicode = pStartBuffer->unicode;
 	}
+	if (!retVal)
+	{
+	    retVal = ' ';  // Don't return 0 if we got a virtual key, since that's interpreted as no input.
+	}
+	pStartBuffer = inputPointerNext(pStartBuffer);
 
 	return retVal;
 }
 
-char inputGetCharKey(void) {
-	return currentChar;
-}
-
 
 /*!
  * Handle keyboard events
@@ -224,7 +236,7 @@ char inputGetCharKey(void) {
 void inputHandleKeyEvent(SDL_KeyboardEvent * keyEvent)
 {
 	UDWORD code, vk;
-	unsigned char char_code = keyEvent->keysym.unicode; // FIXME Discarding last 8 bit of 16bit UNICODE !!!
+	utf_32_char unicode = keyEvent->keysym.unicode;
 
 	switch (keyEvent->type)
 	{
@@ -266,12 +278,12 @@ void inputHandleKeyEvent(SDL_KeyboardEvent * keyEvent)
 					break;
 			}
 
-			debug( LOG_NEVER, "Code: %x\n", vk);
-			if (char_code < 32)
+			debug( LOG_INPUT, "Key Code (pressed): 0x%x, %d, [%c] SDLkey=[%s]", vk, vk, (vk < 128) && (vk > 31) ? (char) vk : '?' , SDL_GetKeyName(keyCodeToSDLKey((KEY_CODE)keyEvent->keysym.sym)));
+			if (unicode < 32)
 			{
-				char_code = 0;
+				unicode = 0;
 			}
-			inputAddBuffer(vk, char_code, 1);
+			inputAddBuffer(vk, unicode);
 
 			code = sdlKeyToKeyCode(keyEvent->keysym.sym);
 			if ( aKeyState[code].state == KEY_UP ||
@@ -316,7 +328,7 @@ void inputHandleMouseButtonEvent(SDL_MouseButtonEvent * buttonEvent)
 					&& buttonEvent->button != SDL_BUTTON_WHEELDOWN))
 				{
 				//whether double click or not
-					if ( gameTime - aMouseState[buttonEvent->button].lastdown < DOUBLE_CLICK_INTERVAL )
+					if ( gameTime2 - aMouseState[buttonEvent->button].lastdown < DOUBLE_CLICK_INTERVAL )
 					{
 						aMouseState[buttonEvent->button].state = KEY_DOUBLECLICK;
 						aMouseState[buttonEvent->button].lastdown = 0;
@@ -324,7 +336,7 @@ void inputHandleMouseButtonEvent(SDL_MouseButtonEvent * buttonEvent)
 					else
 					{
 						aMouseState[buttonEvent->button].state = KEY_PRESSED;
-						aMouseState[buttonEvent->button].lastdown = gameTime;
+						aMouseState[buttonEvent->button].lastdown = gameTime2;
 					}
 
 				}
@@ -368,20 +380,17 @@ void inputHandleMouseMotionEvent(SDL_MouseMotionEvent * motionEvent)
 	switch (motionEvent->type)
 	{
 		case SDL_MOUSEMOTION:
-			if(!mouseDown(MOUSE_MMB))
-			{
-				/* store the current mouse position */
-				mouseXPos = motionEvent->x;
-				mouseYPos = motionEvent->y;
+			/* store the current mouse position */
+			mouseXPos = motionEvent->x;
+			mouseYPos = motionEvent->y;
 
-				/* now see if a drag has started */
-				if (  ( aMouseState[dragKey].state == KEY_PRESSED ||
-						aMouseState[dragKey].state == KEY_DOWN )
-				&& ( ABSDIF(dragX, mouseXPos) > DRAG_THRESHOLD ||
-						ABSDIF(dragY, mouseYPos) > DRAG_THRESHOLD ) )
-				{
-					aMouseState[dragKey].state = KEY_DRAG;
-				}
+			/* now see if a drag has started */
+			if ((aMouseState[dragKey].state == KEY_PRESSED ||
+			     aMouseState[dragKey].state == KEY_DOWN) &&
+			    (ABSDIF(dragX, mouseXPos) > DRAG_THRESHOLD ||
+			     ABSDIF(dragY, mouseYPos) > DRAG_THRESHOLD))
+			{
+				aMouseState[dragKey].state = KEY_DRAG;
 			}
 			break;
 		default:
@@ -448,21 +457,21 @@ void inputLooseFocus(void)
 }
 
 /* This returns true if the key is currently depressed */
-BOOL keyDown(KEY_CODE code)
+bool keyDown(KEY_CODE code)
 {
 	ASSERT( keyCodeToSDLKey(code) < KEY_MAXSCAN, "Invalid key code: %d", code );
 	return (aKeyState[code].state != KEY_UP);
 }
 
 /* This returns true if the key went from being up to being down this frame */
-BOOL keyPressed(KEY_CODE code)
+bool keyPressed(KEY_CODE code)
 {
 	ASSERT( keyCodeToSDLKey(code) < KEY_MAXSCAN, "Invalid key code: %d", code );
 	return ((aKeyState[code].state == KEY_PRESSED) || (aKeyState[code].state == KEY_PRESSRELEASE));
 }
 
 /* This returns true if the key went from being down to being up this frame */
-BOOL keyReleased(KEY_CODE code)
+bool keyReleased(KEY_CODE code)
 {
 	ASSERT( keyCodeToSDLKey(code) < KEY_MAXSCAN, "Invalid key code: %d", code );
 	return ((aKeyState[code].state == KEY_RELEASED) || (aKeyState[code].state == KEY_PRESSRELEASE));
@@ -481,19 +490,22 @@ Uint16 mouseY(void)
 }
 
 /* This returns true if the mouse key is currently depressed */
-BOOL mouseDown(MOUSE_KEY_CODE code)
+bool mouseDown(MOUSE_KEY_CODE code)
 {
-	return (aMouseState[code].state != KEY_UP);
+	return (aMouseState[code].state != KEY_UP) ||
+
+	       // holding down LMB and RMB counts as holding down MMB
+	       (code == MOUSE_MMB && aMouseState[MOUSE_LMB].state != KEY_UP && aMouseState[MOUSE_RMB].state != KEY_UP);
 }
 
 /* This returns true if the mouse key was double clicked */
-BOOL mouseDClicked(MOUSE_KEY_CODE code)
+bool mouseDClicked(MOUSE_KEY_CODE code)
 {
 	return (aMouseState[code].state == KEY_DOUBLECLICK);
 }
 
 /* This returns true if the mouse key went from being up to being down this frame */
-BOOL mousePressed(MOUSE_KEY_CODE code)
+bool mousePressed(MOUSE_KEY_CODE code)
 {
 	return ((aMouseState[code].state == KEY_PRESSED) ||
 			(aMouseState[code].state == KEY_DOUBLECLICK) ||
@@ -501,7 +513,7 @@ BOOL mousePressed(MOUSE_KEY_CODE code)
 }
 
 /* This returns true if the mouse key went from being down to being up this frame */
-BOOL mouseReleased(MOUSE_KEY_CODE code)
+bool mouseReleased(MOUSE_KEY_CODE code)
 {
 	return ((aMouseState[code].state == KEY_RELEASED) ||
 			(aMouseState[code].state == KEY_DOUBLECLICK) ||
@@ -509,9 +521,13 @@ BOOL mouseReleased(MOUSE_KEY_CODE code)
 }
 
 /* Check for a mouse drag, return the drag start coords if dragging */
-BOOL mouseDrag(MOUSE_KEY_CODE code, UDWORD *px, UDWORD *py)
+bool mouseDrag(MOUSE_KEY_CODE code, UDWORD *px, UDWORD *py)
 {
-	if (aMouseState[code].state == KEY_DRAG)
+	if ((aMouseState[code].state == KEY_DRAG) ||
+
+	    // dragging LMB and RMB counts as dragging MMB
+	    (code == MOUSE_MMB && ((aMouseState[MOUSE_LMB].state == KEY_DRAG && aMouseState[MOUSE_RMB].state != KEY_UP) ||
+	     (aMouseState[MOUSE_LMB].state != KEY_UP && aMouseState[MOUSE_RMB].state == KEY_DRAG))))
 	{
 		*px = dragX;
 		*py = dragY;
