@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ extern int strres_lex_destroy(void);
 void strres_error(const char* msg);
 
 /* Store a string */
-extern BOOL strresStoreString(struct STR_RES *psRes, const char* pID, const char* pString);
+extern bool strresStoreString(struct STR_RES *psRes, const char* pID, const char* pString);
 
 #endif
 
