@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -62,7 +62,7 @@ TREAP_NODE** treapCreate()
 	TREAP_NODE** const psTreap = (TREAP_NODE**)malloc(sizeof(*psTreap));
 	if (!psTreap)
 	{
-		debug(LOG_ERROR, "Out of memory");
+		debug(LOG_FATAL, "Out of memory");
 		abort();
 		return NULL;
 	}
@@ -136,7 +136,7 @@ static void treapAddNode(TREAP_NODE **ppsRoot, TREAP_NODE *psNew)
 
 /* Add an object to a treap
  */
-BOOL treapAdd(TREAP_NODE** psTreap, const char* key, const char* string)
+bool treapAdd(TREAP_NODE** psTreap, const char* key, const char* string)
 {
 	/* Over-allocate so that we can put the key and the string in the same
 	 * chunck of memory as the TREAP_NODE struct. Which means a single
@@ -148,7 +148,8 @@ BOOL treapAdd(TREAP_NODE** psTreap, const char* key, const char* string)
 
 	if (psNew == NULL)
 	{
-		debug(LOG_ERROR, "treapAdd: Out of memory");
+		debug(LOG_FATAL, "treapAdd: Out of memory");
+		abort();
 		return false;
 	}
 
