@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -27,6 +27,9 @@
 /* Allow frame header files to be singly included */
 #define FRAME_LIB_INCLUDE
 
+#include "types.h"
+#include "trig.h"
+
 #include <assert.h>
 #include <stdlib.h>
 
@@ -48,7 +51,7 @@ static float aInvSin[TRIG_ACCURACY];
 
 
 /* Initialise the Trig tables */
-BOOL trigInitialise(void)
+bool trigInitialise(void)
 {
 	float val = 0.0f, inc = 2.0f * M_PI / TRIG_DEGREES;
 	int i;
