@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -181,7 +181,7 @@ animObj_Update( void )
 			if ( hashTable_RemoveElement( g_pAnimObjTable, psObj,
 				(intptr_t) psObj->psParent, psObj->psAnim->uwID ) == false )
 			{
-				debug( LOG_ERROR, "animObj_Update: couldn't remove anim obj\n" );
+				debug( LOG_FATAL, "animObj_Update: couldn't remove anim obj\n" );
 				abort();
 			}
 		}
@@ -240,7 +240,7 @@ animObj_Add( void *pParentObj, int iAnimID,
 
 	if ( uwObj > ANIM_MAX_COMPONENTS )
 	{
-		debug( LOG_ERROR, "animObj_Add: number of components too small\n" );
+		debug( LOG_FATAL, "animObj_Add: number of components too small\n" );
 		abort();
 	}
 
