@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
  *  Render routines for 3D coloured and shaded transparency rendering.
  */
 
-#include "lib/ivis_opengl/GLee.h"
+#include <GLee.h>
 #include <string.h>
 #include <SDL_video.h>
 
@@ -409,7 +409,7 @@ static void pie_DrawShadow(iIMDShape *shape, int flag, int flag_data, Vector3f*
 						newstack = realloc(edgelist, sizeof(EDGE) * edgelistsize);
 						if (newstack == NULL)
 						{
-							debug(LOG_ERROR, "pie_DrawShadow: Out of memory!");
+							debug(LOG_FATAL, "pie_DrawShadow: Out of memory!");
 							abort();
 							return;
 						}
