@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -38,6 +38,10 @@ void pal_Init(void)
 	WZCOL_HEALTH_HIGH	= WZCOL_GREEN;
 	WZCOL_HEALTH_MEDIUM	= WZCOL_YELLOW;
 	WZCOL_HEALTH_LOW	= WZCOL_RED;
+	WZCOL_HEALTH_HIGH_SHADOW	= pal_Colour(0, 160, 0);
+	WZCOL_HEALTH_MEDIUM_SHADOW	= pal_Colour(160, 160, 0);
+	WZCOL_HEALTH_LOW_SHADOW		= pal_Colour(160, 0, 0);
+	WZCOL_HEALTH_RESISTANCE		= pal_Colour(128, 192, 255);
 	WZCOL_CURSOR		= WZCOL_WHITE;
 
 	WZCOL_MENU_BACKGROUND = pal_Colour(0, 1, 97);
@@ -97,6 +101,9 @@ void pal_Init(void)
 	WZCOL_MENU_SHADOW = WZCOL_BLACK;
 	WZCOL_DBLUE = pal_Colour(0x0f,0x08,0x56);
 	WZCOL_LBLUE = pal_Colour(0x1c,0x9f,0xfb);
+	WZCOL_BLUEPRINT_VALID = pal_Colour(80,255,120);
+	WZCOL_BLUEPRINT_INVALID = pal_Colour(255,80,80);
+	WZCOL_BLUEPRINT_PLANNED = pal_Colour(50,160,75);
 }
 
 void pal_ShutDown(void)
