@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -21,11 +21,12 @@
  *  Renderer setup and state control routines for 3D rendering.
  */
 
-#include "lib/ivis_opengl/GLee.h"
+#include <GLee.h>
 #include "lib/framework/frame.h"
 
 #include <SDL.h>
 #include <SDL_mouse.h>
+#include <SDL_opengl.h>
 
 #include "lib/ivis_common/piestate.h"
 #include "lib/ivis_common/piedef.h"
@@ -258,3 +259,15 @@ void pie_ShowMouse(bool visible)
 	}
 }
 
+bool _glerrors(const char *function, const char *file, int line)
+{
+	bool ret = false;
+	GLenum err = glGetError();
+	while (err != GL_NO_ERROR)
+	{
+		ret = true;
+		debug(LOG_ERROR, "OpenGL error in function %s at %s:%u: %s\n", function, file, line, gluErrorString(err));
+		err = glGetError();
+	}
+	return ret;
+}
