@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
  *
  */
 
-#include "lib/ivis_opengl/GLee.h"
+#include <GLee.h>
 #include "lib/framework/frame.h"
 #include "lib/exceptionhandler/dumpinfo.h"
 
@@ -35,8 +35,11 @@
 #include "lib/ivis_common/tex.h"
 
 #include "lib/framework/frameint.h"
+#include "lib/ivis_common/textdraw.h"
 #include "lib/ivis_common/piestate.h"
 #include "lib/ivis_common/pieblitfunc.h"
+#include "lib/ivis_common/pieclip.h"
+
 #if defined(WZ_OS_MAC)
 #include <OpenGL/glu.h>
 #else
@@ -44,6 +47,7 @@
 #endif
 #include "screen.h"
 #include "src/console.h"
+#include "src/levels.h"
 
 /* The Current screen size and bit depth */
 UDWORD		screenWidth = 0;
@@ -59,112 +63,124 @@ static char		screendump_filename[PATH_MAX];
 static BOOL		screendump_required = false;
 static GLuint		backDropTexture = ~0;
 
-// Variables needed for our FBO
-GLuint fbo;					// Our handle to the FBO
-GLuint FBOtexture;			// The texture we are going to use
-GLuint FBOdepthbuffer;		// Our handle to the depth render buffer
-static BOOL FBOinit = false;
-BOOL bFboProblem = false;	// hack to work around people with bad drivers. (*cough*intel*cough*)
+static int preview_width = 0, preview_height = 0;
+static Vector2i player_pos[MAX_PLAYERS];
+static BOOL mappreview = false;
+static char mapname[256];
 
 /* Initialise the double buffered display */
-BOOL screenInitialise(
+bool screenInitialise(
 			UDWORD		width,		// Display width
 			UDWORD		height,		// Display height
 			UDWORD		bitDepth,	// Display bit depth
-			BOOL		fullScreen,	// Whether to start windowed
+			bool		fullScreen,	// Whether to start windowed
 							// or full screen
-			BOOL		vsync)		// If to sync to vblank or not
+			bool		vsync)		// If to sync to vblank or not
 {
-	static int video_flags = 0;
+	int video_flags = 0;
 	int bpp = 0, value;
 
-	/* Store the screen information */
-	screenWidth = width;
-	screenHeight = height;
-	screenDepth = bitDepth;
+	// Fetch the video info.
+	const SDL_VideoInfo* video_info = SDL_GetVideoInfo();
 
-	// Calculate the common flags for windowed and fullscreen modes.
-	if (video_flags == 0) {
-		// Fetch the video info.
-		const SDL_VideoInfo* video_info = SDL_GetVideoInfo();
+	if (width == 0 || height == 0)
+	{
+		pie_SetVideoBufferWidth(width = screenWidth = video_info->current_w);
+		pie_SetVideoBufferHeight(height = screenHeight = video_info->current_h);
+		pie_SetVideoBufferDepth(bitDepth = screenDepth = video_info->vfmt->BitsPerPixel);
+	}
+	else
+	{
+		screenWidth = width;
+		screenHeight = height;
+		screenDepth = bitDepth;
+	}
+	screenWidth = MAX(screenWidth, 640);
+	screenHeight = MAX(screenHeight, 480);
 
-		if (!video_info) {
-			return false;
-		}
+	if (!video_info)
+	{
+		return false;
+	}
 
-		// The flags to pass to SDL_SetVideoMode.
-		video_flags  = SDL_OPENGL;    // Enable OpenGL in SDL.
-		video_flags |= SDL_ANYFORMAT; // Don't emulate requested BPP if not available.
-		video_flags |= SDL_HWPALETTE; // Store the palette in hardware.
+	// The flags to pass to SDL_SetVideoMode.
+	video_flags  = SDL_OPENGL;    // Enable OpenGL in SDL.
+	video_flags |= SDL_ANYFORMAT; // Don't emulate requested BPP if not available.
+	video_flags |= SDL_HWPALETTE; // Store the palette in hardware.
 
-		// This checks to see if surfaces can be stored in memory.
-		if (video_info->hw_available) {
-			video_flags |= SDL_HWSURFACE;
-		} else {
-			video_flags |= SDL_SWSURFACE;
-		}
+	// This checks to see if surfaces can be stored in memory.
+	if (video_info->hw_available)
+	{
+		video_flags |= SDL_HWSURFACE;
+	}
+	else
+	{
+		video_flags |= SDL_SWSURFACE;
+	}
 
-		// This checks if hardware blits can be done.
-		if (video_info->blit_hw) {
-			video_flags |= SDL_HWACCEL;
-		}
+	// This checks if hardware blits can be done.
+	if (video_info->blit_hw)
+	{
+		video_flags |= SDL_HWACCEL;
+	}
 
-		if (fullScreen) {
-			video_flags |= SDL_FULLSCREEN;
-		}
+	if (fullScreen)
+	{
+		video_flags |= SDL_FULLSCREEN;
+	}
 
-		// Set the double buffer OpenGL attribute.
-		SDL_GL_SetAttribute(SDL_GL_DOUBLEBUFFER, 1);
+	// Set the double buffer OpenGL attribute.
+	SDL_GL_SetAttribute(SDL_GL_DOUBLEBUFFER, 1);
 
-		// Enable vsync if requested by the user
-		SDL_GL_SetAttribute(SDL_GL_SWAP_CONTROL, vsync);
+	// Enable vsync if requested by the user
+	SDL_GL_SetAttribute(SDL_GL_SWAP_CONTROL, vsync);
 
-		bpp = SDL_VideoModeOK(width, height, bitDepth, video_flags);
-		if (!bpp) {
-			debug( LOG_ERROR, "Error: Video mode %dx%d@%dbpp is not supported!\n", width, height, bitDepth );
-			return false;
-		}
-		switch ( bpp )
-		{
-			case 32:
-			case 24:
-				SDL_GL_SetAttribute( SDL_GL_RED_SIZE, 8 );
-				SDL_GL_SetAttribute( SDL_GL_GREEN_SIZE, 8 );
-				SDL_GL_SetAttribute( SDL_GL_BLUE_SIZE, 8 );
-				SDL_GL_SetAttribute( SDL_GL_ALPHA_SIZE, 8 );
-				SDL_GL_SetAttribute( SDL_GL_DEPTH_SIZE, 16 );
-				SDL_GL_SetAttribute( SDL_GL_STENCIL_SIZE, 8 );
-				break;
-			case 16:
-				debug( LOG_ERROR, "Warning: Using colour depth of %i instead of %i.", bpp, screenDepth );
-				debug( LOG_ERROR, "You will experience graphics glitches or crashes!" );
-				SDL_GL_SetAttribute( SDL_GL_RED_SIZE, 5 );
-				SDL_GL_SetAttribute( SDL_GL_GREEN_SIZE, 6 );
-				SDL_GL_SetAttribute( SDL_GL_BLUE_SIZE, 5 );
-				SDL_GL_SetAttribute( SDL_GL_DEPTH_SIZE, 16 );
-				SDL_GL_SetAttribute( SDL_GL_STENCIL_SIZE, 8 );
-				break;
-			case 8:
-				debug( LOG_ERROR, "Error: You don't want to play Warzone with a bit depth of %i, do you?", bpp );
-				exit( 1 );
-				break;
-			default:
-				debug( LOG_ERROR, "Error: Unsupported bit depth: %i", bpp );
-				exit( 1 );
-				break;
-		}
+	bpp = SDL_VideoModeOK(width, height, bitDepth, video_flags);
+	if (!bpp)
+	{
+		debug(LOG_ERROR, "Video mode %dx%d@%dbpp is not supported!", width, height, bitDepth);
+		return false;
+	}
+	switch (bpp)
+	{
+		case 32:
+		case 24:
+			SDL_GL_SetAttribute(SDL_GL_RED_SIZE, 8);
+			SDL_GL_SetAttribute(SDL_GL_GREEN_SIZE, 8);
+			SDL_GL_SetAttribute(SDL_GL_BLUE_SIZE, 8);
+			SDL_GL_SetAttribute(SDL_GL_ALPHA_SIZE, 8);
+			SDL_GL_SetAttribute(SDL_GL_DEPTH_SIZE, 16);
+			SDL_GL_SetAttribute(SDL_GL_STENCIL_SIZE, 8);
+			break;
+		case 16:
+			info("Using colour depth of %i instead of %i.", bpp, screenDepth);
+			info("You might experience graphics glitches or crashes!");
+			SDL_GL_SetAttribute(SDL_GL_RED_SIZE, 5);
+			SDL_GL_SetAttribute(SDL_GL_GREEN_SIZE, 6);
+			SDL_GL_SetAttribute(SDL_GL_BLUE_SIZE, 5);
+			SDL_GL_SetAttribute(SDL_GL_DEPTH_SIZE, 16);
+			SDL_GL_SetAttribute(SDL_GL_STENCIL_SIZE, 8);
+			break;
+		case 8:
+			debug(LOG_FATAL, "You don't want to play Warzone with a bit depth of %i, do you?", bpp);
+			exit(1);
+			break;
+		default:
+			debug(LOG_FATAL, "Unsupported bit depth: %i", bpp);
+			exit(1);
+			break;
 	}
 
 	screen = SDL_SetVideoMode(width, height, bpp, video_flags);
-	if ( !screen )
+	if (!screen)
 	{
-		debug( LOG_ERROR, "Error: SDL_SetVideoMode failed (%s).", SDL_GetError() );
+		debug(LOG_ERROR, "SDL_SetVideoMode failed (%s).", SDL_GetError());
 		return false;
 	}
-	if ( SDL_GL_GetAttribute(SDL_GL_DOUBLEBUFFER, &value) == -1)
+	if (SDL_GL_GetAttribute(SDL_GL_DOUBLEBUFFER, &value) == -1)
 	{
-		debug( LOG_ERROR, "OpenGL initialization did not give double buffering!" );
-		debug( LOG_ERROR, "Double buffering is required for this game!");
+		debug(LOG_FATAL, "OpenGL initialization did not give double buffering!");
+		debug(LOG_FATAL, "Double buffering is required for this game!");
 		exit(1);
 	}
 	// Note that no initialisation of GLee is required, since this is handled automatically.
@@ -179,8 +195,11 @@ BOOL screenInitialise(
 		addDumpInfo(buf);
 		ssprintf(buf, "OpenGL Version : %s", glGetString(GL_VERSION));
 		addDumpInfo(buf);
-		ssprintf(buf, "OpenGL GLSL Version : %s", glGetString(GL_SHADING_LANGUAGE_VERSION));
-		addDumpInfo(buf);
+		if (GLEE_VERSION_2_0)
+		{
+			ssprintf(buf, "OpenGL GLSL Version : %s", glGetString(GL_SHADING_LANGUAGE_VERSION));
+			addDumpInfo(buf);
+		}
 		ssprintf(buf, "Video Mode %d x %d (%d bpp) (%s)", width, height, bpp, fullScreen ? "fullscreen" : "window");
 		addDumpInfo(buf);
 		/* Dump information about OpenGL implementation to the console */
@@ -203,9 +222,11 @@ BOOL screenInitialise(
 		debug(LOG_3D, "  * Anisotropic filtering %s supported.", GLEE_EXT_texture_filter_anisotropic ? "is" : "is NOT");
 		debug(LOG_3D, "  * Rectangular texture %s supported.", GLEE_ARB_texture_rectangle ? "is" : "is NOT");
 		debug(LOG_3D, "  * FrameBuffer Object (FBO) %s supported.", GLEE_EXT_framebuffer_object ? "is" : "is NOT");
-		debug(LOG_3D, "  * Shader Objects %s supported.", GL_ARB_shader_objects ? "is" : "is NOT");
-		debug(LOG_3D, "  * Vertex Buffer Object (VBO) %s supported.", GL_ARB_vertex_buffer_object ? "is" : "is NOT");
-		debug(LOG_3D, "  * OpenGL GLSL Version : %s", glGetString(GL_SHADING_LANGUAGE_VERSION));
+		debug(LOG_3D, "  * Vertex Buffer Object (VBO) %s supported.", GLEE_ARB_vertex_buffer_object ? "is" : "is NOT");
+		if (GLEE_VERSION_2_0)
+		{
+			debug(LOG_3D, "  * OpenGL GLSL Version : %s", glGetString(GL_SHADING_LANGUAGE_VERSION));
+		}
 	}
 
 	glViewport(0, 0, width, height);
@@ -223,7 +244,9 @@ BOOL screenInitialise(
 	glEnable(GL_CULL_FACE);
 
 	glClearColor(0.0f, 0.0f, 0.0f, 1.0f);
+	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT | GL_ACCUM_BUFFER_BIT | GL_STENCIL_BUFFER_BIT);
 
+	glErrors();
 	return true;
 }
 
@@ -233,6 +256,9 @@ void screenShutDown(void)
 {
 	if (screen != NULL)
 	{
+		glClearColor(0.0f, 0.0f, 0.0f, 1.0f);
+		glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT | GL_ACCUM_BUFFER_BIT | GL_STENCIL_BUFFER_BIT);
+		glFlush();
 		SDL_FreeSurface(screen);
 		screen = NULL;
 	}
@@ -299,9 +325,25 @@ BOOL screen_GetBackDrop(void)
 //******************************************************************
 //slight hack to display maps (or whatever) in background.
 //bitmap MUST be (BACKDROP_HACK_WIDTH * BACKDROP_HACK_HEIGHT) for now.
-void screen_Upload(const char *newBackDropBmp)
+void screen_Upload(const char *newBackDropBmp, BOOL preview)
 {
 	static bool processed = false;
+	int x1 = 0, x2 = screenWidth, y1 = 0, y2 = screenHeight, i, scale = 0, w = 0, h = 0;
+	float tx = 1, ty = 1;
+	const float aspect = screenWidth / (float)screenHeight, backdropAspect = 4 / (float)3;
+
+	if (aspect < backdropAspect)
+	{
+		int offset = (screenWidth - screenHeight * backdropAspect) / 2;
+		x1 += offset;
+		x2 -= offset;
+	}
+	else
+	{
+		int offset = (screenHeight - screenWidth / backdropAspect) / 2;
+		y1 += offset;
+		y2 -= offset;
+	}
 
 	if(newBackDropBmp != NULL)
 	{
@@ -318,8 +360,6 @@ void screen_Upload(const char *newBackDropBmp)
 			0, GL_RGB, GL_UNSIGNED_BYTE, newBackDropBmp);
 
 		glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
-		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
-		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
 		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP);
 		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP);
 		processed = true;
@@ -336,16 +376,106 @@ void screen_Upload(const char *newBackDropBmp)
 	glBindTexture(GL_TEXTURE_2D, backDropTexture);
 	glColor3f(1, 1, 1);
 
+	if (preview)
+	{
+		int s1, s2;
+		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
+		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
+
+		s1 = screenWidth / preview_width;
+		s2 = screenHeight / preview_height;
+		scale = MIN(s1, s2);
+
+		w = preview_width * scale;
+		h = preview_height * scale;
+		x1 = screenWidth / 2 - w / 2;
+		x2 = screenWidth / 2 + w / 2;
+		y1 = screenHeight / 2 - h / 2;
+		y2 = screenHeight / 2 + h / 2;
+
+		tx = preview_width / (float)BACKDROP_HACK_WIDTH;
+		ty = preview_height / (float)BACKDROP_HACK_HEIGHT;
+	}
+	else
+	{
+		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
+		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
+	}
+
+	// we use 0..256 as texture coordinates, not 0..1
+	tx *= 256;
+	ty *= 256;
+
 	glBegin(GL_TRIANGLE_STRIP);
 		glTexCoord2f(0, 0);
-		glVertex2f(0, 0);
-		glTexCoord2f(255, 0);
-		glVertex2f(screenWidth, 0);
-		glTexCoord2f(0, 255);
-		glVertex2f(0, screenHeight);
-		glTexCoord2f(255, 255);
-		glVertex2f(screenWidth, screenHeight);
+		glVertex2f(x1, y1);
+		glTexCoord2f(tx, 0);
+		glVertex2f(x2, y1);
+		glTexCoord2f(0, ty);
+		glVertex2f(x1, y2);
+		glTexCoord2f(tx, ty);
+		glVertex2f(x2, y2);
 	glEnd();
+
+	if (preview)
+	{
+		for (i = 0; i < MAX_PLAYERS; i++)
+		{
+			int x = player_pos[i].x;
+			int y = player_pos[i].y;
+			char text[5];
+
+			if (x == 0x77777777)
+				continue;
+
+			x = screenWidth / 2 - w / 2 + x * scale;
+			y = screenHeight / 2 - h / 2 + y * scale;
+			ssprintf(text, "%d", i);
+			iV_SetFont(font_large);
+			iV_SetTextColour(WZCOL_BLACK);
+			iV_DrawText(text, x - 1, y - 1);
+			iV_DrawText(text, x + 1, y - 1);
+			iV_DrawText(text, x - 1, y + 1);
+			iV_DrawText(text, x + 1, y + 1);
+			iV_SetTextColour(WZCOL_WHITE);
+			iV_DrawText(text, x, y);
+		}
+	}
+}
+
+void screen_enableMapPreview(char *name, int width, int height, Vector2i *playerpositions)
+{
+	int i;
+	mappreview = true;
+	preview_width = width;
+	preview_height = height;
+	sstrcpy(mapname, name);
+	for (i = 0; i < MAX_PLAYERS; i++)
+	{
+		player_pos[i].x = playerpositions[i].x;
+		player_pos[i].y = playerpositions[i].y;
+	}
+}
+
+const char *screen_getMapName(void)
+{
+	return mapname;
+}
+
+void screen_disableMapPreview(void)
+{
+	if (mappreview)
+	{
+		mappreview = false;
+		sstrcpy(mapname, "none");
+		pie_LoadBackDrop(SCREEN_RANDOMBDROP);
+		screen_RestartBackDrop();
+	}
+}
+
+BOOL screen_getMapPreview(void)
+{
+	return mappreview;
 }
 
 /* Swap between windowed and full screen mode */
@@ -370,7 +500,7 @@ static const unsigned int channelsPerPixel = 3;
 void screenDoDumpToDiskIfRequired(void)
 {
 	const char* fileName = screendump_filename;
-	static iV_Image image = { 0, 0, 0, NULL };
+	iV_Image image = { 0, 0, 0, NULL };
 
 	if (!screendump_required) return;
 	debug( LOG_3D, "Saving screenshot %s\n", fileName );
@@ -400,13 +530,16 @@ void screenDoDumpToDiskIfRequired(void)
 	}
 	glReadPixels(0, 0, image.width, image.height, GL_RGB, GL_UNSIGNED_BYTE, image.bmp);
 
-	// Write the screen to a PNG
 	iV_saveImage_PNG(fileName, &image);
+	iV_saveImage_JPEG(fileName, &image);
 
 	// display message to user about screenshot
 	snprintf(ConsoleString,sizeof(ConsoleString),"Screenshot %s saved!",fileName);
 	addConsoleMessage(ConsoleString, LEFT_JUSTIFY,SYSTEM_MESSAGE);
-
+	if (image.bmp)
+	{
+		free(image.bmp);
+	}
 	screendump_required = false;
 }
 
@@ -419,135 +552,19 @@ void screenDoDumpToDiskIfRequired(void)
  */
 void screenDumpToDisk(const char* path)
 {
-	static unsigned int screendump_num = 0;
+	unsigned int screendump_num = 0;
+	time_t aclock;
+	struct tm *t;
 
-	while (++screendump_num != 0) {
-		// We can safely use '/' as path separator here since PHYSFS uses that as its default separator
-		ssprintf(screendump_filename, "%s/wz2100_shot_%03i.png", path, screendump_num);
-		if (!PHYSFS_exists(screendump_filename)) {
-			// Found a usable filename, so we'll stop searching.
-			break;
-		}
-	}
+	time(&aclock);           /* Get time in seconds */
+	t = localtime(&aclock);  /* Convert time to struct */
 
-	ASSERT( screendump_num != 0, "screenDumpToDisk: integer overflow; no more filenumbers available.\n" );
+	ssprintf(screendump_filename, "%s/wz2100-%04d%02d%02d_%02d%02d%02d-%s.png", path, t->tm_year + 1900, t->tm_mon + 1, t->tm_mday, t->tm_hour, t->tm_min, t->tm_sec, getLevelName());
 
-	// If we have an integer overflow, we don't want to go about and overwrite files
-	if (screendump_num != 0)
-		screendump_required = true;
-}
-
-/**
- * Checks if an OpenGL error has occurred.
- * \param label Label to print when an OpenGL occurred.
- */
-void checkGLErrors(const char *label)
-{
-	const GLenum errCode = glGetError();
-
-	if (errCode == GL_NO_ERROR)
-		return;
-
-	debug(LOG_ERROR, "OpenGL ERROR in %s: %s, (0x%0x)", label, gluErrorString(errCode), errCode);
-	bFboProblem = true;		// we have a issue with the FBO, fallback to normal routine
-}
-
-BOOL Init_FBO(unsigned int width, unsigned int height)
-{
-	GLenum status;
-
-	// Bail out if FBOs aren't supported
-	if (!GLEE_EXT_framebuffer_object)
-		return false;
-
-	// No need to create two FBOs
-	if (FBOinit)
-		return true;
-
-	// Create the FBO
-	glGenFramebuffersEXT(1, &fbo);
-	glBindFramebufferEXT(GL_FRAMEBUFFER_EXT, fbo);
-
-	// create depthbuffer
-	glGenRenderbuffersEXT(1, &FBOdepthbuffer);
-	glBindRenderbufferEXT(GL_RENDERBUFFER_EXT, FBOdepthbuffer);
-	glRenderbufferStorageEXT(GL_RENDERBUFFER_EXT, GL_DEPTH_COMPONENT, width, height);
-	glFramebufferRenderbufferEXT(GL_FRAMEBUFFER_EXT, GL_DEPTH_ATTACHMENT_EXT, GL_RENDERBUFFER_EXT, FBOdepthbuffer);
-
-	// Now setup a texture to render to
-	glGenTextures(1, &FBOtexture);
-	glBindTexture(GL_TEXTURE_2D, FBOtexture);
-	glTexImage2D(GL_TEXTURE_2D, 0, GL_RGB,  width, height,0, GL_RGB, GL_UNSIGNED_BYTE, NULL);
-	glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE);
-	glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE);
-	glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
-	glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
-
-	// attach that texture to the color
-	glFramebufferTexture2DEXT (GL_FRAMEBUFFER_EXT, GL_COLOR_ATTACHMENT0_EXT,
-				   GL_TEXTURE_2D, FBOtexture, 0);
-	glBindFramebufferEXT (GL_FRAMEBUFFER_EXT, 0); // unbind FBO
-
-	// make sure everything went OK
-	status = glCheckFramebufferStatusEXT(GL_FRAMEBUFFER_EXT);
-	if(status != GL_FRAMEBUFFER_COMPLETE_EXT)
+        while (PHYSFS_exists(screendump_filename))
 	{
-		switch (status)
-		{
-			case GL_FRAMEBUFFER_COMPLETE_EXT:
-				break;
-			case GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT_EXT:
-				debug(LOG_ERROR, "Error: FBO missing a required image/buffer attachment!");
-				break;
-			case GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT_EXT:
-				debug(LOG_ERROR, "Error: FBO has no images/buffers attached!");
-				break;
-			case GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS_EXT:
-				debug(LOG_ERROR, "Error: FBO has mismatched image/buffer dimensions!");
-				break;
-			case GL_FRAMEBUFFER_INCOMPLETE_FORMATS_EXT:
-				debug(LOG_ERROR, "Error: FBO colorbuffer attachments have different types!");
-				break;
-			case GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER_EXT:
-				debug(LOG_ERROR, "Error: FBO trying to draw to non-attached color buffer!");
-				break;
-			case GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER_EXT:
-				debug(LOG_ERROR, "Error: FBO trying to read from a non-attached color buffer!");
-				break;
-			case GL_FRAMEBUFFER_UNSUPPORTED_EXT:
-				debug(LOG_ERROR, "Error: FBO format is not supported by current graphics card/driver!");
-				break;
-			case GL_INVALID_FRAMEBUFFER_OPERATION_EXT :
-				debug(LOG_ERROR, "Error: FBO Non-framebuffer passed to glCheckFramebufferStatusEXT()!");
-				break;
-			default:
-				debug(LOG_ERROR, "*UNKNOWN FBO ERROR* reported from glCheckFramebufferStatusEXT() for %x!", status);
-				break;
-		}
-		FBOinit = false;	//we have a error with the FBO setup
-		return false;
+		ssprintf(screendump_filename, "%s/wz2100-%04d%02d%02d_%02d%02d%02d-%s-%d.png", path, t->tm_year + 1900, t->tm_mon + 1, t->tm_mday, t->tm_hour, t->tm_min, t->tm_sec, getLevelName(), ++screendump_num);
 	}
-	else
-	{
-		FBOinit = true;		//everything is OK with FBO setup.
-	}
-
-	glBindFramebufferEXT (GL_FRAMEBUFFER_EXT, 0); // unbind it for now.
-	checkGLErrors("Init_FBO() Completed");
-	return true;
-
+	screendump_required = true;
 }
 
-void Delete_FBO(void)
-{
-	if(FBOinit)
-	{
-		glDeleteFramebuffersEXT(1, &fbo);
-		checkGLErrors("Deleting FBO");
-		glDeleteRenderbuffersEXT(1, &FBOdepthbuffer);
-		checkGLErrors("deleting FBOdepthbuffer");
-		glDeleteTextures(1,&FBOtexture);
-		checkGLErrors("deleting FBOtexture");
-		fbo = FBOdepthbuffer = FBOtexture = FBOinit = 0;	//reset everything.
-	}
-}
