@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
 
-#include "lib/ivis_opengl/GLee.h"
+#include <GLee.h>
 #include "lib/framework/frame.h"
 
 #if defined(WZ_OS_MAC)
@@ -92,7 +92,7 @@ int pie_AddTexPage(iV_Image *s, const char* filename, int slot, int maxTextureSi
 	/* Stick the name into the tex page structures */
 	sstrcpy(_TEX_PAGE[i].name, filename);
 
-	glGenTextures(1, (GLuint *) &_TEX_PAGE[i].id);
+	glGenTextures(1, &_TEX_PAGE[i].id);
 	// FIXME: This function is used instead of glBindTexture, but we're juggling with difficult to trace global state here. Look into pie_SetTexturePage's definition for details.
 	pie_SetTexturePage(i);
 
@@ -246,7 +246,7 @@ int pie_ReplaceTexPage(iV_Image *s, const char *texPage, int maxTextureSize)
 		return -1;
 	}
 
-	glDeleteTextures(1, (GLuint *) &_TEX_PAGE[i].id);
+	glDeleteTextures(1, &_TEX_PAGE[i].id);
 	debug(LOG_TEXTURE, "Reloading texture %s from index %d", texPage, i);
 	_TEX_PAGE[i].name[0] = '\0';
 	pie_AddTexPage(s, texPage, i, maxTextureSize);
