@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
 
-#include "lib/ivis_opengl/GLee.h"
+#include <GLee.h>
 #include "lib/framework/frame.h"
 #include <stdlib.h>
 #include <string.h>
@@ -82,11 +82,12 @@ static inline void iV_printFontList(void)
 {
 	unsigned int i;
 	unsigned int font_count = glcGeti(GLC_CURRENT_FONT_COUNT);
-	debug(LOG_NEVER, "GLC_CURRENT_FONT_COUNT = %d", font_count);
 
+	debug(LOG_NEVER, "GLC_CURRENT_FONT_COUNT = %d", font_count);
 	if (font_count == 0)
 	{
-		debug(LOG_ERROR, "The required font (%s) isn't loaded", font_family);
+		debug(LOG_ERROR, "The requested font (%s) isn't loaded", font_family);
+		info("Forcing GLC_AUTO_FONT");
 
 		// Fall back to unselected fonts since the requested font apparently
 		// isn't available.
@@ -118,16 +119,16 @@ static void iV_initializeGLC(void)
 	_glcContext = glcGenContext();
 	if (!_glcContext)
 	{
-		debug(LOG_ERROR, "Failed to initialize");
+		debug(LOG_ERROR, "Failed to initialize error code %0x", glcGetError());
 	}
 	else
 	{
-		debug(LOG_NEVER, "Succesfully initialized. _glcContext = %d", _glcContext);
+		debug(LOG_NEVER, "Successfully initialized. _glcContext = %d", _glcContext);
 	}
 
 	glcContext(_glcContext);
 
-	glcDisable(GLC_AUTO_FONT);
+	glcEnable(GLC_AUTO_FONT);		// We *do* want font fall-backs
 	glcRenderStyle(GLC_TEXTURE);
 	glcStringType(GLC_UTF8_QSO); // Set GLC's string type to UTF-8 FIXME should be UCS4 to avoid conversions
 
@@ -136,7 +137,9 @@ static void iV_initializeGLC(void)
 
 	if (!glcNewFontFromFamily(_glcFont_Regular, font_family))
 	{
-		debug(LOG_ERROR, "Failed to select font family %s as regular font", font_family);
+		debug(LOG_ERROR, "Failed to select font family %s as regular font error code %0x", font_family, glcGetError());
+		// select a default font since requested font failed and print out what is available to QuesoGLC
+		iV_printFontList();
 	}
 	else
 	{
@@ -145,7 +148,7 @@ static void iV_initializeGLC(void)
 
 	if (!glcFontFace(_glcFont_Regular, font_face_regular))
 	{
-		debug(LOG_WARNING, "Failed to select the \"%s\" font face of font family %s", font_face_regular, font_family);
+		debug(LOG_WARNING, "Failed to select the \"%s\" font face of font family %s error code %0x", font_face_regular, font_family, glcGetError());
 	}
 	else
 	{
@@ -154,7 +157,7 @@ static void iV_initializeGLC(void)
 
 	if (!glcNewFontFromFamily(_glcFont_Bold, font_family))
 	{
-		debug(LOG_ERROR, "iV_initializeGLC: Failed to select font family %s for the bold font", font_family);
+		debug(LOG_ERROR, "iV_initializeGLC: Failed to select font family %s for the bold font error code %0x", font_family, glcGetError());
 	}
 	else
 	{
@@ -163,7 +166,7 @@ static void iV_initializeGLC(void)
 
 	if (!glcFontFace(_glcFont_Bold, font_face_bold))
 	{
-		debug(LOG_WARNING, "Failed to select the \"%s\" font face of font family %s", font_face_bold, font_family);
+		debug(LOG_WARNING, "Failed to select the \"%s\" font face of font family %s error code %0x", font_face_bold, font_family, glcGetError());
 	}
 	else
 	{
@@ -177,7 +180,6 @@ void iV_TextInit()
 {
 	iV_initializeGLC();
 	iV_SetFont(font_regular);
-
 #ifdef DEBUG
 	iV_printFontList();
 #endif
@@ -216,6 +218,11 @@ void iV_SetFont(enum iV_fonts FontID)
 			iV_SetTextSize(21.f);
 			glcFont(_glcFont_Bold);
 			break;
+
+		case font_small:
+			iV_SetTextSize(9.f);
+			glcFont(_glcFont_Regular);
+			break;
 	}
 }
 
