@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -51,11 +51,12 @@ static const char *packetname[NUM_GAME_PACKETS] =
 	"NET_BUILDFINISHED",
 	"NET_RESEARCH",
 	"NET_TEXTMSG",
-	"NET_REQUESTDROID",
+	"NET_UNUSED_18",
+	"NET_UNUSED_19",
 	"NET_PLAYERCOMPLETE",
-	"NET_REQUESTPLAYER",
+	"NET_UNUSED_21",
 	"NET_STRUCT",
-	"NET_WHOLEDROID",
+	"NET_UNUSED_23",
 	"NET_FEATURES",
 	"NET_PLAYERRESPONDING",
 	"NET_OPTIONS",
@@ -78,7 +79,7 @@ static const char *packetname[NUM_GAME_PACKETS] =
 	"NET_DROIDDISEMBARK",
 	"NET_RESEARCHSTATUS",
 	"NET_LASSAT",
-	"NET_REQUESTMAP",
+	"NET_UNUSED_46",
 	"NET_AITEXTMSG",
 	"NET_TEAMS_ON",
 	"NET_BEACONMSG",
@@ -91,8 +92,21 @@ static const char *packetname[NUM_GAME_PACKETS] =
 	"NET_PLAYER_LEAVING",
 	"NET_PLAYER_DROPPED",
 	"NET_GAME_FLAGS",
-	"NET_VERSION_CHECK",
-	"NET_REQUEST_VERSION"
+	"NET_READY_REQUEST",
+	"NET_NEVERUSE",
+	"NET_REJECTED",
+	"NET_UNUSED_62",
+	"NET_UNUSED_63",
+	"NET_UNUSED_64",
+	"NET_POSITIONREQUEST",
+	"NET_DATA_CHECK",
+	"NET_HOST_DROPPED",
+	"NET_FUTURE1",
+	"NET_FUTURE2",
+	"NET_FUTURE3",
+	"NET_FILE_REQUESTED",
+	"NET_FILE_CANCELLED",
+	"NET_FILE_PAYLOAD"
 };
 
 static PHYSFS_file	*pFileHandle = NULL;
@@ -104,7 +118,7 @@ BOOL NETstartLogging(void)
 	time_t aclock;
 	struct tm *newtime;
 	char buf[256];
-	static const char filename[] = "netplay.log";
+	static char filename[256] = {'\0'};
 	int i;
 
 	for (i = 0; i < NUM_GAME_PACKETS; i++)
@@ -118,6 +132,7 @@ BOOL NETstartLogging(void)
 	time( &aclock );                 /* Get time in seconds */
 	newtime = localtime( &aclock );  /* Convert time to struct */
 
+	snprintf(filename, sizeof(filename), "logs/netplay-%02d%02d_%02d%02d%02d.log", newtime->tm_mon, newtime->tm_mday, newtime->tm_hour, newtime->tm_min, newtime->tm_sec );
 	pFileHandle = PHYSFS_openWrite( filename ); // open the file
 	if (!pFileHandle)
 	{
@@ -132,8 +147,10 @@ BOOL NETstartLogging(void)
 
 BOOL NETstopLogging(void)
 {
+	static const char dash_line[] = "-----------------------------------------------------------\n";
 	char buf[256];
 	int i;
+	UDWORD totalBytessent = 0, totalBytesrecv = 0, totalPacketsent = 0, totalPacketrecv = 0;
 
 	if (!pFileHandle)
 	{
@@ -143,10 +160,53 @@ BOOL NETstopLogging(void)
 	/* Output stats */
 	for (i = 0; i < NUM_GAME_PACKETS; i++)
 	{
-		snprintf(buf, sizeof(buf), "%s: received %u times, %u bytes; sent %u times, %u bytes\n", packetname[i],
-			packetcount[0][i], packetsize[0][i], packetcount[1][i], packetsize[1][i]);
+		snprintf(buf, sizeof(buf), "%-24s:\t received %u times, %u bytes; sent %u times, %u bytes\n", packetname[i],
+			packetcount[1][i], packetsize[1][i], packetcount[0][i], packetsize[0][i]);
 		PHYSFS_write(pFileHandle, buf, strlen(buf), 1);
+		totalBytessent += packetsize[0][i];
+		totalBytesrecv += packetsize[1][i];
+		totalPacketsent += packetcount[0][i];
+		totalPacketrecv += packetcount[1][i];
 	}
+	snprintf(buf, sizeof(buf), "== Total bytes sent %u, Total bytes received %u ==\n", totalBytessent, totalBytesrecv);
+	PHYSFS_write(pFileHandle, buf, strlen(buf), 1);
+	snprintf(buf, sizeof(buf), "== Total packets sent %u, recv %u ==\n", totalPacketsent, totalPacketrecv);
+	PHYSFS_write(pFileHandle, buf, strlen(buf), 1);
+	snprintf(buf, sizeof(buf), "\n-Sync statistics -\n");
+	PHYSFS_write(pFileHandle, buf, strlen(buf), 1);
+	PHYSFS_write(pFileHandle, dash_line, strlen(dash_line), 1);
+	snprintf(buf, sizeof(buf), "joins: %hhu, kicks: %hhu, drops: %hhu, left %hhu\n", sync_counter.joins, sync_counter.kicks, sync_counter.drops, sync_counter.left );
+	PHYSFS_write(pFileHandle, buf, strlen(buf), 1);
+	snprintf(buf, sizeof(buf), "banned: %hhu, cantjoin: %hhu, rejected: %hhu\n", sync_counter.banned, sync_counter.cantjoin, sync_counter.rejected );
+	PHYSFS_write(pFileHandle, buf, strlen(buf), 1);
+	if (sync_counter.banned && IPlist)
+	{
+		snprintf(buf, sizeof(buf), "Banned list:\n");
+		PHYSFS_write(pFileHandle, buf, strlen(buf), 1);
+		for (i = 0; i < MAX_BANS; i++)
+		{
+			if (IPlist[i].IPAddress[0] != '\0')
+			{
+				snprintf(buf, sizeof(buf), "player %s, IP: %s\n", IPlist[i].pname, IPlist[i].IPAddress);
+				PHYSFS_write(pFileHandle, buf, strlen(buf), 1);
+			}
+		}
+
+	}
+	PHYSFS_write(pFileHandle, dash_line, strlen(dash_line), 1);
+	snprintf(buf, sizeof(buf), "sent/unsent DroidCheck %"PRIu64" / %"PRIu64"\n", sync_counter.sentDroidCheck, sync_counter.unsentDroidCheck);
+	PHYSFS_write(pFileHandle, buf, strlen(buf), 1);
+	snprintf(buf, sizeof(buf), "sent/unsent StructureCheck %"PRIu64" / %"PRIu64"\n", sync_counter.sentStructureCheck, sync_counter.unsentStructureCheck);
+	PHYSFS_write(pFileHandle, buf, strlen(buf), 1);
+	snprintf(buf, sizeof(buf), "sent/unsent PowerCheck %"PRIu64" / %"PRIu64"\n", sync_counter.sentPowerCheck, sync_counter.unsentPowerCheck);
+	PHYSFS_write(pFileHandle, buf, strlen(buf), 1);
+	snprintf(buf, sizeof(buf), "sent/unsent ScoreCheck %"PRIu64" / %"PRIu64"\n", sync_counter.sentScoreCheck, sync_counter.unsentScoreCheck);
+	PHYSFS_write(pFileHandle, buf, strlen(buf), 1);
+	snprintf(buf, sizeof(buf), "sent/unsent Ping %"PRIu64" / %"PRIu64"\n", sync_counter.sentPing, sync_counter.unsentPing);
+	PHYSFS_write(pFileHandle, buf, strlen(buf), 1);
+	snprintf(buf, sizeof(buf), "sent/unsent isMPDirtyBit %"PRIu64" / %"PRIu64"\n", sync_counter.sentisMPDirtyBit, sync_counter.unsentisMPDirtyBit);
+	PHYSFS_write(pFileHandle, buf, strlen(buf), 1);
+	PHYSFS_write(pFileHandle, dash_line, strlen(dash_line), 1);
 
 	if (!PHYSFS_close(pFileHandle))
 	{
@@ -158,14 +218,20 @@ BOOL NETstopLogging(void)
 	return true;
 }
 
-void NETlogPacket(NETMSG *msg, BOOL received)
+
+/** log packet
+ *  \param type, uint8_t, the packet's type.
+ *  \param size, uint16_t, the packet's size
+ *  \param received, BOOL, true if we are receiving a packet, false if we are sending a packet.
+*/
+void NETlogPacket( uint8_t type, uint16_t size, BOOL received)
 {
-	if (msg->type >= NUM_GAME_PACKETS)
+	if (type >= NUM_GAME_PACKETS)
 	{
 		return;
 	}
-	packetcount[received][msg->type]++;
-	packetsize[received][msg->type] += msg->size;
+	packetcount[received][type]++;
+	packetsize[received][type] += size;
 }
 
 BOOL NETlogEntry(const char *str,UDWORD a,UDWORD b)
@@ -182,17 +248,10 @@ BOOL NETlogEntry(const char *str,UDWORD a,UDWORD b)
 		return false;
 	}
 
-#ifndef MASSIVELOGS
-	if(a ==9 || a==10)
-	{
-		return true;
-	}
-#endif
+	time( &aclock );					/* Get time in seconds */
+	newtime = localtime( &aclock );		/* Convert time to struct */
 
-	time( &aclock );                 /* Get time in seconds */
-	newtime = localtime( &aclock );  /* Convert time to struct */
-
-	if (!newtime || a >= NET_GAME_FLAGS || !str || !pFileHandle)
+	if (!newtime || !str || !pFileHandle)
 	{
 		debug(LOG_ERROR, "Fatal error averted in NETlog");
 		return false;
@@ -204,25 +263,28 @@ BOOL NETlogEntry(const char *str,UDWORD a,UDWORD b)
 		static const char dash_line[] = "-----------------------------------------------------------\n";
 
 		lastframe = frame;
-
 		PHYSFS_write(pFileHandle, dash_line, strlen(dash_line), 1);
 	}
 
-	if (a <= 51)
+	if (a < NUM_GAME_PACKETS)
 		// replace common msgs with txt descriptions
 		snprintf(buf, sizeof(buf), "%s \t: %s \t:%d\t\t%s", str, packetname[a], b, asctime(newtime));
+	else if (a == SYNC_FLAG)
+		snprintf(buf, sizeof(buf), "%s \t: %d \t(Sync) \t%s", str, b, asctime(newtime));
 	else
 		snprintf(buf, sizeof(buf), "%s \t:%d \t\t\t:%d\t\t%s", str, a, b, asctime(newtime));
 
-	if (a == 56 || a==57 ) // NET_PLAYER_LEAVING || NET_PLAYER_DROPPED
+	if (a == NET_PLAYER_LEAVING || a == NET_PLAYER_DROPPED )
+	{
 		// Write a starry line above NET_LEAVING messages
 		PHYSFS_write(pFileHandle, star_line, strlen(star_line), 1);
-
-	PHYSFS_write(pFileHandle, buf, strlen( buf ), 1);
-
-	if (a == 56 || a== 57 ) // NET_PLAYER_LEAVING ||NET_PLAYER_DROPPED
-		// Write a starry line below NET_LEAVING messages
+		PHYSFS_write(pFileHandle, buf, strlen( buf ), 1);
 		PHYSFS_write(pFileHandle, star_line, strlen(star_line), 1);
+	}
+	else
+	{
+		PHYSFS_write(pFileHandle, buf, strlen( buf ), 1);
+	}
 
 	PHYSFS_flush(pFileHandle);
 	return true;
