@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 BOOL NETstartLogging(void);
 BOOL NETstopLogging(void);
 BOOL NETlogEntry( const char *str, UDWORD a, UDWORD b );
-void NETlogPacket(NETMSG *msg, BOOL received);
+void NETlogPacket( uint8_t type, uint16_t size, BOOL received);
 
 #endif // _netlog_h
 
