@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,17 +54,204 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 /* Substitute the variable and function names.  */
-#define yyparse chat_parse
-#define yylex   chat_lex
-#define yyerror chat_error
-#define yylval  chat_lval
-#define yychar  chat_char
-#define yydebug chat_debug
-#define yynerrs chat_nerrs
+#define yyparse         chat_parse
+#define yylex           chat_lex
+#define yyerror         chat_error
+#define yylval          chat_lval
+#define yychar          chat_char
+#define yydebug         chat_debug
+#define yynerrs         chat_nerrs
+
+
+/* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
+#line 20 "chat_parser.y"
+
+/*
+ * chat_parser.y
+ *
+ * yacc grammar for multiplayer chat messages
+ *
+ */
+#include "lib/framework/frame.h"
+#include "lib/framework/string_ext.h"
+
+#include "lib/framework/frameresource.h"
+#include "lib/script/chat_processing.h"
+
+#define MAX_CHAT_ARGUMENTS 10
+
+/* Holds information about a processed player chat message */
+CHAT_MSG chat_msg;
+
+// Parameter variable
+static INTERP_VAL scrParameter;
+
+extern int chat_lex(void);
+
+// Store extracted command for use in scripts
+static void chat_store_command(const char *command);
+
+/* Return value of the chat parsing - to be used in scripts */
+static BOOL chat_store_parameter(INTERP_VAL *parameter);
+
+// Store players that were addressed in a command
+static void chat_store_player(SDWORD cmdIndex, SDWORD playerIndex);
+
+// Reset a command
+static void chat_reset_command(SDWORD cmdIndex);
+
+// Information extracted from message and available for scripts
+//static int					numMsgParams=0;		//number of parameters currently extracted/stored
+//static INTERP_VAL		msgParams[MAX_CHAT_ARGUMENTS];
+
+/* Store command parameter extracted from the message */
+static BOOL chat_store_parameter(INTERP_VAL *cmdParam)
+{
+	SDWORD	numCmdParams, numCommands;
+
+	//console("chat_store_parameter: new parameter");
+
+	/* Make sure we have no overflow */
+	//if(numMsgParams >= MAX_CHAT_ARGUMENTS)
+	if(chat_msg.numCommands >= MAX_CHAT_COMMANDS)
+	{
+		ASSERT(false, "chat_store_parameter: too many commands in a message");
+		return false;
+	}
+
+	numCommands = chat_msg.numCommands;
+	numCmdParams = chat_msg.cmdData[numCommands].numCmdParams;
+
+	/* Make sure we still have room for more parameters */
+	if(numCmdParams >= MAX_CHAT_CMD_PARAMS)
+	{
+		ASSERT(false, "chat_store_parameter: out of parameters for command %d", numCommands);
+		return false;
+	}
+
+	/* Store parameter for command we are currently processing */
+	//memcpy(&(msgParams[numMsgParams]), parameter, sizeof(INTERP_VAL));
+	memcpy(&(chat_msg.cmdData[numCommands].parameter[numCmdParams]), cmdParam, sizeof(INTERP_VAL));
+
+	chat_msg.cmdData[numCommands].numCmdParams++;
+
+	return true;
+}
+
+// Store extracted command for use in scripts
+static void chat_store_command(const char *command)
+{
+	SDWORD	numCmdParams, numCommands;
+
+	//console("chat_store_command: new command: %s", command);
+
+	/* Make sure we have no overflow */
+	if(chat_msg.numCommands >= MAX_CHAT_COMMANDS)
+	{
+		ASSERT(false, "chat_store_command: too many commands in a message");
+		return;
+	}
+
+	numCommands = chat_msg.numCommands;
+	numCmdParams = chat_msg.cmdData[numCommands].numCmdParams;
+
+	/* Make sure we still have room for more parameters */
+	if(numCmdParams >= MAX_CHAT_CMD_PARAMS)
+	{
+		ASSERT(false, "chat_store_command: out of parameters for command %d", numCommands);
+		return;
+	}
+
+	/* Store command */
+	chat_msg.cmdData[numCommands].pCmdDescription = command;
+
+	chat_msg.numCommands++;
+}
+
+// Store players that were addressed in a command
+static void chat_store_player(SDWORD cmdIndex, SDWORD playerIndex)
+{
+	SDWORD i;
+
+	//console("chat_store_player: player %d addressd in command %d", playerIndex, cmdIndex);
+
+	/* Make sure we have no overflow */
+	if(cmdIndex < 0 || cmdIndex >= MAX_CHAT_COMMANDS)
+	{
+		ASSERT(false, "chat_store_player: command message out of bounds: %d", cmdIndex);
+		return;
+	}
+
+	if(playerIndex == -1)	//no player specified means all players addressed
+	{
+		/* Ally players addressed */
+		for(i=0; i<MAX_PLAYERS; i++)
+		{
+			chat_msg.cmdData[cmdIndex].bPlayerAddressed[i] = true;
+		}
+	}
+	else if(playerIndex >= 0 && playerIndex < MAX_PLAYERS)
+	{
+		chat_msg.cmdData[cmdIndex].bPlayerAddressed[playerIndex] = true;
+	}
+	else	/* Wrong player index */
+	{
+		ASSERT(false, "chat_store_player: wrong player index: %d", playerIndex);
+		return;
+	}
+}
+
+static void chat_reset_command(SDWORD cmdIndex)
+{
+	SDWORD i;
+
+	ASSERT(cmdIndex >= 0 && cmdIndex < MAX_CHAT_COMMANDS,
+		"chat_reset_command: command index out of bounds: %d", cmdIndex);
+
+	chat_msg.cmdData[cmdIndex].numCmdParams = 0;
+
+	for(i=0; i<MAX_PLAYERS; i++)
+	{
+		chat_msg.cmdData[cmdIndex].bPlayerAddressed[i] = false;
+	}
+}
+
+static void yyerror(const char* msg);
+
+
+
+/* Line 189 of yacc.c  */
+#line 237 "chat_parser.tab.c"
+
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 0
+#endif
+
+/* Enabling verbose error messages.  */
+#ifdef YYERROR_VERBOSE
+# undef YYERROR_VERBOSE
+# define YYERROR_VERBOSE 1
+#else
+# define YYERROR_VERBOSE 0
+#endif
+
+/* Enabling the token table.  */
+#ifndef YYTOKEN_TABLE
+# define YYTOKEN_TABLE 0
+#endif
 
 
 /* Tokens.  */
@@ -255,203 +441,32 @@
 
 
 
-/* Copy the first part of user declarations.  */
-#line 20 "chat_parser.y"
-
-/*
- * chat_parser.y
- *
- * yacc grammar for multiplayer chat messages
- *
- */
-#include "lib/framework/frame.h"
-#include "lib/framework/string_ext.h"
-
-#include "lib/framework/frameresource.h"
-#include "lib/script/chat_processing.h"
-
-#define MAX_CHAT_ARGUMENTS 10
-
-/* Holds information about a processed player chat message */
-CHAT_MSG chat_msg;
-
-// Parameter variable
-static INTERP_VAL scrParameter;
-
-extern int chat_lex(void);
-
-// Store extracted command for use in scripts
-static void chat_store_command(const char *command);
-
-/* Return value of the chat parsing - to be used in scripts */
-static BOOL chat_store_parameter(INTERP_VAL *parameter);
-
-// Store players that were addressed in a command
-static void chat_store_player(SDWORD cmdIndex, SDWORD playerIndex);
-
-// Reset a command
-static void chat_reset_command(SDWORD cmdIndex);
-
-// Information extracted from message and available for scripts
-//static int					numMsgParams=0;		//number of parameters currently extracted/stored
-//static INTERP_VAL		msgParams[MAX_CHAT_ARGUMENTS];
-
-/* Store command parameter extracted from the message */
-static BOOL chat_store_parameter(INTERP_VAL *cmdParam)
-{
-	SDWORD	numCmdParams, numCommands;
-
-	//console("chat_store_parameter: new parameter");
-
-	/* Make sure we have no overflow */
-	//if(numMsgParams >= MAX_CHAT_ARGUMENTS)
-	if(chat_msg.numCommands >= MAX_CHAT_COMMANDS)
-	{
-		ASSERT(false, "chat_store_parameter: too many commands in a message");
-		return false;
-	}
-
-	numCommands = chat_msg.numCommands;
-	numCmdParams = chat_msg.cmdData[numCommands].numCmdParams;
-
-	/* Make sure we still have room for more parameters */
-	if(numCmdParams >= MAX_CHAT_CMD_PARAMS)
-	{
-		ASSERT(false, "chat_store_parameter: out of parameters for command %d", numCommands);
-		return false;
-	}
-
-	/* Store parameter for command we are currently processing */
-	//memcpy(&(msgParams[numMsgParams]), parameter, sizeof(INTERP_VAL));
-	memcpy(&(chat_msg.cmdData[numCommands].parameter[numCmdParams]), cmdParam, sizeof(INTERP_VAL));
-
-	chat_msg.cmdData[numCommands].numCmdParams++;
-
-	return true;
-}
-
-// Store extracted command for use in scripts
-static void chat_store_command(const char *command)
-{
-	SDWORD	numCmdParams, numCommands;
-
-	//console("chat_store_command: new command: %s", command);
-
-	/* Make sure we have no overflow */
-	if(chat_msg.numCommands >= MAX_CHAT_COMMANDS)
-	{
-		ASSERT(false, "chat_store_command: too many commands in a message");
-		return;
-	}
-
-	numCommands = chat_msg.numCommands;
-	numCmdParams = chat_msg.cmdData[numCommands].numCmdParams;
-
-	/* Make sure we still have room for more parameters */
-	if(numCmdParams >= MAX_CHAT_CMD_PARAMS)
-	{
-		ASSERT(false, "chat_store_command: out of parameters for command %d", numCommands);
-		return;
-	}
-
-	/* Store command */
-	chat_msg.cmdData[numCommands].pCmdDescription = command;
-
-	chat_msg.numCommands++;
-}
-
-// Store players that were addressed in a command
-static void chat_store_player(SDWORD cmdIndex, SDWORD playerIndex)
-{
-	SDWORD i;
-
-	//console("chat_store_player: player %d addressd in command %d", playerIndex, cmdIndex);
-
-	/* Make sure we have no overflow */
-	if(cmdIndex < 0 || cmdIndex >= MAX_CHAT_COMMANDS)
-	{
-		ASSERT(false, "chat_store_player: command message out of bounds: %d", cmdIndex);
-		return;
-	}
-
-	if(playerIndex == -1)	//no player specified means all players addressed
-	{
-		/* Ally players addressed */
-		for(i=0; i<MAX_PLAYERS; i++)
-		{
-			chat_msg.cmdData[cmdIndex].bPlayerAddressed[i] = true;
-		}
-	}
-	else if(playerIndex >= 0 && playerIndex < MAX_PLAYERS)
-	{
-		chat_msg.cmdData[cmdIndex].bPlayerAddressed[playerIndex] = true;
-	}
-	else	/* Wrong player index */
-	{
-		ASSERT(false, "chat_store_player: wrong player index: %d", playerIndex);
-		return;
-	}
-}
-
-static void chat_reset_command(SDWORD cmdIndex)
-{
-	SDWORD i;
-
-	ASSERT(cmdIndex >= 0 && cmdIndex < MAX_CHAT_COMMANDS,
-		"chat_reset_command: command index out of bounds: %d", cmdIndex);
-
-	chat_msg.cmdData[cmdIndex].numCmdParams = 0;
-
-	for(i=0; i<MAX_PLAYERS; i++)
-	{
-		chat_msg.cmdData[cmdIndex].bPlayerAddressed[i] = false;
-	}
-}
-
-static void yyerror(const char* msg);
-
-
-
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
-
-/* Enabling verbose error messages.  */
-#ifdef YYERROR_VERBOSE
-# undef YYERROR_VERBOSE
-# define YYERROR_VERBOSE 1
-#else
-# define YYERROR_VERBOSE 0
-#endif
-
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
-#endif
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 177 "chat_parser.y"
 {
+
+/* Line 214 of yacc.c  */
+#line 177 "chat_parser.y"
+
 	BOOL				bval;
 	SDWORD			ival;
-}
-/* Line 187 of yacc.c.  */
-#line 442 "chat_parser.tab.c"
-	YYSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 458 "chat_parser.tab.c"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 455 "chat_parser.tab.c"
+/* Line 264 of yacc.c  */
+#line 470 "chat_parser.tab.c"
 
 #ifdef short
 # undef short
@@ -526,14 +541,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -614,9 +629,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -650,12 +665,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -1301,17 +1316,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -1345,11 +1363,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1629,10 +1647,8 @@ yydestruct (yymsg, yytype, yyvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1648,11 +1664,10 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1660,9 +1675,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1686,14 +1701,39 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1701,51 +1741,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1775,7 +1792,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1783,7 +1799,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1806,9 +1821,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1819,7 +1833,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1829,6 +1842,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1837,16 +1853,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1878,20 +1894,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1931,6 +1943,8 @@ yyreduce:
   switch (yyn)
     {
         case 3:
+
+/* Line 1455 of yacc.c  */
 #line 289 "chat_parser.y"
     {
 											chat_store_player(chat_msg.numCommands - 1, -1);	/* No player list means current command is addressed to everyone */
@@ -1938,6 +1952,8 @@ yyreduce:
     break;
 
   case 5:
+
+/* Line 1455 of yacc.c  */
 #line 294 "chat_parser.y"
     {
 											chat_store_player(chat_msg.numCommands - 1, -1);
@@ -1945,6 +1961,8 @@ yyreduce:
     break;
 
   case 6:
+
+/* Line 1455 of yacc.c  */
 #line 298 "chat_parser.y"
     {
 											//console("-unrecognized phrase");
@@ -1955,6 +1973,8 @@ yyreduce:
     break;
 
   case 11:
+
+/* Line 1455 of yacc.c  */
 #line 327 "chat_parser.y"
     {
 										chat_store_command("ally me");		/* Store current command */
@@ -1962,6 +1982,8 @@ yyreduce:
     break;
 
   case 12:
+
+/* Line 1455 of yacc.c  */
 #line 331 "chat_parser.y"
     {
 										chat_store_command("go?");
@@ -1969,6 +1991,8 @@ yyreduce:
     break;
 
   case 13:
+
+/* Line 1455 of yacc.c  */
 #line 335 "chat_parser.y"
     {
 										chat_store_command("go!");
@@ -1976,6 +2000,8 @@ yyreduce:
     break;
 
   case 14:
+
+/* Line 1455 of yacc.c  */
 #line 339 "chat_parser.y"
     {
 										chat_store_command("drop a beacon");
@@ -1983,6 +2009,8 @@ yyreduce:
     break;
 
   case 15:
+
+/* Line 1455 of yacc.c  */
 #line 343 "chat_parser.y"
     {
 										chat_store_command("go center");
@@ -1990,6 +2018,8 @@ yyreduce:
     break;
 
   case 16:
+
+/* Line 1455 of yacc.c  */
 #line 347 "chat_parser.y"
     {
 										chat_store_command("status?");
@@ -1997,6 +2027,8 @@ yyreduce:
     break;
 
   case 17:
+
+/* Line 1455 of yacc.c  */
 #line 351 "chat_parser.y"
     {
 										chat_store_command("pumping units");
@@ -2004,6 +2036,8 @@ yyreduce:
     break;
 
   case 18:
+
+/* Line 1455 of yacc.c  */
 #line 355 "chat_parser.y"
     {
 										chat_store_command("stop");
@@ -2011,6 +2045,8 @@ yyreduce:
     break;
 
   case 19:
+
+/* Line 1455 of yacc.c  */
 #line 359 "chat_parser.y"
     {
 										chat_store_command("got power?");
@@ -2018,6 +2054,8 @@ yyreduce:
     break;
 
   case 20:
+
+/* Line 1455 of yacc.c  */
 #line 363 "chat_parser.y"
     {
 										chat_store_command("help me");
@@ -2025,6 +2063,8 @@ yyreduce:
     break;
 
   case 21:
+
+/* Line 1455 of yacc.c  */
 #line 367 "chat_parser.y"
     {
 										chat_store_command("i'm ok");
@@ -2032,6 +2072,8 @@ yyreduce:
     break;
 
   case 22:
+
+/* Line 1455 of yacc.c  */
 #line 371 "chat_parser.y"
     {
 										chat_store_command("roger");
@@ -2039,6 +2081,8 @@ yyreduce:
     break;
 
   case 23:
+
+/* Line 1455 of yacc.c  */
 #line 375 "chat_parser.y"
     {
 										chat_store_command("ally player");
@@ -2046,6 +2090,8 @@ yyreduce:
     break;
 
   case 24:
+
+/* Line 1455 of yacc.c  */
 #line 379 "chat_parser.y"
     {
 										chat_store_command("attack player");
@@ -2053,6 +2099,8 @@ yyreduce:
     break;
 
   case 25:
+
+/* Line 1455 of yacc.c  */
 #line 383 "chat_parser.y"
     {
 										chat_store_command("attacking player?");
@@ -2060,6 +2108,8 @@ yyreduce:
     break;
 
   case 26:
+
+/* Line 1455 of yacc.c  */
 #line 387 "chat_parser.y"
     {
 										chat_store_command("player has vtols");
@@ -2067,6 +2117,8 @@ yyreduce:
     break;
 
   case 27:
+
+/* Line 1455 of yacc.c  */
 #line 391 "chat_parser.y"
     {
 										chat_store_command("getting player oil");
@@ -2074,6 +2126,8 @@ yyreduce:
     break;
 
   case 28:
+
+/* Line 1455 of yacc.c  */
 #line 395 "chat_parser.y"
     {
 										chat_store_command("lassat player");
@@ -2081,6 +2135,8 @@ yyreduce:
     break;
 
   case 29:
+
+/* Line 1455 of yacc.c  */
 #line 399 "chat_parser.y"
     {
 										chat_store_command("wait for me");
@@ -2088,6 +2144,8 @@ yyreduce:
     break;
 
   case 30:
+
+/* Line 1455 of yacc.c  */
 #line 403 "chat_parser.y"
     {
 										chat_store_command("rush");
@@ -2095,6 +2153,8 @@ yyreduce:
     break;
 
   case 31:
+
+/* Line 1455 of yacc.c  */
 #line 411 "chat_parser.y"
     {
 										chat_store_player(chat_msg.numCommands, (yyvsp[(1) - (1)].ival));		/* Remember this player was addressed in current command */
@@ -2102,6 +2162,8 @@ yyreduce:
     break;
 
   case 32:
+
+/* Line 1455 of yacc.c  */
 #line 415 "chat_parser.y"
     {
 										chat_store_player(chat_msg.numCommands, (yyvsp[(2) - (2)].ival));
@@ -2109,6 +2171,8 @@ yyreduce:
     break;
 
   case 33:
+
+/* Line 1455 of yacc.c  */
 #line 419 "chat_parser.y"
     {
 										chat_store_player(chat_msg.numCommands, (yyvsp[(3) - (3)].ival));
@@ -2116,6 +2180,8 @@ yyreduce:
     break;
 
   case 34:
+
+/* Line 1455 of yacc.c  */
 #line 423 "chat_parser.y"
     {
 										chat_store_player(chat_msg.numCommands, (yyvsp[(3) - (3)].ival));
@@ -2123,6 +2189,8 @@ yyreduce:
     break;
 
   case 35:
+
+/* Line 1455 of yacc.c  */
 #line 429 "chat_parser.y"
     {
 									(yyval.ival) = (yyvsp[(1) - (2)].ival);	// just pass player index
@@ -2130,6 +2198,8 @@ yyreduce:
     break;
 
   case 125:
+
+/* Line 1455 of yacc.c  */
 #line 631 "chat_parser.y"
     {
 												/* Store for scripts */
@@ -2143,6 +2213,8 @@ yyreduce:
     break;
 
   case 126:
+
+/* Line 1455 of yacc.c  */
 #line 644 "chat_parser.y"
     {
 													/* Store for scripts */
@@ -2156,6 +2228,8 @@ yyreduce:
     break;
 
   case 127:
+
+/* Line 1455 of yacc.c  */
 #line 654 "chat_parser.y"
     {
 													/* Store for scripts */
@@ -2169,6 +2243,8 @@ yyreduce:
     break;
 
   case 128:
+
+/* Line 1455 of yacc.c  */
 #line 667 "chat_parser.y"
     {
 													/* Store for scripts */
@@ -2182,6 +2258,8 @@ yyreduce:
     break;
 
   case 129:
+
+/* Line 1455 of yacc.c  */
 #line 680 "chat_parser.y"
     {
 													/* Store for scripts */
@@ -2195,6 +2273,8 @@ yyreduce:
     break;
 
   case 130:
+
+/* Line 1455 of yacc.c  */
 #line 692 "chat_parser.y"
     {
 													/* Store for scripts */
@@ -2208,6 +2288,8 @@ yyreduce:
     break;
 
   case 131:
+
+/* Line 1455 of yacc.c  */
 #line 704 "chat_parser.y"
     {
 													/* Store for scripts */
@@ -2221,8 +2303,9 @@ yyreduce:
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 2226 "chat_parser.tab.c"
+
+/* Line 1455 of yacc.c  */
+#line 2309 "chat_parser.tab.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2233,7 +2316,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -2298,7 +2380,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -2315,7 +2397,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -2372,9 +2454,6 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -2399,7 +2478,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -2410,7 +2489,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -2436,6 +2515,8 @@ yyreturn:
 }
 
 
+
+/* Line 1675 of yacc.c  */
 #line 720 "chat_parser.y"
 
 
