@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -883,7 +883,7 @@ BOOL eventLoadTrigger(UDWORD time, SCRIPT_CONTEXT *psContext,
 	psNewTrig = malloc(sizeof(ACTIVE_TRIGGER));
 	if (psNewTrig == NULL)
 	{
-		debug( LOG_ERROR, "eventLoadTrigger: out of memory" );
+		debug( LOG_FATAL, "eventLoadTrigger: out of memory" );
 		abort();
 		return false;
 	}
