@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -952,14 +952,14 @@ BOOL stackInitialise(void)
 	psStackBase = calloc(1, sizeof(*psStackBase));
 	if (psStackBase == NULL)
 	{
-		debug( LOG_ERROR, "Out of memory" );
+		debug( LOG_FATAL, "Out of memory" );
 		abort();
 		return false;
 	}
 	psStackBase->aVals = calloc(INIT_SIZE, sizeof(*psStackBase->aVals));
 	if (!psStackBase->aVals)
 	{
-		debug( LOG_ERROR, "Out of memory" );
+		debug( LOG_FATAL, "Out of memory" );
 		abort();
 		return false;
 	}
@@ -1013,6 +1013,7 @@ void stackShutDown(void)
 		free(psCurr->aVals);
 		free(psCurr);
 	}
+	psStackBase = NULL;
 }
 
 /* Get rid of the top value without returning it */
