@@ -1,6 +1,6 @@
 /*
 	This file is part of Warzone 2100.
-	Copyright (C) 2008-2009  Warzone Resurrection Project
+	Copyright (C) 2008-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -55,10 +55,12 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include <GLee.h>
+#include "lib/framework/frame.h"
+#include "lib/framework/frameint.h"
 #include "sequence.h"
 #include "timer.h"
 #include "lib/framework/math_ext.h"
-#include "lib/ivis_opengl/GLee.h"
 #include "lib/ivis_common/piestate.h"
 #include "lib/sound/audio.h"
 #include "lib/sound/openal_error.h"
@@ -169,8 +171,10 @@ static int frames = 0;
 static int dropped = 0;
 
 // Screen dimensions
-static int ScrnvidXsize = 0;
-static int ScrnvidYsize = 0;
+static int videoX1 = 0;
+static int videoX2 = 0;
+static int videoY1 = 0;
+static int videoY2 = 0;
 static int ScrnvidXpos = 0;
 static int ScrnvidYpos = 0;
 
@@ -232,9 +236,8 @@ static void open_audio(void)
 	alGenBuffers(1, &audiodata.buffer1);
 	sound_GetError();
 	alGenBuffers(1, &audiodata.buffer2);
-	sound_GetError();
-	// Clear Error Codes
-	alGetError();
+	sound_GetError();	// Log and clear error codes
+
 	audiodata.totbufstarted = 0;
 
 	// set the volume of the FMV based on the user's preferences
@@ -300,7 +303,7 @@ static void video_write(bool update)
 	const int video_width = videodata.ti.frame_width;
 	const int video_height = videodata.ti.frame_height;
 	yuv_buffer yuv;
-	GLenum errCode = glGetError();		//clear error codes out
+	glErrors();
 
 	glEnable(GL_TEXTURE_2D);
 	glBindTexture(GL_TEXTURE_2D, video_texture);
@@ -335,13 +338,7 @@ static void video_write(bool update)
 
 		glTexSubImage2D(GL_TEXTURE_2D, 0, 0, 0, video_width,
 				video_height, GL_RGBA, GL_UNSIGNED_BYTE, RGBAframe);
-
-		errCode = glGetError();
-
-		if (errCode != GL_NO_ERROR)
-		{
-			debug(LOG_ERROR, "OpenGL error uploading frame: %s, (0x%0x)", gluErrorString(errCode), errCode);
-		}
+		glErrors();
 	}
 
 	glDisable(GL_DEPTH_TEST);
@@ -354,13 +351,13 @@ static void video_write(bool update)
 	glTranslatef(ScrnvidXpos, ScrnvidYpos, 0.0f);
 	glBegin(GL_TRIANGLE_STRIP);
 	glTexCoord2f(0, 0);
-	glVertex2f(0, 0);
+	glVertex2f(videoX1, videoY1);
 	glTexCoord2f(256 * video_width / texture_width, 0);
-	glVertex2f(ScrnvidXsize, 0);				//screenWidth
+	glVertex2f(videoX2, videoY1);				//screenWidth
 	glTexCoord2f(0, 256 * video_height / texture_height);
-	glVertex2f(0, ScrnvidYsize);				//screenHeight
+	glVertex2f(videoX1, videoY2);				//screenHeight
 	glTexCoord2f(256 * video_width / texture_width, 256 * video_height / texture_height);
-	glVertex2f(ScrnvidXsize, ScrnvidYsize);		//screenWidth,screenHeight
+	glVertex2f(videoX2, videoY2);		//screenWidth,screenHeight
 	glEnd();
 
 	glPopMatrix();
@@ -433,7 +430,7 @@ static void seq_InitOgg(void)
 {
 	debug(LOG_VIDEO, "seq_InitOgg");
 
-	ASSERT((ScrnvidXsize && ScrnvidYsize), "Screen dimensions not specified!");
+	ASSERT((videoX2 && videoY2), "Screen dimensions not specified!");
 
 	stateflag = false;
 	theora_p = 0;
@@ -677,6 +674,7 @@ bool seq_Play(const char* filename)
 	/* open video */
 	if (theora_p)
 	{
+		char *blackframe = calloc(1, texture_width * texture_height * 4);
 		if (videodata.ti.frame_width > texture_width ||
 				videodata.ti.frame_height > texture_height)
 		{
@@ -694,7 +692,8 @@ bool seq_Play(const char* filename)
 		glGenTextures(1, &video_texture);
 		glBindTexture(GL_TEXTURE_2D, video_texture);
 		glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, texture_width, texture_height,
-				0, GL_RGBA, GL_UNSIGNED_BYTE, NULL);
+				0, GL_RGBA, GL_UNSIGNED_BYTE, blackframe);
+		free(blackframe);
 		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
 		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
 		glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP);
@@ -979,8 +978,31 @@ int seq_GetFrameNumber()
 // this controls the size of the video to display on screen
 void seq_SetDisplaySize(int sizeX, int sizeY, int posX, int posY)
 {
-	ScrnvidXsize = sizeX;
-	ScrnvidYsize = sizeY;
+	videoX1 = 0;
+	videoY1 = 0;
+	videoX2 = sizeX;
+	videoY2 = sizeY;
+
+	if (sizeX > 640 || sizeY > 480)
+	{
+		const float aspect = screenWidth / (float)screenHeight, videoAspect = 4 / (float)3;
+
+		if (aspect > videoAspect)
+		{
+			int offset = (screenWidth - screenHeight * videoAspect) / 2;
+			videoX1 += offset;
+			videoX2 -= offset;
+		}
+		else
+		{
+			int offset = (screenHeight - screenWidth / videoAspect) / 2;
+			videoY1 += offset;
+			videoY2 -= offset;
+		}
+
+
+	}
+
 	ScrnvidXpos = posX;
 	ScrnvidYpos = posY;
 }
