@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@ static AUDIO_SAMPLE *g_psSampleQueue = NULL;
 static BOOL			g_bAudioEnabled = false;
 static BOOL			g_bAudioPaused = false;
 static AUDIO_SAMPLE g_sPreviousSample;
+static int			g_iPreviousSampleTime;
 
 /** Counts the number of samples in the SampleQueue
  *  \return the number of samples in the SampleQueue
@@ -173,6 +174,31 @@ BOOL audio_GetPreviousQueueTrackPos( SDWORD *iX, SDWORD *iY, SDWORD *iZ )
 	return true;
 }
 
+BOOL audio_GetPreviousQueueTrackRadarBlipPos( SDWORD *iX, SDWORD *iY )
+{
+	if (g_sPreviousSample.x == SAMPLE_COORD_INVALID
+		|| g_sPreviousSample.y == SAMPLE_COORD_INVALID)
+	{
+		return false;
+	}
+
+	if (g_sPreviousSample.iTrack != ID_SOUND_STRUCTURE_UNDER_ATTACK && g_sPreviousSample.iTrack != ID_SOUND_UNIT_UNDER_ATTACK &&
+	    g_sPreviousSample.iTrack != ID_SOUND_LASER_SATELLITE_FIRING && g_sPreviousSample.iTrack != ID_SOUND_INCOMING_LASER_SAT_STRIKE)
+	{
+		return false;
+	}
+
+	if (gameTime2 > g_iPreviousSampleTime + 5*GAME_TICKS_PER_SEC)
+	{
+		return false;
+	}
+
+	*iX = g_sPreviousSample.x;
+	*iY = g_sPreviousSample.y;
+
+	return true;
+}
+
 //*
 // =======================================================================================================================
 // =======================================================================================================================
@@ -511,6 +537,8 @@ static void audio_UpdateQueue( void )
 		g_sPreviousSample.x = psSample->x;
 		g_sPreviousSample.y = psSample->y;
 		g_sPreviousSample.z = psSample->z;
+		g_sPreviousSample.iTrack = psSample->iTrack;
+		g_iPreviousSampleTime = gameTime2;
 	}
 }
 
@@ -527,9 +555,14 @@ void audio_Update()
 	{
 		return;
 	}
-	sound_GetError();	// clear error codes
+
+#ifndef WZ_NOSOUND
+	alGetError();	// clear error codes
+#endif
 	audio_UpdateQueue();
-	sound_GetError();	// clear error codes
+#ifndef WZ_NOSOUND
+	alGetError();	// clear error codes
+#endif
 	// get player position
 	playerPos = audio_GetPlayerPos();
 	audio_Get3DPlayerRotAboutVerticalAxis(&angle);
@@ -543,8 +576,8 @@ void audio_Update()
 		// remove finished samples from list
 		if ( psSample->bFinishedPlaying == true )
 		{
-			audio_RemoveSample( &g_psSampleList, psSample );
 			psSampleTemp = psSample->psNext;
+			audio_RemoveSample( &g_psSampleList, psSample );
 			free(psSample);
 			psSample = psSampleTemp;
 		}
@@ -586,7 +619,7 @@ void audio_Update()
  *  \param loop whether the track should be looped until explicitly stopped
  *  \param volume the volume this track should be played on (range is 0-100)
  *  \param audibleRadius the radius from the source of sound where it can be heard
- *  \return a non-zero value when succesfull or audio is disabled, zero when the file is not found or no more tracks can be loaded (i.e. the limit is reached)
+ *  \return a non-zero value when successful or audio is disabled, zero when the file is not found or no more tracks can be loaded (i.e. the limit is reached)
  */
 unsigned int audio_SetTrackVals(const char* fileName, BOOL loop, unsigned int volume, unsigned int audibleRadius)
 {
@@ -665,10 +698,12 @@ static BOOL audio_Play3DTrack( SDWORD iX, SDWORD iY, SDWORD iZ, int iTrack, void
 	//~~~~~~~~~~~~~~~~~~~~~~
 	AUDIO_SAMPLE	*psSample;
 	// coordinates
-	float	listenerX, listenerY, listenerZ, dX, dY, dZ;
+	float	listenerX = .0f, listenerY = .0f, listenerZ = .0f, dX, dY, dZ;
 	// calculation results
 	float	distance, gain, sfx3d_volume;
+#ifndef WZ_NOSOUND
 	ALenum err;
+#endif
 	//~~~~~~~~~~~~~~~~~~~~~~
 
 	// if audio not enabled return true to carry on game without audio
@@ -684,12 +719,14 @@ static BOOL audio_Play3DTrack( SDWORD iX, SDWORD iY, SDWORD iZ, int iTrack, void
 
 	// compute distance
 	// NOTE, if this call fails, expect garbage
+#ifndef WZ_NOSOUND
 	alGetListener3f(AL_POSITION, &listenerX, &listenerY, &listenerZ);
 	err = sound_GetError();
 	if (err != AL_NO_ERROR)
 	{
 		return false;
 	}
+#endif
 	dX = (float)iX - listenerX; // distances on all axis
 	dY = (float)iY - listenerY;
 	dZ = (float)iZ - listenerZ;
@@ -1163,7 +1200,7 @@ void audioTest()
 {
 	int i;
 
-	for (i = 0; i < 50; i++)
+	for (i = 0; i < 10; i++)
 	{
 		// On non-debug builds prevent warnings about defining but not using dummyCB
 		(void)dummyCB;
