@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 2007  Giel van Schijndel
-	Copyright (C) 2007-2009  Warzone Resurrection Project
+	Copyright (C) 2007-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -73,7 +73,7 @@ ALenum __sound_GetError(const char* location_description)
 	return error;
 }
 
-ALenum __sound_GetDeviceError(ALCdevice* device, const char* location_description)
+ALenum __sound_GetContextError(ALCdevice* device, const char* location_description)
 {
 	const char* errorString;
 	ALCenum error = alcGetError(device);
