@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -121,13 +121,11 @@ static void sound_RemoveSample(SAMPLE_LIST* previous, SAMPLE_LIST* to_remove)
 #ifndef WZ_NOSOUND
 static void PrintOpenALVersion(code_part part)
 {
-	const ALchar* pDeviceNames = NULL;
 	char buf[256];
+#if 0
+	// This code is disabled because enumerating devices apparently crashes PulseAudio on Fedora12
 
-	debug(part, "OpenAL Vendor: %s", alGetString(AL_VENDOR));
-	debug(part, "OpenAL Version: %s", alGetString(AL_VERSION));
-	debug(part, "OpenAL Renderer: %s", alGetString(AL_RENDERER));
-	debug(part, "OpenAL Extensions: %s", alGetString(AL_EXTENSIONS));
+	const ALchar* pDeviceNames = NULL;
 
 	// Print the available devices
 	pDeviceNames = alcGetString(NULL, ALC_DEVICE_SPECIFIER);
@@ -140,6 +138,12 @@ static void PrintOpenALVersion(code_part part)
 		debug(part, "available openAL device(s) are: %s", pDeviceNames);
 		pDeviceNames += strlen(pDeviceNames) + 1;
 	}
+#endif
+
+	debug(part, "OpenAL Vendor: %s", alGetString(AL_VENDOR));
+	debug(part, "OpenAL Version: %s", alGetString(AL_VERSION));
+	debug(part, "OpenAL Renderer: %s", alGetString(AL_RENDERER));
+	debug(part, "OpenAL Extensions: %s", alGetString(AL_EXTENSIONS));
 
 	// Copy this info to be used by the crash handler for the dump file
 	ssprintf(buf, "OpenAL Vendor: %s", alGetString(AL_VENDOR));
@@ -195,7 +199,7 @@ BOOL sound_InitLibrary( void )
 	}
 	alcMakeContextCurrent(context);
 
-	err = sound_GetDeviceError(device);
+	err = sound_GetContextError(device);
 	if (err != ALC_NO_ERROR)
 	{
 		PrintOpenALVersion(LOG_ERROR);
@@ -248,17 +252,23 @@ void sound_ShutdownLibrary( void )
 		sound_StopStream(stream);
 	}
 	sound_UpdateStreams();
+	
+	alcGetError(device);	// clear error codes
 
 	/* On Linux since this caused some versions of OpenAL to hang on exit. - Per */
 	debug(LOG_SOUND, "make default context NULL");
 	alcMakeContextCurrent(NULL);
+	sound_GetContextError(device);
 
 	debug(LOG_SOUND, "destroy previous context");
 	alcDestroyContext(context); // this gives a long delay on some impl.
+	sound_GetContextError(device);
 
 	debug(LOG_SOUND, "close device");
-	alcCloseDevice(device);
-	sound_GetError();
+	if (alcCloseDevice(device) == ALC_FALSE)
+	{
+		debug(LOG_SOUND, "OpenAl could not close the audio device." ); 
+	}
 #endif
 
 	while( aSample )
@@ -389,7 +399,7 @@ void sound_Update()
 
 	alcProcessContext(context);
 
-	err = sound_GetDeviceError(device);
+	err = sound_GetContextError(device);
 	if (err != ALC_NO_ERROR)
 	{
 		debug(LOG_ERROR, "Error while processing audio context: %s", alGetString(err));
@@ -472,7 +482,15 @@ static inline TRACK* sound_DecodeOggVorbisTrack(TRACK *psTrack, PHYSFS_file* PHY
 	{
 		return NULL;
 	}
+
 	decoder = sound_CreateOggVorbisDecoder(PHYSFS_fileHandle, true);
+	if (decoder == NULL)
+	{
+		debug(LOG_WARNING, "Failed to open audio file for decoding");
+		free(psTrack);
+		return NULL;
+	}
+
 	soundBuffer = sound_DecodeOggVorbis(decoder, 0);
 	sound_DestroyOggVorbisDecoder(decoder);
 
@@ -549,7 +567,7 @@ TRACK* sound_LoadTrackFromFile(const char *fileName)
 	pTrack = (TRACK*)malloc(sizeof(TRACK) + filename_size);
 	if (pTrack == NULL)
 	{
-		debug( LOG_ERROR, "sound_ConstructTrack: couldn't allocate memory\n" );
+		debug( LOG_FATAL, "sound_ConstructTrack: couldn't allocate memory\n" );
 		abort();
 		return NULL;
 	}
@@ -822,7 +840,7 @@ AUDIO_STREAM* sound_PlayStreamWithBuf(PHYSFS_file* fileHandle, float volume, voi
 	stream = malloc(sizeof(AUDIO_STREAM));
 	if (stream == NULL)
 	{
-		debug(LOG_ERROR, "sound_PlayStream: Out of memory");
+		debug(LOG_FATAL, "sound_PlayStream: Out of memory");
 		abort();
 		return NULL;
 	}
@@ -941,6 +959,30 @@ AUDIO_STREAM* sound_PlayStreamWithBuf(PHYSFS_file* fileHandle, float volume, voi
 #endif
 }
 
+/** Checks if the stream is playing.
+ *  \param stream the stream to check
+ *  \post true if playing, false otherwise.
+ *
+ */
+BOOL sound_isStreamPlaying(AUDIO_STREAM *stream)
+{
+#if !defined(WZ_NOSOUND)
+	ALint state;
+
+	if (stream)
+	{
+		alGetSourcei(stream->source, AL_SOURCE_STATE, &state);
+		sound_GetError();
+		if (state == AL_PLAYING)
+		{
+			return true;
+		}
+	}
+	return false;
+
+#endif
+}
+
 /** Stops the current stream from playing.
  *  \param stream the stream to stop
  *  \post The stopped stream will be destroyed on the next invocation of
@@ -953,7 +995,7 @@ void sound_StopStream(AUDIO_STREAM* stream)
 	assert(stream != NULL);
 
 #if !defined(WZ_NOSOUND)
-	sound_GetError();	// clear error codes
+	alGetError();	// clear error codes
 	// Tell OpenAL to stop playing on the given source
 	alSourceStop(stream->source);
 	sound_GetError();
@@ -1176,7 +1218,7 @@ static void sound_DestroyStream(AUDIO_STREAM* stream)
  */
 static void sound_UpdateStreams()
 {
-	AUDIO_STREAM *stream = active_streams, *previous = NULL;
+	AUDIO_STREAM *stream = active_streams, *previous = NULL, *next = NULL;
 
 	while (stream != NULL)
 	{
@@ -1184,24 +1226,26 @@ static void sound_UpdateStreams()
 		// destroy it instead.
 		if (!sound_UpdateStream(stream))
 		{
+			next = stream->next;
+
 			// First remove our current stream from the linked list
 			if (previous)
 			{
 				// Make the previous item skip over the current to the next item
-				previous->next = stream->next;
+				previous->next = next;
 			}
 			else
 			{
 				// Apparently this is the first item in the list, so make the
 				// next item the list-head.
-				active_streams = stream->next;
+				active_streams = next;
 			}
 
 			// Now actually destroy the current stream
 			sound_DestroyStream(stream);
 
 			// Make sure the current stream pointer is intact again
-			stream = (previous != NULL) ? previous->next : active_streams;
+			stream = next;
 
 			// Skip regular style iterator incrementing
 			continue;
@@ -1226,7 +1270,7 @@ void sound_StopSample(AUDIO_SAMPLE* psSample)
 		debug(LOG_SOUND, "sound_StopSample: sample number (%u) out of range, we probably have run out of available OpenAL sources", psSample->iSample);
 		return;
 	}
-	sound_GetError();	// clear error codes
+	alGetError();	// clear error codes
 	// Tell OpenAL to stop playing the given sample
 	alSourceStop(psSample->iSample);
 	sound_GetError();
