@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -107,7 +107,7 @@ bool PlayList_Read(const char* path)
 		song = malloc(sizeof(*songList));
 		if (song == NULL)
 		{
-			debug(LOG_ERROR, "Out of memory!");
+			debug(LOG_FATAL, "Out of memory!");
 			PHYSFS_close(fileHandle);
 			abort();
 			return false;
@@ -164,7 +164,7 @@ void playListTest()
 {
 	int i;
 
-	for (i = 0; i < 100; i++)
+	for (i = 0; i < 10; i++)
 	{
 		const char *cur, *next;
 
