@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -101,7 +101,7 @@ static W_FORM* formCreatePlain(const W_FORMINIT* psInit)
 	W_FORM* psWidget = (W_FORM *)malloc(sizeof(W_FORM));
 	if (psWidget == NULL)
 	{
-		debug(LOG_ERROR, "formCreatePlain: Out of memory");
+		debug(LOG_FATAL, "formCreatePlain: Out of memory");
 		abort();
 		return NULL;
 	}
@@ -158,7 +158,7 @@ static W_CLICKFORM* formCreateClickable(const W_FORMINIT* psInit)
 	W_CLICKFORM* psWidget = (W_CLICKFORM *)malloc(sizeof(W_CLICKFORM));
 	if (psWidget == NULL)
 	{
-		debug(LOG_ERROR, "formCreateClickable: Out of memory");
+		debug(LOG_FATAL, "formCreateClickable: Out of memory");
 		abort();
 		return NULL;
 	}
@@ -255,7 +255,7 @@ static W_TABFORM* formCreateTabbed(const W_FORMINIT* psInit)
 	psWidget = (W_TABFORM *)malloc(sizeof(W_TABFORM));
 	if (psWidget == NULL)
 	{
-		debug(LOG_ERROR, "formCreateTabbed: Out of memory");
+		debug(LOG_FATAL, "formCreateTabbed: Out of memory");
 		abort();
 		return NULL;
 	}
