@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -84,7 +84,7 @@ W_SLIDER* sliderCreate(const W_SLDINIT* psInit)
 	psWidget = (W_SLIDER *)malloc(sizeof(W_SLIDER));
 	if (psWidget == NULL)
 	{
-		debug(LOG_ERROR, "sliderCreate: Out of memory");
+		debug(LOG_FATAL, "sliderCreate: Out of memory");
 		abort();
 		return NULL;
 	}
@@ -233,7 +233,11 @@ void sliderRun(W_SLIDER *psWidget, W_CONTEXT *psContext)
 		psWidget->state &= ~SLD_DRAG;
 		widgSetReturn(psContext->psScreen, (WIDGET *)psWidget);
 	}
-	else if (psWidget->state & SLD_DRAG)
+	else if (!(psWidget->state & SLD_DRAG) && mouseDown(MOUSE_LMB))
+	{
+		sliderClicked(psWidget, psContext);
+	}
+	if (psWidget->state & SLD_DRAG)
 	{
 		/* Figure out where the drag box should be */
 		mx = psContext->mx - psWidget->x;
