@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include "lib/framework/frame.h"
 #include "lib/framework/string_ext.h"
 #include "lib/framework/frameint.h"
+#include "lib/framework/utf.h"
 #include "lib/ivis_common/textdraw.h"
 
 #include "widget.h"
@@ -101,7 +102,7 @@ W_SCREEN* widgCreateScreen()
 	W_SCREEN* psScreen = (W_SCREEN *)malloc(sizeof(W_SCREEN));
 	if (psScreen == NULL)
 	{
-		debug(LOG_ERROR, "widgCreateScreen: Out of memory");
+		debug(LOG_FATAL, "widgCreateScreen: Out of memory");
 		abort();
 		return NULL;
 	}
@@ -1145,8 +1146,12 @@ const char *widgGetString(W_SCREEN *psScreen, UDWORD id)
 				}
 				break;
 			case WIDG_EDITBOX:
-				sstrcpy(aStringRetBuffer, ((W_EDITBOX *)psWidget)->aText);
+			{
+				char *utf = UTF32toUTF8(((W_EDITBOX *)psWidget)->aText, NULL);
+				sstrcpy(aStringRetBuffer, utf);
+				free(utf);
 				break;
+			}
 			case WIDG_BARGRAPH:
 				ASSERT( false, "widgGetString: Bar Graphs do not have a string" );
 				aStringRetBuffer[0] = '\0';
