@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -79,7 +79,7 @@
  */
 #define WBUT_NOPRIMARY		0x10
 #define WBUT_SECONDARY		0x20	///< Enable secondary buttons.
-#define WBUT_TXTCENTRE		64	///< Text only buttons. centre the text?
+#define WBUT_TXTCENTRE		0x40	///< Text only buttons. centre the text?
 
 /*********** Edit Box styles *************/
 
