@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -83,7 +83,7 @@ typedef struct _droid_action_data
 	BASE_STATS		*psStats;
 } DROID_ACTION_DATA;
 
-// Check if a droid has stoped moving
+// Check if a droid has stopped moving
 #define DROID_STOPPED(psDroid) \
 	(psDroid->sMove.Status == MOVEINACTIVE || psDroid->sMove.Status == MOVEHOVER || \
 	 psDroid->sMove.Status == MOVESHUFFLE)
@@ -104,7 +104,7 @@ const char* getDroidActionName(DROID_ACTION action)
 		"DACTION_ATTACK",					// attacking something
 		"DACTION_OBSERVE",				// 7 observing something
 		"DACTION_FIRESUPPORT",			// attacking something visible by a sensor droid
-		"DACTION_SULK",					// 9 refuse to do anything aggresive for a fixed time
+		"DACTION_SULK",					// 9 refuse to do anything aggressive for a fixed time
 		"DACTION_DESTRUCT",				// self destruct
 		"DACTION_TRANSPORTOUT",			// 11 move transporter offworld
 		"DACTION_TRANSPORTWAITTOFLYIN",	// wait for timer to move reinforcements in
@@ -149,6 +149,7 @@ BOOL actionInAttackRange(DROID *psDroid, BASE_OBJECT *psObj, int weapon_slot)
 {
 	SDWORD			dx, dy, dz, radSq, rangeSq, longRange;
 	WEAPON_STATS	*psStats;
+	int compIndex;
 
 	CHECK_DROID(psDroid);
 	if (psDroid->asWeaps[0].nStat == 0)
@@ -162,7 +163,9 @@ BOOL actionInAttackRange(DROID *psDroid, BASE_OBJECT *psObj, int weapon_slot)
 
 	radSq = dx*dx + dy*dy;
 
-	psStats = asWeaponStats + psDroid->asWeaps[weapon_slot].nStat;
+	compIndex = psDroid->asWeaps[weapon_slot].nStat;
+	ASSERT_OR_RETURN( false, compIndex < numWeaponStats, "Invalid range referenced for numWeaponStats, %d > %d", compIndex, numWeaponStats);
+	psStats = asWeaponStats + compIndex;
 
 	if (psDroid->order == DORDER_ATTACKTARGET
 		&& secondaryGetState(psDroid, DSO_HALTTYPE) == DSS_HALT_HOLD)
@@ -221,6 +224,7 @@ BOOL actionInRange(DROID *psDroid, BASE_OBJECT *psObj, int weapon_slot)
 {
 	SDWORD			dx, dy, dz, radSq, rangeSq, longRange;
 	WEAPON_STATS	*psStats;
+	int compIndex;
 
 	CHECK_DROID(psDroid);
 
@@ -229,7 +233,9 @@ BOOL actionInRange(DROID *psDroid, BASE_OBJECT *psObj, int weapon_slot)
 		return false;
 	}
 
-	psStats = asWeaponStats + psDroid->asWeaps[weapon_slot].nStat;
+	compIndex = psDroid->asWeaps[weapon_slot].nStat;
+	ASSERT_OR_RETURN( false, compIndex < numWeaponStats, "Invalid range referenced for numWeaponStats, %d > %d", compIndex, numWeaponStats);
+	psStats = asWeaponStats + compIndex;
 
 	dx = (SDWORD)psDroid->pos.x - (SDWORD)psObj->pos.x;
 	dy = (SDWORD)psDroid->pos.y - (SDWORD)psObj->pos.y;
@@ -645,6 +651,7 @@ BOOL actionTargetTurret(BASE_OBJECT *psAttacker, BASE_OBJECT *psTarget, WEAPON *
 BOOL actionVisibleTarget(DROID *psDroid, BASE_OBJECT *psTarget, int weapon_slot)
 {
 	WEAPON_STATS	*psStats;
+	int compIndex;
 
 	CHECK_DROID(psDroid);
 	ASSERT_OR_RETURN(false, psTarget != NULL, "Target is NULL");
@@ -665,8 +672,10 @@ BOOL actionVisibleTarget(DROID *psDroid, BASE_OBJECT *psTarget, int weapon_slot)
 		}
 		return false;
 	}
+	compIndex = psDroid->asWeaps[weapon_slot].nStat;
+	ASSERT_OR_RETURN( false, compIndex < numWeaponStats, "Invalid range referenced for numWeaponStats, %d > %d", compIndex, numWeaponStats);
+	psStats = asWeaponStats + compIndex;
 
-	psStats = asWeaponStats + psDroid->asWeaps[weapon_slot].nStat;
 	if (proj_Direct(psStats))
 	{
 		if (visibleObject((BASE_OBJECT*)psDroid, psTarget, true))
@@ -1012,15 +1021,23 @@ void actionUpdateDroid(DROID *psDroid)
 			setDroidActionTarget(psDroid, NULL, i);
 			if (i == 0)
 			{
-				if ( (psDroid->action != DACTION_MOVEFIRE) &&
-					(psDroid->action != DACTION_TRANSPORTIN) &&
-					(psDroid->action != DACTION_TRANSPORTOUT)   )
+				if (psDroid->action != DACTION_MOVEFIRE &&
+				    psDroid->action != DACTION_TRANSPORTIN &&
+				    psDroid->action != DACTION_TRANSPORTOUT)
 				{
 					psDroid->action = DACTION_NONE;
-					//if Vtol - return to rearm pad
+					// if VTOL - return to rearm pad if not patrolling
 					if (isVtolDroid(psDroid))
 					{
-						moveToRearm(psDroid);
+						if (psDroid->order == DORDER_PATROL)
+						{
+							// Back to the patrol.
+							actionDroidLoc(psDroid, DACTION_MOVE, psDroid->orderX,psDroid->orderY);
+						}
+						else
+						{
+							moveToRearm(psDroid);
+						}
 					}
 				}
 			}
@@ -1327,7 +1344,7 @@ void actionUpdateDroid(DROID *psDroid)
 		}
 
 		/* Extra bit of paranoia, in case none of the weapons have a target */
-		bHasTarget = false; 
+		bHasTarget = false;
 		for (i = 0; i < psDroid->numWeaps; i++)
 		{
 			if (psDroid->psActionTarget[i] != NULL)
@@ -1920,7 +1937,7 @@ void actionUpdateDroid(DROID *psDroid)
 			if (actionDroidOnBuildPos(psDroid,
 						(SDWORD)psDroid->orderX,(SDWORD)psDroid->orderY, psDroid->psTarStats))
 			{
-				SDWORD pbx, pby;
+				SDWORD pbx = 0, pby = 0;
 
 				actionHomeBasePos(psDroid->player, &pbx, &pby);
 				if (pbx == 0 || pby == 0)
@@ -1954,7 +1971,6 @@ void actionUpdateDroid(DROID *psDroid)
 			!actionReachedBuildPos(psDroid,
 						(SDWORD)psDroid->orderX,(SDWORD)psDroid->orderY, psDroid->psTarStats))
 		{
-//			psDroid->action = DACTION_MOVETOBUILD;
 			moveDroidToNoFormation(psDroid, psDroid->orderX, psDroid->orderY);
 		}
 		else if (!DROID_STOPPED(psDroid) &&
@@ -1966,13 +1982,8 @@ void actionUpdateDroid(DROID *psDroid)
 			moveStopDroid(psDroid);
 		}
 
-		if (droidUpdateBuild(psDroid))
+		if (psDroid->action == DACTION_BUILD && droidUpdateBuild(psDroid))
 		{
-/*			if ( (psDroid->psTarget) && (psDroid->sMove.Status != MOVESHUFFLE) )
-			{
-				moveTurnDroid(psDroid,psDroid->psTarget->pos.x,psDroid->psTarget->pos.y);
-			}*/
-			// make construct droid to use turretRotation[0]
 			actionTargetTurret((BASE_OBJECT*)psDroid, psDroid->psActionTarget[0], &psDroid->asWeaps[0]);
 		}
 		break;
@@ -2024,7 +2035,7 @@ void actionUpdateDroid(DROID *psDroid)
 			if (actionDroidOnBuildPos(psDroid,
 						(SDWORD)psDroid->actionX,(SDWORD)psDroid->actionY, psDroid->psTarStats))
 			{
-				SDWORD pbx, pby;
+				SDWORD pbx = 0, pby = 0;
 
 				actionHomeBasePos(psDroid->player, &pbx, &pby);
 				if (pbx == 0 || pby == 0)
@@ -2336,16 +2347,14 @@ void actionUpdateDroid(DROID *psDroid)
 			// Got to destination - start repair
 			//rotate turret to point at droid being repaired
 			//use 0 for repair droid
-			if (actionTargetTurret((BASE_OBJECT*)psDroid, psDroid->psActionTarget[0], &psDroid->asWeaps[0]))
+			actionTargetTurret((BASE_OBJECT*)psDroid, psDroid->psActionTarget[0], &psDroid->asWeaps[0]);
+			if (droidStartDroidRepair(psDroid))
 			{
-				if (droidStartDroidRepair(psDroid))
-				{
-					psDroid->action = DACTION_DROIDREPAIR;
-				}
-				else
-				{
-					psDroid->action = DACTION_NONE;
-				}
+				psDroid->action = DACTION_DROIDREPAIR;
+			}
+			else
+			{
+				psDroid->action = DACTION_NONE;
 			}
 		}
 		if (DROID_STOPPED(psDroid))
@@ -2383,7 +2392,7 @@ void actionUpdateDroid(DROID *psDroid)
 					 && psWeapStats->rotate
 					 && aiBestNearestTarget(psDroid, &psTemp, i) >= 0)
 					{
-						if (secondaryGetState(psDroid, DSO_ATTACK_LEVEL) != DSS_ALEV_ALWAYS)
+						if (secondaryGetState(psDroid, DSO_HALTTYPE) != DSS_HALT_HOLD || psDroid->order == DORDER_REPAIR)
 						{
 							psTemp = NULL;
 						}
@@ -2566,6 +2575,8 @@ static void actionDroidBase(DROID *psDroid, DROID_ACTION_DATA *psAction)
 
 	CHECK_DROID(psDroid);
 
+	psDroid->actionStarted = gameTime;
+
 	switch (psAction->action)
 	{
 	case DACTION_NONE:
@@ -2859,6 +2870,7 @@ static void actionDroidBase(DROID *psDroid, DROID_ACTION_DATA *psAction)
 		setDroidActionTarget(psDroid, psAction->psObj, 0);
 		//initialise the action points
 		psDroid->actionPoints  = 0;
+		psDroid->actionStarted = gameTime;
 		if (secondaryGetState(psDroid, DSO_HALTTYPE) == DSS_HALT_HOLD &&
 		    (psDroid->order == DORDER_NONE || psDroid->order == DORDER_TEMP_HOLD))
 		{
