@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -27,10 +27,8 @@
 extern void	avInformOfChange(SDWORD x, SDWORD y);
 extern void	avUpdateTiles( void );
 extern UDWORD avGetObjLightLevel( BASE_OBJECT *psObj, UDWORD origLevel);
-extern void	avGetStats(UDWORD *considered, UDWORD *ignored, UDWORD *calculated);
 extern void	setRevealStatus( BOOL val );
 extern BOOL	getRevealStatus( void );
 extern void	preProcessVisibility( void );
-extern void	avSetStatus(BOOL var);
 
 #endif // __INCLUDED_SRC_ADVVIS_H__
