@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -37,11 +37,14 @@
 #include "projectile.h"
 #include "visibility.h"
 
+#define FRUSTRATED_TIME (1000 * 5)
+
 /* Calculates attack priority for a certain target */
 static SDWORD targetAttackWeight(BASE_OBJECT *psTarget, BASE_OBJECT *psAttacker, SDWORD weapon_slot);
 
 // alliances
-UBYTE	alliances[MAX_PLAYERS][MAX_PLAYERS];
+// players are 0-7; player 8 appears to be unused; player 9 is features
+UBYTE	alliances[MAX_PLAYERS + 2][MAX_PLAYERS + 2];
 
 
 // see if a structure has the range to fire on a target
@@ -73,20 +76,25 @@ static BOOL aiStructHasRange(STRUCTURE *psStruct, BASE_OBJECT *psTarget, int wea
 
 static BOOL aiDroidHasRange(DROID *psDroid, BASE_OBJECT *psTarget, int weapon_slot)
 {
-	WEAPON_STATS		*psWStats;
-	SDWORD			xdiff, ydiff, longRange;
+	int32_t xdiff, ydiff, longRange;
 
-	if (psDroid->numWeaps == 0 || psDroid->asWeaps[0].nStat == 0)
+	if (psDroid->droidType == DROID_SENSOR)
+	{
+		longRange = psDroid->sensorRange;
+	}
+	else if (psDroid->numWeaps == 0 || psDroid->asWeaps[0].nStat == 0)
 	{
 		// Can't attack without a weapon
 		return false;
 	}
-
-	psWStats = psDroid->asWeaps[weapon_slot].nStat + asWeaponStats;
+	else
+	{
+		WEAPON_STATS *psWStats = psDroid->asWeaps[weapon_slot].nStat + asWeaponStats;
+		longRange = proj_GetLongRange(psWStats);
+	}
 
 	xdiff = (SDWORD)psDroid->pos.x - (SDWORD)psTarget->pos.x;
 	ydiff = (SDWORD)psDroid->pos.y - (SDWORD)psTarget->pos.y;
-	longRange = proj_GetLongRange(psWStats);
 	if (xdiff*xdiff + ydiff*ydiff < longRange*longRange)
 	{
 		// in range
@@ -110,33 +118,18 @@ static BOOL aiObjHasRange(BASE_OBJECT *psObj, BASE_OBJECT *psTarget, int weapon_
 	return false;
 }
 
-/* alliance code for ai. return true if an alliance has formed. */
-BOOL aiCheckAlliances(UDWORD s1,UDWORD s2)
-{
-    //features have their player number set to (MAX_PLAYERS + 1)
-    if ( s1 == (MAX_PLAYERS + 1) || s2 == (MAX_PLAYERS + 1))
-    {
-        return false;
-    }
-	if ((s1 == s2) ||
-		(alliances[s1][s2] == ALLIANCE_FORMED))
-	{
-		return true;
-	}
-
-	return false;
-}
-
 /* Initialise the AI system */
 BOOL aiInitialise(void)
 {
 	SDWORD		i,j;
 
-	for(i=0; i<MAX_PLAYERS; i++)
+	// The +1 is for features, that are owned by player 9 for hackish reasons
+	// Yes, we do mean "player 9", as in "the players are 0-7, and we skip over player 8"
+	for (i = 0; i < MAX_PLAYERS+2; i++)
 	{
-		for(j=0; j<MAX_PLAYERS; j++)
+		for (j = 0; j < MAX_PLAYERS+2; j++)
 		{
-			alliances[i][j] = ALLIANCE_BROKEN;
+			alliances[i][j] = (i < MAX_PLAYERS && i == j) ? ALLIANCE_FORMED : ALLIANCE_BROKEN;
 		}
 	}
 
@@ -228,7 +221,7 @@ SDWORD aiBestNearestTarget(DROID *psDroid, BASE_OBJECT **ppsObj, int weapon_slot
 
 	/* Return if have no weapons */
 	// The ai orders a non-combat droid to patrol = crash without it...
-	if(psDroid->asWeaps[0].nStat == 0 || psDroid->numWeaps == 0)
+	if ((psDroid->asWeaps[0].nStat == 0 || psDroid->numWeaps == 0) && psDroid->droidType != DROID_SENSOR)
 	{
 		return failure;
 	}
@@ -296,7 +289,7 @@ SDWORD aiBestNearestTarget(DROID *psDroid, BASE_OBJECT **ppsObj, int weapon_slot
 
 		if (targetInQuestion != NULL
 		    && targetInQuestion != (BASE_OBJECT *)psDroid		// in case friendly unit had me as target
-		    && (targetInQuestion->type == OBJ_DROID ||  targetInQuestion->type == OBJ_STRUCTURE)
+		    && (targetInQuestion->type == OBJ_DROID || targetInQuestion->type == OBJ_STRUCTURE || targetInQuestion->type == OBJ_FEATURE)
 		    && targetInQuestion->visible[psDroid->player]
 		    && targetInQuestion->player != psDroid->player
 		    && !aiCheckAlliances(targetInQuestion->player,psDroid->player)
@@ -345,6 +338,13 @@ SDWORD aiBestNearestTarget(DROID *psDroid, BASE_OBJECT **ppsObj, int weapon_slot
 					psTarget = targetInQuestion;
 				}
 			}
+			else if (targetInQuestion->type == OBJ_FEATURE
+			         && gameTime - psDroid->lastFrustratedTime < FRUSTRATED_TIME
+			         && ((FEATURE *)targetInQuestion)->psStats->damageable
+			         && !(game.scavengers && psDroid->player == 7))			// hack to avoid scavs blowing up their nice feature walls
+			{
+				psTarget = targetInQuestion;
+			}
 
 			/* Check if our weapon is most effective against this object */
 			if(psTarget != NULL && psTarget == targetInQuestion)		//was assigned?
@@ -586,7 +586,7 @@ static SDWORD targetAttackWeight(BASE_OBJECT *psTarget, BASE_OBJECT *psAttacker,
 	}
 	else	//a feature
 	{
-		return noTarget;
+		return 1;
 	}
 
 	/* We prefer objects we can see and can attack immediately */
@@ -932,7 +932,8 @@ void aiUpdateDroid(DROID *psDroid)
 	
 	// look for a target if doing nothing
 	if (orderState(psDroid, DORDER_NONE) ||
-		orderState(psDroid, DORDER_GUARD))
+		orderState(psDroid, DORDER_GUARD) ||
+		orderState(psDroid, DORDER_TEMP_HOLD))
 	{
 		lookForTarget = true;
 	}
@@ -1007,9 +1008,8 @@ void aiUpdateDroid(DROID *psDroid)
 		updateTarget = false;
 	}
 
-	// only computer sensor droids in the single player game aquire targets
-	if ((psDroid->droidType == DROID_SENSOR && psDroid->player == selectedPlayer)
-	    && !bMultiPlayer)
+	// CB and VTOL CB droids can't autotarget.
+	if (psDroid->droidType == DROID_SENSOR && !standardSensorDroid(psDroid))
 	{
 		lookForTarget = false;
 		updateTarget = false;
@@ -1073,8 +1073,8 @@ void aiUpdateDroid(DROID *psDroid)
 /* Set of rules which determine whether the weapon associated with the object can fire on the propulsion type of the target. */
 BOOL validTarget(BASE_OBJECT *psObject, BASE_OBJECT *psTarget, int weapon_slot)
 {
-	BOOL	bTargetInAir, bValidTarget = false;
-	UBYTE	surfaceToAir;
+	BOOL	bTargetInAir = false, bValidTarget = false;
+	UBYTE	surfaceToAir = 0;
 
 	if (!psTarget)
 	{
@@ -1085,8 +1085,7 @@ BOOL validTarget(BASE_OBJECT *psObject, BASE_OBJECT *psTarget, int weapon_slot)
 	switch (psTarget->type)
 	{
 	case OBJ_DROID:
-		if (asPropulsionTypes[asPropulsionStats[((DROID *)psTarget)->asBits[
-		                                            COMP_PROPULSION].nStat].propulsionType].travel == AIR)
+		if (asPropulsionTypes[asPropulsionStats[((DROID *)psTarget)->asBits[COMP_PROPULSION].nStat].propulsionType].travel == AIR)
 		{
 			if (((DROID *)psTarget)->sMove.Status != MOVEINACTIVE)
 			{
@@ -1113,10 +1112,13 @@ BOOL validTarget(BASE_OBJECT *psObject, BASE_OBJECT *psTarget, int weapon_slot)
 	switch (psObject->type)
 	{
 	case OBJ_DROID:
+		if (((DROID *)psObject)->droidType == DROID_SENSOR)
+		{
+			return !bTargetInAir;  // Sensor droids should not target anything in the air.
+		}
+
 		// Can't attack without a weapon
-		//Watermelon:re-enabled if (((DROID *)psObject)->numWeaps != 0) to prevent crash
-		if (((DROID *)psObject)->numWeaps != 0 &&
-		        ((DROID *)psObject)->asWeaps[weapon_slot].nStat != 0)
+		if (((DROID *)psObject)->numWeaps != 0 && ((DROID *)psObject)->asWeaps[weapon_slot].nStat != 0)
 		{
 			surfaceToAir = asWeaponStats[((DROID *)psObject)->asWeaps[weapon_slot].nStat].surfaceToAir;
 			if (((surfaceToAir & SHOOT_IN_AIR) && bTargetInAir) || ((surfaceToAir & SHOOT_ON_GROUND) && !bTargetInAir))
@@ -1128,16 +1130,6 @@ BOOL validTarget(BASE_OBJECT *psObject, BASE_OBJECT *psTarget, int weapon_slot)
 		{
 			return false;
 		}
-		/*
-		if (((DROID *)psObject)->asWeaps[0].nStat != 0 && ((DROID *)psObject)->numWeaps > 0)
-		{
-		    surfaceToAir = asWeaponStats[((DROID *)psObject)->asWeaps[0].nStat].surfaceToAir;
-		}
-		else
-		{
-			 surfaceToAir = 0;
-		}
-		*/
 		break;
 	case OBJ_STRUCTURE:
 		// Can't attack without a weapon
