@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -38,8 +38,14 @@ typedef enum _object_type
 	OBJ_FEATURE,    ///< Things like roads, trees, bridges, fires
 	OBJ_PROJECTILE, ///< Comes out of guns, stupid :-)
 	OBJ_TARGET,     ///< for the camera tracking
+	OBJ_NUM_TYPES,  ///< number of object types - MUST BE LAST
 } OBJECT_TYPE;
 
+typedef struct _tilePos
+{
+	UBYTE x, y;
+} TILEPOS;
+
 /*
  Coordinate system used for objects in Warzone 2100:
   x - "right"
@@ -75,6 +81,8 @@ typedef enum _object_type
 	SDWORD              sensorPower;		/**< Active sensor power */ \
 	SDWORD              sensorRange;		/**< Range of sensor */ \
 	SDWORD              ECMMod;			/**< Ability to conceal oneself from sensors */ \
+	UWORD               numWatchedTiles;		/**< Number of watched tiles, zero for features */ \
+	TILEPOS             *watchedTiles;		/**< Variable size array of watched tiles, NULL for features */ \
 	UDWORD              armour[NUM_HIT_SIDES][WC_NUM_WEAPON_CLASSES]
 
 #define NEXTOBJ(pointerType) \
