@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -233,7 +233,7 @@ BOOL	startHigher;
 	}
 	else
 	{
-		debug( LOG_ERROR, "Weirdy Bridge requested - no axes allignment" );
+		debug( LOG_FATAL, "Weirdy Bridge requested - no axes allignment" );
 		abort();
 	}
 }
