@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -247,7 +247,7 @@ extern BOOL bucketRenderCurrentList(void)
 					renderAnimComponent((COMPONENT_OBJECT*)thisTag->pObject);
 				break;
 				case RENDER_DELIVPOINT:
-					renderDeliveryPoint((FLAG_POSITION*)thisTag->pObject);
+					renderDeliveryPoint((FLAG_POSITION*)thisTag->pObject, false);
 				break;
 			}
 			thisTag = thisTag->psNextTag;
