@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -24,11 +24,11 @@
 /* Alex M 19th - Jan. 1999 */
 
 #include "lib/framework/frame.h"
-#include "lib/framework/string_ext.h"
 #include "lib/exceptionhandler/dumpinfo.h"
+
 #include "cheat.h"
-#include "console.h"
 #include "keybind.h"
+#include "keymap.h"
 
 typedef struct _cheat_entry
 {
@@ -39,14 +39,7 @@ typedef struct _cheat_entry
 bool Cheated = false;
 static CHEAT_ENTRY cheatCodes[] =
 {
-//	{"VQKZMY^\\Z",kf_ToggleOverlays},//interface
-//	{"LWPH R^OOVQXL",kf_ShowMappings},//show mappings
-//	{"KZROS^KZL",kf_GiveTemplateSet},//templates
-//	{"LZSZ\\K ^SS",kf_SelectAllCombatUnits},//select all
-//	{"SZK KWZMZ ]Z SVXWK",kf_RecalcLighting},//let there be light
-//	{"PJKSVQZ,",kf_ToggleOutline},
-//	{"L\\MZZQ[JRO",kf_ScreenDump},	//screendump
-
+	{"clone wars", kf_CloneSelected}, // clone selected units
 	{"noassert", kf_NoAssert}, // turn off asserts
 	{"count me", kf_ShowNumObjects}, // give a count of objects in the world
 	{"give all", kf_AllAvailable},	// give all
@@ -77,6 +70,8 @@ static CHEAT_ENTRY cheatCodes[] =
 	{"showfps", kf_ToggleFPS},	//displays your average FPS
 	{"showsamples", kf_ToggleSamples}, //displays the # of Sound samples in Queue & List
 	{"showorders", kf_ToggleOrders}, //displays unit order/action state.
+	{"showlevelname", kf_ToggleLevelName}, // shows the current level name on screen
+	{"legs", kf_DebugTemplates},	// for template debugging
 };
 
 BOOL attemptCheatCode(const char* cheat_name)
@@ -84,6 +79,41 @@ BOOL attemptCheatCode(const char* cheat_name)
 	const CHEAT_ENTRY * curCheat;
 	static const CHEAT_ENTRY * const EndCheat = &cheatCodes[ARRAY_SIZE(cheatCodes)];
 
+	// there is no reason to make people enter "cheat mode" to enter following commands
+	if (!strcasecmp("showfps", cheat_name)) 
+	{
+		kf_ToggleFPS(); 
+		return true; 
+	}
+	else if (!strcasecmp("showlevelname", cheat_name))
+	{
+		kf_ToggleLevelName();
+		return true;
+	}
+	else if (!strcasecmp("legs", cheat_name))
+	{
+		kf_DebugTemplates();
+		return true;
+	}
+
+	if (strcmp(cheat_name, "cheat on") == 0 || strcmp(cheat_name, "debug") == 0)
+	{
+		if (!getDebugMappingStatus())
+		{
+			kf_ToggleDebugMappings();
+		}
+		return true;
+	}
+	if (strcmp(cheat_name, "cheat off") == 0 && getDebugMappingStatus())
+	{
+		kf_ToggleDebugMappings();
+		return true;
+	}
+	if (!getDebugMappingStatus())
+	{
+		return false;
+	}
+
 	for (curCheat = cheatCodes; curCheat != EndCheat; ++curCheat)
 	{
 		if (strcmp(cheat_name, curCheat->pName) == 0)
@@ -109,7 +139,7 @@ BOOL attemptCheatCode(const char* cheat_name)
 		char	errorString[255];
 
 		sstrcpy(errorString, cheat_name);
-		sstrcat(errorString, "?");
+		sstrcat(errorString, _(": Unknown cheat code."));
 
 		addConsoleMessage(errorString, LEFT_JUSTIFY,SYSTEM_MESSAGE);
 	}
