@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
  *
  */
 #include <string.h>
-
+#include <float.h>
 #include "lib/framework/frame.h"
 #include "objects.h"
 #include "cmddroiddef.h"
@@ -177,13 +177,19 @@ void cmdDroidUpdateKills(DROID *psKiller, float experienceInc)
 {
 	DROID	*psCommander;
 
-	ASSERT( psKiller != NULL,
-		"cmdUnitUpdateKills: invalid Unit pointer" );
+	ASSERT_OR_RETURN( , psKiller != NULL, "invalid Unit pointer" );
 
 	if (hasCommander(psKiller))
 	{
 		psCommander = psKiller->psGroup->psCommander;
-		psCommander->experience += experienceInc;
+		if (psCommander->experience + experienceInc > FLT_MAX)
+		{
+			psCommander->experience = FLT_MAX;
+		}
+		else
+		{
+			psCommander->experience += experienceInc;
+		}
 	}
 }
 
