@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -105,6 +105,7 @@ void combFire(WEAPON *psWeap, BASE_OBJECT *psAttacker, BASE_OBJECT *psTarget, in
 	DROID			*psDroid = NULL;
 	int				minOffset = 5;
 	SDWORD			dist;
+	int				compIndex;
 
 	CHECK_OBJECT(psAttacker);
 	CHECK_OBJECT(psTarget);
@@ -121,7 +122,9 @@ void combFire(WEAPON *psWeap, BASE_OBJECT *psAttacker, BASE_OBJECT *psTarget, in
 	}
 
 	/* Get the stats for the weapon */
-	psStats = asWeaponStats + psWeap->nStat;
+	compIndex = psWeap->nStat;
+	ASSERT_OR_RETURN( , compIndex < numWeaponStats, "Invalid range referenced for numWeaponStats, %d > %d", compIndex, numWeaponStats);
+	psStats = asWeaponStats + compIndex;
 
 	// check valid weapon/prop combination
 	if (!validTarget(psAttacker, psTarget, weapon_slot))
@@ -519,7 +522,7 @@ void counterBatteryFire(BASE_OBJECT *psAttacker, BASE_OBJECT *psTarget)
  * \param weaponClass the class of the weapon that deals the damage
  * \param weaponSubClass the subclass of the weapon that deals the damage
  * \param angle angle of impact (from the damage dealing projectile in relation to this object)
- * \return > 0 when the dealt damage destroys the object, < 0 when the object survives
+ * \return < 0 when the dealt damage destroys the object, > 0 when the object survives
  */
 float objDamage(BASE_OBJECT *psObj, UDWORD damage, UDWORD originalhp, UDWORD weaponClass, UDWORD weaponSubClass, HIT_SIDE impactSide)
 {
@@ -556,7 +559,14 @@ float objDamage(BASE_OBJECT *psObj, UDWORD damage, UDWORD originalhp, UDWORD wea
 		}
 	}
 
-	armour = psObj->armour[impactSide][weaponClass];
+	if (impactSide != HIT_SIDE_PIERCE)
+	{
+		armour = 0;
+	}
+	else
+	{
+		armour = psObj->armour[impactSide][weaponClass];
+	}
 
 	debug(LOG_ATTACK, "objDamage(%d): body %d armour %d damage: %d", psObj->id, psObj->body, armour, damage);
 
@@ -585,13 +595,20 @@ float objDamage(BASE_OBJECT *psObj, UDWORD damage, UDWORD originalhp, UDWORD wea
 
 	objTrace(psObj->id, "objDamage: Penetrated %d", actualDamage);
 
+	// for some odd reason, we have 0 hitpoints.
+	if (!originalhp)
+	{
+		ASSERT(originalhp, "original hitpoints are 0 ?");
+		return -1.0f;	// it is dead
+	}
+
 	// If the shell did sufficient damage to destroy the object, deal with it and return
 	if (actualDamage >= psObj->body)
 	{
 		return (float) psObj->body / (float) originalhp * -1.0f;
 	}
 
-	// Substract the dealt damage from the droid's remaining body points
+	// Subtract the dealt damage from the droid's remaining body points
 	psObj->body -= actualDamage;
 
 	return (float) actualDamage / (float) originalhp;
