@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -22,57 +22,51 @@
  * Saves your favourite options to the Registry.
  *
  */
-#include <string.h>
 
 #include "lib/framework/frame.h"
-#include "lib/framework/strres.h"
-
-#include "configuration.h"
 #include "lib/framework/configfile.h"
-#include "objmem.h"
-#include "lib/sound/track.h"		// audio
-#include "lib/sound/cdaudio.h"	// audio
-#include "warzoneconfig.h"	// renderMode
-#include "component.h"
-#include "seqdisp.h"
-#include "difficulty.h"
 #include "lib/netplay/netplay.h"
-#include "display3d.h"
-#include "multiplay.h"
-#include "ai.h"
-#include "advvis.h"
 #include "lib/sound/mixer.h"
-#include "hci.h"
-#include "radar.h"
+#include "lib/ivis_opengl/screen.h"
+
+#include "advvis.h"
+#include "ai.h"
 // HACK bAllowDebugMode shouldn't be in clparse
 #include "clparse.h"
+#include "component.h"
+#include "configuration.h"
+#include "difficulty.h"
+#include "display3d.h"
+#include "hci.h"
 #include "multiint.h"
+#include "multiplay.h"
+#include "radar.h"
+#include "seqdisp.h"
 #include "texture.h"
+#include "warzoneconfig.h"	// renderMode
 
 // ////////////////////////////////////////////////////////////////////////////
 
-#define DEFAULTFXVOL	80
-#define DEFAULTCDVOL	60
 #define DEFAULTSCROLL	1000
 
-#define MASTERSERVERPORT 9990
-#define GAMESERVERPORT   2100
+#define MASTERSERVERPORT	9990
+#define GAMESERVERPORT		2100
 
-extern void registry_clear(void); // from configfile.c
+/* Frame limit for multiplayer games (excluding skirmish and campaign) */
+#define MP_FRAME_LIMIT 45
 
-void	setSinglePlayerFrameLimit		(SDWORD limit);
-SDWORD	getSinglePlayerFrameLimit		(void);
-void	setDefaultFrameRateLimit		(void);
+/* Default frame limit for single player: skirmish ans campaign */
+#define SP_FRAME_LIMIT 60
 
 // current frame limit for single player modes
 static SDWORD	spFrameLimit = SP_FRAME_LIMIT;
 
-void setSinglePlayerFrameLimit(SDWORD limit)
+static void setSinglePlayerFrameLimit(SDWORD limit)
 {
 	spFrameLimit = limit;
 }
 
-SDWORD getSinglePlayerFrameLimit(void)
+static SDWORD getSinglePlayerFrameLimit(void)
 {
 	return spFrameLimit;
 }
@@ -92,7 +86,7 @@ void setDefaultFrameRateLimit(void)
 // ////////////////////////////////////////////////////////////////////////////
 BOOL loadConfig(void)
 {
-	SDWORD	val;
+	int val;
 	char	sBuf[255];
 
 	openWarzoneKey();
@@ -100,13 +94,6 @@ BOOL loadConfig(void)
 	//  options screens.
 	// //////////////////////////
 
-	// //////////////////////////
-	// subtitles
-	if(getWarzoneKeyNumeric("allowsubtitles", &val))
-	{
-		war_SetAllowSubtitles(val);
-	}
-
 	// //////////////////////////
 	// voice vol
 	if(getWarzoneKeyNumeric("voicevol", &val))
@@ -232,7 +219,7 @@ BOOL loadConfig(void)
 		setInvertMouseStatus(true);
 		setWarzoneKeyNumeric("mouseflip", true);
 	}
-	
+
 	// //////////////////////////
 	// mouse buttons
 	if (getWarzoneKeyNumeric("RightClickOrders", &val))
@@ -244,6 +231,15 @@ BOOL loadConfig(void)
 		setRightClickOrders(false);
 		setWarzoneKeyNumeric("RightClickOrders", false);
 	}
+	if (getWarzoneKeyNumeric("MiddleClickRotate", &val))
+	{
+		setMiddleClickRotate(val);
+	}
+	else
+	{
+		setMiddleClickRotate(false);
+		setWarzoneKeyNumeric("MiddleClickRotate", false);
+	}
 	
 	// //////////////////////////
 	// rotate radar
@@ -278,7 +274,7 @@ BOOL loadConfig(void)
 	else
 	{
 		NETsetMasterserverName("lobby.wz2100.net");
-		setWarzoneKeyString("masterserver_name", "lobby.wz2100.net");
+		setWarzoneKeyString("masterserver_name", NETgetMasterserverName());
 	}
 
 	if (getWarzoneKeyString("fontname", sBuf))
@@ -332,7 +328,7 @@ BOOL loadConfig(void)
 	else
 	{
 		NETsetMasterserverPort(MASTERSERVERPORT);
-		setWarzoneKeyNumeric("masterserver_port", MASTERSERVERPORT);
+		setWarzoneKeyNumeric("masterserver_port", NETgetMasterserverPort());
 	}
 
 	if (getWarzoneKeyNumeric("gameserver_port", &val))
@@ -346,7 +342,7 @@ BOOL loadConfig(void)
 	else
 	{
 		NETsetGameserverPort(GAMESERVERPORT);
-		setWarzoneKeyNumeric("gameserver_port", GAMESERVERPORT);
+		setWarzoneKeyNumeric("gameserver_port", NETgetGameserverPort());
 	}
 
 	// //////////////////////////
@@ -391,17 +387,14 @@ BOOL loadConfig(void)
 		if(val)
 		{
 			war_SetFog(false);
-			avSetStatus(true);
 		}
 		else
 		{
-			avSetStatus(false);
 			war_SetFog(true);
 		}
 	}
 	else
 	{
-		avSetStatus(false);
 		war_SetFog(true);
 		setWarzoneKeyNumeric("visfog", 0);
 	}
@@ -410,7 +403,6 @@ BOOL loadConfig(void)
 	// favourite colour
 	if(!bMultiPlayer)
 	{
-		initPlayerColours();	// clear current maps.
 		if(getWarzoneKeyNumeric("colour", &val))
 		{
 			setPlayerColour(0, val);
@@ -464,9 +456,13 @@ BOOL loadConfig(void)
 	// map name
 	if(getWarzoneKeyString("mapName", sBuf))
 	{
-		sstrcpy(game.map, sBuf);
+		/* FIXME: Get rid of storing the max-player count in the config
+		 *        file. Instead we should parse the map *before*
+		 *        showing the skirmish/multiplayer setup screen.
+		 */
 		if (getWarzoneKeyNumeric("maxPlayers", &val))
 		{
+			sstrcpy(game.map, sBuf);
 			game.maxPlayers = val;
 		}
 		else
@@ -592,6 +588,17 @@ BOOL loadConfig(void)
 		setWarzoneKeyNumeric("textureSize", getTextureSize());
 	}
 
+	// UPnP detection
+	if (getWarzoneKeyNumeric("UPnP", &val))
+	{
+		NetPlay.isUPNP = val;
+	}
+	else
+	{
+		setWarzoneKeyNumeric("UPnP", 1);
+		NetPlay.isUPNP = 1;
+	}
+
 	return closeWarzoneKey();
 }
 
@@ -674,8 +681,8 @@ BOOL loadRenderMode(void)
 	{
 		// If we have an invalid or incomplete resolution specified
 		// fall back to the defaults.
-		war_SetWidth(640);
-		war_SetHeight(480);
+		war_SetWidth(0);
+		war_SetHeight(0);
 	}
 
 	if (getWarzoneKeyNumeric("bpp", &val))
@@ -715,7 +722,6 @@ BOOL saveConfig(void)
 	{
 		setDifficultyLevel(DL_NORMAL);
 	}
-	setWarzoneKeyNumeric("allowSubtitles", war_GetAllowSubtitles());
 	setWarzoneKeyNumeric("debugmode", bAllowDebugMode);
 	setWarzoneKeyNumeric("framerate", (SDWORD)getFramerateLimit());
 	setWarzoneKeyNumeric("showFPS", (SDWORD)showFPS);
@@ -725,6 +731,7 @@ BOOL saveConfig(void)
 	setWarzoneKeyNumeric("shake",(SDWORD)(getShakeStatus()));		// screenshake
 	setWarzoneKeyNumeric("mouseflip",(SDWORD)(getInvertMouseStatus()));	// flipmouse
 	setWarzoneKeyNumeric("RightClickOrders",(SDWORD)(getRightClickOrders()));
+	setWarzoneKeyNumeric("MiddleClickRotate",(SDWORD)(getMiddleClickRotate()));
 	setWarzoneKeyNumeric("shadows",(SDWORD)(getDrawShadows()));	// shadows
 	setWarzoneKeyNumeric("sound", (SDWORD)war_getSoundEnabled());
 	setWarzoneKeyNumeric("FMVmode",(SDWORD)(war_GetFMVmode()));		// sequences
@@ -735,8 +742,12 @@ BOOL saveConfig(void)
 	setWarzoneKeyNumeric("trapCursor", war_GetTrapCursor());
 	setWarzoneKeyNumeric("vsync", war_GetVsync());
 	setWarzoneKeyNumeric("textureSize", getTextureSize());
+	setWarzoneKeyNumeric("rotateRadar", rotateRadar);
 	setWarzoneKeyNumeric("PauseOnFocusLoss", war_GetPauseOnFocusLoss());
 	setWarzoneKeyNumeric("ColouredCursor", war_GetColouredCursor());
+	setWarzoneKeyString("masterserver_name", NETgetMasterserverName());
+	setWarzoneKeyNumeric("masterserver_port", NETgetMasterserverPort());
+	setWarzoneKeyNumeric("gameserver_port", NETgetGameserverPort());
 
 	if(!bMultiPlayer)
 	{
@@ -745,17 +756,20 @@ BOOL saveConfig(void)
 	else
 	{
 		debug( LOG_NEVER, "Writing multiplay prefs to registry\n" );
-		if(NetPlay.bHost && ingame.localJoiningInProgress)
+		if (NetPlay.isHost && ingame.localJoiningInProgress)
 		{
-			setWarzoneKeyString("gameName", game.name);			//  last hosted game
+			if (bMultiPlayer && NetPlay.bComms)
+			{
+				setWarzoneKeyString("gameName", game.name);			//  last hosted game
+			}
+			setWarzoneKeyString("mapName", game.map);				//  map name
+			setWarzoneKeyNumeric("maxPlayers",game.maxPlayers);		// maxPlayers
+			setWarzoneKeyNumeric("power", game.power);				// power
+			setWarzoneKeyNumeric("type", game.type);				// game type
+			setWarzoneKeyNumeric("base", game.base);				// size of base
+			setWarzoneKeyNumeric("fog", game.fog);					// fog 'o war
+			setWarzoneKeyNumeric("alliance", game.alliance);		// allow alliances
 		}
-		setWarzoneKeyString("mapName", game.map);				//  map name
-		setWarzoneKeyNumeric("maxPlayers",game.maxPlayers);		// maxPlayers
-		setWarzoneKeyNumeric("power", game.power);				// power
-		setWarzoneKeyNumeric("type", game.type);				// game type
-		setWarzoneKeyNumeric("base", game.base);				// size of base
-		setWarzoneKeyNumeric("fog", game.fog);					// fog 'o war
-		setWarzoneKeyNumeric("alliance", game.alliance);		// allow alliances
 		setWarzoneKeyString("playerName",(char*)sPlayer);		// player name
 		setWarzoneKeyString("phrase0", ingame.phrases[0]);		// phrases
 		setWarzoneKeyString("phrase1", ingame.phrases[1]);
@@ -767,6 +781,119 @@ BOOL saveConfig(void)
 	return closeWarzoneKey();
 }
 
+// Saves and loads the relevant part of the config files for MP games
+// Ensures that others' games don't change our own configuration settings
+BOOL reloadMPConfig(void)
+{
+	int val;
+	char	sBuf[255];
+
+	debug( LOG_WZ, "Reloading prefs prefs to registry\n" );
+
+	// If we're in-game, we already have our own configuration set, so no need to reload it.
+
+	if (NetPlay.isHost && !ingame.localJoiningInProgress)
+	{
+		if (bMultiPlayer && !NetPlay.bComms && openWarzoneKey())
+		{
+			// one-player skirmish mode sets game name to "One Player Skirmish", so
+			// reset the name
+			if (getWarzoneKeyString("gameName", sBuf))
+			{
+				sstrcpy(game.name, sBuf);
+			}
+			return closeWarzoneKey();
+		}
+		return true;
+	}
+
+	if(!openWarzoneKey())
+	{
+		return false;
+	}
+
+	// If we're host and not in-game, we can safely save our settings and return.
+
+	if (NetPlay.isHost && ingame.localJoiningInProgress)
+	{
+		if (bMultiPlayer && NetPlay.bComms)
+		{
+			setWarzoneKeyString("gameName", game.name);			//  last hosted game
+		}
+		else
+		{
+			// One-player skirmish mode sets game name to "One Player Skirmish", so
+			// reset the name
+			if (getWarzoneKeyString("gameName", sBuf))
+			{
+				sstrcpy(game.name, sBuf);
+			}
+		}
+		setWarzoneKeyString("mapName", game.map);				//  map name
+		setWarzoneKeyNumeric("maxPlayers",game.maxPlayers);		// maxPlayers
+		setWarzoneKeyNumeric("power", game.power);				// power
+		setWarzoneKeyNumeric("type", game.type);				// game type
+		setWarzoneKeyNumeric("base", game.base);				// size of base
+		setWarzoneKeyNumeric("fog", game.fog);					// fog 'o war
+		setWarzoneKeyNumeric("alliance", game.alliance);		// allow alliances
+		return closeWarzoneKey();
+	}
+
+	// We're not host, so let's get rid of the host's game settings and restore our own.
+	
+	// game name
+	if (getWarzoneKeyString("gameName", sBuf))
+	{
+		sstrcpy(game.name, sBuf);
+	}
+
+	// map name
+	if(getWarzoneKeyString("mapName", sBuf))
+	{
+		/* FIXME: Get rid of storing the max-player count in the config
+		 *        file. Instead we should parse the map *before*
+		 *        showing the skirmish/multiplayer setup screen.
+		 */
+		if (getWarzoneKeyNumeric("maxPlayers", &val))
+		{
+			sstrcpy(game.map, sBuf);
+			game.maxPlayers = val;
+		}
+	}
+
+	// power
+	if(getWarzoneKeyNumeric("power", &val))
+	{
+		game.power = val;
+	}
+
+	// fog
+	if(getWarzoneKeyNumeric("fog", &val))
+	{
+		game.fog= val;
+	}
+
+	//type
+	if(getWarzoneKeyNumeric("type", &val))
+	{
+		game.type =(UBYTE)val;
+	}
+
+	//base
+	if(getWarzoneKeyNumeric("base", &val))
+	{
+		game.base =(UBYTE)val;
+	}
+
+	//alliance
+	if(getWarzoneKeyNumeric("alliance", &val))
+	{
+		game.alliance =(UBYTE)val;
+	}
+
+	return closeWarzoneKey();
+}
+
 void closeConfig( void )
 {
 	registry_clear();
