@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -24,24 +24,23 @@
 #ifndef __INCLUDED_SRC_CONFIGURATION_H__
 #define __INCLUDED_SRC_CONFIGURATION_H__
 
-extern BOOL loadConfig(void);
-extern BOOL loadRenderMode(void);
-extern BOOL saveConfig(void);
-extern void closeConfig( void );
-extern void setSinglePlayerFrameLimit(SDWORD limit);
-extern SDWORD getSinglePlayerFrameLimit(void);
-extern void setDefaultFrameRateLimit(void);
+#ifdef __cplusplus
+extern "C"
+{
+#endif //__cplusplus
 
-/* Frame limit for multiplayer games (excluding skirmish and campaign) */
-#define	MP_FRAME_LIMIT	45
+BOOL loadConfig(void);
+BOOL loadRenderMode(void);
+BOOL saveConfig(void);
+BOOL reloadMPConfig(void);
+void closeConfig( void );
+void setDefaultFrameRateLimit(void);
 
-/* Default frame limit for single player: skirmish ans campaign */
-#define	SP_FRAME_LIMIT	60
-
-/// Default map for Mayhem
-#define DEFAULTCAMPAIGNMAP	"Rush"
 /// Default map for Skirmish
-#define DEFAULTSKIRMISHMAP	"Sk-Rush"
+static const char DEFAULTSKIRMISHMAP[] = "Sk-Rush";
 
+#ifdef __cplusplus
+}
+#endif //__cplusplus
 
 #endif // __INCLUDED_SRC_CONFIGURATION_H__
