@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -129,10 +129,19 @@ void	setConsoleTextColor			( SDWORD player );
 /** Sets the system up */
 void	initConsoleMessages( void )
 {
+	int TextLineSize = iV_GetTextLineSize();
 	messageIndex = 0;
 
 	/* Console can extend to half screen height */
-	maxDrop = ((pie_GetVideoBufferHeight()/iV_GetTextLineSize())/2);
+	if (TextLineSize)
+	{
+		maxDrop = ((pie_GetVideoBufferHeight() / TextLineSize)/2);
+	}
+	else
+	{
+		debug(LOG_FATAL, "Something is wrong with the fonts? Aborting.");
+		abort();
+	}
 
 	if(maxDrop>32) maxDrop = 32;
 
@@ -227,6 +236,8 @@ static BOOL _addConsoleMessage(const char *messageText, CONSOLE_TEXT_JUSTIFICATI
 		jusType = defJustification;
 	}
 
+	debug(LOG_CONSOLE, "(to player %d): %s", (int)player, messageText);
+
 	consoleStorage[messageIndex].player = player;
 
 	/* Precalculate and store (quicker!) the indent for justified text */
@@ -248,7 +259,7 @@ static BOOL _addConsoleMessage(const char *messageText, CONSOLE_TEXT_JUSTIFICATI
 		break;
 		/* Gone tits up by the looks of it */
 	default:
-		debug( LOG_ERROR, "Weirdy type of text justification for console print" );
+		debug( LOG_FATAL, "Weirdy type of text justification for console print" );
 		abort();
 		break;
 	}
@@ -531,6 +542,13 @@ void	displayConsoleMessages( void )
 		MesY = iV_DrawFormattedText(psMessage->text, mainConsole.topX, MesY,
 									mainConsole.width, psMessage->JustifyType);
 
+#ifdef WZ_OS_MAC
+		if (!bTextBoxActive)
+		{
+			MesY -= 3; // make them fit inside the chat box
+		}
+#endif
+
 		/* Move on */
 		++numProcessed;
 	}
@@ -682,7 +700,7 @@ void	setDefaultConsoleJust(CONSOLE_TEXT_JUSTIFICATION defJ)
 		defJustification = defJ;
 		break;
 	default:
-		debug( LOG_ERROR, "Weird default text justification for console" );
+		debug( LOG_FATAL, "Weird default text justification for console" );
 		abort();
 		break;
 	}
