@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -21,8 +21,10 @@
 #ifndef __INCLUDED_SRC_DIFFICULTY_H__
 #define __INCLUDED_SRC_DIFFICULTY_H__
 
-// required to ensure "types.h" is included the proper way (we need the "bool" type)
-#include "lib/framework/frame.h"
+#ifdef __cplusplus
+extern "C"
+{
+#endif //__cplusplus
 
 typedef enum _difficulty_level
 {
@@ -33,9 +35,12 @@ typedef enum _difficulty_level
 	DL_KILLER
 } DIFFICULTY_LEVEL;
 
-extern void	setDifficultyLevel( DIFFICULTY_LEVEL lev);
-extern DIFFICULTY_LEVEL	getDifficultyLevel( void );
-extern int modifyForDifficultyLevel(int basicVal, bool IsPlayer);
-extern void setModifiers(float Player,float Enemy);
+void setDifficultyLevel(DIFFICULTY_LEVEL lev);
+DIFFICULTY_LEVEL getDifficultyLevel(void);
+int modifyForDifficultyLevel(int basicVal, bool IsPlayer);
+
+#ifdef __cplusplus
+}
+#endif //__cplusplus
 
 #endif // __INCLUDED_SRC_DIFFICULTY_H__
