@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -511,7 +511,7 @@ void driveUpdate(void)
 
 	if(DirectControl) {
 		if(psDrivenDroid != NULL) {
-			if(bMultiPlayer && (driveBumpTime < gameTime))	// send latest info about driven droid.
+			if(bMultiMessages && (driveBumpTime < gameTime))	// send latest info about driven droid.
 			{
 				SendDroidInfo(psDrivenDroid,DORDER_MOVE,psDrivenDroid->pos.x,psDrivenDroid->pos.y, NULL);
 			}
@@ -738,7 +738,7 @@ void driveProcessRadarInput(int x,int y)
 	// when drive mode is active, clicking on the radar orders all selected droids
 	// to move to this position.
 	CalcRadarPosition(x, y, &PosX, &PosY);
-	orderSelectedLoc(selectedPlayer, PosX*TILE_UNITS,PosY*TILE_UNITS);
+	orderSelectedLoc(selectedPlayer, PosX*TILE_UNITS, PosY*TILE_UNITS, ctrlShiftDown());  // ctrlShiftDown() = ctrl clicked a destination, add an order
 }
 /*
 void driveMarkTarget(void)
