@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -50,6 +50,8 @@ back when building is destroyed*/
 
 //storage
 extern DROID_TEMPLATE			*apsDroidTemplates[MAX_PLAYERS];
+extern DROID_TEMPLATE			*apsStaticTemplates;			// for AIs and scripts
+
 extern bool runningMultiplayer(void);
 
 /* The range for neighbouring objects */
@@ -108,7 +110,7 @@ extern void	removeDroidBase(DROID *psDel);
 // refresh the naybor list
 // this only does anything if the naybor list is out of date
 extern void droidGetNaybors(DROID *psDroid);
-
+extern char *RemakeTemplate(DROID_TEMPLATE	*templatelist, COMPONENT_STATS *cStat, COMPONENT_TYPE COMP_PART);
 extern BOOL loadDroidTemplates(const char *pDroidData, UDWORD bufferSize);
 extern BOOL loadDroidWeapons(const char *pWeaponData, UDWORD bufferSize);
 
@@ -238,12 +240,13 @@ extern BOOL activateGroupAndMove(UDWORD playerNumber, UDWORD groupNumber);
 /* calculate muzzle tip location in 3d world added int weapon_slot to fix the always slot 0 hack*/
 extern BOOL calcDroidMuzzleLocation(DROID *psDroid, Vector3f *muzzle, int weapon_slot);
 
+/* gets a template from its aName (when pName is unknown) */ 
+extern DROID_TEMPLATE	*GetHumanDroidTemplate(char *aName);
+extern DROID_TEMPLATE	*GetAIDroidTemplate(char *aName);
 /* gets a template from its name - relies on the name being unique */
 extern DROID_TEMPLATE * getTemplateFromUniqueName(const char *pName, unsigned int player);
 /* gets a template from its name - relies on the name being unique */
 extern DROID_TEMPLATE* getTemplateFromTranslatedNameNoPlayer(char *pName);
-/*getTemplateFromSinglePlayerID gets template for unique ID  searching one players list */
-extern DROID_TEMPLATE* getTemplateFromSinglePlayerID(UDWORD multiPlayerID, UDWORD player);
 /*getTemplateFromMultiPlayerID gets template for unique ID  searching all lists */
 extern DROID_TEMPLATE* getTemplateFromMultiPlayerID(UDWORD multiPlayerID);
 
@@ -335,10 +338,14 @@ extern BOOL droidUpdateClearing( DROID *psDroid );
 a defined range*/
 extern BASE_OBJECT * checkForRepairRange(DROID *psDroid,DROID *psTarget);
 
-//access function
+/// Returns true iff the droid has VTOL propulsion, and is not a transport.
 extern BOOL isVtolDroid(const DROID* psDroid);
-/*returns true if a VTOL Weapon Droid which has completed all runs*/
+/// Returns true iff the droid has VTOL propulsion and is moving.
+extern BOOL isFlying(const DROID* psDroid);
+/*returns true if a VTOL weapon droid which has completed all runs*/
 extern BOOL vtolEmpty(DROID *psDroid);
+/*returns true if a VTOL weapon droid which still has full ammo*/
+extern BOOL vtolFull(DROID *psDroid);
 /*Checks a vtol for being fully armed and fully repaired to see if ready to
 leave reArm pad */
 extern BOOL  vtolHappy(const DROID* psDroid);
@@ -367,6 +374,8 @@ extern BOOL droidSensorDroidWeapon(BASE_OBJECT *psObj, DROID *psDroid);
 
 // return whether a droid has a CB sensor on it
 extern BOOL cbSensorDroid(DROID *psDroid);
+// return whether a droid has a standard sensor on it (standard, VTOL strike, or wide spectrum)
+extern BOOL standardSensorDroid(DROID *psDroid);
 
 // give a droid from one player to another - used in Electronic Warfare and multiplayer
 extern DROID * giftSingleDroid(DROID *psD, UDWORD to);
@@ -561,5 +570,6 @@ void checkDroid(const DROID *droid, const char * const location_description, con
 
 // Minimum damage a weapon will deal to its target
 #define	MIN_WEAPON_DAMAGE	1
+void templateSetParts(const DROID *psDroid, DROID_TEMPLATE *psTemplate);
 
 #endif // __INCLUDED_SRC_DROID_H__
