@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -21,10 +21,19 @@
 #ifndef __INCLUDED_SRC_E3DEMO_H__
 #define __INCLUDED_SRC_E3DEMO_H__
 
-extern	void	initDemoCamera		( void );
-extern	void	processDemoCam		( void );
-extern	void	toggleDemoStatus	( void );
-extern	BOOL	demoGetStatus		( void );
-extern	void	setFindNewTarget	( void );
+#ifdef __cplusplus
+extern "C"
+{
+#endif //__cplusplus
+
+void initDemoCamera(void);
+void processDemoCam(void);
+void toggleDemoStatus(void);
+BOOL demoGetStatus(void);
+void setFindNewTarget(void);
+
+#ifdef __cplusplus
+}
+#endif //__cplusplus
 
 #endif //__INCLUDED_SRC_E3DEMO_H__ 
