@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -127,11 +127,18 @@ BOOL loadFeatureStats(const char *pFeatureData, UDWORD bufferSize)
 
 	numFeatureStats = numCR(pFeatureData, bufferSize);
 
+	// Skip descriptive header
+	if (strncmp(pFeatureData,"Feature ",8)==0)
+	{
+		pFeatureData = strchr(pFeatureData,'\n') + 1;
+		numFeatureStats--;
+	}
+	
 	asFeatureStats = (FEATURE_STATS*)malloc(sizeof(FEATURE_STATS) * numFeatureStats);
 
 	if (asFeatureStats == NULL)
 	{
-		debug( LOG_ERROR, "Feature Stats - Out of memory" );
+		debug( LOG_FATAL, "Feature Stats - Out of memory" );
 		abort();
 		return false;
 	}
@@ -171,6 +178,12 @@ BOOL loadFeatureStats(const char *pFeatureData, UDWORD bufferSize)
 			return false;
 		}
 
+		if (psFeature->damageable && psFeature->body == 0)
+		{
+			debug(LOG_ERROR, "The feature %s, ref %d, is damageable, but has no body points!  The files need to be updated / fixed.  " \
+							 "Assigning 1 body point to feature.", psFeature->pName, psFeature->ref);
+			psFeature->body = 1;
+		}
 		//determine the feature type
 		featureType(psFeature, type);
 
@@ -220,9 +233,9 @@ float featureDamage(FEATURE *psFeature, UDWORD damage, UDWORD weaponClass, UDWOR
 {
 	float		relativeDamage;
 
-	ASSERT_OR_RETURN(0.0, psFeature != NULL, "Invalid feature pointer");
+	ASSERT_OR_RETURN(0.0f, psFeature != NULL, "Invalid feature pointer");
 
-	debug(LOG_ATTACK, "featureDamage(%d): body %d armour %d damage: %d",
+	debug(LOG_ATTACK, "feature (id %d): body %d armour %d damage: %d",
 	      psFeature->id, psFeature->body, psFeature->armour[impactSide][weaponClass], damage);
 
 	relativeDamage = objDamage((BASE_OBJECT *)psFeature, damage, psFeature->psStats->body, weaponClass, weaponSubClass, impactSide);
@@ -230,6 +243,7 @@ float featureDamage(FEATURE *psFeature, UDWORD damage, UDWORD weaponClass, UDWOR
 	// If the shell did sufficient damage to destroy the feature
 	if (relativeDamage < 0.0f)
 	{
+		debug(LOG_ATTACK, "feature (id %d) DESTROYED", psFeature->id);
 		destroyFeature(psFeature);
 		return relativeDamage * -1.0f;
 	}
@@ -480,31 +494,36 @@ void featureUpdate(FEATURE *psFeat)
 // free up a feature with no visual effects
 bool removeFeature(FEATURE *psDel)
 {
-	UDWORD		mapX, mapY, width,breadth, player;
-	MESSAGE		*psMessage;
-	Vector3i pos;
+	int		mapX, mapY, width, breadth, player;
+ 	MESSAGE		*psMessage;
+	Vector3i	pos;
 
 	ASSERT_OR_RETURN(false, psDel != NULL, "Invalid feature pointer");
 	ASSERT_OR_RETURN(false, !psDel->died, "Feature already dead");
 
-	if(bMultiPlayer && !ingame.localJoiningInProgress)
+	if(bMultiMessages && !ingame.localJoiningInProgress)
 	{
 		SendDestroyFeature(psDel);	// inform other players of destruction
 	}
 
 	//remove from the map data
-	mapX = map_coord(psDel->pos.x - psDel->psStats->baseWidth * TILE_UNITS / 2);
-	mapY = map_coord(psDel->pos.y - psDel->psStats->baseBreadth * TILE_UNITS / 2);
-	for (width = 0; width < psDel->psStats->baseWidth; width++)
+	mapX = map_coord(psDel->pos.x);
+	mapY = map_coord(psDel->pos.y);
+	for (width = -psDel->psStats->baseWidth; width < psDel->psStats->baseWidth; width++)
 	{
-		for (breadth = 0; breadth < psDel->psStats->baseBreadth; breadth++)
+		for (breadth = -psDel->psStats->baseBreadth; breadth < psDel->psStats->baseBreadth; breadth++)
 		{
-			MAPTILE *psTile = mapTile(mapX + width, mapY + breadth);
-
-			psTile->psObject = NULL;
-
-			CLEAR_TILE_TALLSTRUCTURE(psTile);
-			CLEAR_TILE_NOTBLOCKING(psTile);
+			if (tileOnMap(mapX + width, mapY + breadth))
+			{
+				MAPTILE *psTile = mapTile(mapX + width, mapY + breadth);
+	 
+				if (psTile->psObject == (BASE_OBJECT *)psDel)
+				{
+					psTile->psObject = NULL;
+					CLEAR_TILE_TALLSTRUCTURE(psTile);
+					CLEAR_TILE_NOTBLOCKING(psTile);
+				}
+			}
 		}
 	}
 
@@ -518,17 +537,16 @@ bool removeFeature(FEATURE *psDel)
 		intRefreshScreen();
 	}
 
-	if (  (psDel->psStats->subType == FEAT_GEN_ARTE)
-		||(psDel->psStats->subType == FEAT_OIL_RESOURCE))
+	if (psDel->psStats->subType == FEAT_GEN_ARTE || psDel->psStats->subType == FEAT_OIL_RESOURCE)
 	{
 		// have to check all players cos if you cheat you'll get em.
-		for (player=0; player<MAX_PLAYERS; player ++)
+		for (player = 0; player < MAX_PLAYERS; player++)
 		{
 			//see if there is a proximity message FOR THE SELECTED PLAYER at this location
-			psMessage = findMessage((MSG_VIEWDATA *)psDel, MSG_PROXIMITY, selectedPlayer);
+			psMessage = findMessage((MSG_VIEWDATA *)psDel, MSG_PROXIMITY, player);
 			while (psMessage)
 			{
-				removeMessage(psMessage, selectedPlayer);
+				removeMessage(psMessage, player);
 				psMessage = findMessage((MSG_VIEWDATA *)psDel, MSG_PROXIMITY, player);
 			}
 		}
