@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -420,11 +420,14 @@ static FPATH_RETVAL fpathRoute(MOVE_CONTROL *psMove, int id, int startX, int sta
 	// Check if waiting for a result
 	if (psMove->Status == MOVEWAITROUTE)
 	{
-		PATHRESULT *psPrev = NULL, *psNext = firstResult;
+		PATHRESULT *psPrev = NULL, *psNext;
 
 		objTrace(id, "Checking if we have a path yet");
 		SDL_SemWait(fpathSemaphore);
 
+		// psNext should be _declared_ here, after the mutex lock! Used to be a race condition, thanks to -Wdeclaration-after-statement style pseudocompiler compatibility.
+		psNext = firstResult;
+
 		while (psNext)
 		{
 			if (psNext->droidID == id && psNext->done)
@@ -576,8 +579,8 @@ FPATH_RETVAL fpathDroidRoute(DROID* psDroid, SDWORD tX, SDWORD tY)
 		}
 		else
 		{
-			tX = world_coord(map_coord(tX) + aDirOffset[nearestDir].x) + TILE_SHIFT / 2;
-			tY = world_coord(map_coord(tY) + aDirOffset[nearestDir].y) + TILE_SHIFT / 2;
+			tX = world_coord(map_coord(tX) + aDirOffset[nearestDir].x) + TILE_UNITS / 2;
+			tY = world_coord(map_coord(tY) + aDirOffset[nearestDir].y) + TILE_UNITS / 2;
 			objTrace(psDroid->id, "Workaround found at (%d, %d)", map_coord(tX), map_coord(tY));
 		}
 	}
@@ -700,3 +703,31 @@ void fpathTest(int x, int y, int x2, int y2)
 	assert(firstJob == NULL);
 	assert(firstResult == NULL);
 }
+
+bool fpathCheck(Vector2i orig, Vector2i dest, PROPULSION_TYPE propulsion)
+{
+	MAPTILE *origTile = mapTile(orig.x, orig.y);
+	MAPTILE *destTile = mapTile(dest.x, dest.y);
+
+	ASSERT(propulsion != PROPULSION_TYPE_NUM, "Bad propulsion type");
+	ASSERT(origTile != NULL && destTile != NULL, "Bad tile parameter");
+
+	switch (propulsion)
+	{
+	case PROPULSION_TYPE_PROPELLOR:
+	case PROPULSION_TYPE_WHEELED:
+	case PROPULSION_TYPE_TRACKED:
+	case PROPULSION_TYPE_LEGGED:
+	case PROPULSION_TYPE_SKI: 	// ?!
+	case PROPULSION_TYPE_HALF_TRACKED:
+		return origTile->limitedContinent == destTile->limitedContinent;
+	case PROPULSION_TYPE_HOVER:
+		return origTile->hoverContinent == destTile->hoverContinent;
+	case PROPULSION_TYPE_JUMP:
+	case PROPULSION_TYPE_LIFT:
+		return true;	// FIXME: This is not entirely correct for all possible maps. - Per
+	case PROPULSION_TYPE_NUM:
+		break;
+	}
+	return true;	// should never get here
+}
