@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -93,6 +93,10 @@ extern void fpathSetDirectRoute(DROID* psDroid, SDWORD targetX, SDWORD targetY);
 /** Clean up path jobs and results for a droid. Function is thread-safe. */
 extern void fpathRemoveDroidData(int id);
 
+/** Quick O(1) test of whether it is theoretically possible to go from origin to destination
+ *  using the given propulsion type. */
+bool fpathCheck(Vector2i orig, Vector2i dest, PROPULSION_TYPE propulsion);
+
 /** Unit testing. */
 void fpathTest(int x, int y, int x2, int y2);
 
