@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -257,7 +257,11 @@ enum {
 	IMAGE_TRANS_LOCKED,		// clear background 'locked'
 	IMAGE_TRANS_UNLOCKED,	//  "       "       'unlocked'
 	IMAGE_UNLOCK_BLUE,		// Custom image for the host screen to fix the blend issue
-	IMAGE_LOCK_BLUE			//
+	IMAGE_LOCK_BLUE,		//
+	IMAGE_SCAVENGERS_ON,
+	IMAGE_SCAVENGERS_OFF,
+	IMAGE_SCAVENGERS_ON_HI,
+	IMAGE_SCAVENGERS_OFF_HI,
 };
 
 #endif // __INCLUDED_SRC_FREND_H__
