@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -139,7 +139,7 @@ static BOOL storeName(FUNCTION* pFunction, const char* pNameToStore)
 	pFunction->pName = strdup(pNameToStore);
 	if (pFunction->pName == NULL)
 	{
-		debug( LOG_ERROR, "Function Name - Out of memory" );
+		debug( LOG_FATAL, "Function Name - Out of memory" );
 		abort();
 		return false;
 	}
@@ -161,7 +161,7 @@ static BOOL loadProduction(const char *pData)
 	psFunction = (PRODUCTION_FUNCTION *)malloc(sizeof(PRODUCTION_FUNCTION));
 	if (psFunction == NULL)
 	{
-		debug( LOG_ERROR, "Production Function - Out of memory" );
+		debug( LOG_FATAL, "Production Function - Out of memory" );
 		abort();
 		return false;
 	}
@@ -251,7 +251,7 @@ static BOOL loadProductionUpgradeFunction(const char *pData)
 		(PRODUCTION_UPGRADE_FUNCTION));
 	if (psFunction == NULL)
 	{
-		debug( LOG_ERROR, "Production Upgrade Function - Out of memory" );
+		debug( LOG_FATAL, "Production Upgrade Function - Out of memory" );
 		abort();
 		return false;
 	}
@@ -316,7 +316,7 @@ static BOOL loadResearchFunction(const char *pData)
 	psFunction = (RESEARCH_FUNCTION *)malloc(sizeof(RESEARCH_FUNCTION));
 	if (psFunction == NULL)
 	{
-		debug( LOG_ERROR, "Research Function - Out of memory" );
+		debug( LOG_FATAL, "Research Function - Out of memory" );
 		abort();
 		return false;
 	}
@@ -350,7 +350,7 @@ static BOOL loadReArmFunction(const char *pData)
 	psFunction = (REARM_FUNCTION *)malloc(sizeof(REARM_FUNCTION));
 	if (psFunction == NULL)
 	{
-		debug( LOG_ERROR, "ReArm Function - Out of memory" );
+		debug( LOG_FATAL, "ReArm Function - Out of memory" );
 		abort();
 		return false;
 	}
@@ -387,7 +387,7 @@ static BOOL loadUpgradeFunction(const char *pData, UBYTE type)
 	psFunction = (UPGRADE_FUNCTION *)malloc(sizeof(UPGRADE_FUNCTION));
 	if (psFunction == NULL)
 	{
-		debug( LOG_ERROR, "Upgrade Function - Out of memory" );
+		debug( LOG_FATAL, "Upgrade Function - Out of memory" );
 		abort();
 		return false;
 	}
@@ -471,7 +471,7 @@ static BOOL loadDroidBodyUpgradeFunction(const char *pData)
 		sizeof(DROIDBODY_UPGRADE_FUNCTION));
 	if (psFunction == NULL)
 	{
-		debug( LOG_ERROR, "UnitBody Upgrade Function - Out of memory" );
+		debug( LOG_FATAL, "UnitBody Upgrade Function - Out of memory" );
 		abort();
 		return false;
 	}
@@ -538,7 +538,7 @@ static BOOL loadDroidSensorUpgradeFunction(const char *pData)
 		sizeof(DROIDSENSOR_UPGRADE_FUNCTION));
 	if (psFunction == NULL)
 	{
-		debug( LOG_ERROR, "UnitSensor Upgrade Function - Out of memory" );
+		debug( LOG_FATAL, "UnitSensor Upgrade Function - Out of memory" );
 		abort();
 		return false;
 	}
@@ -587,7 +587,7 @@ static BOOL loadWeaponUpgradeFunction(const char *pData)
 		(WEAPON_UPGRADE_FUNCTION));
 	if (psFunction == NULL)
 	{
-		debug( LOG_ERROR, "Weapon Upgrade Function - Out of memory" );
+		debug( LOG_FATAL, "Weapon Upgrade Function - Out of memory" );
 		abort();
 		return false;
 	}
@@ -657,7 +657,7 @@ static BOOL loadStructureUpgradeFunction(const char *pData)
 		(STRUCTURE_UPGRADE_FUNCTION));
 	if (psFunction == NULL)
 	{
-		debug( LOG_ERROR, "Structure Upgrade Function - Out of memory" );
+		debug( LOG_FATAL, "Structure Upgrade Function - Out of memory" );
 		abort();
 		return false;
 	}
@@ -708,7 +708,7 @@ static BOOL loadWallDefenceUpgradeFunction(const char *pData)
 		(WALLDEFENCE_UPGRADE_FUNCTION));
 	if (psFunction == NULL)
 	{
-		debug( LOG_ERROR, "WallDefence Upgrade Function - Out of memory" );
+		debug( LOG_FATAL, "WallDefence Upgrade Function - Out of memory" );
 		abort();
 		return false;
 	}
@@ -757,7 +757,7 @@ static BOOL loadPowerGenFunction(const char *pData)
 		(POWER_GEN_FUNCTION));
 	if (psFunction == NULL)
 	{
-		debug( LOG_ERROR, "Power Gen Function - Out of memory" );
+		debug( LOG_FATAL, "Power Gen Function - Out of memory" );
 		abort();
 		return false;
 	}
@@ -780,10 +780,10 @@ static BOOL loadPowerGenFunction(const char *pData)
 		&psFunction->criticalMassDamage, &psFunction->radiationDecayTime);
 
 
-	if(bMultiPlayer)
-	{
-		modifyResources(psFunction);
-	}
+//	if(bMultiPlayer)
+//	{
+//		modifyResources(psFunction);
+//	}
 
 
 	//allocate storage for the name
@@ -802,7 +802,7 @@ static BOOL loadResourceFunction(const char *pData)
 		(RESOURCE_FUNCTION));
 	if (psFunction == NULL)
 	{
-		debug( LOG_ERROR, "Resource Function - Out of memory" );
+		debug( LOG_FATAL, "Resource Function - Out of memory" );
 		abort();
 		return false;
 	}
@@ -838,7 +838,7 @@ static BOOL loadRepairDroidFunction(const char *pData)
 		(REPAIR_DROID_FUNCTION));
 	if (psFunction == NULL)
 	{
-		debug( LOG_ERROR, "Repair Droid Function - Out of memory" );
+		debug( LOG_FATAL, "Repair Droid Function - Out of memory" );
 		abort();
 		return false;
 	}
@@ -878,7 +878,7 @@ static BOOL loadWallFunction(const char *pData)
 	psFunction = (WALL_FUNCTION *)malloc(sizeof(WALL_FUNCTION));
 	if (psFunction == NULL)
 	{
-		debug( LOG_ERROR, "Wall Function - Out of memory" );
+		debug( LOG_FATAL, "Wall Function - Out of memory" );
 		abort();
 		return false;
 	}
@@ -1178,30 +1178,25 @@ void structureReArmUpgrade(STRUCTURE *psBuilding)
 
 void structurePowerUpgrade(STRUCTURE *psBuilding)
 {
-	POWER_GEN					*pPowerGen = &psBuilding->pFunctionality->powerGenerator;
-	POWER_GEN_FUNCTION			*pPGFunc;
-    UDWORD                       baseOutput;
-    STRUCTURE_STATS             *psStat;
+	POWER_GEN		*pPowerGen = &psBuilding->pFunctionality->powerGenerator;
+	POWER_GEN_FUNCTION	*pPGFunc = (POWER_GEN_FUNCTION *)psBuilding->pStructureType->asFuncList[0];
+	UDWORD			multiplier;
+	STRUCTURE_STATS		*psStat;
 
-	//upgrade the research points
-	ASSERT(pPowerGen != NULL, "structurePowerUpgrade: invalid Power Gen pointer");
+	ASSERT(pPowerGen != NULL, "Invalid Power Gen pointer");
+	ASSERT(pPGFunc != NULL, "Invalid function pointer");
 
-	pPGFunc = (POWER_GEN_FUNCTION *)psBuilding->pStructureType->asFuncList[0];
-	ASSERT( pPGFunc != NULL,
-		"structurePowerUpgrade: invalid Function pointer" );
-
-    //current base value depends on whether there are modules attached to the structure
-    baseOutput = pPGFunc->powerMultiplier;
-    psStat = getModuleStat(psBuilding);
-    if (psStat)
-    {
-        if (pPowerGen->capacity)
-        {
-            baseOutput += ((POWER_GEN_FUNCTION*)psStat->asFuncList[0])->powerOutput;
-        }
-    }
-	pPowerGen->multiplier = baseOutput + (pPGFunc->powerMultiplier *
-		asPowerUpgrade[psBuilding->player].modifier) / 100;
+	// Current base value depends on whether there are modules attached to the structure
+	multiplier = pPGFunc->powerMultiplier;
+	psStat = getModuleStat(psBuilding);
+	if (psStat)
+	{
+		if (pPowerGen->capacity)
+		{
+			multiplier += ((POWER_GEN_FUNCTION*)psStat->asFuncList[0])->powerMultiplier;
+		}
+	}
+	pPowerGen->multiplier = multiplier + (pPGFunc->powerMultiplier * asPowerUpgrade[psBuilding->player].modifier) / 100;
 }
 
 void structureRepairUpgrade(STRUCTURE *psBuilding)
@@ -1575,7 +1570,7 @@ BOOL loadFunctionStats(const char *pFunctionData, UDWORD bufferSize)
 	asFunctions = (FUNCTION**) malloc(totalFunctions*sizeof(FUNCTION*));
 	if (!asFunctions)
 	{
-		debug( LOG_ERROR, "Out of memory" );
+		debug( LOG_FATAL, "Out of memory" );
 		abort();
 		return false;
 	}
