@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -29,6 +29,8 @@
 #ifndef __INCLUDED_SRC_GAME_H__
 #define __INCLUDED_SRC_GAME_H__
 
+#include "lib/framework/vector.h"
+
 /***************************************************************************/
 /*
  *	Global Definitions
@@ -71,9 +73,11 @@
 #define VERSION_34              34              //saves AI names for multiplayer (.gam file)
 #define VERSION_35              35              //uses the (de)serialization API for saving/loading games and is big-endian instead of little-endian
 #define VERSION_36              36              //saves beacon properly
+#define VERSION_37              37              //dpid changes; this had better be the last version
+#define VERSION_38              38              //mod list!
 
 
-#define CURRENT_VERSION_NUM     VERSION_36
+#define CURRENT_VERSION_NUM     VERSION_38
 
 //used in the loadGame
 #define KEEPOBJECTS				true
@@ -153,5 +157,5 @@ extern UDWORD getSaveGameType(void);
 
 UDWORD RemapPlayerNumber(UDWORD OldNumber);
 
-BOOL plotStructurePreview16(char *backDropSprite, UBYTE scale, UDWORD offX, UDWORD offY, Vector2i playeridpos[]);
+BOOL plotStructurePreview16(char *backDropSprite, Vector2i playeridpos[]);
 #endif // __INCLUDED_SRC_GAME_H__
