@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -109,7 +109,7 @@ BOOL gwNewGateway(SDWORD x1, SDWORD y1, SDWORD x2, SDWORD y2)
 	psNew = (GATEWAY*)malloc(sizeof(GATEWAY));
 	if (!psNew)
 	{
-		debug( LOG_ERROR, "gwNewGateway: out of memory" );
+		debug( LOG_FATAL, "gwNewGateway: out of memory" );
 		abort();
 		return false;
 	}
