@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -23,22 +23,14 @@
  * Link droids together into a group for AI etc.
  *
  */
-#include <string.h>
 
 #include "lib/framework/frame.h"
-#include "objects.h"
-#include "group.h"
-#include "orderdef.h"
 
 #include "multiplay.h"
 
 static DROID_GROUP *firstGroup = NULL;
 static BOOL grpInitialized = false;
 
-// sizes for the group heap
-#define GRP_HEAP_INIT	45
-#define GRP_HEAP_EXT	15
-
 // initialise the group system
 BOOL grpInitialise(void)
 {
@@ -103,11 +95,11 @@ void grpJoin(DROID_GROUP *psGroup, DROID *psDroid)
 {
 	ASSERT(grpInitialized, "Group code not initialized yet");
 
-	psGroup->refCount += 1;
-
-	ASSERT( psGroup != NULL,
+	ASSERT_OR_RETURN(, psGroup != NULL,
 		"grpJoin: invalid group pointer" );
 
+	psGroup->refCount += 1;
+
 	// if psDroid == NULL just increase the refcount don't add anything to the list
 	if (psDroid != NULL)
 	{
@@ -126,7 +118,7 @@ void grpJoin(DROID_GROUP *psGroup, DROID *psDroid)
 
 		if (psDroid->droidType == DROID_TRANSPORTER)
 		{
-			ASSERT( (psGroup->type == GT_NORMAL),
+			ASSERT_OR_RETURN(, (psGroup->type == GT_NORMAL),
 				"grpJoin: Cannot have two transporters in a group" );
 			psGroup->type = GT_TRANSPORTER;
 			psDroid->psGrpNext = psGroup->psList;
@@ -135,7 +127,7 @@ void grpJoin(DROID_GROUP *psGroup, DROID *psDroid)
 		else if ((psDroid->droidType == DROID_COMMAND) &&
 				 (psGroup->type != GT_TRANSPORTER))
 		{
-			ASSERT( (psGroup->type == GT_NORMAL) && (psGroup->psCommander == NULL),
+			ASSERT_OR_RETURN(, (psGroup->type == GT_NORMAL) && (psGroup->psCommander == NULL),
 				"grpJoin: Cannot have two command droids in a group" );
 			psGroup->type = GT_COMMAND;
 			psGroup->psCommander = psDroid;
@@ -149,16 +141,17 @@ void grpJoin(DROID_GROUP *psGroup, DROID *psDroid)
 }
 
 // add a droid to a group at the end of the list
+// NOTE: Unused! void grpJoinEnd(DROID_GROUP *psGroup, DROID *psDroid)
 void grpJoinEnd(DROID_GROUP *psGroup, DROID *psDroid)
 {
 	DROID		*psPrev, *psCurr;
 
-	psGroup->refCount += 1;
-
 	ASSERT(grpInitialized, "Group code not initialized yet");
-	ASSERT( psGroup != NULL,
+	ASSERT_OR_RETURN(, psGroup != NULL,
 		"grpJoin: invalid group pointer" );
 
+	psGroup->refCount += 1;
+
 	// if psDroid == NULL just increase the refcount don't add anything to the list
 	if (psDroid != NULL)
 	{
@@ -177,7 +170,7 @@ void grpJoinEnd(DROID_GROUP *psGroup, DROID *psDroid)
 
 		if (psDroid->droidType == DROID_COMMAND)
 		{
-			ASSERT( (psGroup->type == GT_NORMAL) && (psGroup->psCommander == NULL),
+			ASSERT_OR_RETURN(, (psGroup->type == GT_NORMAL) && (psGroup->psCommander == NULL),
 				"grpJoin: Cannot have two command droids in a group" );
 			psGroup->type = GT_COMMAND;
 			psGroup->psCommander = psDroid;
@@ -292,7 +285,7 @@ unsigned int grpNumMembers(const DROID_GROUP* psGroup)
 	unsigned int num;
 
 	ASSERT(grpInitialized, "Group code not initialized yet");
-	ASSERT(psGroup != NULL, "invalid droid group");
+	ASSERT_OR_RETURN(0, psGroup != NULL, "invalid droid group");
 
 	num = 0;
 	for (psCurr = psGroup->psList; psCurr; psCurr = psCurr->psGrpNext)
@@ -309,7 +302,7 @@ void grpReset(DROID_GROUP *psGroup)
 	DROID	*psCurr, *psNext;
 
 	ASSERT(grpInitialized, "Group code not initialized yet");
-	ASSERT( psGroup != NULL,
+	ASSERT_OR_RETURN(, psGroup != NULL,
 		"grpReset: invalid droid group" );
 
 	for(psCurr = psGroup->psList; psCurr; psCurr = psNext)
@@ -325,7 +318,7 @@ void orderGroup(DROID_GROUP *psGroup, DROID_ORDER order)
 	DROID *psCurr;
 
 	ASSERT(grpInitialized, "Group code not initialized yet");
-	ASSERT( psGroup != NULL,
+	ASSERT_OR_RETURN(, psGroup != NULL,
 		"orderGroup: invalid droid group" );
 
 	for (psCurr = psGroup->psList; psCurr; psCurr=psCurr->psGrpNext)
@@ -340,20 +333,20 @@ void orderGroupLoc(DROID_GROUP *psGroup, DROID_ORDER order, UDWORD x, UDWORD y)
 	DROID	*psCurr;
 
 	ASSERT(grpInitialized, "Group code not initialized yet");
-	ASSERT( psGroup != NULL,
+	ASSERT_OR_RETURN(, psGroup != NULL,
 		"orderGroupLoc: invalid droid group" );
 
-	if(bMultiPlayer)
+	if(bMultiMessages)
 	{
 		SendGroupOrderGroup(psGroup,order,x,y,NULL);
-		bMultiPlayer = false;
+		bMultiMessages = false;
 
 		for(psCurr=psGroup->psList; psCurr; psCurr = psCurr->psGrpNext)
 		{
 			orderDroidLoc(psCurr, order, x,y);
 		}
 
-		bMultiPlayer = true;
+		bMultiMessages = true;
 	}
 	else
 	{
@@ -369,20 +362,20 @@ void orderGroupObj(DROID_GROUP *psGroup, DROID_ORDER order, BASE_OBJECT *psObj)
 {
 	DROID	*psCurr;
 
-	ASSERT( psGroup != NULL,
+	ASSERT_OR_RETURN(, psGroup != NULL,
 		"orderGroupObj: invalid droid group" );
 
-	if(bMultiPlayer)
+	if(bMultiMessages)
 	{
 		SendGroupOrderGroup(psGroup,order,0,0,psObj);
-		bMultiPlayer = false;
+		bMultiMessages = false;
 
 		for(psCurr = psGroup->psList; psCurr; psCurr = psCurr->psGrpNext)
 		{
 			orderDroidObj(psCurr, order, (BASE_OBJECT *)psObj);
 		}
 
-		bMultiPlayer = true;
+		bMultiMessages = true;
 	}
 	else
 	{
@@ -399,7 +392,7 @@ void grpSetSecondary(DROID_GROUP *psGroup, SECONDARY_ORDER sec, SECONDARY_STATE
 	DROID	*psCurr;
 
 	ASSERT(grpInitialized, "Group code not initialized yet");
-	ASSERT( psGroup != NULL,
+	ASSERT_OR_RETURN(, psGroup != NULL,
 		"grpSetSecondary: invalid droid group" );
 
 	for(psCurr = psGroup->psList; psCurr; psCurr = psCurr->psGrpNext)
