@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -110,7 +110,7 @@
 #define IDSTAT_ALLYEND			4900
 
 // Reticule position.
-#define RET_X				23
+#define RET_X				24
 #define RET_Y				(324+E_H)
 #define RET_FORMWIDTH		132
 #define RET_FORMHEIGHT		132
@@ -264,7 +264,8 @@ typedef enum {
 	INT_TRANSPORTER, //Loading/unloading a Transporter
 	INT_MISSIONRES,	// Results of a mission display.
 	INT_MULTIMENU,	// multiplayer only, player stats etc...
-	INT_CDCHANGE,		// CD Change message box
+	INT_CDCHANGE,	// CD Change message box
+	INT_POPUPMSG,	// Adds a popup message to user
 
     INT_MAXMODE,   //leave as last so we can start the objMode at this value
 } INTMODE;
@@ -309,6 +310,7 @@ extern BOOL ClosingIntelMap;
 extern BOOL	ClosingTrans;
 extern BOOL	ClosingTransCont;
 extern BOOL	ClosingTransDroids;
+extern BOOL ClosingOrder;
 
 /* Initialise the in game interface */
 extern BOOL intInitialise(void);
