@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -30,16 +30,18 @@ extern BOOL intCloseInGameOptions		(BOOL bPutUpLoadSave, BOOL bResetMissionWidge
 extern void intCloseInGameOptionsNoAnim	(BOOL bResetMissionWidgets);
 extern BOOL intRunInGameOptions			(void);
 extern void intProcessInGameOptions		(UDWORD);
+extern void intAddInGamePopup(void);
 
 // status bools.
 extern BOOL	ClosingInGameOp;
 extern BOOL	InGameOpUp;
-
+extern bool isInGamePopupUp;
 // ////////////////////////////////////////////////////////////////////////////
 // defines
 
 // the screen itself.
 #define INTINGAMEOP				10500
+#define INTINGAMEPOPUP			77335
 
 // position info for window.
 
@@ -101,6 +103,10 @@ enum
 	INTINGAMEOP_CURSOR_S,
 	INTINGAMEOP_SUBTITLES,
 	INTINGAMEOP_SUBTITLES_BT,
+	INTINGAMEOP_POPUP_QUIT,
+	INTINGAMEOP_POPUP_MSG1,
+	INTINGAMEOP_POPUP_MSG2,
+	INTINGAMEOP_POPUP_MSG3
 };
 
 
