@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -47,6 +47,7 @@
 
 #include "advvis.h"
 #include "atmos.h"
+#include "challenge.h"
 #include "cluster.h"
 #include "cmddroid.h"
 #include "component.h"
@@ -80,6 +81,7 @@
 #include "multiplay.h"
 #include "projectile.h"
 #include "radar.h"
+#include "research.h"
 #include "lib/framework/cursors.h"
 #include "scriptextern.h"
 #include "scripttabs.h"
@@ -90,15 +92,12 @@
 #include "warzoneconfig.h"
 #include "main.h"
 #include "wrappers.h"
+#include "ingameop.h"
 
 static void	initMiscVars(void);
 
 static const char UserMusicPath[] = "music";
 
-extern char * global_mods[];
-extern char * campaign_mods[];
-extern char * multiplay_mods[];
-
 // FIXME Totally inappropriate place for this.
 char fileLoadBuffer[FILE_LOAD_BUFFER_SIZE];
 
@@ -172,6 +171,7 @@ void cleanSearchPath( void )
 		free( curSearchPath );
 		curSearchPath = tmpSearchPath;
 	}
+	searchPathRegistry = NULL;
 }
 
 
@@ -233,11 +233,15 @@ BOOL rebuildSearchPath( searchPathMode mode, BOOL force )
 	wzSearchPath * curSearchPath = searchPathRegistry;
 	char tmpstr[PATH_MAX] = "\0";
 
-	if ( mode != current_mode || force )
+	if (mode != current_mode || force ||
+	    (use_override_mods && strcmp(override_mod_list, getModList())))
 	{
-		current_mode = mode;
+		if (mode != mod_clean)
+		{
+			rebuildSearchPath( mod_clean, false );
+		}
 
-		rebuildSearchPath( mod_clean, false );
+		current_mode = mode;
 
 		// Start at the lowest priority
 		while( curSearchPath->lowerPriority )
@@ -247,6 +251,7 @@ BOOL rebuildSearchPath( searchPathMode mode, BOOL force )
 		{
 			case mod_clean:
 				debug(LOG_WZ, "Cleaning up");
+				clearLoadedMods();
 
 				while( curSearchPath )
 				{
@@ -256,9 +261,10 @@ BOOL rebuildSearchPath( searchPathMode mode, BOOL force )
 					// Remove maps and mods
 					removeSubdirs( curSearchPath->path, "maps", NULL );
 					removeSubdirs( curSearchPath->path, "mods/music", NULL );
-					removeSubdirs( curSearchPath->path, "mods/global", global_mods );
-					removeSubdirs( curSearchPath->path, "mods/campaign", campaign_mods );
-					removeSubdirs( curSearchPath->path, "mods/multiplay", multiplay_mods );
+					removeSubdirs( curSearchPath->path, "mods/global", NULL );
+					removeSubdirs( curSearchPath->path, "mods/campaign", NULL );
+					removeSubdirs( curSearchPath->path, "mods/multiplay", NULL );
+					removeSubdirs( curSearchPath->path, "mods/autoload", NULL );
 
 					// Remove multiplay patches
 					sstrcpy(tmpstr, curSearchPath->path);
@@ -288,6 +294,7 @@ BOOL rebuildSearchPath( searchPathMode mode, BOOL force )
 				break;
 			case mod_campaign:
 				debug(LOG_WZ, "*** Switching to campaign mods ***");
+				clearLoadedMods();
 
 				while( curSearchPath )
 				{
@@ -297,12 +304,14 @@ BOOL rebuildSearchPath( searchPathMode mode, BOOL force )
 					// Add global and campaign mods
 					PHYSFS_addToSearchPath( curSearchPath->path, PHYSFS_APPEND );
 
-					addSubdirs( curSearchPath->path, "mods/music", PHYSFS_APPEND, NULL );
-					addSubdirs( curSearchPath->path, "mods/global", PHYSFS_APPEND, global_mods );
-					addSubdirs( curSearchPath->path, "mods/campaign", PHYSFS_APPEND, campaign_mods );
+					addSubdirs( curSearchPath->path, "mods/music", PHYSFS_APPEND, NULL, false );
+					addSubdirs( curSearchPath->path, "mods/global", PHYSFS_APPEND, use_override_mods?override_mods:global_mods, true );
+					addSubdirs( curSearchPath->path, "mods", PHYSFS_APPEND, use_override_mods?override_mods:global_mods, true );
+					addSubdirs( curSearchPath->path, "mods/autoload", PHYSFS_APPEND, use_override_mods?override_mods:NULL, true );
+					addSubdirs( curSearchPath->path, "mods/campaign", PHYSFS_APPEND, use_override_mods?override_mods:campaign_mods, true );
 					if (!PHYSFS_removeFromSearchPath( curSearchPath->path ))
 					{
-						info("* Failed to remove path %s again", curSearchPath->path);
+						debug(LOG_WZ, "* Failed to remove path %s again", curSearchPath->path);
 					}
 
 					// Add plain dir
@@ -326,6 +335,7 @@ BOOL rebuildSearchPath( searchPathMode mode, BOOL force )
 				break;
 			case mod_multiplay:
 				debug(LOG_WZ, "*** Switching to multiplay mods ***");
+				clearLoadedMods();
 
 				while( curSearchPath )
 				{
@@ -334,10 +344,12 @@ BOOL rebuildSearchPath( searchPathMode mode, BOOL force )
 #endif // DEBUG
 					// Add maps and global and multiplay mods
 					PHYSFS_addToSearchPath( curSearchPath->path, PHYSFS_APPEND );
-					addSubdirs( curSearchPath->path, "maps", PHYSFS_APPEND, NULL );
-					addSubdirs( curSearchPath->path, "mods/music", PHYSFS_APPEND, NULL );
-					addSubdirs( curSearchPath->path, "mods/global", PHYSFS_APPEND, global_mods );
-					addSubdirs( curSearchPath->path, "mods/multiplay", PHYSFS_APPEND, multiplay_mods );
+					addSubdirs( curSearchPath->path, "maps", PHYSFS_APPEND, NULL, false );
+					addSubdirs( curSearchPath->path, "mods/music", PHYSFS_APPEND, NULL, false );
+					addSubdirs( curSearchPath->path, "mods/global", PHYSFS_APPEND, use_override_mods?override_mods:global_mods, true );
+					addSubdirs( curSearchPath->path, "mods", PHYSFS_APPEND, use_override_mods?override_mods:global_mods, true );
+					addSubdirs( curSearchPath->path, "mods/autoload", PHYSFS_APPEND, use_override_mods?override_mods:NULL, true );
+					addSubdirs( curSearchPath->path, "mods/multiplay", PHYSFS_APPEND, use_override_mods?override_mods:multiplay_mods, true );
 					PHYSFS_removeFromSearchPath( curSearchPath->path );
 
 					// Add multiplay patches
@@ -371,6 +383,15 @@ BOOL rebuildSearchPath( searchPathMode mode, BOOL force )
 				debug(LOG_ERROR, "Can't switch to unknown mods %i", mode);
 				return false;
 		}
+		if (use_override_mods && mode != mod_clean)
+		{
+			if (strcmp(getModList(),override_mod_list))
+			{
+				debug(LOG_POPUP, _("The required mod could not be loaded: %s\n\nWarzone will try to load the game without it."), override_mod_list);
+			}
+			clearOverrideMods();
+			current_mode = mod_override;
+		}
 
 		// User's home dir must be first so we allways see what we write
 		PHYSFS_removeFromSearchPath(PHYSFS_getWriteDir());
@@ -380,6 +401,11 @@ BOOL rebuildSearchPath( searchPathMode mode, BOOL force )
 		printSearchPath();
 #endif // DEBUG
 	}
+	else if (use_override_mods)
+	{
+		// override mods are already the same as current mods, so no need to do anything
+		clearOverrideMods();
+	}
 	return true;
 }
 
@@ -421,7 +447,8 @@ BOOL systemInitialise(void)
 
 	// Initialize render engine
 	war_SetFog(war_GetFog());		// Set Fog mode based on user preferences
-	if (!pie_Initialise()) {
+	if (!pie_Initialise())
+	{
 		debug(LOG_ERROR, "Unable to initialise renderer");
 		return false;
 	}
@@ -465,10 +492,16 @@ BOOL systemInitialise(void)
 // ////////////////////////////////////////////////////////////////////////////
 // Called once at program shutdown.
 //
+extern char *mod_list;
+
 void systemShutdown(void)
 {
-//	unsigned int i;
+	if (mod_list)
+	{
+		free(mod_list);
+	}
 
+	closeLoadingScreen();
 	keyClearMappings();
 
 	// free up all the load functions (all the data should already have been freed)
@@ -476,7 +509,8 @@ void systemShutdown(void)
 
 	if (!multiShutdown()) // ajl. init net stuff
 	{
-		return;
+		debug(LOG_FATAL, "Unable to multiShutdown() cleanly!");
+		abort();
 	}
 
 	debug(LOG_MAIN, "shutting down audio subsystems");
@@ -486,7 +520,8 @@ void systemShutdown(void)
 
 	if ( audio_Disabled() == false && !audio_Shutdown() )
 	{
-		return;
+		debug(LOG_FATAL, "Unable to audio_Shutdown() cleanly!");
+		abort();
 	}
 
 	debug(LOG_MAIN, "shutting down graphics subsystem");
@@ -494,10 +529,15 @@ void systemShutdown(void)
 	levShutDown();
 	widgShutDown();
 	pie_TerrainCleanup();
-
 	fpathShutdown();
-
-	return;
+	debug(LOG_MAIN, "shutting down everything else");
+	pal_ShutDown();		// currently unused stub
+	frameShutDown();	// close screen / SDL / resources / cursors / trig
+	closeConfig();		// "registry" close
+	cleanSearchPath();	// clean PHYSFS search paths
+	debug_exit();		// cleanup debug routines
+	PHYSFS_deinit();	// cleanup PHYSFS (If failure, state of PhysFS is undefined, and probably badly screwed up.)
+	// NOTE: Exception handler is cleaned via atexit(ExchndlShutdown);
 }
 
 /***************************************************************************/
@@ -639,8 +679,6 @@ BOOL frontendShutdown(void)
 		return false;
 	}
 
-	releasePlayerPower();
-
 	interfaceShutDown();
 	scrShutDown();
 
@@ -667,6 +705,8 @@ BOOL frontendShutdown(void)
 	debug(LOG_TEXTURE, "=== frontendShutdown ===");
 	pie_TexShutDown();
 	pie_TexInit(); // ready for restart
+	freeComponentLists();
+	statsShutDown();
 
 	return true;
 }
@@ -766,14 +806,10 @@ BOOL stageOneInitialise(void)
 		return false;
 	}
 
-
-    if (!environInit())
-    {
-        return false;
-    }
-	// reset speed limiter
-	moveSetFormationSpeedLimiting(true);
-
+	if (!environInit())
+	{
+		return false;
+	}
 
 	initMission();
 	initTransporters();
@@ -818,7 +854,6 @@ BOOL stageOneShutDown(void)
 	grpShutDown();
 
 	formationShutDown();
-	releasePlayerPower();
 
 	ResearchRelease();
 
@@ -893,7 +928,7 @@ BOOL stageTwoInitialise(void)
 	if(!initMiscImds())			/* Set up the explosions */
 	{
 		iV_ShutDown();
-		debug( LOG_ERROR, "Can't find all the explosions graphics?" );
+		debug( LOG_FATAL, "Can't find all the explosions graphics?" );
 		abort();
 		return false;
 	}
@@ -1106,6 +1141,10 @@ BOOL stageThreeShutDown(void)
 {
 	debug(LOG_WZ, "== stageThreeShutDown ==");
 
+	challengesUp = false;
+	challengeActive = false;
+	isInGamePopupUp = false;
+
 	// make sure any button tips are gone.
 	widgReset();
 
