@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -92,9 +92,6 @@
 
 #define FORM_OPEN_ANIM_DURATION		(GAME_TICKS_PER_SEC/6) // Time duration for form open/close anims.
 
-//number of pulses in the blip for the radar
-#define NUM_PULSES			3
-
 //the loop default value
 #define DEFAULT_LOOP		1
 
@@ -1554,19 +1551,20 @@ void intDisplayButtonHilight(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset, W
 
 }
 
-// Flash one of two images depending on if the widget is hilighted by the mouse.
-//
+// Flash one of two images, regardless of whether or not it is highlighted
+// Commented-out portions are retained because I am planning on making the intensity of the
+// flash depend on whether or not the button is highlighted.
 void intDisplayButtonFlash(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset, WZ_DECL_UNUSED PIELIGHT *pColours)
 {
 	UDWORD x = xOffset+psWidget->x;
 	UDWORD y = yOffset+psWidget->y;
-	BOOL Hilight = false;
-	UDWORD Down = 0;
+	//BOOL Hilight = false;
+	//UDWORD Down = 0;
 	UWORD ImageID;
 
 	ASSERT( psWidget->type == WIDG_BUTTON,"intDisplayButtonFlash : Not a button" );
 
-	if( ((W_BUTTON*)psWidget)->state & WBUTS_HILITE)
+	/* if( ((W_BUTTON*)psWidget)->state & WBUTS_HILITE)
 	{
 		Hilight = true;
 	}
@@ -1574,14 +1572,13 @@ void intDisplayButtonFlash(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset, WZ_
 	if( ((W_BUTTON*)psWidget)->state & (WBUTS_DOWN | WBUTS_LOCKED | WBUTS_CLICKLOCK))
 	{
 		Down = 1;
-	}
+	} */
 
-
-	if ( Down && ((gameTime2/250) % 2 == 0) )
+	if ( /* Down && */ (gameTime2/250) % 2 == 0 )
 	{
 		ImageID = UNPACKDWORD_TRI_B(psWidget->UserData);
-		Hilight = false;
-	} else
+	}
+	else
 	{
 		ImageID = UNPACKDWORD_TRI_C(psWidget->UserData);
 	}
@@ -2950,7 +2947,11 @@ void intDisplayStatsBar(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset, WZ_DEC
 	/* draw text value */
 	sprintf(szVal, "%d", BarGraph->iOriginal);
 	iV_SetTextColour(WZCOL_TEXT_BRIGHT);
+#ifdef WZ_OS_MAC
+	iV_DrawText( szVal, x0, iY+2 );
+#else
 	iV_DrawText( szVal, x0, iY );
+#endif
 
 	//draw the comparison value - only if not zero
 	if (BarGraph->minorSize != 0)
@@ -3007,7 +3008,11 @@ void intDisplayDesignPowerBar(WIDGET *psWidget, UDWORD xOffset,
 	/* draw text value */
 	sprintf(szVal, "%d", BarGraph->iOriginal);
 	iV_SetTextColour(WZCOL_TEXT_BRIGHT);
+#ifdef WZ_OS_MAC
+	iV_DrawText( szVal, x0, iY+2 );
+#else
 	iV_DrawText( szVal, x0, iY );
+#endif
 
 	//draw the comparison value - only if not zero
 	if (BarGraph->minorSize != 0)
@@ -3129,6 +3134,12 @@ void drawRadarBlips(int radarX, int radarY, float pixSizeH, float pixSizeV)
 	UDWORD			delay = 150;
 	UDWORD			i;
 	SDWORD width, height;
+	int		x = 0, y = 0;
+	static const uint16_t imagesEnemy[] = {IMAGE_RAD_ENMREAD, IMAGE_RAD_ENM1, IMAGE_RAD_ENM2, IMAGE_RAD_ENM3};
+	static const uint16_t imagesResource[] = {IMAGE_RAD_RESREAD, IMAGE_RAD_RES1, IMAGE_RAD_RES2, IMAGE_RAD_RES3};
+	static const uint16_t imagesArtifact[] = {IMAGE_RAD_ARTREAD, IMAGE_RAD_ART1, IMAGE_RAD_ART2, IMAGE_RAD_ART3};
+	static const uint16_t imagesBurningResource[] = {IMAGE_RAD_BURNRESREAD, IMAGE_RAD_BURNRES1, IMAGE_RAD_BURNRES2, IMAGE_RAD_BURNRES3, IMAGE_RAD_BURNRES4, IMAGE_RAD_BURNRES5, IMAGE_RAD_BURNRES6};
+	static const uint16_t *const imagesProxTypes[] = {imagesEnemy, imagesResource, imagesArtifact};
 
 	// store the width & height of the radar/mini-map
 	width = scrollMaxX - scrollMinX;
@@ -3164,12 +3175,18 @@ void drawRadarBlips(int radarX, int radarY, float pixSizeH, float pixSizeV)
 	/* Go through all the proximity Displays */
 	for (psProxDisp = apsProxDisp[selectedPlayer]; psProxDisp != NULL; psProxDisp = psProxDisp->psNext)
 	{
-		PROX_TYPE	proxType;
-		int		x = 0, y = 0;
+		unsigned        animationLength = ARRAY_SIZE(imagesEnemy) - 1;  // Same size as imagesResource and imagesArtifact.
+		const uint16_t *images;
+
+		if (psProxDisp->psMessage->player != selectedPlayer)
+		{
+			continue;
+		}
 
 		if (psProxDisp->type == POS_PROXDATA)
 		{
-			proxType = ((VIEW_PROXIMITY*)((VIEWDATA *)psProxDisp->psMessage->pViewData)->pData)->proxType;
+			PROX_TYPE proxType = ((VIEW_PROXIMITY*)((VIEWDATA *)psProxDisp->psMessage->pViewData)->pData)->proxType;
+			images = imagesProxTypes[proxType];
 		}
 		else
 		{
@@ -3178,32 +3195,33 @@ void drawRadarBlips(int radarX, int radarY, float pixSizeH, float pixSizeV)
 			ASSERT(psFeature && psFeature->psStats, "Bad feature message");
 			if (psFeature && psFeature->psStats && psFeature->psStats->subType == FEAT_OIL_RESOURCE)
 			{
-				proxType = PROX_RESOURCE;
+				images = imagesResource;
+				if (fireOnLocation(psFeature->pos.x, psFeature->pos.y))
+				{
+					images = imagesBurningResource;
+					animationLength = ARRAY_SIZE(imagesBurningResource) - 1;  // Longer animation for burning oil wells.
+				}
 			}
 			else
 			{
-				proxType = PROX_ARTEFACT;
+				images = imagesArtifact;
 			}
 		}
 
 		// Draw the 'blips' on the radar - use same timings as radar blips if the message is read - don't animate
 		if (psProxDisp->psMessage->read)
 		{
-			imageID = IMAGE_RAD_ENM3 + (proxType * (NUM_PULSES + 1));
+			imageID = images[0];
 		}
 		else
 		{
 			// Draw animated
-			if ((gameTime2 - psProxDisp->timeLastDrawn) > delay)
+			if (gameTime2 - psProxDisp->timeLastDrawn > delay)
 			{
-				psProxDisp->strobe++;
-				if (psProxDisp->strobe > (NUM_PULSES-1))
-				{
-					psProxDisp->strobe = 0;
-				}
+				psProxDisp->strobe = (psProxDisp->strobe + 1) % animationLength;
 				psProxDisp->timeLastDrawn = gameTime2;
 			}
-			imageID = (UWORD)(IMAGE_RAD_ENM1 + psProxDisp->strobe + (proxType * (NUM_PULSES + 1)));
+			imageID = images[1 + psProxDisp->strobe];
 		}
 
 		if (psProxDisp->type == POS_PROXDATA)
@@ -3227,8 +3245,26 @@ void drawRadarBlips(int radarX, int radarY, float pixSizeH, float pixSizeV)
 		// NOTE:  On certain missions (limbo & expand), there is still valid data that is stored outside the
 		// normal radar/mini-map view.  We must now calculate the radar/mini-map's bounding box, and clip
 		// everything outside the box.
-		if ( (x+radarX) < width && (x+radarX) > -width 
-			&& (y+radarY) < height && (y+radarY) > -height)
+		if ( (x+radarX) < width*pixSizeV/2 && (x+radarX) > -width*pixSizeV/2 
+			&& (y+radarY) < height*pixSizeH/2 && (y+radarY) > -height*pixSizeH/2)
+		{
+			// Draw the 'blip'
+			iV_DrawImage(IntImages, imageID, x + radarX, y + radarY);
+		}
+	}
+	if (audio_GetPreviousQueueTrackRadarBlipPos(&x, &y))
+	{
+		unsigned        animationLength = ARRAY_SIZE(imagesEnemy) - 1;
+		int             strobe = (gameTime2/delay) % animationLength;
+		x = (x / TILE_UNITS - scrollMinX) * pixSizeH;
+		y = (y / TILE_UNITS - scrollMinY) * pixSizeV;
+		imageID = imagesEnemy[strobe];
+		
+		// NOTE:  On certain missions (limbo & expand), there is still valid data that is stored outside the
+		// normal radar/mini-map view.  We must now calculate the radar/mini-map's bounding box, and clip
+		// everything outside the box.
+		if ( (x+radarX) < width*pixSizeV/2 && (x+radarX) > -width*pixSizeV/2 
+			&& (y+radarY) < height*pixSizeH/2 && (y+radarY) > -height*pixSizeH/2)
 		{
 			// Draw the 'blip'
 			iV_DrawImage(IntImages, imageID, x + radarX, y + radarY);
@@ -3249,7 +3285,7 @@ void intDisplayProximityBlips(WIDGET *psWidget, WZ_DECL_UNUSED UDWORD xOffset,
 	ASSERT( psMsg->type == MSG_PROXIMITY, "Invalid message type" );
 
 	//if no data - ignore message
-	if (psMsg->pViewData == NULL)
+	if (psMsg->pViewData == NULL || psMsg->player != selectedPlayer)
 	{
 		return;
 	}
@@ -3319,7 +3355,6 @@ void intUpdateQuantitySlider(WIDGET *psWidget, W_CONTEXT *psContext)
 			if(Slider->pos > 0)
 			{
 				Slider->pos = (UWORD)(Slider->pos - sliderMouseUnit(Slider));
-				bUsingSlider = true;
 				SetMousePos(sliderMousePos(Slider), mouseY());	// move mouse
 			}
 		}
@@ -3328,7 +3363,6 @@ void intUpdateQuantitySlider(WIDGET *psWidget, W_CONTEXT *psContext)
 			if(Slider->pos < Slider->numStops)
 			{
 				Slider->pos = (UWORD)(Slider->pos + sliderMouseUnit(Slider));
-				bUsingSlider = true;
 				SetMousePos(sliderMousePos(Slider), mouseY());	// move mouse
 			}
 		}
