@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -60,9 +60,12 @@
 #include "multiplay.h"
 #include "lib/sound/cdaudio.h"
 #include "lib/sequence/sequence.h"
+#include "lib/sound/track.h"
 
 #include "scriptextern.h"
 
+#include "multimenu.h"
+
 //#define NO_VIDEO
 
 /* Intelligence Map screen IDs */
@@ -287,6 +290,11 @@ BOOL intAddIntelMap(void)
 		return false;
 	}
 
+	if (bMultiPlayer && !MultiMenuUp && !playCurrent)
+	{
+		intAddMultiMenu();
+	}
+
 	return true;
 }
 
@@ -489,7 +497,11 @@ BOOL intAddMessageView(MESSAGE * psMessage)
 		intRemoveMessageView(false);
 		Animate = false;
 	}
-
+	if (MultiMenuUp)
+	{
+		intCloseMultiMenuNoAnim();
+	}
+	
 	/* Add the base form */
 	memset(&sFormInit, 0, sizeof(W_FORMINIT));
 	sFormInit.formID = 0;
@@ -702,6 +714,14 @@ void intProcessIntelMap(UDWORD id)
 		//if close button pressed on 3D View then close the view only
 		psCurrentMsg = NULL;
 		intRemoveMessageView(true);
+		if (bMultiPlayer && !MultiMenuUp)
+		{
+			intAddMultiMenu();
+		}
+	}
+	else if (MultiMenuUp)
+	{
+		intProcessMultiMenu(id);
 	}
 }
 
@@ -947,32 +967,39 @@ void intIntelButtonPressed(BOOL proxMsg, UDWORD id)
 			if (psResearch != NULL)
 			{
 				static const float maxVolume = 1.f;
+				static AUDIO_STREAM *playing = NULL;
+
+				// only play the sample once, otherwise, they tend to overlap each other
+				if (sound_isStreamPlaying(playing))
+				{
+					sound_StopStream(playing);
+				}
 
 				switch(psResearch->iconID)
 				{
 				case IMAGE_RES_DROIDTECH:
-					audio_PlayStream("sequenceaudio/res_droid.ogg", maxVolume, NULL, NULL);
+					playing = audio_PlayStream("sequenceaudio/res_droid.ogg", maxVolume, NULL, NULL);
 						break;
 				case IMAGE_RES_WEAPONTECH:
-					audio_PlayStream("sequenceaudio/res_weapons.ogg", maxVolume, NULL, NULL);
+					playing = audio_PlayStream("sequenceaudio/res_weapons.ogg", maxVolume, NULL, NULL);
 						break;
 				case IMAGE_RES_COMPUTERTECH:
-					audio_PlayStream("sequenceaudio/res_com.ogg", maxVolume, NULL, NULL);
+					playing = audio_PlayStream("sequenceaudio/res_com.ogg", maxVolume, NULL, NULL);
 						break;
 				case IMAGE_RES_POWERTECH:
-					audio_PlayStream("sequenceaudio/res_pow.ogg", maxVolume, NULL, NULL);
+					playing = audio_PlayStream("sequenceaudio/res_pow.ogg", maxVolume, NULL, NULL);
 						break;
 				case IMAGE_RES_SYSTEMTECH:
-					audio_PlayStream("sequenceaudio/res_systech.ogg", maxVolume, NULL, NULL);
+					playing = audio_PlayStream("sequenceaudio/res_systech.ogg", maxVolume, NULL, NULL);
 						break;
 				case IMAGE_RES_STRUCTURETECH:
-					audio_PlayStream("sequenceaudio/res_strutech.ogg", maxVolume, NULL, NULL);
+					playing = audio_PlayStream("sequenceaudio/res_strutech.ogg", maxVolume, NULL, NULL);
 						break;
 				case IMAGE_RES_CYBORGTECH:
-					audio_PlayStream("sequenceaudio/res_droid.ogg", maxVolume, NULL, NULL);
+					playing = audio_PlayStream("sequenceaudio/res_droid.ogg", maxVolume, NULL, NULL);
 						break;
 				case IMAGE_RES_DEFENCE:
-					audio_PlayStream("sequenceaudio/res_strutech.ogg", maxVolume, NULL, NULL);
+					playing = audio_PlayStream("sequenceaudio/res_strutech.ogg", maxVolume, NULL, NULL);
 						break;
 				}
 			}
@@ -1048,6 +1075,11 @@ void intRemoveIntelMap(void)
 	//remove the text label
 	widgDelete(psWScreen, IDINTMAP_PAUSELABEL);
 
+	if (bMultiPlayer && MultiMenuUp)
+	{
+		intCloseMultiMenu();
+	}
+	
 	intCleanUpIntelMap();
 }
 
@@ -1067,6 +1099,11 @@ void intRemoveIntelMapNoAnim(void)
 	//remove the text label
 	widgDelete(psWScreen, IDINTMAP_PAUSELABEL);
 
+	if (bMultiPlayer && MultiMenuUp)
+	{
+		intCloseMultiMenuNoAnim();
+	}
+
 	intCleanUpIntelMap();
 }
 
@@ -1129,7 +1166,7 @@ void intDisplayMessageButton(WIDGET *psWidget, UDWORD xOffset,
 
 	// Get the object associated with this widget.
 	psMsg = (MESSAGE *)psBuffer->Data;
-	ASSERT( psMsg != NULL, "psBuffer->Data empty. Why?" );
+	ASSERT_OR_RETURN( , psMsg != NULL, "psBuffer->Data empty. Why?" );
 	//shouldn't have any proximity messages here...
 	if (psMsg->type == MSG_PROXIMITY)
 	{
