@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -253,21 +253,6 @@ enum {
 	IMAGE_ASCII124,
 	IMAGE_ASCII125,
 	IMAGE_ASCII126,
-	IMAGE_CURSOR_ATTACK,
-	IMAGE_CURSOR_SELECT,
-	IMAGE_CURSOR_LOCKON,
-	IMAGE_CURSOR_ECM,
-	IMAGE_CURSOR_DEFAULT,
-	IMAGE_CURSOR_BUILD,
-	IMAGE_CURSOR_MOVE,
-	IMAGE_CURSOR_GUARD,
-	IMAGE_CURSOR_EMBARK,
-	IMAGE_CURSOR_BRIDGE,
-	IMAGE_CURSOR_ATTACH,
-	IMAGE_CURSOR_FIX,
-	IMAGE_CURSOR_REPAIR,
-	IMAGE_CURSOR_PICKUP,
-	IMAGE_CURSOR_NOTPOS,
 	IMAGE_SIDETAB,
 	IMAGE_SIDETABHI,
 	IMAGE_SIDETABDOWN,
@@ -373,7 +358,6 @@ enum {
 	IMAGE_DES_EDITBOXRIGHT,
 	IMAGE_DES_EDITBOXMIDH,
 	IMAGE_DES_EDITBOXRIGHTH,
-	IMAGE_CURSOR_DEST,
 	IMAGE_RES_CYBORGTECH,
 	IMAGE_LOOP_UP,
 	IMAGE_LOOP_DOWN,
@@ -534,7 +518,34 @@ enum {
 	IMAGE_EDIT_RESEARCH_DOWN,
 	IMAGE_EDIT_MANUFACTURE_UP,
 	IMAGE_EDIT_MANUFACTURE_DOWN,
-	RADAR_NORTH
+	RADAR_NORTH,
+	IMAGE_CURSOR_EMBARK,
+	IMAGE_CURSOR_DEST,
+	IMAGE_CURSOR_DEFAULT,
+	IMAGE_CURSOR_BUILD,
+	IMAGE_CURSOR_SCOUT,
+	IMAGE_CURSOR_DISEMBARK,
+	IMAGE_CURSOR_ATTACK,
+	IMAGE_CURSOR_GUARD,
+	IMAGE_CURSOR_FIX,
+	IMAGE_CURSOR_SELECT,
+	IMAGE_CURSOR_REPAIR,
+	IMAGE_CURSOR_PICKUP,
+	IMAGE_CURSOR_NOTPOS,
+	IMAGE_CURSOR_MOVE,
+	IMAGE_CURSOR_LOCKON,
+	IMAGE_CURSOR_ECM,
+	IMAGE_CURSOR_ATTACH,
+	IMAGE_CURSOR_BRIDGE,
+	IMAGE_CURSOR_BOMB,
+	IMAGE_SLIDER_AI,
+	IMAGE_RAD_BURNRESREAD,
+	IMAGE_RAD_BURNRES1,
+	IMAGE_RAD_BURNRES2,
+	IMAGE_RAD_BURNRES3,
+	IMAGE_RAD_BURNRES4,
+	IMAGE_RAD_BURNRES5,
+	IMAGE_RAD_BURNRES6
 };
 
 #endif // __INCLUDED_SRC_INTFAC_H__
