@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #include "lib/framework/frame.h"
 #include "lib/framework/strres.h"
 #include "lib/framework/stdio_ext.h"
+#include "lib/framework/utf.h"
 #include "objects.h"
 #include "basedef.h"
 #include "map.h"
@@ -89,6 +90,8 @@
 #include "aiexperience.h"	/* for console commands */
 #include "scriptfuncs.h"
 #include "clparse.h"
+#include "research.h"
+#include <time.h>
 
 /*
 	KeyBind.c
@@ -253,7 +256,164 @@ void	kf_FaceWest(void)
 	}
 }
 // --------------------------------------------------------------------------
+// Dump out all templates for each player, and the AI templates as well to the
+// standard csv format file.
+void	kf_DebugTemplates(void)
+{
+	DROID_TEMPLATE	*templatelist = NULL;
+	PHYSFS_file	*pFileHandle = NULL;
+	int i, numPlayers;
+	char filename[256] = {'\0'};
+	char outbuf[1024] = {'\0'};
+	char templateName[MAX_STR_LENGTH] = {'\0'};
+	char templateMID[MAX_STR_LENGTH] = {'\0'};
+	char *compBody;
+	char *compBrain;
+	char *compConstruct;
+	char *compECM;
+	char *compPropulsion;
+	char *compRepair;
+	char *compSensor;
+	char templateType[MAX_STR_LENGTH] = {'\0'};
+	char playerID[MAX_STR_LENGTH] = {'\0'};
+	char numWeapons[MAX_STR_LENGTH] = {'\0'};
 
+	time_t aclock;
+	struct tm *newtime;
+
+	static const char *Tlist[]=
+	{
+		"DROID",
+		"DROID_SENSOR",
+		"DROID_ECM",
+		"DROID_CONSTRUCT",
+		"PERSON",
+		"CYBORG",
+		"TRANSPORTER",
+		"DROID_COMMAND",
+		"DROID_REPAIR",
+		"ZNULLDROID",
+		"CYBORG_CONSTRUCT",
+		"CYBORG_REPAIR",
+		"CYBORG_SUPER",
+		"DROID_ANY",
+	};
+
+
+	time( &aclock );					// Get time in seconds
+	newtime = localtime( &aclock );		// Convert time to struct
+
+	// we use 1 for SP games, and maxPlayers for MP games, and trap it so we don't exceed MAX_PLAYERS --not that this should be possible
+	numPlayers = MIN((game.maxPlayers == 0) ? 1 : game.maxPlayers, MAX_PLAYERS) ;
+	for (i=0; i < numPlayers; i++)
+	{
+		if (!isHumanPlayer(i)) continue;	// skip AI players--this file would be empty.
+		snprintf(filename, sizeof(filename), "logs/template_%02d-%s_%02d%02d%02d.txt",i, game.map, newtime->tm_hour, newtime->tm_min, newtime->tm_sec );
+		pFileHandle = PHYSFS_openWrite(filename); // open the file
+		if (!pFileHandle)
+		{
+			debug(LOG_POPUP, "Could not create template file %s: %s", filename, PHYSFS_getLastError());
+			return;
+		}
+
+		templatelist = apsDroidTemplates[i];
+		while (templatelist)
+		{
+			if (templatelist->pName)
+			{
+				sprintf(templateName, "%s", templatelist->pName);
+			}
+			else if (templatelist->aName)
+			{
+				sprintf(templateName, "%s", templatelist->aName);
+			}
+			else
+			{
+				sprintf(templateName, "(null)");
+			}
+			sprintf(templateMID, "%d", templatelist->multiPlayerID);
+			compBody = RemakeTemplate(templatelist, (COMPONENT_STATS *)asBodyStats, COMP_BODY);
+			compBrain = RemakeTemplate(templatelist, (COMPONENT_STATS *)asBrainStats, COMP_BRAIN);
+			compConstruct = RemakeTemplate(templatelist, (COMPONENT_STATS *)asConstructStats, COMP_CONSTRUCT);
+			compECM = RemakeTemplate(templatelist, (COMPONENT_STATS *)asECMStats, COMP_ECM);
+			compPropulsion = RemakeTemplate(templatelist, (COMPONENT_STATS *)asPropulsionStats, COMP_PROPULSION);
+			compRepair = RemakeTemplate(templatelist, (COMPONENT_STATS *)asRepairStats, COMP_REPAIRUNIT);
+			compSensor = RemakeTemplate(templatelist, (COMPONENT_STATS *)asSensorStats, COMP_SENSOR);
+			sprintf(playerID, "0");		// 0 for humans.
+			sprintf(templateType, "%s", Tlist[templatelist->droidType]);
+			sprintf(numWeapons, "%d", templatelist->numWeaps);
+
+			sprintf(outbuf, "%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n", templateName, templateMID, compBody, compBrain, compConstruct,
+				compECM, playerID, compPropulsion, compRepair, templateType, compSensor, numWeapons );
+			PHYSFS_write(pFileHandle, outbuf, strlen(outbuf), 1);
+
+			templatelist = templatelist->psNext;
+		}
+	}
+
+	if (pFileHandle && !PHYSFS_close(pFileHandle))
+	{
+		debug(LOG_POPUP, "Could not close template file: %s", PHYSFS_getLastError());
+		return;
+	}
+	pFileHandle = NULL;
+
+	snprintf(filename, sizeof(filename), "logs/templateAI-%s_%02d%02d%02d.txt", game.map, newtime->tm_hour, newtime->tm_min, newtime->tm_sec );
+	pFileHandle = PHYSFS_openWrite(filename); // open the file
+	if (!pFileHandle)
+	{
+		debug(LOG_POPUP, "Could not create templateAI file %s: %s", filename, PHYSFS_getLastError());
+		return;
+	}
+
+	templatelist = apsStaticTemplates;		//AI templates
+	while (templatelist)
+	{
+		if (templatelist->pName)
+		{
+			sprintf(templateName, "%s", templatelist->pName);
+		}
+		else if (templatelist->aName)
+		{
+			sprintf(templateName, "%s", templatelist->aName);
+		}
+		else
+		{
+			sprintf(templateName, "(null)");
+		}
+		sprintf(templateMID, "%d", templatelist->multiPlayerID);
+		compBody = RemakeTemplate(templatelist, (COMPONENT_STATS *)asBodyStats, COMP_BODY);
+		compBrain = RemakeTemplate(templatelist, (COMPONENT_STATS *)asBrainStats, COMP_BRAIN);
+		compConstruct = RemakeTemplate(templatelist, (COMPONENT_STATS *)asConstructStats, COMP_CONSTRUCT);
+		compECM = RemakeTemplate(templatelist, (COMPONENT_STATS *)asECMStats, COMP_ECM);
+		compPropulsion = RemakeTemplate(templatelist, (COMPONENT_STATS *)asPropulsionStats, COMP_PROPULSION);
+		compRepair = RemakeTemplate(templatelist, (COMPONENT_STATS *)asRepairStats, COMP_REPAIRUNIT);
+		compSensor = RemakeTemplate(templatelist, (COMPONENT_STATS *)asSensorStats, COMP_SENSOR);
+
+		sprintf(playerID, "3");		// AI's always have "3" now
+		sprintf(templateType, "%s", Tlist[templatelist->droidType]);
+		sprintf(numWeapons, "%d", templatelist->numWeaps);
+
+		sprintf(outbuf, "%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n", templateName, templateMID, compBody, compBrain, compConstruct,
+			compECM, playerID, compPropulsion, compRepair, templateType, compSensor, numWeapons );
+		PHYSFS_write(pFileHandle, outbuf, strlen(outbuf), 1);
+
+		templatelist = templatelist->psNext;
+	}
+
+	if (!PHYSFS_close(pFileHandle))
+	{
+		debug(LOG_POPUP, "Could not close templateAI file: %s", PHYSFS_getLastError());
+		return;
+	}
+	{
+		char *cmsg;
+		sasprintf((char**)&cmsg, _("(Player %u) has detected the borg 'legs' bug! Please enter legs in your console and upload the files to us!"), selectedPlayer);
+		sendTextMessage(cmsg, true);
+		sprintf(outbuf, "The logs are located here: %s", filename);
+		addConsoleMessage(outbuf, LEFT_JUSTIFY, NOTIFY_MESSAGE);
+	}
+}
 /* Writes out debug info about all the selected droids */
 void	kf_DebugDroidInfo( void )
 {
@@ -268,6 +428,76 @@ DROID	*psDroid;
 	}
 }
 
+void	kf_CloneSelected( void )
+{
+	DROID		*psDroid, *psNewDroid = NULL;
+	DROID_TEMPLATE	sTemplate;
+	DROID_TEMPLATE	*sTemplate2 = NULL;
+	const int	limit = 10;	// make 10 clones
+	int		i, impact_side;
+	const char* msg;
+
+#ifndef DEBUG
+	// Bail out if we're running a _true_ multiplayer game (to prevent MP cheating)
+	if (runningMultiplayer())
+	{
+		noMPCheatMsg();
+		return;
+	}
+#endif
+
+	for (psDroid = apsDroidLists[selectedPlayer]; psDroid; psDroid=psDroid->psNext)
+	{
+		for (i = 0; psDroid->selected && i < limit; i++)
+		{
+			// create a template based on the droid
+			if (!sTemplate2)
+			{
+				sTemplate2 = GetHumanDroidTemplate(psDroid->aName);
+				if (!sTemplate2)
+				{	// we now search the AI template list (apsStaticTemplates)
+					sTemplate2 = GetAIDroidTemplate(psDroid->aName);
+				}
+			}
+			if (!sTemplate2)
+			{
+				debug(LOG_ERROR, "We can't find the template for this droid: %s, id:%u, type:%d!", psDroid->aName, psDroid->id, psDroid->droidType);
+				return;
+			}
+			memcpy(&sTemplate, sTemplate2, sizeof(DROID_TEMPLATE));
+			templateSetParts(psDroid, &sTemplate);
+
+			// create a new droid
+			psNewDroid = buildDroid(&sTemplate, psDroid->pos.x, psDroid->pos.y, psDroid->player, false);
+			ASSERT_OR_RETURN(, psNewDroid != NULL, "Unable to build a unit");
+			addDroid(psNewDroid, apsDroidLists);
+			psNewDroid->body = psDroid->body;
+			for (impact_side = 0; impact_side < NUM_HIT_SIDES; impact_side=impact_side+1)
+			{
+				psNewDroid->armour[impact_side][WC_KINETIC] = psDroid->armour[impact_side][WC_KINETIC];
+				psNewDroid->armour[impact_side][WC_HEAT] = psDroid->armour[impact_side][WC_HEAT];
+			}
+			psNewDroid->experience = psDroid->experience;
+			psNewDroid->direction = psDroid->direction;
+			if (!(psNewDroid->droidType == DROID_PERSON || cyborgDroid(psNewDroid) || psNewDroid->droidType == DROID_TRANSPORTER))
+			{
+				updateDroidOrientation(psNewDroid);
+			}
+		}
+		if (psNewDroid)
+		{
+			// Send a text message to all players, notifying them of
+			// the fact that we're cheating ourselves a new droid army
+			sasprintf((char**)&msg, _("Player %u is cheating him/herself a new droid army of %s(s)."), selectedPlayer, psNewDroid->aName);
+			sendTextMessage(msg, true);
+			audio_PlayTrack(ID_SOUND_NEXUS_LAUGH1);
+			sTemplate2 = NULL;
+			psNewDroid = NULL;
+			Cheated = true;
+		}
+	}
+}
+
 // --------------------------------------------------------------------------
 //
 ///* Prints out the date and time of the build of the game */
@@ -326,7 +556,7 @@ void	kf_UpThePower( void )
 		noMPCheatMsg();
 		return;
 	}
-	asPower[selectedPlayer].currentPower+=1000;
+	addPower(selectedPlayer, 1000);
 	sasprintf((char**)&cmsg, _("(Player %u) is using cheat :%s"),
 				selectedPlayer, _("1000 big ones!!!"));
 	sendTextMessage(cmsg, true);
@@ -343,7 +573,7 @@ void	kf_MaxPower( void )
 		noMPCheatMsg();
 		return;
 	}
-	asPower[selectedPlayer].currentPower = SDWORD_MAX / 2;
+	setPower(selectedPlayer, 100000);
 	sasprintf((char**)&cmsg, _("(Player %u) is using cheat :%s"),
 				selectedPlayer, _("Power overwhelming"));
 	sendTextMessage(cmsg, true);
@@ -421,7 +651,10 @@ void kf_ToggleOrders(void)	// Displays orders & action of currently selected uni
 		showORDERS = !showORDERS;
 		CONPRINTF(ConsoleString, (ConsoleString, "Unit Order/Action displayed is %s", showORDERS ? "Enabled" : "Disabled"));
 }
-
+void kf_ToggleLevelName(void) // toggles level name 
+{
+	showLevelName = !showLevelName;
+}
 /* Writes out the frame rate */
 void	kf_FrameRate( void )
 {
@@ -742,7 +975,7 @@ void	kf_ZoomOut( void )
 // --------------------------------------------------------------------------
 void	kf_RadarZoomIn( void )
 {
-	float RadarZoomLevel = GetRadarZoom();
+	uint8_t RadarZoomLevel = GetRadarZoom();
 
 	if(RadarZoomLevel < MAX_RADARZOOM)
 	{
@@ -750,15 +983,11 @@ void	kf_RadarZoomIn( void )
 		SetRadarZoom(RadarZoomLevel);
 		audio_PlayTrack( ID_SOUND_BUTTON_CLICK_5 );
 	}
-	else	// at maximum already
-	{
-		audio_PlayTrack( ID_SOUND_BUILD_FAIL );
-	}
 }
 // --------------------------------------------------------------------------
 void	kf_RadarZoomOut( void )
 {
-	float RadarZoomLevel = GetRadarZoom();
+	uint8_t RadarZoomLevel = GetRadarZoom();
 
 	if (RadarZoomLevel > MIN_RADARZOOM)
 	{
@@ -766,10 +995,6 @@ void	kf_RadarZoomOut( void )
 		SetRadarZoom(RadarZoomLevel);
 		audio_PlayTrack( ID_SOUND_BUTTON_CLICK_5 );
 	}
-	else	// at minimum already
-	{
-		audio_PlayTrack( ID_SOUND_BUILD_FAIL );
-	}
 }
 // --------------------------------------------------------------------------
 // --------------------------------------------------------------------------
@@ -1043,7 +1268,10 @@ void	kf_ToggleDroidInfo( void )
 void	kf_addInGameOptions( void )
 {
 		setWidgetsStatus(true);
-		intAddInGameOptions();
+		if (!isInGamePopupUp)	// they can *only* quit when popup is up.
+		{
+			intAddInGameOptions();
+		}
 }
 // --------------------------------------------------------------------------
 /* Tell the scripts to start a mission*/
@@ -1178,21 +1406,18 @@ void	kf_ToggleDebugMappings( void )
 	}
 #endif
 
-	if (bAllowDebugMode)
+	if (getDebugMappingStatus())
 	{
-		if(getDebugMappingStatus())
-		{
-			processDebugMappings(false);
-		}
-		else
-		{
-			game_SetValidityKey(VALIDITYKEY_CHEAT_MODE);
-			processDebugMappings(true);
-		}
-		sasprintf((char**)&cmsg, _("(Player %u) is using cheat :%s"), selectedPlayer,
-			 getDebugMappingStatus() ? _("CHEATS ARE NOW ENABLED!") : _("CHEATS ARE NOW DISABLED!"));
-		sendTextMessage(cmsg, true);
+		processDebugMappings(false);
 	}
+	else
+	{
+		game_SetValidityKey(VALIDITYKEY_CHEAT_MODE);
+		processDebugMappings(true);
+	}
+	sasprintf((char**)&cmsg, _("(Player %u) is using cheat :%s"), selectedPlayer,
+		 getDebugMappingStatus() ? _("CHEATS ARE NOW ENABLED!") : _("CHEATS ARE NOW DISABLED!"));
+	sendTextMessage(cmsg, true);
 }
 // --------------------------------------------------------------------------
 
@@ -1263,6 +1488,17 @@ void	kf_SeekNorth( void )
 	CONPRINTF(ConsoleString,(ConsoleString,_("View Aligned to North")));
 }
 
+void kf_toggleTrapCursor(void)
+{
+	const char *msg;
+	bool trap = !war_GetTrapCursor();
+	war_SetTrapCursor(trap);
+	SDL_WM_GrabInput(trap ? SDL_GRAB_ON : SDL_GRAB_OFF);
+	sasprintf((char**)&msg, _("Trap cursor %s"), trap ? "ON" : "OFF");
+	addConsoleMessage(msg, DEFAULT_JUSTIFY, SYSTEM_MESSAGE);
+}
+
+
 // --------------------------------------------------------------------------
 void	kf_TogglePauseMode( void )
 {
@@ -1523,12 +1759,12 @@ void	kf_ToggleOverlays( void )
 
 void	kf_SensorDisplayOn( void )
 {
-	bDisplaySensorRange = true;
+	// Now a placeholder for future stuff
 }
 
 void	kf_SensorDisplayOff( void )
 {
-	bDisplaySensorRange = false;
+	// Now a placeholder for future stuff
 }
 
 
@@ -1749,6 +1985,7 @@ void	kf_KillEnemy( void )
 	sasprintf((char**)&cmsg, _("(Player %u) is using cheat :%s"),
 				selectedPlayer, _("All enemies destroyed by cheating!"));
 	sendTextMessage(cmsg, true);
+	Cheated = true;
 
 	for (player = 0; player < MAX_PLAYERS; player++)
 	{
@@ -1791,6 +2028,9 @@ void kf_KillSelected(void)
 	sendTextMessage(cmsg, true);
 
 	debug(LOG_DEATH, "Destroying selected droids and structures");
+	audio_PlayTrack(ID_SOUND_COLL_DIE);
+	Cheated = true;
+
 	for(psCDroid=apsDroidLists[selectedPlayer]; psCDroid; psCDroid=psNDroid)
 	{
 		psNDroid = psCDroid->psNext;
@@ -1836,22 +2076,13 @@ void kf_ShowGridInfo(void)
 	}
 }
 
-
-// --------------------------------------------------------------------------
-void kf_GiveTemplateSet(void)
-{
-	addTemplateSet(4,0);
-	addTemplateSet(4,1);
-	addTemplateSet(4,2);
-	addTemplateSet(4,3);
-}
-
 // --------------------------------------------------------------------------
 // Chat message. NOTE THIS FUNCTION CAN DISABLE ALL OTHER KEYPRESSES
 void kf_SendTextMessage(void)
 {
-	char	ch;
+	UDWORD	ch;
 	char tmp[MAX_CONSOLE_STRING_LENGTH + 100];
+	utf_32_char unicode;
 
 	if(bAllowOtherKeyPresses)									// just starting.
 	{
@@ -1861,11 +2092,13 @@ void kf_SendTextMessage(void)
 		inputClearBuffer();
 	}
 
-	ch = (char)inputGetKey();
+	ch = inputGetKey(&unicode);
 	while (ch != 0)												// in progress
 	{
-		// Kill if they hit return - it maxes out console or it's more than one line long
-		if ((ch == INPBUF_CR) || (strlen(sTextToSend)>=MAX_CONSOLE_STRING_LENGTH-16) // Prefixes with ERROR: and terminates with '?'
+		// FIXME: Why are we using duplicate defines? INPBUF_CR == KEY_RETURN == SDLK_RETURN
+
+		// Kill if they hit return or keypad enter or it maxes out console or it's more than one line long
+		if ((ch == INPBUF_CR) || (ch == SDLK_KP_ENTER) || (strlen(sTextToSend)>=MAX_CONSOLE_STRING_LENGTH-16) // Prefixes with ERROR: and terminates with '?'
 		 || iV_GetTextWidth(sTextToSend) > (pie_GetVideoBufferWidth()-64))// sendit
 		{
 			bAllowOtherKeyPresses = true;
@@ -1895,10 +2128,7 @@ void kf_SendTextMessage(void)
 			if (runningMultiplayer())
 			{
 				sendTextMessage(sTextToSend,false);
-				if (getDebugMappingStatus())
-				{
-					attemptCheatCode(sTextToSend);
-				}
+				attemptCheatCode(sTextToSend);
 			}
 			else
 			{
@@ -1920,10 +2150,7 @@ void kf_SendTextMessage(void)
 					}
 				}
 
-				if (getDebugMappingStatus())
-				{
-					attemptCheatCode(sTextToSend);
-				}
+				attemptCheatCode(sTextToSend);
 			}
 			return;
 		}
@@ -1931,7 +2158,10 @@ void kf_SendTextMessage(void)
 		{
 			if(sTextToSend[0] != '\0')							// cant delete nothing!
 			{
-				sTextToSend[strlen(sTextToSend)-1]= '\0';
+				size_t newlen = strlen(sTextToSend) - 1;
+				while(newlen > 0 && (sTextToSend[newlen]&0xC0) == 0x80)
+				    --newlen;  // Don't delete half a unicode character.
+				sTextToSend[newlen]= '\0';
 				sstrcpy(sCurrentConsoleText, sTextToSend);		//beacons
 			}
 		}
@@ -1944,13 +2174,14 @@ void kf_SendTextMessage(void)
 		}
 		else							 						// display
 		{
-			const char input_char[2] = { inputGetCharKey(), '\0' };
-
-			sstrcat(sTextToSend, input_char);
+			const utf_32_char input_char[2] = { unicode, '\0' };
+			char *utf = UTF32toUTF8(input_char, NULL);
+			sstrcat(sTextToSend, utf);
+			free(utf);
 			sstrcpy(sCurrentConsoleText, sTextToSend);
 		}
 
-		ch = (char)inputGetKey();
+		ch = inputGetKey(&unicode);
 	}
 
 	// macro store stuff
@@ -2183,6 +2414,12 @@ void	kf_SetDroidMoveHold( void )
 	}
 }
 
+// --------------------------------------------------------------------------
+void	kf_SetDroidMoveGuard( void )
+{
+	kfsf_SetSelectedDroidsState(DSO_HALTTYPE,DSS_HALT_GUARD);
+}
+
 // --------------------------------------------------------------------------
 void	kf_SetDroidMovePursue( void )
 {
@@ -2201,6 +2438,12 @@ void	kf_SetDroidReturnToBase( void )
 	kfsf_SetSelectedDroidsState(DSO_RETURN_TO_LOC,DSS_RTL_BASE);
 }
 
+// --------------------------------------------------------------------------
+void	kf_SetDroidGoToTransport( void )
+{
+	kfsf_SetSelectedDroidsState(DSO_RETURN_TO_LOC,DSS_RTL_TRANSPORT);
+}
+
 // --------------------------------------------------------------------------
 void	kf_SetDroidGoForRepair( void )
 {
@@ -2321,17 +2564,7 @@ UDWORD		xJump = 0, yJump = 0;
 // --------------------------------------------------------------------------
 void kf_ToggleFormationSpeedLimiting( void )
 {
-	// THIS IS NOT A CHEAT
-
-	if ( moveFormationSpeedLimitingOn() )
-	{
-		addConsoleMessage(_("Formation speed limiting OFF"),LEFT_JUSTIFY, SYSTEM_MESSAGE);
-	}
-	else
-	{
-		addConsoleMessage(_("Formation speed limiting ON"),LEFT_JUSTIFY, SYSTEM_MESSAGE);
-	}
-	moveToggleFormationSpeedLimiting();
+	addConsoleMessage(_("Formation speed limiting has been removed from the game due to bugs."), LEFT_JUSTIFY, SYSTEM_MESSAGE);
 }
 
 // --------------------------------------------------------------------------
@@ -2380,10 +2613,12 @@ void	kf_ToggleMouseInvert( void )
 	if(getInvertMouseStatus())
 	{
 		setInvertMouseStatus(false);
+		CONPRINTF(ConsoleString,(ConsoleString,_("Vertical rotation direction: Normal")));
 	}
 	else
 	{
 		setInvertMouseStatus(true);
+		CONPRINTF(ConsoleString,(ConsoleString,_("Vertical rotation direction: Flipped")));
 	}
 }
 // --------------------------------------------------------------------------
@@ -2392,10 +2627,12 @@ void	kf_ToggleShakeStatus( void )
 	if(getShakeStatus())
 	{
 		setShakeStatus(false);
+		CONPRINTF(ConsoleString,(ConsoleString,_("Screen shake when things die: Off")));
 	}
 	else
 	{
 		setShakeStatus(true);
+		CONPRINTF(ConsoleString,(ConsoleString,_("Screen shake when things die: On")));
 	}
 }
 // --------------------------------------------------------------------------
@@ -2439,7 +2676,9 @@ void kf_SpeedUp( void )
 	if (runningMultiplayer() || bInTutorial)
 	{
 		if (!bInTutorial)
-			noMPCheatMsg();
+		{
+			addConsoleMessage(_("Sorry, but game speed cannot be changed in multiplayer."), DEFAULT_JUSTIFY, SYSTEM_MESSAGE);
+		}
 		return;
 	}
 
@@ -2480,7 +2719,9 @@ void kf_SlowDown( void )
 	if (runningMultiplayer() || bInTutorial)
 	{
 		if (!bInTutorial)
-			noMPCheatMsg();
+		{
+			addConsoleMessage(_("Sorry, but game speed cannot be changed in multiplayer."), DEFAULT_JUSTIFY, SYSTEM_MESSAGE);
+		}
 		return;
 	}
 
@@ -2562,8 +2803,12 @@ void kf_ToggleRadarAllyEnemy(void)
 
 void kf_ToggleRadarTerrain(void)
 {
-	radarDrawMode = radarDrawMode + 1;
+	radarDrawMode = (RADAR_DRAW_MODE)(radarDrawMode + 1);
 
+	if (radarDrawMode == RADAR_MODE_TERRAIN_SEEN && getRevealStatus())
+	{
+		radarDrawMode = (RADAR_DRAW_MODE)(radarDrawMode + 1);  // skip this radar mode for fog of war mode
+	}
 	if (radarDrawMode >= NUM_RADAR_MODES)
 	{
 		radarDrawMode = 0;
@@ -2579,6 +2824,9 @@ void kf_ToggleRadarTerrain(void)
 		case RADAR_MODE_TERRAIN:
 			CONPRINTF(ConsoleString, (ConsoleString, _("Radar showing terrain")));
 			break;
+		case RADAR_MODE_TERRAIN_SEEN:
+			CONPRINTF(ConsoleString, (ConsoleString, _("Radar showing revealed terrain")));
+			break;
 		case RADAR_MODE_HEIGHT_MAP:
 			CONPRINTF(ConsoleString, (ConsoleString, _("Radar showing height")));
 			break;
@@ -2586,8 +2834,6 @@ void kf_ToggleRadarTerrain(void)
 			assert(false);
 			break;
 	}
-
-	resetRadarRedraw();
 }
 
 
