@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@ extern void	kf_BuildInfo( void );
 extern void	kf_ToggleFPS(void);			//FPS counter NOT same as kf_Framerate! -Q
 extern void	kf_ToggleSamples(void);		// Displays # of sound samples in Queue/list.
 extern void kf_ToggleOrders(void);		//displays unit's Order/action state.
+extern void kf_ToggleLevelName(void);
 extern void	kf_FrameRate( void );
 extern void	kf_ShowNumObjects( void );
 extern void	kf_ToggleRadar( void );
@@ -101,6 +102,7 @@ extern void	kf_SeekNorth( void );
 extern void	kf_MaxScrollLimits( void );
 extern void	kf_LevelSea( void );
 extern void	kf_TestWater( void );
+extern void	kf_toggleTrapCursor(void);
 extern void	kf_TogglePauseMode( void );
 extern void	kf_ToggleDemoMode( void );
 extern void	kf_ToggleRadarAllign( void );
@@ -120,7 +122,6 @@ extern void	kf_ChooseCancel( void );
 extern void	kf_ToggleWeather( void );
 extern void	kf_KillSelected(void);
 extern void	kf_ShowGridInfo(void);
-extern void	kf_GiveTemplateSet(void);
 extern void	kf_SendTextMessage(void);
 extern void	kf_SelectPlayer( void );
 extern void	kf_ToggleDrivingMode( void );
@@ -148,10 +149,12 @@ extern void	kf_SetDroidAttackReturn( void );
 extern void	kf_SetDroidAttackCease( void );
 
 extern void	kf_SetDroidMoveHold( void );
+extern void	kf_SetDroidMoveGuard( void );
 extern void	kf_SetDroidMovePursue( void ); //not there?
 extern void	kf_SetDroidMovePatrol( void ); // not there?
 
 extern void	kf_SetDroidReturnToBase( void );
+extern void	kf_SetDroidGoToTransport( void );
 extern void	kf_SetDroidGoForRepair( void );
 extern void	kf_SetDroidRecycle( void );
 extern void	kf_ScatterDroids( void );
@@ -227,6 +230,8 @@ extern void kf_SpeedUp( void );
 extern void kf_SlowDown( void );
 extern void kf_NormalSpeed( void );
 
+extern void kf_CloneSelected( void );
+
 #define SPIN_SCALING	(360*DEG_1)
 #define	SECS_PER_SPIN	2
 #define MAP_SPIN_RATE	(SPIN_SCALING/SECS_PER_SPIN)
@@ -239,6 +244,7 @@ void kf_TileInfo(void);
 void kf_NoAssert(void);
 
 extern void	kf_ToggleWatchWindow( void );
+extern void kf_DebugTemplates( void );
 
 bool runningMultiplayer(void);
 
