@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -23,32 +23,21 @@
  * alexl.
  */
 
-// ////////////////////////////////////////////////////////////////////////////
-// includes
-#include <string.h>
-#include <SDL.h>
-#include <physfs.h>
-
 #include "lib/framework/frame.h"
-#include "lib/framework/strres.h"
-#include "lib/framework/input.h"
+#include "lib/ivis_common/bitimage.h"
+#include "lib/ivis_common/pieblitfunc.h"
 #include "lib/sound/audio.h"
+#include "lib/sound/audio_id.h"
 
-#include "lib/widget/widget.h"
-#include "frontend.h"
 #include "frend.h"
-#include "lib/ivis_common/textdraw.h"
-#include "lib/ivis_common/piepalette.h"
+#include "frontend.h"
 #include "hci.h"
 #include "init.h"
-#include "loadsave.h"
-#include "keymap.h"
-#include "intimage.h"
-#include "lib/ivis_common/bitimage.h"
 #include "intdisplay.h"
-#include "lib/sound/audio_id.h"
-#include "lib/ivis_common/pieblitfunc.h"
-#include "lib/netplay/netplay.h"
+#include "keyedit.h"
+#include "keymap.h"
+#include "loadsave.h"
+#include "main.h"
 #include "multiint.h"
 
 // ////////////////////////////////////////////////////////////////////////////
@@ -67,9 +56,6 @@
 #define KM_X				30
 #define KM_Y				20
 
-#define KM_RETURNX			(KM_W-90)
-#define KM_RETURNY			(KM_H-42)
-
 #define BUTTONSPERKEYMAPPAGE 20
 
 #define KM_ENTRYW			480
@@ -80,19 +66,7 @@
 // variables
 
 static KEY_MAPPING	*selectedKeyMap;
-// ////////////////////////////////////////////////////////////////////////////
-// protos
-
-BOOL		runKeyMapEditor		(void);
-static BOOL keyMapToString		(char *pStr, KEY_MAPPING *psMapping);
-static void displayKeyMap(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset, PIELIGHT *pColours);
-BOOL		startKeyMapEditor	(BOOL first);
-BOOL		saveKeyMap		(void);
-BOOL		loadKeyMap		(void);
-static BOOL	pushedKeyMap		(UDWORD key);
-
-char	keymapVersion[8] = "KM_0002";
-extern char    KeyMapPath[];
+static char keymapVersion[8] = "KM_0002";
 
 // ////////////////////////////////////////////////////////////////////////////
 // funcs
@@ -163,6 +137,13 @@ static BOOL pushedKeyCombo(KEY_CODE subkey)
 		alt = KEY_RSHIFT;
 	}
 
+	// meta (cmd)
+	else if( keyDown(KEY_RMETA) || keyDown(KEY_LMETA) )
+	{
+		metakey = KEY_LMETA;
+		alt = KEY_RMETA;
+	}
+
 	// check if bound to a fixed combo.
 	pExist = keyFindMapping(  metakey,  subkey );
 	if(pExist && (pExist->status == KEYMAP_ALWAYS || pExist->status == KEYMAP_ALWAYS_PROCESS))
@@ -235,6 +216,8 @@ static UDWORD scanKeyBoardForBinding(void)
 			&& i != KEY_LCTRL
 			&& i != KEY_RSHIFT
 			&& i != KEY_LSHIFT
+			&& i != KEY_LMETA
+			&& i != KEY_RMETA
 			)
 			{
 				return i;	// top row key pressed
@@ -254,7 +237,7 @@ BOOL runKeyMapEditor(void)
 	if(id == KM_RETURN)			// return
 	{
 		saveKeyMap();
-		changeTitleMode(TITLE);
+		changeTitleMode(OPTIONS);
 	}
 	if(id == KM_DEFAULT)
 	{
@@ -279,6 +262,11 @@ BOOL runKeyMapEditor(void)
 
 	widgDisplayScreen(psWScreen);				// show the widgets currently running
 
+	if (CancelPressed())
+	{
+		changeTitleMode(OPTIONS);
+	}
+
 	return true;
 }
 
@@ -302,14 +290,14 @@ static BOOL keyMapToString(char *pStr, KEY_MAPPING *psMapping)
 	}
 	else
 	{
-		sprintf(pStr,"%s - %s",asciiMeta,asciiSub);
+		sprintf(pStr,"%s + %s",asciiMeta,asciiSub);
 	}
 	return true;
 }
 
 // ////////////////////////////////////////////////////////////////////////////
 // display a keymap on the interface.
-void displayKeyMap(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset, WZ_DECL_UNUSED PIELIGHT *pColours)
+static void displayKeyMap(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset, WZ_DECL_UNUSED PIELIGHT *pColours)
 {
 	UDWORD		x = xOffset+psWidget->x;
 	UDWORD		y = yOffset+psWidget->y;
@@ -324,6 +312,7 @@ void displayKeyMap(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset, WZ_DECL_UNU
 	}
 	else if(psMapping->status == KEYMAP_ALWAYS || psMapping->status == KEYMAP_ALWAYS_PROCESS)
 	{
+		// when user can't edit something...
 		pie_BoxFill(x, y , x + w, y + h, WZCOL_KEYMAP_FIXED);
 	}
 	else
@@ -332,14 +321,20 @@ void displayKeyMap(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset, WZ_DECL_UNU
 	}
 
 	// draw name
-	iV_SetFont(font_regular);											// font
+	iV_SetFont(font_regular);											// font type
 	iV_SetTextColour(WZCOL_TEXT_BRIGHT);
 
-	iV_DrawText(psMapping->pName, x + 2, y + (psWidget->height / 2) + 3);
+	iV_DrawText(_(psMapping->pName), x + 2, y + (psWidget->height / 2) + 3);
 
 	// draw binding
 	keyMapToString(sKey,psMapping);
-	iV_DrawText(sKey, x + 370, y + (psWidget->height / 2) + 3);
+	// Check to see if key is on the numpad, if so tell user and change color
+	if (psMapping->subKeyCode >= KEY_KP_0 && psMapping->subKeyCode <= KEY_KPENTER)
+	{
+		iV_SetTextColour(WZCOL_YELLOW);
+		ssprintf(sKey, "(numpad)%s", SDL_GetKeyName((SDLKey)psMapping->subKeyCode));
+	}
+	iV_DrawText(sKey, x + 364, y + (psWidget->height / 2) + 3);
 }
 
 // ////////////////////////////////////////////////////////////////////////////
@@ -517,16 +512,16 @@ BOOL saveKeyMap(void)
   // KeyMapPath
 	debug(LOG_WZ, "We are to write %s for keymap info", KeyMapPath);
 	pfile = PHYSFS_openWrite(KeyMapPath);
-	if (!pfile) {
-		debug(LOG_ERROR, "saveKeyMap: %s could not be created: %s", KeyMapPath,
-		      PHYSFS_getLastError());
+	if (!pfile)
+	{	// NOTE: Changed to LOG_FATAL, since we want to inform user via pop-up (windows only)
+		debug(LOG_FATAL, "saveKeyMap: %s could not be created: %s", KeyMapPath, PHYSFS_getLastError());
 		assert(false);
 		return false;
 	}
 
 #define WRITE(var, size)                                               \
 	if (PHYSFS_write(pfile, var, 1, size) != size) {                     \
-		debug(LOG_ERROR, "saveKeyMap: could not write to %s %d bytes: %s", \
+		debug(LOG_FATAL, "saveKeyMap: could not write to %s %d bytes: %s", \
 		      KeyMapPath, (int)size, PHYSFS_getLastError());                    \
 		assert(false);                                                     \
 		return false;                                                      \
@@ -534,7 +529,8 @@ BOOL saveKeyMap(void)
 
 	// write out number of entries.
 	count = 0;
-	for (psMapping = keyMappings; psMapping; psMapping = psMapping->psNext) {
+	for (psMapping = keyMappings; psMapping; psMapping = psMapping->psNext)
+	{
 		count++;
 	}
 	WRITE(&count, sizeof(count));
@@ -558,15 +554,14 @@ BOOL saveKeyMap(void)
 			count++);
 		if(keyMapSaveTable[count] == NULL)
 		{
-			debug( LOG_ERROR, "can't find keymapped function %s in the keymap "
-			       "save table at %d!", name, count );
+			debug( LOG_FATAL, "can't find keymapped function %s in the keymap save table at %d!", name, count );
 			abort();
 		}
 		WRITE(&count, sizeof(count));
 	}
-	if (!PHYSFS_close(pfile)) {
-		debug(LOG_ERROR, "saveKeyMap: Error closing %s: %s", KeyMapPath,
-		      PHYSFS_getLastError());
+	if (!PHYSFS_close(pfile))
+	{
+		debug(LOG_FATAL, "Error closing %s: %s", KeyMapPath, PHYSFS_getLastError());
 		assert(false);
 		return false;
 	}
@@ -595,13 +590,16 @@ BOOL loadKeyMap(void)
 	// throw away any keymaps!!
 	keyClearMappings();
 
-	if (!PHYSFS_exists(KeyMapPath)) {
-		debug(LOG_WZ, "loadKeyMap: %s not found", KeyMapPath);
+	if (!PHYSFS_exists(KeyMapPath))
+	{
+		debug(LOG_WZ, "%s not found", KeyMapPath);
 		return false;
 	}
 	pfile = PHYSFS_openRead(KeyMapPath);
-	if (!pfile) {
-		debug(LOG_ERROR, "loadKeyMap: [directory: %s] %s could not be opened: %s", PHYSFS_getRealDir(KeyMapPath),
+	if (!pfile)
+	{
+		// NOTE: Changed to LOG_FATAL, since we want to inform user via pop-up (windows only)
+		debug(LOG_FATAL, "loadKeyMap: [directory: %s] %s could not be opened: %s", PHYSFS_getRealDir(KeyMapPath),
 			KeyMapPath, PHYSFS_getLastError());
 		assert(false);
 		return false;
@@ -612,7 +610,7 @@ BOOL loadKeyMap(void)
 	length_read = PHYSFS_read(pfile, var, 1, size);             \
 	countsize += length_read;                                   \
 	if (length_read != size) {                                  \
-		debug(LOG_ERROR, "loadKeyMap: Reading %s short: %s",      \
+		debug(LOG_FATAL, "loadKeyMap: Reading %s short: %s",      \
 		      KeyMapPath, PHYSFS_getLastError());                 \
 		assert(false);                                            \
 		(void) PHYSFS_close(pfile);                               \
@@ -622,7 +620,8 @@ BOOL loadKeyMap(void)
 	READ(&count, sizeof(count));
 	READ(&ver, 8);	// get version number.
 
-	if (strncmp(ver, keymapVersion, 8) != 0) {
+	if (strncmp(ver, keymapVersion, 8) != 0)
+	{
 		/* If wrong version, create a new one instead. */
 		PHYSFS_close(pfile);
 		return false;
@@ -640,14 +639,15 @@ BOOL loadKeyMap(void)
 		keyAddMapping( status, metaCode, subCode, action, keyMapSaveTable[funcmap],(char*)&name);
 	}
 
-	if (!PHYSFS_close(pfile)) {
-		debug(LOG_ERROR, "loadKeyMap: Error closing %s: %s", KeyMapPath,
-		      PHYSFS_getLastError());
+	if (!PHYSFS_close(pfile))
+	{
+		debug(LOG_ERROR, "Error closing %s: %s", KeyMapPath, PHYSFS_getLastError());
 		assert(false);
 		return false;
 	}
-	if (countsize != filesize) {
-		debug(LOG_ERROR, "loadKeyMap: File size different from bytes read!");
+	if (countsize != filesize)
+	{
+		debug(LOG_FATAL, "File size different from bytes read!");
 		assert(false);
 	}
 	return true;
