@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -474,7 +474,7 @@ static BOOL _runLoadSave(BOOL bResetMissionWidgets)
 			}
 			else
 			{
-				goto failure;				// clicked on an empty box
+				return false;				// clicked on an empty box
 			}
 
 			if( bLoadSaveMode == LOAD_FORCE || bLoadSaveMode ==SAVE_FORCE )
@@ -546,9 +546,8 @@ static BOOL _runLoadSave(BOOL bResetMissionWidgets)
 		}
 
 
-		// scan to see if that game exists in another slot, if
-		// so then fail.
-		sstrcpy(sTemp, ((W_EDITBOX *)widgGetFromID(psRequestScreen,id))->aText);
+		// scan to see if that game exists in another slot, if so then fail.
+		sstrcpy(sTemp, widgGetString(psRequestScreen, id));
 
 		for(i=LOADENTRY_START;i<LOADENTRY_END;i++)
 		{
@@ -570,9 +569,9 @@ static BOOL _runLoadSave(BOOL bResetMissionWidgets)
 
 
 		// return with this name, as we've edited it.
-		if (strlen(((W_EDITBOX *)widgGetFromID(psRequestScreen,id))->aText))
+		if (strlen(widgGetString(psRequestScreen, id)))
 		{
-			sstrcpy(sTemp, ((W_EDITBOX *)widgGetFromID(psRequestScreen,id))->aText);
+			sstrcpy(sTemp, widgGetString(psRequestScreen, id));
 			removeWildcards(sTemp);
 			snprintf(sRequestResult, sizeof(sRequestResult), "%s%s.%s", sPath, sTemp, sExt);
 			if (strlen(sDelete) != 0)
@@ -636,7 +635,7 @@ void removeWildcards(char *pStr)
 	// Remember never to allow: < > : " / \ | ? *
 
 	// Whitelist: Get rid of any characters except:
-	// a-z A-Z 0-9 - + ! , = ^ @ # $ % & ' ( ) [ ] (and space)
+	// a-z A-Z 0-9 - + ! , = ^ @ # $ % & ' ( ) [ ] (and space and unicode characters ≥ 0x80)
 	for (i=0; i<strlen(pStr); i++)
 	{
 		if (!isalnum(pStr[i])
@@ -651,6 +650,7 @@ void removeWildcards(char *pStr)
 		    && pStr[i] != '@'
 		    && (pStr[i]<35 || pStr[i]>41) // # $ % & ' ( )
 		    && pStr[i] != '[' && pStr[i] != ']'
+		    && (pStr[i]&0x80) != 0x80  // á é í ó ú α β γ δ ε
 		   )
 		{
 			pStr[i] = '_';
