@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -40,6 +40,7 @@
 #include "lib/sound/audio.h"
 #include "lib/sound/cdaudio.h"
 #include "lib/sound/mixer.h"
+#include "lib/netplay/netplay.h"
 
 #include "loop.h"
 #include "objects.h"
@@ -146,7 +147,12 @@ GAMECODE gameLoop(void)
 	UDWORD		i,widgval;
 	BOOL		quitting=false;
 	INT_RETVAL	intRetVal;
-	int	        clearMode = 0;
+	int			clearMode = 0;
+
+	if (bMultiPlayer && !NetPlay.isHostAlive && NetPlay.bComms && !NetPlay.isHost)
+	{
+		intAddInGamePopup();
+	}
 
 	if (!war_GetFog())
 	{
@@ -312,16 +318,16 @@ GAMECODE gameLoop(void)
 								DROID *psDroid = NULL;
 
 								numTransporterDroids[i] += psCurr->psGroup->refCount-1;
-								// and count the units inside it...for MP games only(?)
-								if (bMultiPlayer)
+								// and count the units inside it...
+								for (psDroid = psCurr->psGroup->psList; psDroid != NULL && psDroid != psCurr; psDroid = psDroid->psGrpNext)
 								{
-									for (psDroid = psCurr->psGroup->psList; psDroid != NULL && psDroid != psCurr; psDroid = psDroid->psGrpNext)
+									if (psDroid->droidType == DROID_CYBORG_CONSTRUCT || psDroid->droidType == DROID_CONSTRUCT)
 									{
-										// since in MP we can only have cyborgs in transport, don't need to count DROID_CONSTRUCT as well.
-										if (psDroid->droidType == DROID_CYBORG_CONSTRUCT)
-										{
-											numConstructorDroids[i] += 1;
-										}
+										numConstructorDroids[i] += 1;
+									}
+									if (psDroid->droidType == DROID_COMMAND)
+									{
+										numCommandDroids[i] += 1;
 									}
 								}
 							}
@@ -496,11 +502,11 @@ GAMECODE gameLoop(void)
 			scroll();
 		}
 
-		if(InGameOpUp)		// ingame options menu up, run it!
+		if(InGameOpUp || isInGamePopupUp)		// ingame options menu up, run it!
 		{
 			widgval = widgRunScreen(psWScreen);
 			intProcessInGameOptions(widgval);
-			if(widgval == INTINGAMEOP_QUIT_CONFIRM)
+			if(widgval == INTINGAMEOP_QUIT_CONFIRM || widgval == INTINGAMEOP_POPUP_QUIT)
 			{
 				if(gamePaused())
 				{
@@ -516,6 +522,7 @@ GAMECODE gameLoop(void)
 			if(bRequestLoad)
 			{
 				loopMissionState = LMS_LOADGAME;
+				NET_InitPlayers();			// otherwise alliances were not cleared
 				sstrcpy(saveGameName, sRequestResult);
 			}
 			else
@@ -590,7 +597,7 @@ GAMECODE gameLoop(void)
 			processInput();
 
 			//no key clicks or in Intelligence Screen
-			if (intRetVal == INT_NONE && !InGameOpUp)
+			if (intRetVal == INT_NONE && !InGameOpUp && !isInGamePopupUp)
 			{
 				processMouseClickInput();
 			}
