@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -27,9 +27,6 @@
 #include <SDL.h>
 
 #if defined(WZ_OS_WIN)
-// FIXME HACK Workaround DATADIR definition in objbase.h
-// This works since DATADIR is never used on Windows.
-#  undef DATADIR
 #  include <shlobj.h> /* For SHGetFolderPath */
 #elif defined(WZ_OS_UNIX)
 #  include <errno.h>
@@ -55,6 +52,7 @@
 #include "lib/sound/cdaudio.h"
 
 #include "clparse.h"
+#include "challenge.h"
 #include "configuration.h"
 #include "display.h"
 #include "frontend.h"
@@ -64,9 +62,11 @@
 #include "lighting.h"
 #include "loadsave.h"
 #include "loop.h"
+#include "mission.h"
 #include "modding.h"
 #include "multiplay.h"
 #include "research.h"
+#include "scripttabs.h"
 #include "seqdisp.h"
 #include "warzoneconfig.h"
 #include "main.h"
@@ -75,25 +75,26 @@
 #include "map.h"
 #include "parsetest.h"
 #include "keybind.h"
+#include <time.h>
 
 /* Always use fallbacks on Windows */
 #if defined(WZ_OS_WIN)
-#  undef DATADIR
+#  undef WZ_DATADIR
 #endif
 
-#if !defined(DATADIR)
-#  define DATADIR "data"
+#if !defined(WZ_DATADIR)
+#  define WZ_DATADIR "data"
 #endif
 
 
 #if defined(WZ_OS_WIN)
-# define WZ_WRITEDIR "Warzone 2100 2.2"
+# define WZ_WRITEDIR "Warzone 2100 2.3"
 #elif defined(WZ_OS_MAC)
 # include <CoreServices/CoreServices.h>
 # include <unistd.h>
-# define WZ_WRITEDIR "Warzone 2100 2.2"
+# define WZ_WRITEDIR "Warzone 2100 2.3"
 #else
-# define WZ_WRITEDIR ".warzone2100-2.2"
+# define WZ_WRITEDIR ".warzone2100-2.3"
 #endif
 
 char datadir[PATH_MAX] = "\0"; // Global that src/clparse.c:ParseCommandLine can write to, so it can override the default datadir on runtime. Needs to be \0 on startup for ParseCommandLine to work!
@@ -103,6 +104,15 @@ char * global_mods[MAX_MODS] = { NULL };
 char * campaign_mods[MAX_MODS] = { NULL };
 char * multiplay_mods[MAX_MODS] = { NULL };
 
+char * override_mods[MAX_MODS] = { NULL };
+char * override_mod_list = NULL;
+bool use_override_mods = false;
+
+char * loaded_mods[MAX_MODS] = { NULL };
+char * mod_list = NULL;
+bool customDebugfile = false;		// Default false: user has NOT specified where to store the stdout/err file.
+int num_loaded_mods = 0;
+
 
 // Warzone 2100 . Pumpkin Studios
 
@@ -150,22 +160,30 @@ static BOOL inList( char * list[], const char * item )
  * \param appendToPath Whether to append or prepend
  * \param checkList List of directories to check. NULL means any.
  */
-void addSubdirs( const char * basedir, const char * subdir, const BOOL appendToPath, char * checkList[] )
+void addSubdirs( const char * basedir, const char * subdir, const bool appendToPath, char * checkList[], bool addToModList )
 {
 	char tmpstr[PATH_MAX];
+	char buf[256];
 	char ** subdirlist = PHYSFS_enumerateFiles( subdir );
 	char ** i = subdirlist;
+
 	while( *i != NULL )
 	{
 #ifdef DEBUG
 		debug( LOG_NEVER, "addSubdirs: Examining subdir: [%s]", *i );
 #endif // DEBUG
-		if( !checkList || inList( checkList, *i ) )
+		if (*i[0] != '.' && (!checkList || inList(checkList, *i)))
 		{
 			snprintf(tmpstr, sizeof(tmpstr), "%s%s%s%s", basedir, subdir, PHYSFS_getDirSeparator(), *i);
 #ifdef DEBUG
 			debug( LOG_NEVER, "addSubdirs: Adding [%s] to search path", tmpstr );
 #endif // DEBUG
+			if (addToModList)
+			{
+				addLoadedMod(*i);
+				snprintf(buf, sizeof(buf), "mod: %s", *i);
+				addDumpInfo(buf);
+			}
 			PHYSFS_addToSearchPath( tmpstr, appendToPath );
 		}
 		i++;
@@ -178,6 +196,7 @@ void removeSubdirs( const char * basedir, const char * subdir, char * checkList[
 	char tmpstr[PATH_MAX];
 	char ** subdirlist = PHYSFS_enumerateFiles( subdir );
 	char ** i = subdirlist;
+
 	while( *i != NULL )
 	{
 #ifdef DEBUG
@@ -189,7 +208,12 @@ void removeSubdirs( const char * basedir, const char * subdir, char * checkList[
 #ifdef DEBUG
 			debug( LOG_NEVER, "removeSubdirs: Removing [%s] from search path", tmpstr );
 #endif // DEBUG
-			PHYSFS_removeFromSearchPath( tmpstr );
+			if (!PHYSFS_removeFromSearchPath( tmpstr ))
+			{
+#ifdef DEBUG	// spams a ton!
+				debug(LOG_NEVER, "Couldn't remove %s from search path because %s", tmpstr, PHYSFS_getLastError());
+#endif // DEBUG
+			}
 		}
 		i++;
 	}
@@ -208,6 +232,122 @@ void printSearchPath( void )
 	PHYSFS_freeList( searchPath );
 }
 
+void setOverrideMods(char * modlist)
+{
+	char * curmod = modlist;
+	char * nextmod;
+	int i=0;
+	while ((nextmod = strstr(curmod, ", ")) && i<MAX_MODS-2)
+	{
+		override_mods[i] = malloc(nextmod-curmod+1);
+		strlcpy(override_mods[i], curmod, nextmod-curmod);
+		override_mods[i][nextmod-curmod] = '\0';
+		curmod = nextmod + 2;
+		i++;
+	}
+	override_mods[i] = strdup(curmod);
+	override_mods[i+1] = NULL;
+	override_mod_list = modlist;
+	use_override_mods = true;
+}
+void clearOverrideMods(void)
+{
+	int i;
+	use_override_mods = false;
+	for (i=0; i<MAX_MODS && override_mods[i]; i++)
+	{
+		free(override_mods[i]);
+	}
+	override_mods[0] = NULL;
+	override_mod_list = NULL;
+}
+
+void addLoadedMod(const char * modname)
+{
+	char * mod = strdup(modname);
+	int i, modlen;
+	if (num_loaded_mods >= MAX_MODS)
+	{
+		// mod list full
+		return;
+	}
+	modlen = strlen(mod);
+	if (modlen >= 3 && strcmp(&mod[modlen-3], ".wz")==0)
+	{
+		// remove ".wz" from end
+		mod[modlen-3] = 0;
+		modlen -= 3;
+	}
+	if (modlen >= 4 && strcmp(&mod[modlen-4], ".cam")==0)
+	{
+		// remove ".cam.wz" from end
+		mod[modlen-4] = 0;
+		modlen -= 4;
+	}
+	else if (modlen >= 4 && strcmp(&mod[modlen-4], ".mod")==0)
+	{
+		// remove ".mod.wz" from end
+		mod[modlen-4] = 0;
+		modlen -= 4;
+	}
+	else if (modlen >= 5 && strcmp(&mod[modlen-5], ".gmod")==0)
+	{
+		// remove ".gmod.wz" from end
+		mod[modlen-5] = 0;
+		modlen -= 5;
+	}
+	// Yes, this is an online insertion sort.
+	// I swear, for the numbers of mods this is going to be dealing with
+	// (i.e. 0 to 2), it really is faster than, say, Quicksort.
+	for (i=0; i<num_loaded_mods && strcmp(loaded_mods[i], mod)>0; i++);
+	if (i < num_loaded_mods)
+	{
+		if (strcmp(loaded_mods[i], mod) == 0)
+		{
+			// mod already in list
+			free(mod);
+			return;
+		}
+		memmove(&loaded_mods[i+1], &loaded_mods[i], (num_loaded_mods-i)*sizeof(char*));
+	}
+	loaded_mods[i] = mod;
+	num_loaded_mods++;
+}
+void clearLoadedMods(void)
+{
+	int i;
+	for (i=0; i<num_loaded_mods; i++)
+	{
+		free(loaded_mods[i]);
+	}
+	num_loaded_mods = 0;
+	if (mod_list)
+	{
+		free(mod_list);
+		mod_list = NULL;
+	}
+}
+char * getModList(void)
+{
+	int i;
+	if (mod_list)
+	{
+		// mod list already constructed
+		return mod_list;
+	}
+	mod_list = malloc(modlist_string_size);
+	mod_list[0] = 0; //initialize
+	for (i=0; i<num_loaded_mods; i++)
+	{
+		if (i != 0)
+		{
+			strlcat(mod_list, ", ", modlist_string_size);
+		}
+		strlcat(mod_list, loaded_mods[i], modlist_string_size);
+	}
+	return mod_list;
+}
+
 
 /*!
  * Retrieves the current working directory and copies it into the provided output buffer
@@ -283,12 +423,19 @@ static void getPlatformUserDir(char * const tmpstr, size_t const size)
 	else
 #endif
 	if (PHYSFS_getUserDir())
+	{
 		strlcpy(tmpstr, PHYSFS_getUserDir(), size); // Use PhysFS supplied UserDir (As fallback on Windows / Mac, default on Linux)
+	}
 	// If PhysicsFS fails (might happen if environment variable HOME is unset or wrong) then use the current working directory
 	else if (getCurrentDir(tmpstr, size))
+	{
 		strlcat(tmpstr, PHYSFS_getDirSeparator(), size);
+	}
 	else
+	{
+		debug(LOG_FATAL, "Can't get UserDir?");
 		abort();
+	}
 }
 
 
@@ -302,14 +449,14 @@ static void initialize_ConfigDir(void)
 
 		if (!PHYSFS_setWriteDir(tmpstr)) // Workaround for PhysFS not creating the writedir as expected.
 		{
-			debug(LOG_ERROR, "Error setting write directory to \"%s\": %s",
+			debug(LOG_FATAL, "Error setting write directory to \"%s\": %s",
 			      tmpstr, PHYSFS_getLastError());
 			exit(1);
 		}
 
 		if (!PHYSFS_mkdir(WZ_WRITEDIR)) // s.a.
 		{
-			debug(LOG_ERROR, "Error creating directory \"%s\": %s",
+			debug(LOG_FATAL, "Error creating directory \"%s\": %s",
 			      WZ_WRITEDIR, PHYSFS_getLastError());
 			exit(1);
 		}
@@ -320,7 +467,7 @@ static void initialize_ConfigDir(void)
 
 		if (!PHYSFS_setWriteDir(tmpstr))
 		{
-			debug( LOG_ERROR, "Error setting write directory to \"%s\": %s",
+			debug( LOG_FATAL, "Error setting write directory to \"%s\": %s",
 			tmpstr, PHYSFS_getLastError() );
 			exit(1);
 		}
@@ -337,10 +484,19 @@ static void initialize_ConfigDir(void)
 
 		if (!PHYSFS_setWriteDir(tmpstr)) // Workaround for PhysFS not creating the writedir as expected.
 		{
-			debug(LOG_ERROR, "Error setting write directory to \"%s\": %s",
+			debug(LOG_FATAL, "Error setting write directory to \"%s\": %s",
 			      tmpstr, PHYSFS_getLastError());
 			exit(1);
 		}
+
+		// NOTE: This is currently only used for mingw builds for now.
+#if defined (WZ_CC_MINGW)
+		if (!OverrideRPTDirectory(tmpstr))
+		{
+			// since it failed, we just use our default path, and not the user supplied one.
+			debug(LOG_ERROR, "Error setting exception hanlder to use directory %s", tmpstr);
+		}
+#endif
 	}
 
 	// User's home dir first so we allways see what we write
@@ -406,8 +562,6 @@ static void scanDataDirs( void )
 		}
 	}
 
-	atexit( cleanSearchPath );
-
 	// Commandline supplied datadir
 	if( strlen( datadir ) != 0 )
 		registerSearchPath( datadir, 1 );
@@ -441,7 +595,7 @@ static void scanDataDirs( void )
 				if( !PHYSFS_exists("gamedesc.lev") )
 				{
 					// Guessed fallback default datadir on Unix
-					registerSearchPath( DATADIR, 6 );
+					registerSearchPath( WZ_DATADIR, 6 );
 					rebuildSearchPath( mod_multiplay, true );
 				}
 			}
@@ -474,7 +628,7 @@ static void scanDataDirs( void )
 	}
 	else
 	{
-		debug( LOG_ERROR, "Could not find game data. Aborting." );
+		debug( LOG_FATAL, "Could not find game data. Aborting." );
 		exit(1);
 	}
 }
@@ -500,7 +654,7 @@ static void make_dir(char *dest, const char *dirname, const char *subdir)
 	}
 	PHYSFS_mkdir(dest);
 	if ( !PHYSFS_mkdir(dest) ) {
-		debug(LOG_ERROR, "Unable to create directory \"%s\" in write dir \"%s\"!",
+		debug(LOG_FATAL, "Unable to create directory \"%s\" in write dir \"%s\"!",
 		      dest, PHYSFS_getWriteDir());
 		exit(EXIT_FAILURE);
 	}
@@ -518,7 +672,7 @@ static void startTitleLoop(void)
 	screen_RestartBackDrop();
 	if (!frontendInitialise("wrf/frontend.wrf"))
 	{
-		debug( LOG_ERROR, "Shutting down after failure" );
+		debug( LOG_FATAL, "Shutting down after failure" );
 		exit(EXIT_FAILURE);
 	}
 	frontendInitVars();
@@ -533,7 +687,7 @@ static void stopTitleLoop(void)
 {
 	if (!frontendShutdown())
 	{
-		debug( LOG_ERROR, "Shutting down after failure" );
+		debug( LOG_FATAL, "Shutting down after failure" );
 		exit(EXIT_FAILURE);
 	}
 }
@@ -549,21 +703,21 @@ static void startGameLoop(void)
 
 	if (!levLoadData(aLevelName, NULL, 0))
 	{
-		debug( LOG_ERROR, "Shutting down after failure" );
+		debug( LOG_FATAL, "Shutting down after failure" );
 		exit(EXIT_FAILURE);
 	}
 	//after data is loaded check the research stats are valid
 	if (!checkResearchStats())
 	{
-		debug( LOG_ERROR, "Invalid Research Stats" );
-		debug( LOG_ERROR, "Shutting down after failure" );
+		debug( LOG_FATAL, "Invalid Research Stats" );
+		debug( LOG_FATAL, "Shutting down after failure" );
 		exit(EXIT_FAILURE);
 	}
 	//and check the structure stats are valid
 	if (!checkStructureStats())
 	{
-		debug( LOG_ERROR, "Invalid Structure Stats" );
-		debug( LOG_ERROR, "Shutting down after failure" );
+		debug( LOG_FATAL, "Invalid Structure Stats" );
+		debug( LOG_FATAL, "Shutting down after failure" );
 		exit(EXIT_FAILURE);
 	}
 
@@ -577,6 +731,15 @@ static void startGameLoop(void)
 
 	// set a flag for the trigger/event system to indicate initialisation is complete
 	gameInitialised = true;
+
+	if (challengeActive)
+	{
+		addMissionTimerInterface();
+	}
+	if (game.type == SKIRMISH)
+	{
+		eventFireCallbackTrigger((TRIGGER_TYPE)CALL_START_NEXT_LEVEL);
+	}
 }
 
 
@@ -598,6 +761,7 @@ static void stopGameLoop(void)
 				debug(LOG_ERROR, "levReleaseAll failed!");
 			}
 		}
+		reloadMPConfig();
 	}
 
 	// Disable cursor trapping
@@ -607,6 +771,7 @@ static void stopGameLoop(void)
 	}
 
 	gameInitialised = false;
+	screen_disableMapPreview();
 }
 
 
@@ -623,7 +788,13 @@ static bool initSaveGameLoad(void)
 	if (!loadGameInit(saveGameName))
 	{
 		// FIXME: we really should throw up a error window, but we can't (easily) so I won't.
-		debug( LOG_ERROR, "Trying to load Game %s failed!", saveGameName);
+		debug(LOG_ERROR, "Trying to load Game %s failed!", saveGameName);
+		debug(LOG_POPUP, "Failed to load a save game! It is either corrupted or a unsupported format.\n\nRestarting main menu.");
+		// FIXME: If we bomb out on a in game load, then we would crash if we don't do the next two calls
+		// Doesn't seem to be a way to tell where we are in game loop to determine if/when we should do the two calls.
+		gameLoopStatus = GAMECODE_FASTEXIT;	// clear out all old data
+		stopGameLoop();
+		startTitleLoop(); // Restart into titleloop
 		SetGameMode(GS_TITLE_SCREEN);
 		return false;
 	}
@@ -635,6 +806,10 @@ static bool initSaveGameLoad(void)
 	{
 		SDL_WM_GrabInput(SDL_GRAB_ON);
 	}
+	if (challengeActive)
+	{
+		addMissionTimerInterface();
+	}
 
 	return true;
 }
@@ -738,7 +913,10 @@ static void handleActiveEvent(SDL_ActiveEvent * activeEvent)
 	// Ignore focus loss through SDL_APPMOUSEFOCUS, since it mostly happens accidentialy
 	// active.state is a bitflag! Mixed events (eg. APPACTIVE|APPMOUSEFOCUS) will thus not be ignored.
 	if ( activeEvent->state == SDL_APPMOUSEFOCUS )
+	{
+		setMouseScroll(activeEvent->gain);
 		return;
+	}
 
 	if ( activeEvent->gain == 1 )
 	{
@@ -747,31 +925,37 @@ static void handleActiveEvent(SDL_ActiveEvent * activeEvent)
 		{
 			focusState = FOCUS_IN;
 
-			gameTimeStart();
-			// Should be: audio_ResumeAll();
+			// Don't pause in multiplayer!
+			if (war_GetPauseOnFocusLoss() && !NetPlay.bComms)
+			{
+				gameTimeStart();
+				audio_ResumeAll();
+				cdAudio_Resume();
+			}
+			// enable scrolling
+			setScrollPause(false);
+			resetScroll();
 		}
-
-		// Resume playing audio.
-		cdAudio_Resume();
 	}
-	// Only loose focus when the config settings allow us to
-	else if (war_GetPauseOnFocusLoss())
+	else
 	{
 		debug( LOG_NEVER, "WM_KILLFOCUS");
 		if (focusState != FOCUS_OUT)
 		{
 			focusState = FOCUS_OUT;
 
-			gameTimeStop();
-			// Should be: audio_PauseAll();
-			audio_StopAll();
+			// Don't pause in multiplayer!
+			if (war_GetPauseOnFocusLoss() && !NetPlay.bComms)
+			{
+				gameTimeStop();
+				audio_PauseAll();
+				cdAudio_Pause();
+			}
+			/* Have to tell the input system that we've lost focus */
+			inputLooseFocus();
+			// stop scrolling
+			setScrollPause(true);
 		}
-		/* Have to tell the input system that we've lost focus */
-		inputLooseFocus();
-
-		// Need to pause playing to prevent the audio code from
-		// thinking playing has finished.
-		cdAudio_Pause();
 	}
 }
 
@@ -805,13 +989,10 @@ static void mainLoop(void)
 					inputHandleMouseMotionEvent(&event.motion);
 					break;
 				case SDL_ACTIVEEVENT:
-					 // Ignore this event during multiplayer games since it breaks the game when one player suddenly pauses!
-					if (!bMultiPlayer)
-					{
-						handleActiveEvent(&event.active);
-					}
+					handleActiveEvent(&event.active);
 					break;
 				case SDL_QUIT:
+					saveConfig();
 					return;
 				default:
 					break;
@@ -824,7 +1005,8 @@ static void mainLoop(void)
 			inputLooseFocus();		// remove it from input stream
 		}
 
-		if (focusState == FOCUS_IN)
+		// only pause when not in multiplayer, no focus, and we actually want to pause
+		if (NetPlay.bComms || focusState == FOCUS_IN || !war_GetPauseOnFocusLoss())
 		{
 			if (loop_GetVideoStatus())
 			{
@@ -853,8 +1035,6 @@ int main(int argc, char *argv[])
 	setupExceptionHandler(argc, argv);
 
 	debug_init();
-	atexit( debug_exit );
-
 	debug_register_callback( debug_callback_stderr, NULL, NULL, NULL );
 #if defined(WZ_OS_WIN) && defined(DEBUG_INSANE)
 	debug_register_callback( debug_callback_win32debug, NULL, NULL, NULL );
@@ -880,17 +1060,33 @@ int main(int argc, char *argv[])
 	 */
 	initialize_ConfigDir();
 
-	debug(LOG_WZ, "Warzone 2100 - %s", version_getFormattedVersionString());
-
 	/*** Initialize directory structure ***/
-	make_dir(ScreenDumpPath, "screendumps", NULL);
+	make_dir(ScreenDumpPath, "screenshots", NULL);
 	make_dir(SaveGamePath, "savegame", NULL);
 	PHYSFS_mkdir("maps");		// MUST have this to prevent crashes when getting map
 	PHYSFS_mkdir("music");
+	PHYSFS_mkdir("logs");		// a place to hold our netplay, mingw crash reports & WZ logs
 	make_dir(MultiPlayersPath, "multiplay", NULL);
 	make_dir(MultiPlayersPath, "multiplay", "players");
-	make_dir(MultiForcesPath, "multiplay", "forces");
-	make_dir(MultiCustomMapsPath, "multiplay", "custommaps");
+	sstrcpy(MultiCustomMapsPath, "maps");
+
+	if (!customDebugfile)
+	{
+		// there was no custom debug file specified  (--debug-file=blah)
+		// so we use our write directory to store our logs.
+		time_t aclock;
+		struct tm *newtime;
+		char buf[PATH_MAX];
+
+		time( &aclock );					// Get time in seconds
+		newtime = localtime( &aclock );		// Convert time to struct
+		// Note: We are using fopen(), and not physfs routines to open the file
+		// log name is logs/(or \)WZlog-MMDD_HHMMSS.txt
+		snprintf(buf, sizeof(buf), "%slogs%sWZlog-%02d%02d_%02d%02d%02d.txt", PHYSFS_getWriteDir(), PHYSFS_getDirSeparator(),
+			newtime->tm_mon, newtime->tm_mday, newtime->tm_hour, newtime->tm_min, newtime->tm_sec );
+		debug_register_callback( debug_callback_file, debug_callback_file_init, debug_callback_file_exit, buf );
+	}
+	debug(LOG_WZ, "Warzone 2100 - %s", version_getFormattedVersionString());
 
 	/* Put these files in the writedir root */
 	setRegistryFilePath("config");
@@ -902,7 +1098,7 @@ int main(int argc, char *argv[])
 	debug(LOG_MAIN, "initializing");
 
 	loadConfig();
-	atexit( closeConfig );
+
 	loadRenderMode(); //get the registry entry for clRendMode
 
 	NETinit(true);
@@ -1004,13 +1200,13 @@ int main(int argc, char *argv[])
 	{
 		return -1;
 	}
-	atexit(frameShutDown);
+	war_SetWidth(pie_GetVideoBufferWidth());
+	war_SetHeight(pie_GetVideoBufferHeight());
 
 	pie_SetFogStatus(false);
 	pie_ScreenFlip(CLEAR_BLACK);
 
 	pal_Init();
-	atexit(pal_ShutDown);
 
 	pie_LoadBackDrop(SCREEN_RANDOMBDROP);
 	pie_SetFogStatus(false);
@@ -1020,7 +1216,6 @@ int main(int argc, char *argv[])
 	{
 		return -1;
 	}
-	atexit(systemShutdown);
 
 	//set all the pause states to false
 	setAllPauseStates(false);
@@ -1065,9 +1260,13 @@ int main(int argc, char *argv[])
 
 	// Enter the mainloop
 	mainLoop();
-
 	debug(LOG_MAIN, "Shutting down Warzone 2100");
 
+#if defined(WZ_CC_MSVC) && defined(DEBUG)
+	debug_MEMSTATS();
+#endif
+
+	atexit(systemShutdown);
 	return EXIT_SUCCESS;
 }
 
