@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -30,10 +30,24 @@ typedef enum {
 //flag to indicate when initialisation is complete
 extern BOOL gameInitialised;
 extern BOOL bDisableLobby;
-
+extern bool customDebugfile;
 extern GS_GAMEMODE GetGameMode(void) WZ_DECL_PURE;
 extern void SetGameMode(GS_GAMEMODE status);
 
-extern char SaveGamePath[];
+extern char SaveGamePath[PATH_MAX];
+extern char datadir[PATH_MAX];
+extern char configdir[PATH_MAX];
+extern char KeyMapPath[PATH_MAX];
+extern char MultiPlayersPath[PATH_MAX];
+
+#define MAX_MODS 100
+
+extern char * global_mods[MAX_MODS];
+extern char * campaign_mods[MAX_MODS];
+extern char * multiplay_mods[MAX_MODS];
+
+extern char * override_mods[MAX_MODS];
+extern char * override_mod_list;
+extern bool use_override_mods;
 
 #endif // __INCLUDED_SRC_MAIN_H__
