@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -51,6 +51,12 @@
 #include "fpath.h"
 #include "levels.h"
 
+struct ffnode
+{
+	struct ffnode *next;
+	int x, y;
+};
+
 //scroll min and max values
 SDWORD		scrollMinX, scrollMaxX, scrollMinY, scrollMaxY;
 
@@ -138,7 +144,7 @@ BOOL mapNew(UDWORD width, UDWORD height)
 	psMapTiles = calloc(width * height, sizeof(MAPTILE));
 	if (psMapTiles == NULL)
 	{
-		debug(LOG_ERROR, "Out of memory");
+		debug(LOG_FATAL, "Out of memory");
 		abort();
 		return false;
 	}
@@ -149,8 +155,9 @@ BOOL mapNew(UDWORD width, UDWORD height)
 		psTile->height = MAX_HEIGHT / 4;
 		psTile->illumination = 255;
 		psTile->level = psTile->illumination;
-		psTile->bMaxed = true;
+		memset(psTile->watchers, 0, sizeof(psTile->watchers));
 		psTile->colour= WZCOL_WHITE;
+		CLEAR_TILE_EXPLORED(psTile);
 		psTile++;
 	}
 
@@ -188,6 +195,9 @@ static BOOL mapLoadV3(char *pFileData, UDWORD fileSize)
 
 		psMapTiles[i].texture = psTileData->texture;
 		psMapTiles[i].height = psTileData->height;
+
+		// Visibility stuff
+		memset(psMapTiles[i].watchers, 0, sizeof(psMapTiles[i].watchers));
 		for (j=0; j<MAX_PLAYERS; j++)
 		{
 			psMapTiles[i].tileVisBits =(UBYTE)(( (psMapTiles[i].tileVisBits) &~ (UBYTE)(1<<j) ));
@@ -283,6 +293,8 @@ BOOL mapLoad(char *pFileData, UDWORD fileSize)
 	scrollMaxX = mapWidth;
 	scrollMaxY = mapHeight;
 
+	mapFloodFillContinents();
+
 	return true;
 }
 
@@ -616,7 +628,7 @@ static void structureSaveTagged(STRUCTURE *psStruct)
 			tagWriteEnter(0x12, 1);
 			tagWrite(0x01, psRearm->reArmPoints);
 			tagWrite(0x02, psRearm->timeStarted);
-			tagWrite(0x03, psRearm->currentPtsAdded);
+			tagWrite(0x03, psRearm->timeLastUpdated);
 			if (psRearm->psObj)
 			{
 				tagWrites(0x04, psRearm->psObj->id);
@@ -1060,7 +1072,7 @@ BOOL mapSave(char **ppFileData, UDWORD *pFileSize)
 	*ppFileData = (char*)malloc(*pFileSize);
 	if (*ppFileData == NULL)
 	{
-		debug( LOG_ERROR, "Out of memory" );
+		debug( LOG_FATAL, "Out of memory" );
 		abort();
 		return false;
 	}
@@ -1156,11 +1168,16 @@ extern SWORD map_Height(int x, int y)
 	int	h0, hx, hy, hxy, wTL = 0, wTR = 0, wBL = 0, wBR = 0;
 	BOOL	bWaterTile = false;
 
-	ASSERT(x >= 0, "map_Height: Negative x value");
-	ASSERT(y >= 0, "map_Height: Negative y value");
-
-	x = (x >= world_coord(mapWidth) ? world_coord(mapWidth - 1) : x);
-	y = (y >= world_coord(mapHeight) ? world_coord(mapHeight - 1) : y);
+	// Clamp x and y values to actual ones
+	// Give one tile worth of leeway before asserting, for units/transporters coming in from off-map.
+	ASSERT(x >= -TILE_UNITS, "map_Height: x value is too small (%d,%d) in %dx%d",map_coord(x),map_coord(y),mapWidth,mapHeight);
+	ASSERT(y >= -TILE_UNITS, "map_Height: y value is too small (%d,%d) in %dx%d",map_coord(x),map_coord(y),mapWidth,mapHeight);
+	x = (x < 0 ? 0 : x);
+	y = (y < 0 ? 0 : y);
+	ASSERT(x < world_coord(mapWidth)+TILE_UNITS, "map_Height: x value is too big (%d,%d) in %dx%d",map_coord(x),map_coord(y),mapWidth,mapHeight);
+	ASSERT(y < world_coord(mapHeight)+TILE_UNITS, "map_Height: y value is too big (%d,%d) in %dx%d",map_coord(x),map_coord(y),mapWidth,mapHeight);
+	x = (x >= world_coord(mapWidth) ? world_coord(mapWidth) - 1 : x);
+	y = (y >= world_coord(mapHeight) ? world_coord(mapHeight) - 1 : y);
 
 	/* Turn into tile coordinates */
 	tileX = map_coord(x);
@@ -1511,6 +1528,7 @@ static void astarTest(const char *name, int x1, int y1, int x2, int y2)
 		job.destY = endy;
 		job.propulsion = PROPULSION_TYPE_WHEELED;
 		job.droidID = 1;
+		job.owner = 0;
 		asret = fpathAStarRoute(&route, &job);
 		free(route.asPath);
 		route.asPath = NULL;
@@ -1537,6 +1555,127 @@ void mapTest()
 	fprintf(stdout, "\tMap self-test: PASSED\n");
 }
 
+// Convert a direction into an offset.
+// dir 0 => x = 0, y = -1
+#define NUM_DIR		8
+static const Vector2i aDirOffset[NUM_DIR] =
+{
+        { 0, 1},
+        {-1, 1},
+        {-1, 0},
+        {-1,-1},
+        { 0,-1},
+        { 1,-1},
+        { 1, 0},
+        { 1, 1},
+};
+
+// Flood fill a "continent". Note that we reuse x, y inside this function.
+static void mapFloodFill(int x, int y, int continent, PROPULSION_TYPE propulsion)
+{
+	struct ffnode *open = NULL;
+	int i;
+
+	do
+	{
+		MAPTILE *currTile = mapTile(x, y);
+
+		// Add accessible neighbouring tiles to the open list
+		for (i = 0; i < NUM_DIR; i++)
+		{
+			// rely on the fact that all border tiles are inaccessible to avoid checking explicitly
+			Vector2i npos = { x + aDirOffset[i].x, y + aDirOffset[i].y };
+			MAPTILE *psTile;
+			bool limitedTile = (propulsion == PROPULSION_TYPE_PROPELLOR || propulsion == PROPULSION_TYPE_WHEELED);
+
+			if (!tileOnMap(npos.x, npos.y) || (npos.x == x && npos.y == y))
+			{
+				continue;
+			}
+			psTile = mapTile(npos.x, npos.y);
+
+			if (!fpathBlockingTile(npos.x, npos.y, propulsion) && ((limitedTile && psTile->limitedContinent == 0) || (!limitedTile && psTile->hoverContinent == 0)))
+			{
+				struct ffnode *node = malloc(sizeof(*node));
+
+				node->next = open;	// add to beginning of open list
+				node->x = npos.x;
+				node->y = npos.y;
+				open = node;
+			}
+		}
+
+		// Set continent value
+		if (propulsion == PROPULSION_TYPE_PROPELLOR || propulsion == PROPULSION_TYPE_WHEELED)
+		{
+			currTile->limitedContinent = continent;
+		}
+		else
+		{
+			currTile->hoverContinent = continent;
+		}
+
+		// Pop the first open node off the list for the next iteration
+		if (open)
+		{
+			struct ffnode *tmp = open;
+
+			x = open->x;
+			y = open->y;
+			open = open->next;
+			free(tmp);
+		}
+	} while (open);
+}
+
+void mapFloodFillContinents()
+{
+	int x, y, limitedContinents = 0, hoverContinents = 0;
+
+	/* Clear continents */
+	for (x = 0; x < mapWidth; x++)
+	{
+		for (y = 0; y < mapHeight; y++)
+		{
+			MAPTILE *psTile = mapTile(x, y);
+
+			psTile->limitedContinent = 0;
+			psTile->hoverContinent = 0;
+		}
+	}
+
+	/* Iterate over the whole map, looking for unset continents */
+	for (x = 0; x < mapWidth; x++)
+	{
+		for (y = 0; y < mapHeight; y++)
+		{
+			MAPTILE *psTile = mapTile(x, y);
+
+			if (psTile->limitedContinent == 0 && !fpathBlockingTile(x, y, PROPULSION_TYPE_WHEELED))
+			{
+				mapFloodFill(x, y, 1 + limitedContinents++, PROPULSION_TYPE_WHEELED);
+			}
+			else if (psTile->limitedContinent == 0 && !fpathBlockingTile(x, y, PROPULSION_TYPE_PROPELLOR))
+			{
+				mapFloodFill(x, y, 1 + limitedContinents++, PROPULSION_TYPE_PROPELLOR);
+			}
+		}
+	}
+	debug(LOG_MAP, "Found %d limited continents", (int)limitedContinents);
+	for (x = 0; x < mapWidth; x++)
+	{
+		for (y = 0; y < mapHeight; y++)
+		{
+			MAPTILE *psTile = mapTile(x, y);
+
+			if (psTile->hoverContinent == 0 && !fpathBlockingTile(x, y, PROPULSION_TYPE_HOVER))
+			{
+				mapFloodFill(x, y, 1 + hoverContinents++, PROPULSION_TYPE_HOVER);
+			}
+		}
+	}
+	debug(LOG_MAP, "Found %d hover continents", (int)hoverContinents);
+}
 
 /** Check if tile contained within the given world coordinates is burning. */
 bool fireOnLocation(unsigned int x, unsigned int y)
