@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -27,6 +27,8 @@
 #include "lib/framework/frame.h"
 #include "lib/framework/debug.h"
 #include "objects.h"
+#include "multiplay.h"
+#include "display.h"
 
 /* The different types of terrain as far as the game is concerned */
 typedef enum _terrain_type
@@ -76,11 +78,12 @@ static inline unsigned short TileNumber_texture(unsigned short tilenumber)
 	return tilenumber & ~TILE_NUMMASK;
 }
 
-#define BITS_NOTBLOCKING 0x01 // units can drive on this even if there is a structure or feature on it
-#define BITS_FPATHBLOCK	0x10		// bit set temporarily by find path to mark a blocking tile
-#define BITS_ON_FIRE	0x20		// cache whether tile is burning
-#define BITS_GATEWAY	0x40		// bit set to show a gateway on the tile
-#define BITS_TALLSTRUCTURE 0x80		// bit set to show a tall structure which camera needs to avoid.
+#define BITS_NOTBLOCKING	0x01	///< Units can drive on this even if there is a structure or feature on it
+#define BITS_EXPLORED		0x02	///< Tile has been explored
+#define BITS_FPATHBLOCK		0x10	///< Bit set temporarily by find path to mark a blocking tile
+#define BITS_ON_FIRE		0x20	///< Cache whether tile is burning
+#define BITS_GATEWAY		0x40	///< Bit set to show a gateway on the tile
+#define BITS_TALLSTRUCTURE	0x80	///< Bit set to show a tall structure which camera needs to avoid.
 
 /* Information stored with each tile */
 typedef struct _maptile
@@ -90,11 +93,12 @@ typedef struct _maptile
 	UBYTE			height;			// The height at the top left of the tile
 	UBYTE			illumination;	// How bright is this tile?
 	UWORD			texture;		// Which graphics texture is on this tile
-	bool			bMaxed;
-	bool			activeSensor;	// selected player can see through fog of war here
+	UBYTE			watchers[MAX_PLAYERS];		// player sees through fog of war here with this many objects
 	float			level;
 	BASE_OBJECT		*psObject;		// Any object sitting on the location (e.g. building)
 	PIELIGHT		colour;
+	short			limitedContinent;	/** For land or sea limited propulsion types */
+	short			hoverContinent;		/** For hover type propulsions */
 
 //	TYPE_OF_TERRAIN	type;			// The terrain type for the tile
 } MAPTILE;
@@ -137,6 +141,12 @@ static inline bool TileIsBurning(const MAPTILE *tile)
 	return tile->tileInfoBits & BITS_ON_FIRE;
 }
 
+/** Check if tile has been explored. */
+static inline bool tileIsExplored(const MAPTILE *psTile)
+{
+	return psTile->tileInfoBits & BITS_EXPLORED;
+}
+
 /** Check if tile is highlighted by the user. Function is thread-safe. */
 static inline bool TileIsHighlighted(const MAPTILE* tile)
 {
@@ -162,6 +172,9 @@ static inline bool TileHasSmallStructure(const MAPTILE* tile)
 	    && ((STRUCTURE*)tile->psObject)->pStructureType->height == 1;
 }
 
+#define SET_TILE_EXPLORED(x) ((x)->tileInfoBits |= BITS_EXPLORED)
+#define CLEAR_TILE_EXPLORED(x) ((x)->tileInfoBits &= ~BITS_EXPLORED)
+
 #define SET_TILE_NOTBLOCKING(x)	((x)->tileInfoBits |= BITS_NOTBLOCKING)
 #define CLEAR_TILE_NOTBLOCKING(x)	((x)->tileInfoBits &= ~BITS_NOTBLOCKING)
 
@@ -270,10 +283,18 @@ BOOL mapSaveTagged(char *pFileName);
 BOOL mapLoadTagged(char *pFileName);
 
 /* Return a pointer to the tile structure at x,y */
-static inline WZ_DECL_PURE MAPTILE *mapTile(UDWORD x, UDWORD y)
+static inline WZ_DECL_PURE MAPTILE *mapTile(SDWORD x, SDWORD y)
 {
-	ASSERT_OR_RETURN(0, x < mapWidth, "x coordinate %u bigger than map width %u", x, mapWidth);
-	ASSERT_OR_RETURN(0, y < mapHeight, "y coordinate %u bigger than map height %u", y, mapHeight);
+	// Clamp x and y values to actual ones
+	// Give one tile worth of leeway before asserting, for units/transporters coming in from off-map.
+	ASSERT(x >= -1, "mapTile: x value is too small (%d,%d) in %dx%d",x,y,mapWidth,mapHeight);
+	ASSERT(y >= -1, "mapTile: y value is too small (%d,%d) in %dx%d",x,y,mapWidth,mapHeight);
+	x = (x < 0 ? 0 : x);
+	y = (y < 0 ? 0 : y);
+	ASSERT(x < mapWidth + 1, "mapTile: x value is too big (%d,%d) in %dx%d",x,y,mapWidth,mapHeight);
+	ASSERT(y < mapHeight + 1, "mapTile: y value is too big (%d,%d) in %dx%d",x,y,mapWidth,mapHeight);
+	x = (x >= mapWidth ? mapWidth - 1 : x);
+	y = (y >= mapHeight ? mapHeight - 1 : y);
 
 	return &psMapTiles[x + (y * mapWidth)];
 }
@@ -364,8 +385,43 @@ extern bool	writeVisibilityData(const char* fileName);
 //scroll min and max values
 extern SDWORD		scrollMinX, scrollMaxX, scrollMinY, scrollMaxY;
 
+void mapFloodFillContinents(void);
+
 extern void mapTest(void);
 
 extern bool fireOnLocation(unsigned int x, unsigned int y);
 
+/**
+ * Transitive sensor check for tile. Has to be here rather than
+ * visibility.h due to header include order issues. 
+ */
+static inline bool hasSensorOnTile(MAPTILE *psTile, int player)
+{
+	int k;
+
+	// if a player has a SAT_UPLINK structure, or has godMode enabled,
+	// they can see everything!
+	if (getSatUplinkExists(player) || (player == selectedPlayer && godMode))
+	{
+		return true;
+	}
+
+	if (psTile->watchers[selectedPlayer] == 0)
+	{
+		if (game.type != CAMPAIGN && game.alliance == ALLIANCES_TEAMS)
+		{
+			// Check if an ally can provide us with vision on this tile
+			for (k = 0;  k < MAX_PLAYERS; k++)
+			{
+				if (aiCheckAlliances(k, selectedPlayer) && (getSatUplinkExists(k) || psTile->watchers[k] > 0))
+				{
+					return true;
+				}
+			}
+		}
+		return false;
+	}
+	return true;
+}
+
 #endif // __INCLUDED_SRC_MAP_H__
