@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -23,26 +23,18 @@
  * Functions for the messages shown in the Intelligence Map
  *
  */
-#include <string.h>
 
 #include "lib/framework/frame.h"
-#include "lib/framework/strres.h"
 #include "lib/framework/frameresource.h"
-#include "lib/framework/lexer_input.h"
-#include "message.h"
-#include "stats.h"
-#include "text.h"
-#include "console.h"
+#include "lib/framework/strres.h"
 #include "lib/sound/audio.h"
 #include "lib/sound/audio_id.h"
-#include "hci.h"
-#include "lib/ivis_common/piedef.h"
-#include "objmem.h"
-#include "map.h"
-#include "message_parser.tab.h"
-#include "messagely.h"
 
-#include "multiplay.h"
+#include "console.h"
+#include "hci.h"
+#include "messagely.h"
+#include "stats.h"
+#include "text.h"
 
 //array of pointers for the view data
 static VIEWDATA_LIST		*apsViewData;
@@ -62,10 +54,6 @@ PROXIMITY_DISPLAY *apsProxDisp[MAX_PLAYERS];
 /* The IMD to use for the proximity messages */
 iIMDShape	*pProximityMsgIMD;
 
-//function declarations
-static void addProximityDisplay(MESSAGE *psMessage, BOOL proxPos, UDWORD player);
-static void removeProxDisp(MESSAGE *psMessage, UDWORD player);
-static void checkMessages(MSG_VIEWDATA *psViewData);
 
 /* Creating a new message
  * new is a pointer to a pointer to the new message
@@ -284,32 +272,7 @@ MESSAGE * addBeaconMessage(MESSAGE_TYPE msgType, BOOL proxPos, UDWORD player)
 	return psBeaconMsgToAdd;
 }
 
-/*Add a message to the list */
-MESSAGE * addMessage(MESSAGE_TYPE msgType, BOOL proxPos, UDWORD player)
-{
-	//first create a message of the required type
-	MESSAGE* psMsgToAdd = createMessage(msgType, player);
-
-	debug(LOG_MSG, "adding message for player %d, type is %d, proximity is %d", player, msgType, proxPos);
-
-	ASSERT(psMsgToAdd, "createMessage failed");
-	if (!psMsgToAdd)
-	{
-		return NULL;
-	}
-	//then add to the players' list
-	addMessageToList(apsMessages, psMsgToAdd, player);
-
-	//add a proximity display
-	if (msgType == MSG_PROXIMITY)
-	{
-		addProximityDisplay(psMsgToAdd, proxPos, player);
-	}
-
-	return psMsgToAdd;
-}
-
-/* adds a proximity display - holds varaibles that enable the message to be
+/* adds a proximity display - holds variables that enable the message to be
  displayed in the Intelligence Screen*/
 static void addProximityDisplay(MESSAGE *psMessage, BOOL proxPos, UDWORD player)
 {
@@ -344,37 +307,60 @@ static void addProximityDisplay(MESSAGE *psMessage, BOOL proxPos, UDWORD player)
 	psToAdd->selected = false;
 	psToAdd->strobe = 0;
 
-	//now add it to the top of the list
-	psToAdd->psNext = apsProxDisp[player];
-	apsProxDisp[player] = psToAdd;
-
 	//add a button to the interface
-	intAddProximityButton(psToAdd, currentNumProxDisplays);
-	currentNumProxDisplays++;
+	if (intAddProximityButton(psToAdd, currentNumProxDisplays))
+	{
+		// Now add it to the top of the list. Be aware that this
+		// check means that messages and proximity displays can
+		// become out of sync - but this should never happen.
+		psToAdd->psNext = apsProxDisp[player];
+		apsProxDisp[player] = psToAdd;
+		currentNumProxDisplays++;
+	}
+	else
+	{
+		free(psToAdd);	// clean up
+	}
 }
 
-/*remove a message */
-void removeMessage(MESSAGE *psDel, UDWORD player)
+/*Add a message to the list */
+MESSAGE * addMessage(MESSAGE_TYPE msgType, BOOL proxPos, UDWORD player)
 {
-	ASSERT_OR_RETURN( , player < MAX_PLAYERS, "Bad player");
-	ASSERT_OR_RETURN( , psDel != NULL, "Bad message");
-	debug(LOG_MSG, "removing message for player %d", player);
+	//first create a message of the required type
+	MESSAGE* psMsgToAdd = createMessage(msgType, player);
 
-	if (psDel->type == MSG_PROXIMITY)
+	debug(LOG_MSG, "adding message for player %d, type is %d, proximity is %d", player, msgType, proxPos);
+
+	ASSERT(psMsgToAdd, "createMessage failed");
+	if (!psMsgToAdd)
 	{
-		removeProxDisp(psDel, player);
+		return NULL;
 	}
-	removeMessageFromList(apsMessages, psDel, player);
+	//then add to the players' list
+	addMessageToList(apsMessages, psMsgToAdd, player);
+
+	//add a proximity display
+	if (msgType == MSG_PROXIMITY)
+	{
+		addProximityDisplay(psMsgToAdd, proxPos, player);
+	}
+
+	return psMsgToAdd;
 }
 
 /* remove a proximity display */
-void removeProxDisp(MESSAGE *psMessage, UDWORD player)
+static void removeProxDisp(MESSAGE *psMessage, UDWORD player)
 {
 	PROXIMITY_DISPLAY		*psCurr, *psPrev;
 
 	ASSERT_OR_RETURN( , player < MAX_PLAYERS, "Bad player");
 	ASSERT_OR_RETURN( , psMessage != NULL, "Bad message");
 
+	if (!apsProxDisp[player])
+	{
+		return;	// no corresponding proximity display
+	}
+
 	//find the proximity display for this message
 	if (apsProxDisp[player]->psMessage == psMessage)
 	{
@@ -403,6 +389,20 @@ void removeProxDisp(MESSAGE *psMessage, UDWORD player)
 	}
 }
 
+/*remove a message */
+void removeMessage(MESSAGE *psDel, UDWORD player)
+{
+	ASSERT_OR_RETURN( , player < MAX_PLAYERS, "Bad player");
+	ASSERT_OR_RETURN( , psDel != NULL, "Bad message");
+	debug(LOG_MSG, "removing message for player %d", player);
+
+	if (psDel->type == MSG_PROXIMITY)
+	{
+		removeProxDisp(psDel, player);
+	}
+	removeMessageFromList(apsMessages, psDel, player);
+}
+
 /* Remove all Messages*/
 void freeMessages(void)
 {
@@ -833,6 +833,8 @@ VIEWDATA * getViewData(const char *pName)
 	VIEWDATA_LIST *psList = NULL;
 	unsigned int i = 0;
 
+	ASSERT_OR_RETURN(NULL, pName[0] != '\0', "Trying to find empty message name");
+
 	for (psList = apsViewData; psList != NULL; psList = psList->psNext)
 	{
 		for (i = 0; i < psList->numViewData; i++)
@@ -845,6 +847,16 @@ VIEWDATA * getViewData(const char *pName)
 		}
 	}
 
+	// Dump mismatched candidates
+	debug(LOG_ERROR, "No match for view data, dumping whole list:");
+	for (psList = apsViewData; psList != NULL; psList = psList->psNext)
+	{
+		for (i = 0; i < psList->numViewData; i++)
+		{
+			debug(LOG_ERROR, "%s != %s", psList->psViewData[i].pName, pName);
+		}
+	}
+
 	ASSERT(false, "Unable to find viewdata for message %s", pName);
 	return NULL;
 }
@@ -857,6 +869,25 @@ BOOL messageShutdown(void)
 	return true;
 }
 
+//check for any messages using this viewdata and remove them
+static void checkMessages(MSG_VIEWDATA *psViewData)
+{
+	MESSAGE			*psCurr, *psNext;
+	UDWORD			i;
+
+	for (i=0; i < MAX_PLAYERS; i++)
+	{
+		for (psCurr = apsMessages[i]; psCurr != NULL; psCurr = psNext)
+		{
+			psNext = psCurr->psNext;
+			if (psCurr->pViewData == psViewData)
+			{
+				removeMessage(psCurr, i);
+			}
+		}
+	}
+}
+
 /* Release the viewdata memory */
 void viewDataShutDown(VIEWDATA *psViewData)
 {
@@ -1001,6 +1032,7 @@ void displayProximityMessage(PROXIMITY_DISPLAY *psProxDisp)
 	psProxDisp->psMessage->read = true;
 }
 
+// NOTE: Unused! PROXIMITY_DISPLAY * getProximityDisplay(MESSAGE *psMessage)
 PROXIMITY_DISPLAY * getProximityDisplay(MESSAGE *psMessage)
 {
 	PROXIMITY_DISPLAY	*psCurr;
@@ -1022,51 +1054,3 @@ PROXIMITY_DISPLAY * getProximityDisplay(MESSAGE *psMessage)
 	return NULL;
 }
 
-//check for any messages using this viewdata and remove them
-void checkMessages(MSG_VIEWDATA *psViewData)
-{
-	MESSAGE			*psCurr, *psNext;
-	UDWORD			i;
-
-	for (i=0; i < MAX_PLAYERS; i++)
-	{
-		for (psCurr = apsMessages[i]; psCurr != NULL; psCurr = psNext)
-		{
-			psNext = psCurr->psNext;
-			if (psCurr->pViewData == psViewData)
-			{
-				removeMessage(psCurr, i);
-			}
-		}
-	}
-}
-
-//add proximity messages for all untapped VISIBLE oil resources
-void addOilResourceProximities(void)
-{
-	FEATURE     *psFeat;
-	MESSAGE     *psMessage;
-
-	//look thru the features to find oil resources
-	for (psFeat = apsFeatureLists[0]; psFeat != NULL; psFeat = psFeat->psNext)
-	{
-		if (psFeat->psStats->subType == FEAT_OIL_RESOURCE)
-		{
-			//check to see if the feature is visible to the selected player
-			if (psFeat->visible[selectedPlayer])
-			{
-				//if there isn't an oil derrick built on it
-				if (!TileHasStructure(mapTile(map_coord(psFeat->pos.x),
-					map_coord(psFeat->pos.y))))
-				{
-					//add a proximity message
-					psMessage = addMessage(MSG_PROXIMITY, true, selectedPlayer);
-					if (psMessage)
-					{
-						psMessage->pViewData = (MSG_VIEWDATA *)psFeat;
-					}
-				}
-			}
-		}
-	}
-}
