@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,57 +54,28 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 /* Substitute the variable and function names.  */
-#define yyparse message_parse
-#define yylex   message_lex
-#define yyerror message_error
-#define yylval  message_lval
-#define yychar  message_char
-#define yydebug message_debug
-#define yynerrs message_nerrs
-
-
-/* Tokens.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     TEXT_T = 258,
-     QTEXT_T = 259,
-     NULL_T = 260,
-     VIEW_T_RES = 261,
-     VIEW_T_RPL = 262,
-     VIEW_T_PROX = 263,
-     VIEW_T_RPLX = 264,
-     VIEW_T_BEACON = 265,
-     IMD_NAME_T = 266,
-     IMD_NAME2_T = 267,
-     SEQUENCE_NAME_T = 268,
-     AUDIO_NAME_T = 269
-   };
-#endif
-/* Tokens.  */
-#define TEXT_T 258
-#define QTEXT_T 259
-#define NULL_T 260
-#define VIEW_T_RES 261
-#define VIEW_T_RPL 262
-#define VIEW_T_PROX 263
-#define VIEW_T_RPLX 264
-#define VIEW_T_BEACON 265
-#define IMD_NAME_T 266
-#define IMD_NAME2_T 267
-#define SEQUENCE_NAME_T 268
-#define AUDIO_NAME_T 269
-
-
+#define yyparse         message_parse
+#define yylex           message_lex
+#define yyerror         message_error
+#define yylval          message_lval
+#define yychar          message_char
+#define yydebug         message_debug
+#define yynerrs         message_nerrs
 
 
 /* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
 #line 20 "message_parser.y"
 
 /** @file
@@ -179,6 +149,9 @@ static void freeViewDataMessageList(VIEWDATAMESSAGE* list)
 
 
 
+/* Line 189 of yacc.c  */
+#line 154 "message_parser.tab.c"
+
 /* Enabling traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -197,10 +170,51 @@ static void freeViewDataMessageList(VIEWDATAMESSAGE* list)
 # define YYTOKEN_TABLE 0
 #endif
 
+
+/* Tokens.  */
+#ifndef YYTOKENTYPE
+# define YYTOKENTYPE
+   /* Put the tokens into the symbol table, so that GDB and other debuggers
+      know about them.  */
+   enum yytokentype {
+     TEXT_T = 258,
+     QTEXT_T = 259,
+     NULL_T = 260,
+     VIEW_T_RES = 261,
+     VIEW_T_RPL = 262,
+     VIEW_T_PROX = 263,
+     VIEW_T_RPLX = 264,
+     VIEW_T_BEACON = 265,
+     IMD_NAME_T = 266,
+     IMD_NAME2_T = 267,
+     SEQUENCE_NAME_T = 268,
+     AUDIO_NAME_T = 269
+   };
+#endif
+/* Tokens.  */
+#define TEXT_T 258
+#define QTEXT_T 259
+#define NULL_T 260
+#define VIEW_T_RES 261
+#define VIEW_T_RPL 262
+#define VIEW_T_PROX 263
+#define VIEW_T_RPLX 264
+#define VIEW_T_BEACON 265
+#define IMD_NAME_T 266
+#define IMD_NAME2_T 267
+#define SEQUENCE_NAME_T 268
+#define AUDIO_NAME_T 269
+
+
+
+
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 94 "message_parser.y"
 {
+
+/* Line 214 of yacc.c  */
+#line 94 "message_parser.y"
+
 	char*                   sval;
 	struct VIEWDATAMESSAGE* viewdatamsg;
 	struct TEXT_MESSAGE*    txtmsg;
@@ -211,22 +225,23 @@ typedef union YYSTYPE
 		const char**    stringArray;
 		unsigned int    count;
 	}                       msg_list;
-}
-/* Line 187 of yacc.c.  */
-#line 217 "message_parser.tab.c"
-	YYSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 233 "message_parser.tab.c"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 230 "message_parser.tab.c"
+/* Line 264 of yacc.c  */
+#line 245 "message_parser.tab.c"
 
 #ifdef short
 # undef short
@@ -301,14 +316,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -389,9 +404,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -425,12 +440,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -822,17 +837,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -866,11 +884,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1146,6 +1164,8 @@ yydestruct (yymsg, yytype, yyvaluep)
   switch (yytype)
     {
       case 3: /* "TEXT_T" */
+
+/* Line 1000 of yacc.c  */
 #line 120 "message_parser.y"
 	{
 #ifndef WZ_OS_WIN
@@ -1156,9 +1176,13 @@ yydestruct (yymsg, yytype, yyvaluep)
 		free(s);
 #endif
 };
-#line 1160 "message_parser.tab.c"
+
+/* Line 1000 of yacc.c  */
+#line 1182 "message_parser.tab.c"
 	break;
       case 4: /* "QTEXT_T" */
+
+/* Line 1000 of yacc.c  */
 #line 120 "message_parser.y"
 	{
 #ifndef WZ_OS_WIN
@@ -1169,23 +1193,35 @@ yydestruct (yymsg, yytype, yyvaluep)
 		free(s);
 #endif
 };
-#line 1173 "message_parser.tab.c"
+
+/* Line 1000 of yacc.c  */
+#line 1199 "message_parser.tab.c"
 	break;
       case 25: /* "all_messages" */
+
+/* Line 1000 of yacc.c  */
 #line 147 "message_parser.y"
 	{
 	freeViewDataMessageList((yyvaluep->viewdatamsg));
 };
-#line 1180 "message_parser.tab.c"
+
+/* Line 1000 of yacc.c  */
+#line 1210 "message_parser.tab.c"
 	break;
       case 26: /* "message" */
+
+/* Line 1000 of yacc.c  */
 #line 147 "message_parser.y"
 	{
 	freeViewDataMessageList((yyvaluep->viewdatamsg));
 };
-#line 1187 "message_parser.tab.c"
+
+/* Line 1000 of yacc.c  */
+#line 1221 "message_parser.tab.c"
 	break;
       case 27: /* "research_message" */
+
+/* Line 1000 of yacc.c  */
 #line 134 "message_parser.y"
 	{
 	// Force type checking by the compiler
@@ -1199,9 +1235,13 @@ yydestruct (yymsg, yytype, yyvaluep)
 		free(r);
 	}
 };
-#line 1203 "message_parser.tab.c"
+
+/* Line 1000 of yacc.c  */
+#line 1241 "message_parser.tab.c"
 	break;
       case 28: /* "imd_name" */
+
+/* Line 1000 of yacc.c  */
 #line 120 "message_parser.y"
 	{
 #ifndef WZ_OS_WIN
@@ -1212,9 +1252,13 @@ yydestruct (yymsg, yytype, yyvaluep)
 		free(s);
 #endif
 };
-#line 1216 "message_parser.tab.c"
+
+/* Line 1000 of yacc.c  */
+#line 1258 "message_parser.tab.c"
 	break;
       case 29: /* "imd_name2" */
+
+/* Line 1000 of yacc.c  */
 #line 120 "message_parser.y"
 	{
 #ifndef WZ_OS_WIN
@@ -1225,70 +1269,90 @@ yydestruct (yymsg, yytype, yyvaluep)
 		free(s);
 #endif
 };
-#line 1229 "message_parser.tab.c"
-	break;
-      case 30: /* "sequence_name" */
-#line 120 "message_parser.y"
-	{
-#ifndef WZ_OS_WIN
-	// Force type checking by the compiler
-	char * const s = (yyvaluep->sval);
 
-	if (s)
-		free(s);
-#endif
-};
-#line 1242 "message_parser.tab.c"
-	break;
-      case 31: /* "audio_name" */
-#line 120 "message_parser.y"
-	{
-#ifndef WZ_OS_WIN
-	// Force type checking by the compiler
-	char * const s = (yyvaluep->sval);
-
-	if (s)
-		free(s);
-#endif
-};
-#line 1255 "message_parser.tab.c"
-	break;
-      case 32: /* "optional_string" */
-#line 120 "message_parser.y"
-	{
-#ifndef WZ_OS_WIN
-	// Force type checking by the compiler
-	char * const s = (yyvaluep->sval);
-
-	if (s)
-		free(s);
-#endif
-};
-#line 1268 "message_parser.tab.c"
-	break;
-      case 34: /* "text_messages" */
-#line 130 "message_parser.y"
-	{
-	freeTextMessageList((yyvaluep->txtmsg));
-};
+/* Line 1000 of yacc.c  */
 #line 1275 "message_parser.tab.c"
 	break;
-      case 35: /* "text_message" */
+      case 30: /* "sequence_name" */
+
+/* Line 1000 of yacc.c  */
+#line 120 "message_parser.y"
+	{
+#ifndef WZ_OS_WIN
+	// Force type checking by the compiler
+	char * const s = (yyvaluep->sval);
+
+	if (s)
+		free(s);
+#endif
+};
+
+/* Line 1000 of yacc.c  */
+#line 1292 "message_parser.tab.c"
+	break;
+      case 31: /* "audio_name" */
+
+/* Line 1000 of yacc.c  */
+#line 120 "message_parser.y"
+	{
+#ifndef WZ_OS_WIN
+	// Force type checking by the compiler
+	char * const s = (yyvaluep->sval);
+
+	if (s)
+		free(s);
+#endif
+};
+
+/* Line 1000 of yacc.c  */
+#line 1309 "message_parser.tab.c"
+	break;
+      case 32: /* "optional_string" */
+
+/* Line 1000 of yacc.c  */
+#line 120 "message_parser.y"
+	{
+#ifndef WZ_OS_WIN
+	// Force type checking by the compiler
+	char * const s = (yyvaluep->sval);
+
+	if (s)
+		free(s);
+#endif
+};
+
+/* Line 1000 of yacc.c  */
+#line 1326 "message_parser.tab.c"
+	break;
+      case 34: /* "text_messages" */
+
+/* Line 1000 of yacc.c  */
 #line 130 "message_parser.y"
 	{
 	freeTextMessageList((yyvaluep->txtmsg));
 };
-#line 1282 "message_parser.tab.c"
+
+/* Line 1000 of yacc.c  */
+#line 1337 "message_parser.tab.c"
+	break;
+      case 35: /* "text_message" */
+
+/* Line 1000 of yacc.c  */
+#line 130 "message_parser.y"
+	{
+	freeTextMessageList((yyvaluep->txtmsg));
+};
+
+/* Line 1000 of yacc.c  */
+#line 1348 "message_parser.tab.c"
 	break;
 
       default:
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1304,11 +1368,10 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1316,9 +1379,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1342,14 +1405,39 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1357,51 +1445,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1431,7 +1496,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1439,7 +1503,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1462,9 +1525,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1475,7 +1537,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1485,6 +1546,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1493,16 +1557,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1534,20 +1598,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1587,6 +1647,8 @@ yyreduce:
   switch (yyn)
     {
         case 2:
+
+/* Line 1455 of yacc.c  */
 #line 154 "message_parser.y"
     {
 					unsigned int numData = 0, i;
@@ -1630,6 +1692,8 @@ yyreduce:
     break;
 
   case 4:
+
+/* Line 1455 of yacc.c  */
 #line 197 "message_parser.y"
     {
 					(yyvsp[(1) - (2)].viewdatamsg)->psNext = (yyvsp[(2) - (2)].viewdatamsg);
@@ -1638,6 +1702,8 @@ yyreduce:
     break;
 
   case 5:
+
+/* Line 1455 of yacc.c  */
 #line 204 "message_parser.y"
     {
 					(yyval.viewdatamsg) = malloc(sizeof(*(yyval.viewdatamsg)));
@@ -1663,6 +1729,8 @@ yyreduce:
     break;
 
   case 6:
+
+/* Line 1455 of yacc.c  */
 #line 228 "message_parser.y"
     {
 					(yyval.researchdata) = malloc(sizeof(*(yyval.researchdata)));
@@ -1711,26 +1779,36 @@ yyreduce:
     break;
 
   case 7:
+
+/* Line 1455 of yacc.c  */
 #line 274 "message_parser.y"
     { (yyval.sval) = (yyvsp[(3) - (3)].sval); }
     break;
 
   case 9:
+
+/* Line 1455 of yacc.c  */
 #line 278 "message_parser.y"
     { (yyval.sval) = (yyvsp[(3) - (3)].sval); }
     break;
 
   case 11:
+
+/* Line 1455 of yacc.c  */
 #line 282 "message_parser.y"
     { (yyval.sval) = (yyvsp[(3) - (3)].sval); }
     break;
 
   case 13:
+
+/* Line 1455 of yacc.c  */
 #line 286 "message_parser.y"
     { (yyval.sval) = (yyvsp[(3) - (3)].sval); }
     break;
 
   case 17:
+
+/* Line 1455 of yacc.c  */
 #line 295 "message_parser.y"
     {
 					size_t bytes = 0;
@@ -1765,8 +1843,8 @@ yyreduce:
 						}
 
 						stringStart = (char*)&(yyval.msg_list).stringArray[(yyval.msg_list).count];
-						for (psCur = (yyvsp[(2) - (3)].txtmsg), i = 0, stringStart;
-						     psCur != NULL && i < (yyval.msg_list).count;
+						for (psCur = (yyvsp[(2) - (3)].txtmsg), i = 0;
+                                                     stringStart && psCur != NULL && i < (yyval.msg_list).count;
 						     psCur = psCur->psNext, ++i)
 						{
 							assert(&stringStart[strlen(psCur->str)] - (char*)(yyval.msg_list).stringArray < bytes);
@@ -1785,6 +1863,8 @@ yyreduce:
     break;
 
   case 20:
+
+/* Line 1455 of yacc.c  */
 #line 351 "message_parser.y"
     {
 					(yyvsp[(1) - (3)].txtmsg)->psNext = (yyvsp[(3) - (3)].txtmsg);
@@ -1793,6 +1873,8 @@ yyreduce:
     break;
 
   case 21:
+
+/* Line 1455 of yacc.c  */
 #line 358 "message_parser.y"
     {
 					const char * const msg = strresGetString(psStringRes, (yyvsp[(1) - (1)].sval));
@@ -1818,6 +1900,8 @@ yyreduce:
     break;
 
   case 22:
+
+/* Line 1455 of yacc.c  */
 #line 380 "message_parser.y"
     {
 					(yyval.txtmsg) = malloc(sizeof(*(yyval.txtmsg)));
@@ -1835,6 +1919,8 @@ yyreduce:
     break;
 
   case 23:
+
+/* Line 1455 of yacc.c  */
 #line 394 "message_parser.y"
     {
 					(yyval.txtmsg) = malloc(sizeof(*(yyval.txtmsg)));
@@ -1852,8 +1938,9 @@ yyreduce:
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 1857 "message_parser.tab.c"
+
+/* Line 1455 of yacc.c  */
+#line 1944 "message_parser.tab.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1864,7 +1951,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -1929,7 +2015,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -1946,7 +2032,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -2003,9 +2089,6 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -2030,7 +2113,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -2041,7 +2124,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
