@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -21,8 +21,15 @@
 #ifndef __INCLUDED_SRC_MODDING_H__
 #define __INCLUDED_SRC_MODDING_H__
 
-void addSubdirs( const char * basedir, const char * subdir, const BOOL appendToPath, char * checkList[] );
+void addSubdirs( const char * basedir, const char * subdir, const bool appendToPath, char * checkList[], bool addToModList );
 void removeSubdirs( const char * basedir, const char * subdir, char * checkList[] );
 void printSearchPath( void );
 
+void setOverrideMods(char * modlist);
+void clearOverrideMods(void);
+
+void addLoadedMod(const char * modname);
+void clearLoadedMods(void);
+char * getModList(void);
+
 #endif // __INCLUDED_SRC_MODDING_H__
