@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -219,8 +219,6 @@ static void	moveCalcBoundary(DROID *psDroid);
 /* Turn a vector into an angle - returns a float (!) */
 static float vectorToAngle(float vx, float vy);
 
-static BOOL	g_bFormationSpeedLimitingOn = true;
-
 /* Return the difference in directions */
 static UDWORD dirDiff(SDWORD start, SDWORD end)
 {
@@ -315,7 +313,7 @@ static BOOL moveDroidToBase(DROID *psDroid, UDWORD x, UDWORD y, BOOL bFormation)
 
 	CHECK_DROID(psDroid);
 
-	if(bMultiPlayer && (psDroid->sMove.Status != MOVEWAITROUTE))
+	if (bMultiMessages && (psDroid->sMove.Status != MOVEWAITROUTE))
 	{
 		if(SendDroidMove(psDroid,x,y,bFormation) == false)
 		{// dont make the move since we'll recv it anyway
@@ -697,9 +695,10 @@ void updateDroidOrientation(DROID *psDroid)
 	double dx, dy;
 	double direction, pitch, roll;
 
-	if(psDroid->droidType == DROID_PERSON || cyborgDroid(psDroid) || psDroid->droidType == DROID_TRANSPORTER)
-	{
-		/* These guys always stand upright */
+	if(psDroid->droidType == DROID_PERSON || cyborgDroid(psDroid) || psDroid->droidType == DROID_TRANSPORTER 
+		|| isFlying(psDroid)) 
+	{ 
+		/* The ground doesn't affect the pitch/roll of these droids*/ 
 		return;
 	}
 
@@ -1049,6 +1048,7 @@ static BOOL moveBlocked(DROID *psDroid)
 				psDroid->order = DORDER_NONE;
 				setDroidTarget(psDroid, NULL);
 				psDroid->psTarStats = NULL;
+				psDroid->lastFrustratedTime = gameTime;	// try desperate things
 			}
 			objTrace(psDroid->id, "Trying to reroute to (%d,%d)", psDroid->sMove.DestinationX, psDroid->sMove.DestinationY);
 			moveDroidTo(psDroid, psDroid->sMove.DestinationX, psDroid->sMove.DestinationY);
@@ -1858,19 +1858,9 @@ static BOOL moveReachedWayPoint(DROID *psDroid)
 	return false;
 }
 
-void moveToggleFormationSpeedLimiting( void )
+static BOOL moveFormationSpeedLimitingOn( void )
 {
-	g_bFormationSpeedLimitingOn = !g_bFormationSpeedLimitingOn;
-}
-
-void moveSetFormationSpeedLimiting( BOOL bVal )
-{
-	g_bFormationSpeedLimitingOn = bVal;
-}
-
-BOOL moveFormationSpeedLimitingOn( void )
-{
-	return g_bFormationSpeedLimitingOn;
+	return false;
 }
 
 #define MAX_SPEED_PITCH  60
@@ -2420,7 +2410,7 @@ static void moveAdjustVtolHeight( DROID * psDroid, UDWORD iMapHeight )
 {
 	UDWORD	iMinHeight, iMaxHeight, iLevelHeight;
 
-	if ( psDroid->droidType == DROID_TRANSPORTER )
+	if ( psDroid->droidType == DROID_TRANSPORTER && !bMultiPlayer )
 	{
 		iMinHeight   = 2*VTOL_HEIGHT_MIN;
 		iLevelHeight = 2*VTOL_HEIGHT_LEVEL;
@@ -2742,27 +2732,26 @@ moveUpdateCyborgModel( DROID *psDroid, SDWORD moveSpeed, SDWORD moveDir, UBYTE o
 	psDroid->roll  = 0;
 }
 
-static BOOL moveDescending( DROID *psDroid, UDWORD iMapHeight )
+static void moveDescending( DROID *psDroid, UDWORD iMapHeight )
 {
-	if ( psDroid->pos.z > iMapHeight )
+	psDroid->sMove.speed = 0;
+
+	if ( psDroid->pos.z > iMapHeight)
 	{
 		/* descending */
 		psDroid->sMove.iVertSpeed = (SWORD)-VTOL_VERTICAL_SPEED;
-		psDroid->sMove.speed = 0;
-
-		/* return true to show still descending */
-		return true;
 	}
 	else
 	{
 		/* on floor - stop */
+		psDroid->pos.z = iMapHeight;
 		psDroid->sMove.iVertSpeed = 0;
 
+		/* reset move state */
+		psDroid->sMove.Status = MOVEINACTIVE;
+
 		/* conform to terrain */
 		updateDroidOrientation(psDroid);
-
-		/* return false to show stopped descending */
-		return false;
 	}
 }
 
@@ -2951,7 +2940,8 @@ static void checkLocalFeatures(DROID *psDroid)
 
 		if(bMultiPlayer && (psObj->player == ANYPLAYER))
 		{
-			giftPower(ANYPLAYER,selectedPlayer,true);			// give power and tell everyone.
+			giftPower(ANYPLAYER,selectedPlayer,true);			// give power
+			CONPRINTF(ConsoleString,(ConsoleString,_("You found %u power in an oil drum."),OILDRUM_POWER));
 			addOilDrum(1);
 		}
 		else
@@ -3249,11 +3239,8 @@ void moveUpdateDroid(DROID *psDroid)
 			 (psDroid->action == DACTION_MOVE) || (psDroid->action == DACTION_WAITFORREARM) ||
 			 (psDroid->action == DACTION_WAITDURINGREARM)  || (psDroid->action == DACTION_FIRESUPPORT))*/
 		{
-			if ( moveDescending( psDroid, iZ ) == false )
-			{
-				/* reset move state */
-				psDroid->sMove.Status = MOVEINACTIVE;
-			}
+			moveDescending( psDroid, iZ );
+			
 /*			else
 			{
 				UDWORD	landX, landY;
@@ -3343,7 +3330,7 @@ void moveUpdateDroid(DROID *psDroid)
 //	}
 
 	/* If it's sitting in water then it's got to go with the flow! */
-	if (terrainType(mapTile(map_coord(psDroid->pos.x), map_coord(psDroid->pos.y))) == TER_WATER)
+	if (worldOnMap(psDroid->pos.x, psDroid->pos.y) && terrainType(mapTile(map_coord(psDroid->pos.x), map_coord(psDroid->pos.y))) == TER_WATER)
 	{
 		updateDroidOrientation(psDroid);
 	}
@@ -3357,5 +3344,6 @@ void moveUpdateDroid(DROID *psDroid)
 	}
 
 	movePlayAudio( psDroid, bStarted, bStopped, moveSpeed );
+	ASSERT(droidOnMap(psDroid), "%s moved off map (%u, %u)->(%u, %u)", droidGetName(psDroid), oldx, oldy, (UDWORD)psDroid->pos.x, (UDWORD)psDroid->pos.y);
 	CHECK_DROID(psDroid);
 }
