@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -83,10 +83,6 @@ extern void moveUpdateTracked(DROID *psDroid);
 /* update body and turret to local slope */
 extern void updateDroidOrientation(DROID *psDroid);
 
-extern void moveSetFormationSpeedLimiting( BOOL );
-extern void moveToggleFormationSpeedLimiting( void );
-extern BOOL moveFormationSpeedLimitingOn( void );
-
 /* audio callback used to kill movement sounds */
 extern BOOL moveCheckDroidMovingAndVisible( void *psObj );
 
