@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -46,7 +46,8 @@
 #include "multirecv.h"
 
 #define ANYPLAYER	99
-#define UNKNOWN		99
+#define DORDER_UNKNOWN		99
+#define DORDER_UNKNOWN_ALT 100
 
 // ////////////////////////////////////////////////////////////////////////////
 // Local Prototypes
@@ -64,7 +65,7 @@ static void ProcessDroidOrder(DROID *psDroid, DROID_ORDER order, UDWORD x, UDWOR
 // happy vtol = vtol ready to go back to attack.
 BOOL sendHappyVtol(const DROID* psDroid)
 {
-	if (!bMultiPlayer)
+	if (!bMultiMessages)
 		return true;
 
 	if (!myResponsibility(psDroid->player))
@@ -123,7 +124,7 @@ BOOL recvHappyVtol()
 // Send
 BOOL sendDroidSecondary(const DROID* psDroid, SECONDARY_ORDER sec, SECONDARY_STATE state)
 {
-	if (!bMultiPlayer)
+	if (!bMultiMessages)
 		return true;
 
 	NETbeginEncode(NET_SECONDARY, NET_ALL_PLAYERS);
@@ -200,7 +201,7 @@ BOOL recvDroidSecondary()
 
 BOOL sendDroidSecondaryAll(const DROID* psDroid)
 {
-	if (!bMultiPlayer)
+	if (!bMultiMessages)
 		return true;
 
 	NETbeginEncode(NET_SECONDARY_ALL, NET_ALL_PLAYERS);
@@ -251,7 +252,7 @@ BOOL recvDroidSecondaryAll()
  */
 BOOL sendDroidEmbark(const DROID* psDroid, const DROID* psTransporter)
 {
-	if (!bMultiPlayer)
+	if (!bMultiMessages)
 		return true;
 
 	NETbeginEncode(NET_DROIDEMBARK, NET_ALL_PLAYERS);
@@ -338,7 +339,7 @@ BOOL recvDroidEmbark()
  */
 BOOL sendDroidDisEmbark(const DROID* psDroid, const DROID* psTransporter)
 {
-	if (!bMultiPlayer)
+	if (!bMultiMessages)
 		return true;
 
 	NETbeginEncode(NET_DROIDDISEMBARK, NET_ALL_PLAYERS);
@@ -440,7 +441,7 @@ BOOL recvDroidDisEmbark()
 // posibly Send an updated droid movement order.
 BOOL SendDroidMove(const DROID* psDroid, uint32_t x, uint32_t y, BOOL formation)
 {
-	if (!bMultiPlayer)
+	if (!bMultiMessages)
 		return true;
 
 	ASSERT(x > 0 && y > 0, "SendDroidMove: Invalid move order");
@@ -500,7 +501,7 @@ BOOL recvDroidMove()
 		}
 		if (!IdToDroid(droid, player, &psDroid))
 		{
-			debug(LOG_ERROR, "Packet from %d refers to non-existent droid %u, [%s : p%d]",
+			debug(LOG_NEVER, "Packet from %d refers to non-existent droid %u, [%s : p%d]",
 				NETgetSource(), droid, isHumanPlayer(player) ? "Human" : "AI", player);
 			return false;
 		}
@@ -524,10 +525,11 @@ BOOL recvDroidMove()
 // Send a new Droid to the other players
 BOOL SendDroid(const DROID_TEMPLATE* pTemplate, uint32_t x, uint32_t y, uint8_t player, uint32_t id)
 {
-	if (!bMultiPlayer)
+	if (!bMultiMessages)
 		return true;
 
 	ASSERT(x != 0 && y != 0, "SendDroid: Invalid droid coordinates");
+	ASSERT( player < MAX_PLAYERS, "invalid player %u", player);
 
 	// Dont send other droids during campaign setup
 	if (ingame.localJoiningInProgress)
@@ -542,7 +544,7 @@ BOOL SendDroid(const DROID_TEMPLATE* pTemplate, uint32_t x, uint32_t y, uint8_t
 		return false;
 	}
 
-	debug(LOG_SYNC, "Droid created with id of %u", id);
+	debug(LOG_SYNC, "Droid sent with id of %u", id);
 	NETbeginEncode(NET_DROID, NET_ALL_PLAYERS);
 	{
 		Vector3uw pos = { x, y, 0 };
@@ -585,6 +587,9 @@ BOOL recvDroid()
 		pT = IdToTemplate(templateID, player);
 	}
 	NETend();
+
+	ASSERT( player < MAX_PLAYERS, "invalid player %u", player);
+
 	debug(LOG_LIFE, "<=== getting Droid from %u id of %u ",player,id);
 	if ((pos.x == 0 && pos.y == 0) || pos.x > world_coord(mapWidth) || pos.y > world_coord(mapHeight))
 	{
@@ -603,7 +608,7 @@ BOOL recvDroid()
 
 	// forget about calculating the power, we *know* they built it, so we set
 	// their power accordingly on the local machine.
-	setPower(player, power);
+	setPower((uint32_t) player, power);
 	debug(LOG_SYNC, "Syncing players %u power to %u", player, power);
 
 	// Create that droid on this machine.
@@ -644,14 +649,14 @@ typedef enum {
  * Droid Group/selection orders.
  * Minimises comms by sending orders for whole groups, rather than each droid
  */
-BOOL SendGroupOrderSelected(uint8_t player, uint32_t x, uint32_t y, const BASE_OBJECT* psObj)
+BOOL SendGroupOrderSelected(uint8_t player, uint32_t x, uint32_t y, const BASE_OBJECT* psObj, BOOL altOrder)
 {
-	if (!bMultiPlayer)
+	if (!bMultiMessages)
 		return true;
 
 	NETbeginEncode(NET_GROUPORDER, NET_ALL_PLAYERS);
 	{
-		DROID_ORDER order = UNKNOWN;
+		DROID_ORDER order = (altOrder?DORDER_UNKNOWN_ALT:DORDER_UNKNOWN);
 		BOOL subType = (psObj) ? true : false, cmdOrder = false;
 		DROID* psDroid;
 		uint8_t droidCount;
@@ -720,7 +725,7 @@ BOOL SendGroupOrderGroup(const DROID_GROUP* psGroup, DROID_ORDER order, uint32_t
 		return false;
 	}
 
-	if (!bMultiPlayer)
+	if (!bMultiMessages)
 		return true;
 
 	NETbeginEncode(NET_GROUPORDER, NET_ALL_PLAYERS);
@@ -846,7 +851,7 @@ BOOL recvGroupOrder()
 	NETend();
 
 	/* Check if the order is valid */
-	if (order != UNKNOWN && ((subType && !validOrderForObj(order)) || (!subType && !validOrderForLoc(order))))
+	if (order != DORDER_UNKNOWN && order != DORDER_UNKNOWN_ALT && ((subType && !validOrderForObj(order)) || (!subType && !validOrderForLoc(order))))
 	{
 		debug(LOG_ERROR, "Invalid group order received from %d, [%s : p%d]", NETgetSource(),
 			isHumanPlayer(player) ? "Human" : "AI", player);
@@ -863,7 +868,7 @@ BOOL recvGroupOrder()
 		// Retrieve the droid associated with the current ID
 		if (!IdToDroid(droidIDs[i], ANYPLAYER, &psDroid))
 		{
-			debug(LOG_ERROR, "Packet from %d refers to non-existent droid %u, [%s : p%d]",
+			debug(LOG_NEVER, "Packet from %d refers to non-existent droid %u, [%s : p%d]",
 				NETgetSource(), droidIDs[i], isHumanPlayer(player) ? "Human" : "AI", player);
 			continue; // continue working on next droid; crossing fingers...
 		}
@@ -918,7 +923,7 @@ BOOL recvGroupOrder()
 // Droid update information
 BOOL SendDroidInfo(const DROID* psDroid, DROID_ORDER order, uint32_t x, uint32_t y, const BASE_OBJECT* psObj)
 {
-	if (!bMultiPlayer)
+	if (!bMultiMessages)
 		return true;
 
 	if (!myResponsibility(psDroid->player))
@@ -974,7 +979,7 @@ BOOL recvDroidInfo()
 
 		if (!IdToDroid(droidId, ANYPLAYER, &psDroid))
 		{
-			debug(LOG_ERROR, "Packet from %d refers to non-existent droid %u, [%s : p%d]",
+			debug(LOG_NEVER, "Packet from %d refers to non-existent droid %u, [%s : p%d]",
 				NETgetSource(), droidId, isHumanPlayer(player) ? "Human" : "AI", player);
 			return false;
 		}
@@ -1034,9 +1039,13 @@ static void ProcessDroidOrder(DROID *psDroid, DROID_ORDER order, uint32_t x, uin
 		}
 
 		// If no specific order was passed work one out based on the location
-		if (order == UNKNOWN)
+		if (order == DORDER_UNKNOWN)
 		{
-			order = chooseOrderLoc(psDroid, x, y);
+			order = chooseOrderLoc(psDroid, x, y, false);
+		}
+		else if (order == DORDER_UNKNOWN_ALT)
+		{
+			order = chooseOrderLoc(psDroid, x, y, true);
 		}
 
 		turnOffMultiMsg(true);
@@ -1080,11 +1089,14 @@ static void ProcessDroidOrder(DROID *psDroid, DROID_ORDER order, uint32_t x, uin
 		}
 
 		// If we didn't sepcify an order, then pick one
-		if (order == UNKNOWN)
+		if (order == DORDER_UNKNOWN)
 		{
-			order = chooseOrderObj(psDroid, psObj);
+			order = chooseOrderObj(psDroid, psObj, false);
+		}
+		else if (order == DORDER_UNKNOWN_ALT)
+		{
+			order = chooseOrderObj(psDroid, psObj, true);
 		}
-
 		turnOffMultiMsg(true);
 		orderDroidObj(psDroid, order, psObj);
 		turnOffMultiMsg(false);
@@ -1096,7 +1108,7 @@ static void ProcessDroidOrder(DROID *psDroid, DROID_ORDER order, uint32_t x, uin
 // Inform other players that a droid has been destroyed
 BOOL SendDestroyDroid(const DROID* psDroid)
 {
-	if (!bMultiPlayer)
+	if (!bMultiMessages)
 	{
 		return true;
 	}
