@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -45,6 +45,7 @@
 #include "scriptcb.h"
 #include "loop.h"
 #include "transporter.h"
+#include "mission.h" // for INVALID_XY
 
 #include "lib/netplay/netplay.h"
 #include "multiplay.h"
@@ -321,10 +322,6 @@ void giftPower(uint8_t from, uint8_t to, BOOL send)
 
 	addPower(to, gifval);
 
-	if (from == ANYPLAYER && to == selectedPlayer)
-	{
-		CONPRINTF(ConsoleString,(ConsoleString,_("You found %u power in an oil drum"),gifval));
-	}
 	if (send)
 	{
 		uint8_t giftType = POWER_GIFT;
@@ -425,13 +422,13 @@ void formAlliance(uint8_t p1, uint8_t p2, BOOL prop, BOOL allowAudio, BOOL allow
 		audio_QueueTrack(ID_ALLIANCE_ACC);
 	}
 
-	if (bMultiPlayer && prop)
+	if (bMultiMessages && prop)
 	{
 		sendAlliance(p1, p2, ALLIANCE_FORMED, false);
 	}
 
 	// Not campaign and alliances are transitive
-	if ((bMultiPlayer || game.type == SKIRMISH) && game.alliance == ALLIANCES_TEAMS)
+	if (game.alliance == ALLIANCES_TEAMS)
 	{
 		giftRadar(p1, p2, false);
 		giftRadar(p2, p1, false);
@@ -519,8 +516,8 @@ void  technologyGiveAway(const STRUCTURE *pS)
 	FEATURE			*pF = NULL;
 	FEATURE_TYPE	type = FEAT_GEN_ARTE;
 
-	// If a factory which is our responsibility got destroyed
-	if (pS->pStructureType->type == REF_FACTORY
+	// If a fully built factory (or with modules under construction) which is our responsibility got destroyed
+	if (pS->pStructureType->type == REF_FACTORY && (pS->status == SS_BUILT || pS->currentBuildPts >= pS->body)
 	 && myResponsibility(pS->player))
 	{
 		x = map_coord(pS->pos.x);
@@ -562,89 +559,6 @@ void  technologyGiveAway(const STRUCTURE *pS)
 	return;
 }
 
-
-
-///////////////////////////////////////////////////////////////////////////////
-// loooosseeeerrr  gifts
-// if the player is losing then give a simple gift.
-
-#define GIFTFREQ (1000*(60*5))			// every 5 mins tops..
-
-static void addLoserGifts(void)
-{
-	static UDWORD	lastgift = 0;
-	int				count, i;
-	uint8_t			player = ONEPLAYER;
-	uint8_t			quantity;
-	uint32_t		x, y;
-	FEATURE			*pF;
-	FEATURE_TYPE	type = FEAT_OIL_DRUM;
-	STRUCTURE		*psStruct;
-
-	if (lastgift > gameTime)
-		lastgift = 0;	// might be a restart
-
-	// Player has no power, so give the player some oil
-	if (apsStructLists[selectedPlayer] && getPower(selectedPlayer) < 10)
-	{
-		// Only proceed if it's been a while
-		if (gameTime - lastgift < GIFTFREQ)
-		{
-			return;
-		}
-
-		// Only proceed if no powergen
-		for (psStruct = apsStructLists[selectedPlayer];
-			 psStruct && psStruct->pStructureType->type != REF_POWER_GEN;
-			 psStruct = psStruct->psNext);
-		if (psStruct)
-		{
-			return;
-		}
-
-		lastgift = gameTime;
-
-		for (i = 0;
-			 i < numFeatureStats && asFeatureStats[i].subType != FEAT_OIL_DRUM;
-			 i++);
-
-		quantity = rand() % 5 + 1;
-
-		NETbeginEncode(NET_ARTIFACTS, NET_ALL_PLAYERS);
-			NETuint8_t(&quantity);
-			NETenum(&type);
-
-			for (count = 0; count < quantity; count++)
-			{
-				x = map_coord(apsStructLists[selectedPlayer]->pos.x);
-				y = map_coord(apsStructLists[selectedPlayer]->pos.y);
-
-				if (!pickATileGen(&x, &y, LOOK_FOR_EMPTY_TILE, zonedPAT))
-				{
-					ASSERT(false, "addlosergifts: Unable to find a free location");
-				}
-
-				NETlogEntry("gift", 0, 0);
-
-				pF = buildFeature((asFeatureStats + i), world_coord(x), world_coord(y), false);
-
-				NETuint32_t(&x);
-				NETuint32_t(&y);
-				NETuint32_t(&pF->id);
-				NETuint8_t(&player);
-
-				if (pF)
-				{
-					// Flag for multiplayer artifacts
-					pF->player = player;
-				}
-			}
-
-		NETend();
-		audio_QueueTrack(ID_GIFT);
-	}
-}
-
 /** Sends a build order for the given feature type to all players
  *  \param subType the type of feature to build
  *  \param x,y the coordinates to place the feature at
@@ -689,46 +603,84 @@ void recvMultiPlayerFeature()
 		}
 	}
 }
+// must match _feature_type in featuredef.h
+static const char *feature_names[] =
+{
+	"FEAT_BUILD_WRECK",
+	"FEAT_HOVER",
+	"FEAT_TANK",
+	"FEAT_GEN_ARTE",
+	"FEAT_OIL_RESOURCE",
+	"FEAT_BOULDER",
+	"FEAT_VEHICLE",
+	"FEAT_BUILDING",
+	"FEAT_DROID",
+	"FEAT_LOS_OBJ",
+	"FEAT_OIL_DRUM",
+	"FEAT_TREE",
+	"FEAT_SKYSCRAPER",
+};
 ///////////////////////////////////////////////////////////////////////////////
 // splatter artifact gifts randomly about.
 void  addMultiPlayerRandomArtifacts(uint8_t quantity, FEATURE_TYPE type)
 {
-	FEATURE		*pF;
-	int			i, count;
+	FEATURE		*pF = NULL;
+	int			i, featureStat, count;
 	uint32_t	x, y;
 	uint8_t		player = ANYPLAYER;
 
+	debug(LOG_FEATURE, "Sending %u artifact(s) type: (%s)", quantity, feature_names[type]);
 	NETbeginEncode(NET_ARTIFACTS, NET_ALL_PLAYERS);
 		NETuint8_t(&quantity);
 		NETenum(&type);
 
-		for(i = 0; i < numFeatureStats && asFeatureStats[i].subType != type; i++);
+		for(featureStat = 0; featureStat < numFeatureStats && asFeatureStats[featureStat].subType != type; featureStat++);
 
 		ASSERT(mapWidth > 20, "map not big enough");
 		ASSERT(mapHeight > 20, "map not big enough");
 
 		for (count = 0; count < quantity; count++)
 		{
-			// Between 10 and mapwidth - 10
-			x = (rand() % (mapWidth - 20)) + 10;
-			y = (rand() % (mapHeight - 20)) + 10;
-
-			if (!pickATileGen(&x, &y, LOOK_FOR_EMPTY_TILE, zonedPAT))
+			for (i = 0; i < 3; i++) // try three times
 			{
-				ASSERT(false, "addMultiPlayerRandomArtifacts: Unable to find a free location");
-			}
+				// Between 10 and mapwidth - 10
+				x = (rand() % (mapWidth - 20)) + 10;
+				y = (rand() % (mapHeight - 20)) + 10;
 
-			pF = buildFeature(asFeatureStats + i, world_coord(x), world_coord(y), false);
+				if (pickATileGen(&x, &y, LOOK_FOR_EMPTY_TILE, zonedPAT))
+				{
+					break;
+				}
+				else if (i == 2)
+				{
+					debug(LOG_FEATURE, "Unable to find a free location after 3 tries; giving up.");
+					x = INVALID_XY;
+				}
+			}
+			if (x != INVALID_XY) // at least one of the tries succeeded
+			{
+				pF = buildFeature(asFeatureStats + featureStat, world_coord(x), world_coord(y), false);
+				if (pF)
+				{
+					pF->player = player;
+				}
+				else
+				{
+					x = INVALID_XY;
+				}
+			}
 
 			NETuint32_t(&x);
 			NETuint32_t(&y);
-			NETuint32_t(&pF->id);
-			NETuint8_t(&player);
-
 			if (pF)
 			{
-				pF->player = player;
+				NETuint32_t(&pF->id);
 			}
+			else
+			{
+				NETuint32_t(&x); // just give them a dummy value; it'll never be used
+			}
+			NETuint8_t(&player);
 		}
 
 	NETend();
@@ -756,6 +708,7 @@ void recvMultiPlayerRandomArtifacts()
 		NETuint8_t(&quantity);
 		NETenum(&type);
 
+	debug(LOG_FEATURE, "receiving %u artifact(s) type: (%s)", quantity, feature_names[type]);
 	for (i = 0; i < numFeatureStats && asFeatureStats[i].subType != type; i++);
 
 	for (count = 0; count < quantity; count++)
@@ -767,15 +720,19 @@ void recvMultiPlayerRandomArtifacts()
 		NETuint32_t(&ref);
 		NETuint8_t(&player);
 
-		if (!tileOnMap(tx, ty))
+		if (tx == INVALID_XY)
 		{
-			debug(LOG_ERROR, "recvMultiPlayerRandomArtifacts: Bad tile coordinates (%u,%u)", tx, ty);
+			continue;
+		}
+		else if (!tileOnMap(tx, ty))
+		{
+			debug(LOG_ERROR, "Bad tile coordinates (%u,%u)", tx, ty);
 			continue;
 		}
 		psTile = mapTile(tx, ty);
 		if (!psTile || psTile->psObject != NULL)
 		{
-			debug(LOG_ERROR, "recvMultiPlayerRandomArtifacts: Already something at (%u,%u)!", tx, ty);
+			debug(LOG_ERROR, "Already something at (%u,%u)!", tx, ty);
 			continue;
 		}
 
@@ -785,6 +742,10 @@ void recvMultiPlayerRandomArtifacts()
 			pF->id		= ref;
 			pF->player	= player;
 		}
+		else
+		{
+			debug(LOG_ERROR, "Couldn't build feature %u for player %u ?", ref, player);
+		}
 	}
 	NETend();
 }
@@ -792,13 +753,12 @@ void recvMultiPlayerRandomArtifacts()
 // ///////////////////////////////////////////////////////////////
 void giftArtifact(UDWORD owner, UDWORD x, UDWORD y)
 {
-	PLAYER_RESEARCH *pO,*pR;
-	SDWORD	topic = 0;
-	pR   = asPlayerResList[selectedPlayer];
+	PLAYER_RESEARCH	*pR = asPlayerResList[selectedPlayer];
 
 	if (owner < MAX_PLAYERS)
 	{
-		pO	 = asPlayerResList[owner];
+		PLAYER_RESEARCH	*pO = asPlayerResList[owner];
+		int topic;
 
 		for (topic = numResearch - 1; topic >= 0; topic--)
 		{
@@ -806,7 +766,7 @@ void giftArtifact(UDWORD owner, UDWORD x, UDWORD y)
 			 && !IsResearchPossible(&pR[topic]))
 			{
 				// Make sure the topic can be researched
-				if (asResearch[topic].researchPower 
+				if (asResearch[topic].researchPower
 				 && asResearch[topic].researchPoints)
 				{
 					MakeResearchPossible(&pR[topic]);
@@ -841,8 +801,6 @@ void processMultiPlayerArtifacts(void)
 	}
 	lastCall = gameTime;
 
-	addLoserGifts();
-
 	for(pF = apsFeatureLists[0]; pF ; pF = pFN)
 	{
 		pFN = pF->psNext;
@@ -881,9 +839,8 @@ void createTeamAlliances(void)
 		for (j = 0; j < MAX_PLAYERS; j++)
 		{
 			if (i != j
-			 && playerTeam[i] == playerTeam[j]	// Wto different players belonging to the same team
+			 && NetPlay.players[i].team == NetPlay.players[j].team	// two different players belonging to the same team
 			 && !aiCheckAlliances(i, j)
-			 && playerTeam[i] >= 0
 			 && game.skDiff[i]
 			 && game.skDiff[j])	// Not allied and not ignoring teams
 			{
