@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -153,8 +153,13 @@ char		debugMenuEntry[DEBUGMENU_MAX_ENTRIES][MAX_STR_LENGTH];
  */
 static void SetPlayerTextColor( int mode, UDWORD player )
 {
+	// override color if they are dead...
+	if (!apsDroidLists[player] && !apsStructLists[player])
+	{
+		iV_SetTextColour(WZCOL_GREY);			// dead text color
+	}
 	// the colors were chosen to match the FRIEND/FOE radar map colors.
-	if (mode == ALLIANCE_FORMED)
+	else if (mode == ALLIANCE_FORMED)
 	{
 		iV_SetTextColour(WZCOL_YELLOW);			// Human alliance text color
 	}
@@ -166,11 +171,6 @@ static void SetPlayerTextColor( int mode, UDWORD player )
 	{
 		iV_SetTextColour(WZCOL_RED);			// Enemy color
 	}
-	// override color if they are dead...
-	if (!apsDroidLists[player] && !apsStructLists[player])
-	{
-		iV_SetTextColour(WZCOL_GREY);			// dead text color
-	}
 }
 // ////////////////////////////////////////////////////////////////////////////
 // enumerates maps in the gamedesc file.
@@ -208,7 +208,7 @@ static char* enumerateMultiMaps(UDWORD* players, bool first, unsigned int camToU
 				char* const found = strdup(lev->pName);
 				if (found == NULL)
 				{
-					debug(LOG_ERROR, "Out of memory");
+					debug(LOG_FATAL, "Out of memory");
 					// No way to indicate out-of-memory failure by return value
 					abort();
 					return NULL;
@@ -243,7 +243,7 @@ static char* enumerateMultiMaps(UDWORD* players, bool first, unsigned int camToU
 				char* const found = strdup(lev->pName);
 				if (found == NULL)
 				{
-					debug(LOG_ERROR, "Out of memory");
+					debug(LOG_FATAL, "Out of memory");
 					// No way to indicate out-of-memory failure by return value
 					abort();
 					return NULL;
@@ -368,13 +368,15 @@ void addMultiRequest(const char* searchDir, const char* fileExtension, UDWORD mo
 
 
 	context = mode;
-	current_tech = mapCam;
-	current_numplayers = numPlayers;
-
+	if(mode == MULTIOP_MAP)
+	{	// only save these when they select MAP button
+		current_tech = mapCam;
+		current_numplayers = numPlayers;
+	}
 	fileList = PHYSFS_enumerateFiles(searchDir);
 	if (!fileList)
 	{
-		debug(LOG_ERROR, "addMultiRequest: Out of memory");
+		debug(LOG_FATAL, "addMultiRequest: Out of memory");
 		abort();
 		return;
 	}
@@ -470,7 +472,7 @@ void addMultiRequest(const char* searchDir, const char* fileExtension, UDWORD mo
 	sButInit.formID = M_REQUEST;
 	sButInit.id = M_REQUEST_CLOSE;
 	sButInit.style = WBUT_PLAIN;
-	sButInit.x = M_REQUEST_W - CLOSE_WIDTH;
+	sButInit.x = M_REQUEST_W - CLOSE_WIDTH - 3;
 	sButInit.y = 0;
 	sButInit.width = CLOSE_WIDTH;
 	sButInit.height = CLOSE_HEIGHT;
@@ -809,7 +811,7 @@ static void displayMultiPlayer(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset,
 
 	if(isHumanPlayer(player) || (game.type == SKIRMISH && player<game.maxPlayers) )
 	{
-		ssprintf(str, "%d:%s", player, getPlayerName(player));
+		ssprintf(str, "%d: %s", NetPlay.players[player].position, getPlayerName(player));
 		if (isHumanPlayer(player))
 		{
 			SetPlayerTextColor(alliances[selectedPlayer][player], player);
@@ -865,13 +867,26 @@ static void displayMultiPlayer(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset,
 	{
 		SetPlayerTextColor(alliances[selectedPlayer][player], player);
 
-		//c8:score,
-		sprintf(str,"%d",getMultiStats(player,true).recentScore);
-		iV_DrawText(str, x+MULTIMENU_C8, y+MULTIMENU_FONT_OSET);
+		// Let's use the real score for MP games
+		if (NetPlay.bComms)
+		{
+			//c8:score,
+			sprintf(str,"%d",getMultiStats(player).recentScore);
+			iV_DrawText(str, x+MULTIMENU_C8, y+MULTIMENU_FONT_OSET);
 
-		//c9:kills,
-		sprintf(str,"%d",getMultiStats(player,true).recentKills);
-		iV_DrawText(str, x+MULTIMENU_C9, y+MULTIMENU_FONT_OSET);
+			//c9:kills,
+			sprintf(str,"%d",getMultiStats(player).recentKills);
+			iV_DrawText(str, x+MULTIMENU_C9, y+MULTIMENU_FONT_OSET);
+		}
+		else
+		{
+			// estimate of score for skirmish games
+			sprintf(str,"%d",ingame.skScores[player][0]);
+			iV_DrawText(str, x+MULTIMENU_C8, y+MULTIMENU_FONT_OSET);
+			// estimated kills
+			sprintf(str,"%d",ingame.skScores[player][1]);
+			iV_DrawText(str, x+MULTIMENU_C9, y+MULTIMENU_FONT_OSET);
+		}
 
 		if(!getDebugMappingStatus())
 		{
@@ -916,12 +931,26 @@ static void displayMultiPlayer(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset,
 	{
 		SetPlayerTextColor(alliances[selectedPlayer][player], player);
 
-		// estimate of score.
-		sprintf(str,"%d",ingame.skScores[player][0]);
-		iV_DrawText(str, x+MULTIMENU_C8, y+MULTIMENU_FONT_OSET);
-		// estimated kills
-		sprintf(str,"%d",ingame.skScores[player][1]);
-		iV_DrawText(str, x+MULTIMENU_C9, y+MULTIMENU_FONT_OSET);
+		// Let's use the real score for MP games
+		if (NetPlay.bComms)
+		{
+			//c8:score,
+			sprintf(str,"%d",getMultiStats(player).recentScore);
+			iV_DrawText(str, x+MULTIMENU_C8, y+MULTIMENU_FONT_OSET);
+
+			//c9:kills,
+			sprintf(str,"%d",getMultiStats(player).recentKills);
+			iV_DrawText(str, x+MULTIMENU_C9, y+MULTIMENU_FONT_OSET);
+		}
+		else
+		{
+			// estimate of score for skirmish games
+			sprintf(str,"%d",ingame.skScores[player][0]);
+			iV_DrawText(str, x+MULTIMENU_C8, y+MULTIMENU_FONT_OSET);
+			// estimated kills
+			sprintf(str,"%d",ingame.skScores[player][1]);
+			iV_DrawText(str, x+MULTIMENU_C9, y+MULTIMENU_FONT_OSET);
+		}
 	}
 
 	/* Display player power instead of number of played games
@@ -930,12 +959,12 @@ static void displayMultiPlayer(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset,
 	if(getDebugMappingStatus())			//Won't pass this when in both release and multiplayer modes
 	{
 		//c10: Total number of player units in possession
-		sprintf(str,"%d",getNumDroids(player));
+		sprintf(str,"%d",getNumDroids(player) + getNumTransporterDroids(player));
 		iV_DrawText(str, x+MULTIMENU_C10, y+MULTIMENU_FONT_OSET);
 
 		//c11: Player power
-		sprintf(str, "%u", getPower(player));
-		iV_DrawText(str, MULTIMENU_FORM_X+MULTIMENU_C11,  y+MULTIMENU_FONT_OSET);
+		sprintf(str, "%u", (int)getPower(player));
+		iV_DrawText(str, MULTIMENU_FORM_X+MULTIMENU_C11, y+MULTIMENU_FONT_OSET);
 	}
 
 	// a droid of theirs.
@@ -1275,7 +1304,7 @@ BOOL intAddMultiMenu(void)
 {
 	W_FORMINIT		sFormInit;
 	W_BUTINIT		sButInit;
-	UDWORD			i,pos = 0,formHeight=0;
+	UDWORD			i;
 
 	//check for already open.
 	if(widgGetFromID(psWScreen,MULTIMENU_FORM))
@@ -1284,17 +1313,9 @@ BOOL intAddMultiMenu(void)
 		return true;
 	}
 
-	intResetScreen(false);
-
-
-	// calculate required height.
-	formHeight = MULTIMENU_PLAYER_H+7;
-	for(i=0;i<MAX_PLAYERS;i++)
+	if (intMode != INT_INTELMAP)
 	{
-		if(isHumanPlayer(i) || (game.type == SKIRMISH && i<game.maxPlayers && game.skDiff[i] ))
-		{
-			formHeight += MULTIMENU_PLAYER_H;
-		}
+		intResetScreen(false);
 	}
 
 	// add form
@@ -1305,7 +1326,7 @@ BOOL intAddMultiMenu(void)
 	sFormInit.x				  =(SWORD)(MULTIMENU_FORM_X);
 	sFormInit.y				  =(SWORD)(MULTIMENU_FORM_Y);
 	sFormInit.width			  = MULTIMENU_FORM_W;
-	sFormInit.height		  = (UWORD)formHeight;			//MULTIMENU_FORM_H;
+	sFormInit.height		  = (UWORD)(MULTIMENU_PLAYER_H*game.maxPlayers + MULTIMENU_PLAYER_H+7);	//MULTIMENU_FORM_H;
 	sFormInit.pDisplay		  = intOpenPlainForm;
 	sFormInit.disableChildren = true;
 
@@ -1319,8 +1340,7 @@ BOOL intAddMultiMenu(void)
 	{
 		if(isHumanPlayer(i) || (game.type == SKIRMISH && i<game.maxPlayers && game.skDiff[i] ) )
 		{
-			addMultiPlayer(i,pos);
-			pos++;
+			addMultiPlayer(i,NetPlay.players[i].position);
 		}
 	}
 
@@ -1344,7 +1364,10 @@ BOOL intAddMultiMenu(void)
 
 	intShowPowerBar();						// add power bar
 
-	intMode		= INT_MULTIMENU;			// change interface mode.
+	if (intMode != INT_INTELMAP)
+	{
+		intMode		= INT_MULTIMENU;			// change interface mode.
+	}
 	MultiMenuUp = true;
 	return true;
 }
@@ -1352,10 +1375,17 @@ BOOL intAddMultiMenu(void)
 // ////////////////////////////////////////////////////////////////////////////
 void intCloseMultiMenuNoAnim(void)
 {
+	if (!MultiMenuUp && !ClosingMultiMenu)
+	{
+		return;
+	}
 	widgDelete(psWScreen, MULTIMENU_CLOSE);
 	widgDelete(psWScreen, MULTIMENU_FORM);
 	MultiMenuUp = false;
-	intMode		= INT_NORMAL;
+	if (intMode != INT_INTELMAP)
+	{
+		intMode		= INT_NORMAL;
+	}
 }
 
 
@@ -1364,6 +1394,11 @@ BOOL intCloseMultiMenu(void)
 {
 	W_TABFORM *Form;
 
+	if (!MultiMenuUp)
+	{
+		return true;
+	}
+
 	widgDelete(psWScreen, MULTIMENU_CLOSE);
 
 	// Start the window close animation.
@@ -1376,7 +1411,10 @@ BOOL intCloseMultiMenu(void)
 		MultiMenuUp  = false;
 	}
 
-	intMode		= INT_NORMAL;
+	if (intMode != INT_INTELMAP)
+	{
+		intMode		= INT_NORMAL;
+	}
 	return true;
 }
 
