@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -53,6 +53,7 @@
 #include "aiexperience.h"	//for beacon messages
 #include "multiint.h"
 #include "multirecv.h"
+#include <SDL.h>
 
 // ////////////////////////////////////////////////////////////////////////////
 // External Variables
@@ -63,8 +64,7 @@ extern char	buildTime[8];
 // ////////////////////////////////////////////////////////////////////////////
 
 // send complete game info set!
-// dpid == 0 for no new players.
-void sendOptions(uint32_t dest, uint32_t play)
+void sendOptions()
 {
 	unsigned int i;
 
@@ -73,42 +73,25 @@ void sendOptions(uint32_t dest, uint32_t play)
 	// First send information about the game
 	NETuint8_t(&game.type);
 	NETstring(game.map, 128);
-	NETstring(game.version, 8);
 	NETuint8_t(&game.maxPlayers);
 	NETstring(game.name, 128);
 	NETbool(&game.fog);
 	NETuint32_t(&game.power);
 	NETuint8_t(&game.base);
 	NETuint8_t(&game.alliance);
+	NETbool(&game.scavengers);
 
 	for (i = 0; i < MAX_PLAYERS; i++)
 	{
 		NETuint8_t(&game.skDiff[i]);
 	}
 
-	// Now the dpid array
-	for (i = 0; i < MAX_PLAYERS; i++)
-	{
-		// We should probably re-define player2dpid as a uint8_t
-		NETint32_t(&player2dpid[i]);
-	}
-
 	// Send the list of who is still joining
 	for (i = 0; i < MAX_PLAYERS; i++)
 	{
 		NETbool(&ingame.JoiningInProgress[i]);
 	}
 
-	// Send dest and play
-	NETuint32_t(&dest);
-	NETuint32_t(&play);
-
-	// Send over the list of player colours
-	for (i = 0; i < MAX_PLAYERS; i++)
-	{
-		NETuint8_t(&PlayerColour[i]);
-	}
-
 	// Same goes for the alliances
 	for (i = 0; i < MAX_PLAYERS; i++)
 	{
@@ -120,16 +103,9 @@ void sendOptions(uint32_t dest, uint32_t play)
 		}
 	}
 
-	// Send their team (this is apparently not related to alliances
-	for (i = 0; i < MAX_PLAYERS; i++)
-	{
-		// This should also be a uint8_t
-		NETint32_t(&playerTeamGUI[i]);
-	}
-
 	// Send the number of structure limits to expect
 	NETuint32_t(&ingame.numStructureLimits);
-
+	debug(LOG_NET, "(Host) Structure limits to process on client is %u", ingame.numStructureLimits);
 	// Send the structures changed
 	for (i = 0; i < ingame.numStructureLimits; i++)
 	{
@@ -137,12 +113,6 @@ void sendOptions(uint32_t dest, uint32_t play)
 		NETuint8_t(&ingame.pStructureLimits[i].limit);
 	}
 
-	// Send ready status of all players
-	for (i = 0; i < MAX_PLAYERS; i++)
-	{
-		NETbool(&bPlayerReadyGUI[i]);
-	}
-
 	NETend();
 }
 
@@ -170,54 +140,32 @@ static BOOL checkGameWdg(const char *nm)
 void recvOptions()
 {
 	unsigned int i;
-	UDWORD	play;
-	UDWORD	newPl;
 
+	debug(LOG_NET, "Receiving options from host");
 	NETbeginDecode(NET_OPTIONS);
 
 	// Get general information about the game
 	NETuint8_t(&game.type);
 	NETstring(game.map, 128);
-	NETstring(game.version, 8);
 	NETuint8_t(&game.maxPlayers);
 	NETstring(game.name, 128);
 	NETbool(&game.fog);
 	NETuint32_t(&game.power);
 	NETuint8_t(&game.base);
 	NETuint8_t(&game.alliance);
+	NETbool(&game.scavengers);
 
 	for (i = 0; i < MAX_PLAYERS; i++)
 	{
 		NETuint8_t(&game.skDiff[i]);
 	}
 
-	// Check the version
-	if (strncmp(game.version, buildTime, 8) != 0)
-	{
-		debug(LOG_ERROR, "Host is running a different version of Warzone2100.");
-	}
-
-	// Now the dpid array
-	for (i = 0; i < MAX_PLAYERS; i++)
-	{
-		NETint32_t(&player2dpid[i]);
-	}
-
 	// Send the list of who is still joining
 	for (i = 0; i < MAX_PLAYERS; i++)
 	{
 		NETbool(&ingame.JoiningInProgress[i]);
 	}
 
-	NETuint32_t(&newPl);
-	NETuint32_t(&play);
-
-	// Player colours
-	for (i = 0; i < MAX_PLAYERS; i++)
-	{
-		NETuint8_t(&PlayerColour[i]);
-	}
-
 	// Alliances
 	for (i = 0; i < MAX_PLAYERS; i++)
 	{
@@ -228,12 +176,7 @@ void recvOptions()
 			NETuint8_t(&alliances[i][j]);
 		}
 	}
-
-	// Teams
-	for (i = 0; i < MAX_PLAYERS; i++)
-	{
-		NETint32_t(&playerTeamGUI[i]);
-	}
+	netPlayersUpdated = true;
 
 	// Free any structure limits we may have in-place
 	if (ingame.numStructureLimits)
@@ -245,7 +188,7 @@ void recvOptions()
 
 	// Get the number of structure limits to expect
 	NETuint32_t(&ingame.numStructureLimits);
-
+	debug(LOG_NET, "Host is sending us %u structure limits", ingame.numStructureLimits);
 	// If there were any changes allocate memory for them
 	if (ingame.numStructureLimits)
 	{
@@ -258,31 +201,6 @@ void recvOptions()
 		NETuint8_t(&ingame.pStructureLimits[i].limit);
 	}
 
-	// Receive ready status of all players
-	for (i = 0; i < MAX_PLAYERS; i++)
-	{
-		NETbool(&bPlayerReadyGUI[i]);
-	}
-
-	NETend();
-
-	// Post process
-	if (newPl != 0)
-	{
-		// If we are the new player
-		if (newPl == NetPlay.dpidPlayer)
- 		{
-			selectedPlayer = play;		// Select player
-			NETplayerInfo();			// Get player info
-			powerCalculated = false;	// Turn off any power requirements
-		}
-		// Someone else is joining.
-		else
-		{
-			setupNewPlayer(newPl, play);
- 		}
- 	}
-
 	// Do the skirmish slider settings if they are up
 	for (i = 0; i < MAX_PLAYERS; i++)
  	{
@@ -291,15 +209,21 @@ void recvOptions()
 			widgSetSliderPos(psWScreen, MULTIOP_SKSLIDE + i, game.skDiff[i]);
 		}
 	}
-
+	debug(LOG_NET, "Rebuilding map list");
+	// clear out the old level list.
+	levShutDown();
+	levInitialise();
+	rebuildSearchPath(mod_multiplay, true);	// MUST rebuild search path for the new maps we just got!
+	buildMapList();
 	// See if we have the map or not
 	if (!checkGameWdg(game.map))
 	{
+		uint32_t player = selectedPlayer;
+
+		debug(LOG_NET, "Map was not found, requesting map %s from host.", game.map);
 		// Request the map from the host
-		NETbeginEncode(NET_REQUESTMAP, NET_ALL_PLAYERS);
-
-		NETuint32_t(&NetPlay.dpidPlayer);
-
+		NETbeginEncode(NET_FILE_REQUESTED, NET_HOST_ONLY);
+		NETuint32_t(&player);
 		NETend();
 
 		addConsoleMessage("MAP REQUESTED!",DEFAULT_JUSTIFY, SYSTEM_MESSAGE);
@@ -316,7 +240,7 @@ void recvOptions()
 BOOL hostCampaign(char *sGame, char *sPlayer)
 {
 	PLAYERSTATS playerStats;
-	UDWORD		pl,numpl,i,j;
+	UDWORD		i;
 
 	debug(LOG_WZ, "Hosting campaign: '%s', player: '%s'", sGame, sPlayer);
 
@@ -329,53 +253,32 @@ BOOL hostCampaign(char *sGame, char *sPlayer)
 		game.maxPlayers = 4;
 	}
 
-	NEThostGame(sGame, sPlayer, game.type, 0, 0, 0, game.maxPlayers); // temporary stuff
+	if (!NEThostGame(sGame, sPlayer, game.type, 0, 0, 0, game.maxPlayers))
+	{
+		return false;
+	}
 
 	for (i = 0; i < MAX_PLAYERS; i++)
 	{
-		player2dpid[i] = 0;
 		setPlayerName(i, ""); //Clear custom names (use default ones instead)
 	}
 
-//	FIXME: FIX ME!!! **RANDOM** ARGH!
-	pl = rand()%game.maxPlayers;						//pick a player
-
-	player2dpid[pl] = NetPlay.dpidPlayer;				// add ourselves to the array.
-	selectedPlayer = pl;
+	NetPlay.players[selectedPlayer].ready = false;
 
 	ingame.localJoiningInProgress = true;
 	ingame.JoiningInProgress[selectedPlayer] = true;
-	bMultiPlayer = true;								// enable messages
+	bMultiPlayer = true;
+	bMultiMessages = true; // enable messages
 
 	loadMultiStats(sPlayer,&playerStats);				// stats stuff
-	setMultiStats(NetPlay.dpidPlayer,playerStats,false);
-	setMultiStats(NetPlay.dpidPlayer,playerStats,true);
-
-	bPlayerReadyGUI[0] = false;
+	setMultiStats(selectedPlayer, playerStats, false);
+	setMultiStats(selectedPlayer, playerStats, true);
 
 	if(!NetPlay.bComms)
 	{
-		NETplayerInfo();
 		strcpy(NetPlay.players[0].name,sPlayer);
-		numpl = 1;
-	}
-	else
-	{
-		numpl = NETplayerInfo();
-	}
-
-	// may be more than one player already. check and resolve!
-	if(numpl >1)
-	{
-		for(j = 0;j<MAX_PLAYERS;j++)
-		{
-			if(NetPlay.players[j].dpid && (NetPlay.players[j].dpid != NetPlay.dpidPlayer))
-			{
-				for(i = 0;player2dpid[i] != 0;i++);
-				player2dpid[i] = NetPlay.players[j].dpid;
-			}
-		}
 	}
+	NetPlay.maxPlayers = game.maxPlayers;
 
 	return true;
 }
@@ -389,61 +292,33 @@ BOOL joinCampaign(UDWORD gameNumber, char *sPlayer)
 
 	if(!ingame.localJoiningInProgress)
 	{
-		NETjoinGame(gameNumber, sPlayer);	// join
+		if (!NETjoinGame(gameNumber, sPlayer))	// join
+		{
+			return false;
+		}
 		ingame.localJoiningInProgress	= true;
 
 		loadMultiStats(sPlayer,&playerStats);
-		setMultiStats(NetPlay.dpidPlayer,playerStats,false);
-		setMultiStats(NetPlay.dpidPlayer,playerStats,true);
-		return false;
+		setMultiStats(selectedPlayer, playerStats, false);
+		setMultiStats(selectedPlayer, playerStats, true);
+		return true;
 	}
 
-	bMultiPlayer = true;
-	return true;
+	return false;
 }
 
-#if 0	// unused - useful?
 // ////////////////////////////////////////////////////////////////////////////
-// Lobby launched. fires the correct routine when the game was lobby launched.
-BOOL LobbyLaunched(void)
-{
-	UDWORD i;
-	PLAYERSTATS pl = { 0, 0, 0, 0, 0, 0, 0, 0, 0 };
-
-	// set the player info as soon as possible to avoid screwy scores appearing elsewhere.
-	NETplayerInfo();
-	NETfindGame();
-
-	for (i = 0; i < MAX_PLAYERS && NetPlay.players[i].dpid != NetPlay.dpidPlayer; i++);
-
-	if(!loadMultiStats(NetPlay.players[i].name, &pl) )
-	{
-		return false; // cheating was detected, so fail.
-	}
-
-	setMultiStats(NetPlay.dpidPlayer, pl, false);
-	setMultiStats(NetPlay.dpidPlayer, pl, true);
-
-	// setup text boxes on multiplay screen.
-	strcpy((char*) sPlayer, NetPlay.players[i].name);
-	strcpy((char*) game.name, NetPlay.games[0].name);
-
-	return true;
-}
-#endif
-
-// ////////////////////////////////////////////////////////////////////////////
-// Broadcast that we are leaving the game 'nicely', (we wanted to) and not
+// Tell the host we are leaving the game 'nicely', (we wanted to) and not
 // because we have some kind of error. (dropped or disconnected)
 BOOL sendLeavingMsg(void)
 {
 	debug(LOG_NET, "We are leaving 'nicely'");
-	NETbeginEncode(NET_PLAYER_LEAVING, NET_ALL_PLAYERS);
+	NETbeginEncode(NET_PLAYER_LEAVING, NET_HOST_ONLY);
 	{
-		uint32_t player_id = player2dpid[selectedPlayer];
-		BOOL host = NetPlay.bHost;
+		BOOL host = NetPlay.isHost;
+		uint32_t id = selectedPlayer;
 
-		NETuint32_t(&player_id);
+		NETuint32_t(&id);
 		NETbool(&host);
 	}
 	NETend();
@@ -471,8 +346,8 @@ BOOL multiShutdown(void)
 }
 
 // ////////////////////////////////////////////////////////////////////////////
-// copy tempates from one player to another.
-BOOL addTemplate(UDWORD player, DROID_TEMPLATE *psNew)
+// copy templates from one player to another.
+BOOL addTemplateToList(DROID_TEMPLATE *psNew, DROID_TEMPLATE **ppList)
 {
 	DROID_TEMPLATE *psTempl = malloc(sizeof(DROID_TEMPLATE));
 
@@ -489,152 +364,23 @@ BOOL addTemplate(UDWORD player, DROID_TEMPLATE *psNew)
 		psTempl->pName = strdup(psNew->pName);
 	}
 
-	psTempl->psNext = apsDroidTemplates[player];
-	apsDroidTemplates[player] = psTempl;
+	psTempl->psNext = *ppList;
+	*ppList = psTempl;
 
 	return true;
 }
 
-BOOL addTemplateSet(UDWORD from,UDWORD to)
+// ////////////////////////////////////////////////////////////////////////////
+// copy templates from one player to another.
+BOOL addTemplate(UDWORD player, DROID_TEMPLATE *psNew)
 {
-	DROID_TEMPLATE	*psCurr;
-
-	if(from == to)
-	{
-		return true;
-	}
-
-	for(psCurr = apsDroidTemplates[from];psCurr;psCurr= psCurr->psNext)
-	{
-		addTemplate(to, psCurr);
-	}
-
-	return true;
-}
-
-BOOL copyTemplateSet(UDWORD from,UDWORD to)
-{
-	DROID_TEMPLATE	*psTempl;
-
-	if(from == to)
-	{
-		return true;
-	}
-
-	while(apsDroidTemplates[to])				// clear the old template out.
-	{
-		psTempl = apsDroidTemplates[to]->psNext;
-		free(apsDroidTemplates[to]);
-		apsDroidTemplates[to] = psTempl;
-	}
-
-	return 	addTemplateSet(from,to);
+	return addTemplateToList(psNew, &apsDroidTemplates[player]);
 }
 
 // ////////////////////////////////////////////////////////////////////////////
 // setup templates
 BOOL multiTemplateSetup(void)
 {
-	UDWORD player, pcPlayer = 0;
-
-	switch (game.type)
-	{
-	case CAMPAIGN:
-		for(player=0;player<game.maxPlayers;player++)
-		{
-			copyTemplateSet(CAMPAIGNTEMPLATES,player);
-		}
-		break;
-
-	case SKIRMISH:
-		// create the pc player list in deathmatch set.
-
-		// Yes, this code really *is* as hacky as it looks.
-		// I'm going to try to narrate what's going on.
-
-		// Player 5 currently contains the human player template set.
-		// (i.e. Nothing but a truck)
-		// Templates from players 5, 2, and 6 are added to player 4.
-		// This puts the AI template set in player 4.
-		addTemplateSet(CAMPAIGNTEMPLATES,DEATHMATCHTEMPLATES);
-		addTemplateSet(6,DEATHMATCHTEMPLATES);
-		addTemplateSet(2,DEATHMATCHTEMPLATES);
-
-		// To reiterate:
-		// Player 5 contains the human player template set.
-		// Player 4 contains the AI player template set.
-
-		//choose which way to do this.
-		if(isHumanPlayer(CAMPAIGNTEMPLATES))
-		{
-			// Player 5 is a human. No workarounds are needed.
-			// We just copy player 4's templates onto all the AI's,
-			// then copy player 5's template onto all the humans.
-
-			//pc first
-			for(player=0;player<game.maxPlayers;player++)
-			{
-				if(!isHumanPlayer(player))
-				{
-					copyTemplateSet(DEATHMATCHTEMPLATES,player);
-				}
-			}
-			//now players.
-			for(player=0;player<game.maxPlayers;player++)
-			{
-				if(isHumanPlayer(player))
-				{
-					copyTemplateSet(CAMPAIGNTEMPLATES,player);
-				}
-			}
-		}
-		else
-		{
-			// Player 5 is an AI player. This is a really bad workaround.
-			// We find an AI player: pcPlayer.
-			// We copy player 4's templates onto pcPlayer.
-			// Then, we copy player 5's templates onto all the
-			// human players, and pcPlayer's templates onto all the
-			// AI players.
-
-			// ensure a copy of pc templates to a pc player.
-			if(isHumanPlayer(DEATHMATCHTEMPLATES))
-			{
-
-				for(player=0;player<MAX_PLAYERS && isHumanPlayer(player);player++);
-				if(!isHumanPlayer(player))
-				{
-					pcPlayer = player;
-					copyTemplateSet(DEATHMATCHTEMPLATES,pcPlayer);
-				}
-			}
-			else
-			{
-				pcPlayer = DEATHMATCHTEMPLATES;
-			}
-			//players first
-			for(player=0;player<game.maxPlayers;player++)
-			{
-				if(isHumanPlayer(player))
-				{
-					copyTemplateSet(CAMPAIGNTEMPLATES,player);
-				}
-			}
-			//now pc
-			for(player=0;player<game.maxPlayers;player++)
-			{
-				if(!isHumanPlayer(player))
-				{
-					copyTemplateSet(pcPlayer,player);
-				}
-			}
-		}
-		break;
-
-	default:
-		break;
-	}
-
 	return true;
 }
 
@@ -649,6 +395,7 @@ static BOOL cleanMap(UDWORD player)
 	BOOL		firstFact,firstRes;
 
 	bMultiPlayer = false;
+	bMultiMessages = false;
 
 	firstFact = true;
 	firstRes = true;
@@ -750,6 +497,7 @@ static BOOL cleanMap(UDWORD player)
 							psStruct->sDisplay.imd	= psStruct->pStructureType->pIMD;
 							psStruct->body			= (UWORD)(structureBody(psStruct));
 						}
+						structurePowerUpgrade(psStruct);
 						psStruct=psStruct->psNext;
 				}
 			}
@@ -765,7 +513,7 @@ static BOOL cleanMap(UDWORD player)
 	case CAMP_WALLS:												//everything.
 		break;
 	default:
-		debug( LOG_ERROR, "Unknown Campaign Style" );
+		debug( LOG_FATAL, "Unknown Campaign Style" );
 		abort();
 		break;
 	}
@@ -774,6 +522,7 @@ static BOOL cleanMap(UDWORD player)
 //	reverseObjectList((BASE_OBJECT**)&apsStructLists[player]);
 
 	bMultiPlayer = true;
+	bMultiMessages = true;
 	return true;
 }
 
@@ -782,10 +531,8 @@ static BOOL cleanMap(UDWORD player)
 static BOOL campInit(void)
 {
 	UDWORD			player;
-	UBYTE		newPlayerArray[MAX_PLAYERS];
-	SDWORD		newPlayerTeam[MAX_PLAYERS] = {-1,-1,-1,-1,-1,-1,-1,-1};
 
-// if this is from a savegame, stop here!
+	// If this is from a savegame, stop here!
 	if((getSaveGameType() == GTYPE_SAVE_START)
 	|| (getSaveGameType() == GTYPE_SAVE_MIDMISSION)	)
 	{
@@ -798,81 +545,25 @@ static BOOL campInit(void)
 		return true;
 	}
 
-	//Convert skirmish GUI player ids to in-game ids
-	if(game.type == SKIRMISH)
-	{
-		unsigned int i;
-		unsigned int lastAI = 0; // last used AI slot
-
-		memset(newPlayerArray,1,MAX_PLAYERS * sizeof(newPlayerArray[0]));		//'1' for humans
-		for(i = 0; i < MAX_PLAYERS; ++i)
-		{
-			if(game.skDiff[i] < UBYTE_MAX )		//slot with enabled or disabled AI
-			{
-				unsigned int player;
-
-				//find first unused slot
-				for (player = lastAI;
-				     player < MAX_PLAYERS && isHumanPlayer(player); // skip humans
-				     ++player);
-
-				ASSERT(player < MAX_PLAYERS, "couldn't find free slot while assigning AI %u, lastAI=%u", i, lastAI);
-
-				newPlayerArray[player] = game.skDiff[i];		//copy over
-				newPlayerTeam[player] = playerTeamGUI[i];
-
-				//remove player if it was disabled in menus
-				if(game.skDiff[i] == 0)
-					clearPlayer(player,true,false);
-
-				lastAI = player;
-				lastAI++;
-			}
-			else if(game.skDiff[i] == UBYTE_MAX)	//human player
-			{
-				unsigned int player;
-
-				//find player net id
-				for (player = 0;
-				     player < MAX_PLAYERS && player2dpid[player] != NetPlay.players[i].dpid;
-				     ++player);
-
-				ASSERT(player < MAX_PLAYERS, "couldn't find player id for GUI id %u", i);
-
-				newPlayerTeam[player] = playerTeamGUI[i];
-			}
-
-		}
-
-		memcpy(game.skDiff,newPlayerArray,MAX_PLAYERS  * sizeof(newPlayerArray[0]));
-		memcpy(playerTeam,newPlayerTeam,MAX_PLAYERS * sizeof(newPlayerTeam[0]));
-	}
-
 	for(player = 0;player<game.maxPlayers;player++)			// clean up only to the player limit for this map..
 	{
-		if( (!isHumanPlayer(player)) && game.type != SKIRMISH)	// strip away unused players
-		{
-			clearPlayer(player,true,true);
-		}
-
 		cleanMap(player);
 	}
 
-	// optionally remove other computer players.
-	// HACK: if actual number of players is 8, then drop baba player to avoid
-	// exceeding player number (babas need a player, too!) - Per
-	if ((game.type == CAMPAIGN && game.maxPlayers > 7) || game.type == SKIRMISH)
+	for (player = 1; player < MAX_PLAYERS; player++)
 	{
-		for(player=game.maxPlayers;player<MAX_PLAYERS;player++)
+		// we want to remove disabled AI & all the other players that don't belong
+		if ((game.skDiff[player] == 0 || player >= game.maxPlayers) && (!game.scavengers || player != 7))
 		{
-			clearPlayer(player,true,false);
+			clearPlayer(player, true);			// do this quietly
+			debug(LOG_NET, "removing disabled AI (%d) from map.", player);
 		}
 	}
 
-	// add free research gifts..
-	if(NetPlay.bHost)
+
+	if (NetPlay.isHost)	// add oil drums
 	{
-		addOilDrum( NetPlay.playercount*2 );		// add some free power.
+		addOilDrum(NetPlay.playercount * 2);
 	}
 
 	playerResponding();			// say howdy!
@@ -928,12 +619,15 @@ BOOL multiGameShutdown(void)
 	sendLeavingMsg();							// say goodbye
 	updateMultiStatsGames();					// update games played.
 
-	st = getMultiStats(selectedPlayer, true);	// save stats
+	st = getMultiStats(selectedPlayer);	// save stats
 
 	saveMultiStats(getPlayerName(selectedPlayer), getPlayerName(selectedPlayer), &st);
 
+	// if we terminate the socket too quickly, then, it is possible not to get the leave message
+	SDL_Delay(1000);
 	// close game
 	NETclose();
+	NETremRedirects();
 
 	if (ingame.numStructureLimits)
 	{
@@ -945,8 +639,9 @@ BOOL multiGameShutdown(void)
 	ingame.localJoiningInProgress = false; // Clean up
 	ingame.localOptionsReceived = false;
 	ingame.bHostSetup = false;	// Dont attempt a host
-	NetPlay.bHost					= false;
+	NetPlay.isHost					= false;
 	bMultiPlayer					= false;	// Back to single player mode
+	bMultiMessages					= false;
 	selectedPlayer					= 0;		// Back to use player 0 (single player friendly)
 
 	return true;
