@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -72,16 +72,15 @@
 // ////////////////////////////////////////////////////////////////////////////
 // ////////////////////////////////////////////////////////////////////////////
 // globals.
+bool						isMPDirtyBit = false;		// When we are forced to use turnOffMultiMsg() we set this
 BOOL						bMultiPlayer				= false;	// true when more than 1 player.
-SDWORD						player2dpid[MAX_PLAYERS]	={0,0,0,0,0,0,0,0};		//stores dpids of each player. FILTHY HACK (ASSUMES 8 players)
+BOOL						bMultiMessages				= false;	// == bMultiPlayer unless multimessages are disabled
 BOOL						openchannels[MAX_PLAYERS]={true};
 UBYTE						bDisplayMultiJoiningStatus;
 
 MULTIPLAYERGAME				game;									//info to describe game.
 MULTIPLAYERINGAME			ingame;
 
-BOOL						bSendingMap					= false;	// map broadcasting.
-
 char						beaconReceiveMsg[MAX_PLAYERS][MAX_CONSOLE_STRING_LENGTH];	//beacon msg for each player
 char								playerName[MAX_PLAYERS][MAX_STR_LENGTH];	//Array to store all player names (humans and AIs)
 BOOL						bPlayerReadyGUI[MAX_PLAYERS] = {false};
@@ -104,7 +103,7 @@ static SDWORD msgStackPos = -1;				//top element pointer
 // Remote Prototypes
 extern RESEARCH*			asResearch;							//list of possible research items.
 extern PLAYER_RESEARCH*		asPlayerResList[MAX_PLAYERS];
-
+extern int NET_PlayerConnectionStatus;
 // ////////////////////////////////////////////////////////////////////////////
 // Local Prototypes
 
@@ -119,28 +118,15 @@ void		startMultiplayerGame		(void);
 // temporarily disable multiplayer mode.
 BOOL turnOffMultiMsg(BOOL bDoit)
 {
-	static BOOL bTemp;
-
-	if(bDoit)	// turn off msgs.
+	if (!bMultiPlayer)
 	{
-		if(bTemp == true)
-		{
-			// Surely, this should be a Assert?
-			debug(LOG_ERROR, "multiple calls to turn off");
-		}
-		if(bMultiPlayer)
-		{
-			bMultiPlayer = false;
-			bTemp = true;
-		}
+		return true;
 	}
-	else	// turn on msgs.
+	
+	bMultiMessages = !bDoit;
+	if (bDoit)
 	{
-		if(bTemp)
-		{
-			bMultiPlayer = true;
-			bTemp = false;
-		}
+		isMPDirtyBit = true;
 	}
 	return true;
 }
@@ -178,7 +164,7 @@ BOOL multiplayerWinSequence(BOOL firstCall)
 	}
 
 	// rotate world
-	if(MissionResUp && !getWarCamStatus())
+	if (MissionResUp && !getWarCamStatus())
 	{
 		rotAmount = timeAdjustedIncrement(MAP_SPIN_RATE / 12, true);
 		player.r.y += rotAmount;
@@ -256,36 +242,45 @@ BOOL multiPlayerLoop(void)
 		{
 			if(bDisplayMultiJoiningStatus)
 			{
-				if (!NetPlay.bHost)
-				{
-					sendDataCheck();
-				}
 				bDisplayMultiJoiningStatus = 0;
 				setWidgetsStatus(true);
 			}
 			if (!ingame.TimeEveryoneIsInGame)
 			{
 				ingame.TimeEveryoneIsInGame = gameTime;
+				debug(LOG_NET, "I have entered the game @ %d", ingame.TimeEveryoneIsInGame );
+				NETlogEntry("player entered game @ ", SYNC_FLAG, ingame.TimeEveryoneIsInGame);
+				if (!NetPlay.isHost)
+				{
+#ifdef DEBUG
+					addConsoleMessage("Sending data check...", LEFT_JUSTIFY, NOTIFY_MESSAGE);
+#endif
+					debug(LOG_NET, "=== Sending hash to host ===");
+					NETlogEntry("player sent hash to host ", SYNC_FLAG, selectedPlayer);
+					sendDataCheck();
+				}
 			}
 			// Only have to do this on a true MP game
-			if (NetPlay.bHost && !ingame.isAllPlayersDataOK && NetPlay.bComms)
+			if (NetPlay.isHost && !ingame.isAllPlayersDataOK && NetPlay.bComms)
 			{
 				if (gameTime - ingame.TimeEveryoneIsInGame > GAME_TICKS_PER_SEC * 60)
 				{
+					// NOTE: 60 secs is used for slow systems and dialup users.
 					// we waited 60 secs to make sure people didn't bypass the data integrity checks
-					int i;
-					for (i=0; i < MAX_PLAYERS; i++)
+					int index;
+					for (index=0; index < MAX_PLAYERS; index++)
 					{
-						if (ingame.DataIntegrity[i] == false && isHumanPlayer(i) && player2dpid[i] != HOST_DPID)
+						if (ingame.DataIntegrity[index] == false && isHumanPlayer(index) && index != NET_HOST_ONLY)
 						{
 							char msg[256] = {'\0'};
 
-							sprintf(msg, _("Kicking player %s, because they tried to bypass data integrity check!"), getPlayerName(i));
+							sprintf(msg, _("Kicking player %s, because they tried to bypass data integrity check!"), getPlayerName(index));
 							sendTextMessage(msg, true);
 							addConsoleMessage(msg, LEFT_JUSTIFY, NOTIFY_MESSAGE);
+							NETlogEntry(msg, SYNC_FLAG, index);
 
-							kickPlayer(player2dpid[i], _("It is not nice to cheat!"), ERROR_CHEAT);
-							debug(LOG_WARNING, "Kicking Player %s (dpid=%u), they tried to bypass data integrity check!", getPlayerName(i), player2dpid[i]);
+							kickPlayer(index, "it is not nice to cheat!", ERROR_CHEAT);
+							debug(LOG_INFO, "Kicking Player %s (%u), they tried to bypass data integrity check!", getPlayerName(index), index);
 						}
 					}
 					ingame.isAllPlayersDataOK = true;
@@ -397,40 +392,29 @@ DROID_TEMPLATE *IdToTemplate(UDWORD tempId,UDWORD player)
 {
 	DROID_TEMPLATE *psTempl = NULL;
 	UDWORD		i;
-	if(player != ANYPLAYER)
+
+	// First try static templates from scripts (could potentially also happen for currently human controlled players)
+	for (psTempl = apsStaticTemplates; psTempl && psTempl->multiPlayerID != tempId; psTempl = psTempl->psNext) ;
+	if (psTempl) return psTempl;
+
+	// Check if we know which player this is from, in that case, assume it is a player template
+	if (player != ANYPLAYER)
 	{
 		for (psTempl = apsDroidTemplates[player];			// follow templates
 		(psTempl && (psTempl->multiPlayerID != tempId ));
 		 psTempl = psTempl->psNext);
+
+		return psTempl;
 	}
-	else
+
+	// We have no idea, so search through every player template
+	for (i = 0; i < MAX_PLAYERS; i++)
 	{
-		// REALLY DANGEROUS!!! ID's are NOT assumed to be unique for TEMPLATES.
-		debug( LOG_NEVER, "Really Dodgy Check performed for a template" );
-		for(i=0;i<MAX_PLAYERS;i++)
-		{
-			for (psTempl = apsDroidTemplates[i];			// follow templates
-			(psTempl && (psTempl->multiPlayerID != tempId ));
-			 psTempl = psTempl->psNext);
-			if(psTempl)
-			{
-				return psTempl;
-			}
-		}
+		for (psTempl = apsDroidTemplates[i]; psTempl && psTempl->multiPlayerID != tempId; psTempl = psTempl->psNext) ;
+		if (psTempl) return psTempl;
 	}
-	return psTempl;
-}
 
-// the same as above, but only checks names in similarity.
-DROID_TEMPLATE *NameToTemplate(const char *sName,UDWORD player)
-{
-	DROID_TEMPLATE *psTempl = NULL;
-
-	for (psTempl = apsDroidTemplates[player];			// follow templates
-		(psTempl && (strcmp(psTempl->aName,sName) != 0) );
-		 psTempl = psTempl->psNext);
-
-	 return psTempl;
+	return NULL;
 }
 
 /////////////////////////////////////////////////////////////////////////////////
@@ -468,43 +452,29 @@ BASE_OBJECT *IdToPointer(UDWORD id,UDWORD player)
 // return a players name.
 const char* getPlayerName(unsigned int player)
 {
-	UDWORD i;
+	ASSERT_OR_RETURN(NULL, player < MAX_PLAYERS , "Wrong player index: %u", player);
 
-	ASSERT( player < MAX_PLAYERS , "getPlayerName: wrong player index: %d", player);
-
-	//Try NetPlay.playerName first (since supports AIs)
-	if(game.type != CAMPAIGN)
-		if(strcmp(playerName[player], "") != 0)
-			return (char*)&playerName[player];
-
-	//Use the ordinary way if failed
-	for(i=0;i<MAX_PLAYERS;i++)
+	if (game.type != CAMPAIGN)
 	{
-		if(player2dpid[player] == (unsigned int)NetPlay.players[i].dpid)
+		if (strcmp(playerName[player], "") != 0)
 		{
-			if(strcmp(NetPlay.players[i].name,"") == 0)
-			{
-				// make up a name for this player.
-				return getPlayerColourName(player);
-			}
-
-			return NetPlay.players[i].name;
+			return (char*)&playerName[player];
 		}
 	}
 
-	return NetPlay.players[0].name;
+	if (strlen(NetPlay.players[player].name) == 0)
+	{
+		// make up a name for this player.
+		return getPlayerColourName(player);
+	}
+
+	return NetPlay.players[player].name;
 }
 
 BOOL setPlayerName(UDWORD player, const char *sName)
 {
-	if(player > MAX_PLAYERS)
-	{
-		ASSERT(false, "setPlayerName: wrong player index (%d)", player);
-		return false;
-	}
-
-	strcpy(playerName[player],sName);
-
+	ASSERT_OR_RETURN(false, player < MAX_PLAYERS, "Player index (%u) out of range", player);
+	sstrcpy(playerName[player], sName);
 	return true;
 }
 
@@ -513,45 +483,27 @@ BOOL setPlayerName(UDWORD player, const char *sName)
 BOOL isHumanPlayer(UDWORD player)
 {
 	if (player >= MAX_PLAYERS)
-		return false;
-
-	return (BOOL) (player2dpid[player] != 0);
+	{
+		return false;	// obvious, really
+	}
+	return NetPlay.players[player].allocated;
 }
 
 // returns player responsible for 'player'
 UDWORD  whosResponsible(UDWORD player)
 {
-	UDWORD c;
-
-    c = ANYPLAYER;
 	if (isHumanPlayer(player))
 	{
-		c = player;
+		return player;			// Responsible for him or her self
 	}
-
-	else if(player == selectedPlayer)
+	else if (player == selectedPlayer)
 	{
-		c = player;
+		return player;			// We are responsibly for ourselves
 	}
-
 	else
 	{
-		SDWORD player;
-
-		// find the host using HOST_DPID
-		for(player=0;player <= MAX_PLAYERS && c == ANYPLAYER;player++)
-		{
-			if(player2dpid[player] == HOST_DPID)
-			{
-				c = player;
-			}
-		}
+		return NET_HOST_ONLY;	// host responsible for all AIs
 	}
-	if(c == ANYPLAYER)
-	{
-		debug( LOG_NEVER, "failed to find a player for %d \n", player );
-	}
-	return c;
 }
 
 //returns true if selected player is responsible for 'player'
@@ -570,7 +522,6 @@ BOOL myResponsibility(UDWORD player)
 //returns true if 'player' is responsible for 'playerinquestion'
 BOOL responsibleFor(UDWORD player, UDWORD playerinquestion)
 {
-
 	if(whosResponsible(playerinquestion) == player)
 	{
 		return true;
@@ -706,8 +657,7 @@ BOOL recvMessage(void)
 			case NET_GIFT:						// an alliance gift from one player to another.
 				recvGift();
 				break;
-			case NET_SCORESUBMIT:				//  a score update from another player
-				recvScoreSubmission();
+			case NET_SCORESUBMIT:				//  a score update from another player [UNUSED] see NET_PLAYER_STATS
 				break;
 			case NET_VTOL:
 				recvHappyVtol();
@@ -744,6 +694,22 @@ BOOL recvMessage(void)
 		case NET_OPTIONS:
 			recvOptions();
 			break;
+		case NET_PLAYER_DROPPED:				// remote player got disconnected
+		{
+			uint32_t player_id;
+
+			NETbeginDecode(NET_PLAYER_DROPPED);
+			{
+				NETuint32_t(&player_id);
+			}
+			NETend();
+
+			debug(LOG_INFO,"** player %u has dropped!", player_id);
+
+			MultiPlayerLeave(player_id);		// get rid of their stuff
+			NET_PlayerConnectionStatus = 2;		//DROPPED_CONNECTION
+			break;
+		}
 		case NET_PLAYERRESPONDING:			// remote player is now playing
 		{
 			uint32_t player_id;
@@ -763,9 +729,13 @@ BOOL recvMessage(void)
 			ingame.JoiningInProgress[player_id] = false;
 			break;
 		}
+		// FIXME: the next 4 cases might not belong here --check (we got two loops for this)
 		case NET_COLOURREQUEST:
 			recvColourRequest();
 			break;
+		case NET_POSITIONREQUEST:
+			recvPositionRequest();
+			break;
 		case NET_TEAMREQUEST:
 			recvTeamRequest();
 			break;
@@ -773,7 +743,7 @@ BOOL recvMessage(void)
 			recvReadyRequest();
 
 			// if hosting try to start the game if everyone is ready
-			if(NetPlay.bHost && multiplayPlayersReady(false))
+			if(NetPlay.isHost && multiplayPlayersReady(false))
 			{
 				startMultiplayerGame();
 			}
@@ -793,19 +763,31 @@ BOOL recvMessage(void)
 			uint32_t player_id;
 			char reason[MAX_KICK_REASON];
 
+			if (player_id == NET_HOST_ONLY)
+			{
+				debug(LOG_ERROR, "someone tried to kick the host--check your netplay logs!");
+				NETend();
+				break;
+			}
+
 			NETbeginDecode(NET_KICK);
 				NETuint32_t(&player_id);
 				NETstring( reason, MAX_KICK_REASON);
 			NETend();
 
-			if (NetPlay.dpidPlayer == player_id)  // we've been told to leave.
+			if (selectedPlayer == player_id)  // we've been told to leave.
 			{
-				debug(LOG_ERROR, "You were kicked because, %s", reason);
+				debug(LOG_ERROR, "You were kicked because %s", reason);
 				setPlayerHasLost(true);
 			}
+			else
+			{
+				NETplayerKicked(player_id);
+			}
 			break;
 		}
 		case NET_FIREUP:				// frontend only
+			debug(LOG_NET, "NET_FIREUP was received (frontend only?)"); 
 			break;
 		case NET_RESEARCHSTATUS:
 			recvResearchStatus();
@@ -837,7 +819,7 @@ BOOL SendResearch(uint8_t player, uint32_t index)
 
 	/*
 	 * Since we are called when the state of research changes (completed,
-	 * stopped &c) we also need to update our onw local copy of what our allies
+	 * stopped &c) we also need to update our own local copy of what our allies
 	 * are doing/have done.
 	 */
 	if (game.type == SKIRMISH)
@@ -979,7 +961,7 @@ BOOL recvResearchStatus()
 		psBuilding = IdToStruct(structRef, player);
 
 		// Set that facility to research
-		if (psBuilding)
+		if (psBuilding && psBuilding->pFunctionality)
 		{
 			psResFacilty = (RESEARCH_FACILITY *) psBuilding->pFunctionality;
 
@@ -1059,22 +1041,23 @@ BOOL recvResearchStatus()
 // ////////////////////////////////////////////////////////////////////////////
 // ////////////////////////////////////////////////////////////////////////////
 // Text Messaging between players. proceed string with players to send to.
-// eg "123 hi there" sends "hi there" to players 1,2 and 3.
+// eg "123hi there" sends "hi there" to players 1,2 and 3.
 BOOL sendTextMessage(const char *pStr, BOOL all)
 {
 	BOOL				normal = true;
 	BOOL				sendto[MAX_PLAYERS];
+	int					posTable[MAX_PLAYERS];
 	UDWORD				i;
 	char				display[MAX_CONSOLE_STRING_LENGTH];
 	char				msg[MAX_CONSOLE_STRING_LENGTH];
-	uint8_t				netplayer = 0;
+	char*				curStr = (char*)pStr;
 
 	if (!ingame.localOptionsReceived)
 	{
 		if(!bMultiPlayer)
 		{
 			// apparently we are not in a mp game, so dump the message to the console.
-			addConsoleMessage(pStr,LEFT_JUSTIFY, SYSTEM_MESSAGE);
+			addConsoleMessage(curStr,LEFT_JUSTIFY, SYSTEM_MESSAGE);
 		}
 		return true;
 	}
@@ -1082,23 +1065,71 @@ BOOL sendTextMessage(const char *pStr, BOOL all)
 	memset(display,0x0, sizeof(display));	//clear buffer
 	memset(msg,0x0, sizeof(display));		//clear buffer
 	memset(sendto,0x0, sizeof(sendto));		//clear private flag
-	sstrcpy(msg, pStr);
-	for (i = 0; pStr[i] >= '0' && pStr[i] <= '7' && i < MAX_PLAYERS; i++)		// for each 0..7 numeric char encountered
-	{
-		sendto[ pStr[i]-'0' ] = true;
-		normal = false;
-	}
+	memset(posTable,0x0, sizeof(posTable));		//clear buffer
+	sstrcpy(msg, curStr);
 
-	if (!all && !normal)	// lets user know it is a private message
+	if (!all)
 	{
-		sstrcpy(display, "(private)");
-		sstrcat(display, pStr);
+		// create a position table
+		for (i = 0; i < game.maxPlayers; i++)
+		{
+			posTable[NetPlay.players[i].position] = i;
+		}
+
+		if (curStr[0] == '.')
+		{
+			curStr++;
+			for (i = 0; i < game.maxPlayers; i++)
+			{
+				if (i != selectedPlayer && aiCheckAlliances(selectedPlayer, i))
+				{
+					sendto[i] = true;
+				}
+			}
+			normal = false;
+			if (!all)
+			{
+				sstrcpy(display, _("(allies"));
+			}
+		}
+		for (; curStr[0] >= '0' && curStr[0] <= '7'; curStr++)		// for each 0..7 numeric char encountered
+		{
+			i = posTable[curStr[0]-'0'];
+			if (normal)
+			{
+				sstrcpy(display, _("(private to "));
+			}
+			else
+			{
+				sstrcat(display, ", ");
+			}
+			if ((isHumanPlayer(i) || (game.type == SKIRMISH && i<game.maxPlayers && game.skDiff[i] ) ))
+			{
+				sstrcat(display, getPlayerName(posTable[curStr[0]-'0']));
+				sendto[i] = true;
+			}
+			else
+			{
+				sstrcat(display, _("[invalid]"));
+			}
+			normal = false;
+		}
+
+		if (!normal)	// lets user know it is a private message
+		{
+			if (curStr[0] == ' ')
+			{
+				curStr++;
+			}
+			sstrcat(display, ") ");
+			sstrcat(display, curStr);
+		}
 	}
 
 	if (all)	//broadcast
 	{
 		NETbeginEncode(NET_TEXTMSG, NET_ALL_PLAYERS);
-			NETuint32_t(&NetPlay.dpidPlayer);		// who this msg is from
+			NETuint32_t(&selectedPlayer);		// who this msg is from
 			NETstring(msg,MAX_CONSOLE_STRING_LENGTH);	// the message to send
 		NETend();
 	}
@@ -1110,9 +1141,8 @@ BOOL sendTextMessage(const char *pStr, BOOL all)
 			{
 				if (isHumanPlayer(i))
 				{
-					netplayer = player2dpid[i];
-					NETbeginEncode(NET_TEXTMSG,netplayer);
-						NETuint32_t(&NetPlay.dpidPlayer);		// who this msg is from
+					NETbeginEncode(NET_TEXTMSG, i);
+						NETuint32_t(&selectedPlayer);		// who this msg is from
 						NETstring(msg,MAX_CONSOLE_STRING_LENGTH);	// the message to send
 					NETend();
 				}
@@ -1131,35 +1161,25 @@ BOOL sendTextMessage(const char *pStr, BOOL all)
 			{
 				if (isHumanPlayer(i))
 				{
-					netplayer = player2dpid[i];
-						NETbeginEncode(NET_TEXTMSG, netplayer);
-						NETuint32_t(&NetPlay.dpidPlayer);				// who this msg is from
+					NETbeginEncode(NET_TEXTMSG, i);
+						NETuint32_t(&selectedPlayer);				// who this msg is from
 						NETstring(display, MAX_CONSOLE_STRING_LENGTH);	// the message to send
 					NETend();
 				}
 				else	//also send to AIs now (non-humans), needed for AI
 				{
-					sendAIMessage(display, selectedPlayer, i);
+					sendAIMessage(curStr, selectedPlayer, i);
 				}
 			}
 		}
-		sprintf(display,"(private)");
 	}
 
 	//This is for local display
-	for (i = 0; i < ARRAY_SIZE(NetPlay.players); ++i)
-	{
-		if (NetPlay.players[i].dpid == NetPlay.dpidPlayer)
-		{
-			sstrcat(display, NetPlay.players[i].name);		// name
-			sstrcat(display, ": ");						// seperator
-			sstrcat(display, pStr);						// add message
-
-			addConsoleMessage(display, DEFAULT_JUSTIFY, selectedPlayer);	// display
-			break;
-		}
-	}
+	sstrcpy(msg, NetPlay.players[selectedPlayer].name);		// name
+	sstrcat(msg, ": ");						// seperator
+	sstrcat(msg, (normal?curStr:display));						// add message
 
+	addConsoleMessage(msg, DEFAULT_JUSTIFY, selectedPlayer);	// display
 
 	return true;
 }
@@ -1167,8 +1187,7 @@ BOOL sendTextMessage(const char *pStr, BOOL all)
 //AI multiplayer message, send from a certain player index to another player index
 BOOL sendAIMessage(char *pStr, UDWORD player, UDWORD to)
 {
-	UDWORD	sendPlayer;		//dpidPlayer is a uint32_t, not int32_t!
-	uint8_t netplayer=0;
+	UDWORD	sendPlayer;
 
 	//check if this is one of the local players, don't need net send then
 	if (to == selectedPlayer || myResponsibility(to))	//(the only) human on this machine or AI on this machine
@@ -1206,10 +1225,9 @@ BOOL sendAIMessage(char *pStr, UDWORD player, UDWORD to)
 			debug(LOG_ERROR, "sendAIMessage() - player is not human.");
 			return false;
 		}
-		netplayer = player2dpid[sendPlayer];
 
 		//send to the player who is hosting 'to' player (might be himself if human and not AI)
-		NETbeginEncode(NET_AITEXTMSG, netplayer);
+		NETbeginEncode(NET_AITEXTMSG, sendPlayer);
 			NETuint32_t(&player);			//save the actual sender
 			//save the actual player that is to get this msg on the source machine (source can host many AIs)
 			NETuint32_t(&to);				//save the actual receiver (might not be the same as the one we are actually sending to, in case of AIs)
@@ -1239,7 +1257,7 @@ BOOL sendBeacon(int32_t locX, int32_t locY, int32_t forPlayer, int32_t sender, c
 
 	// I assume this is correct, looks like it sends it to ONLY that person, and the routine
 	// kf_AddHelpBlip() itterates for each player it needs.
-	NETbeginEncode(NET_BEACONMSG, player2dpid[sendPlayer]);     // send to the player who is hosting 'to' player (might be himself if human and not AI)
+	NETbeginEncode(NET_BEACONMSG, sendPlayer);		// send to the player who is hosting 'to' player (might be himself if human and not AI)
 		NETint32_t(&sender);                                // save the actual sender
 
 		// save the actual player that is to get this msg on the source machine (source can host many AIs)
@@ -1271,56 +1289,36 @@ void displayAIMessage(char *pStr, SDWORD from, SDWORD to)
 // Write a message to the console.
 BOOL recvTextMessage()
 {
-	UDWORD	dpid;
-	UDWORD	i;
+	UDWORD	playerIndex;
 	char	msg[MAX_CONSOLE_STRING_LENGTH];
 	char newmsg[MAX_CONSOLE_STRING_LENGTH];
-	UDWORD  player=MAX_PLAYERS,j;		//console callback - player who sent the message
 
 	memset(msg, 0x0, sizeof(msg));
 	memset(newmsg, 0x0, sizeof(newmsg));
 
 	NETbeginDecode(NET_TEXTMSG);
 		// Who this msg is from
-		NETuint32_t(&dpid);
+		NETuint32_t(&playerIndex);
 		// The message to send
 		NETstring(newmsg, MAX_CONSOLE_STRING_LENGTH);
 	NETend();
 
-
-	for (i = 0; i < MAX_PLAYERS; i++)		//findplayer
+	if (playerIndex >= MAX_PLAYERS)
 	{
-		if (NetPlay.players[i].dpid == dpid)
-		{
-			break;
-		}
+		return false;
 	}
 
-	ASSERT_OR_RETURN(false, i != MAX_PLAYERS, "Failed to find player's dpid %u", dpid);
-
-	//console callback - find real number of the player
-	for (j = 0; i < MAX_PLAYERS; j++)
-	{
-		if (dpid == player2dpid[j])
-		{
-			player = j;
-			break;
-		}
-	}
-
-	ASSERT_OR_RETURN(false, player != MAX_PLAYERS, "Failed to find 'real' owner of dpid %u", dpid);
-
-	sstrcpy(msg, NetPlay.players[i].name);
+	sstrcpy(msg, NetPlay.players[playerIndex].name);
 	// Seperator
 	sstrcat(msg, ": ");
 	// Add message
 	sstrcat(msg, newmsg);
 
-	addConsoleMessage(msg, DEFAULT_JUSTIFY, player);
+	addConsoleMessage(msg, DEFAULT_JUSTIFY, playerIndex);
 
 	// Multiplayer message callback
 	// Received a console message from a player, save
-	MultiMsgPlayerFrom = player;
+	MultiMsgPlayerFrom = playerIndex;
 	MultiMsgPlayerTo = selectedPlayer;
 
 	sstrcpy(MultiplayMsg, newmsg);
@@ -1449,6 +1447,7 @@ BOOL recvTemplate()
 
 	t.psNext = NULL;
 	t.pName = NULL;
+	t.prefab = false;
 
 	psTempl = IdToTemplate(t.multiPlayerID,player);
 
@@ -1457,11 +1456,13 @@ BOOL recvTemplate()
 	{
 		t.psNext = psTempl->psNext;
 		memcpy(psTempl, &t, sizeof(DROID_TEMPLATE));
+		debug(LOG_SYNC, "Updating MP template %d", (int)t.multiPlayerID);
 	}
 	else
 	{
 		addTemplate(player,&t);
 		apsDroidTemplates[player]->ref = REF_TEMPLATE_START;
+		debug(LOG_SYNC, "Creating MP template %d", (int)t.multiPlayerID);
 	}
 
 	return true;
@@ -1552,9 +1553,11 @@ BOOL recvDestroyFeature()
 	pF = IdToFeature(id,ANYPLAYER);
 	if (pF == NULL)
 	{
+		debug(LOG_FEATURE, "feature id %d not found (probably already destroyed)", id);
 		return false;
 	}
 
+	debug(LOG_FEATURE, "p%d feature id %d destroyed (%s)", pF->player, pF->id, pF->psStats->pName);
 	// Remove the feature locally
 	turnOffMultiMsg(true);
 	removeFeature(pF);
@@ -1568,26 +1571,42 @@ BOOL recvDestroyFeature()
 BOOL recvMapFileRequested()
 {
 	char mapStr[256],mapName[256],fixedname[256];
+	uint32_t player;
 
-	// another player is requesting the map
-	if(!NetPlay.bHost)
+	PHYSFS_sint64 fileSize_64;
+	PHYSFS_file	*pFileHandle;
+
+	// We are not the host, so we don't care. (in fact, this would be a error)
+	if(!NetPlay.isHost)
 	{
 		return true;
 	}
 
-	// start sending the map to the other players.
-	if(!bSendingMap)
+	//	Check to see who wants the file
+	NETbeginDecode(NET_FILE_REQUESTED);
+	NETuint32_t(&player);
+	NETend();
+
+	if (!NetPlay.players[player].wzFile.isSending)
 	{
+		NetPlay.players[player].needFile = true;
+		NetPlay.players[player].wzFile.isCancelled = false;
+		NetPlay.players[player].wzFile.isSending = true;
+
 		memset(mapStr,0,256);
 		memset(mapName,0,256);
 		memset(fixedname,0,256);
-		bSendingMap = true;
+
 		addConsoleMessage("Map was requested: SENDING MAP!",DEFAULT_JUSTIFY, SYSTEM_MESSAGE);
 
 		sstrcpy(mapName, game.map);
-		// chop off the -T1
-		mapName[strlen(game.map)-3] = 0;		// chop off the -T1 etc..
-
+		if (	strstr(mapName,"-T1") != 0
+			|| strstr(mapName,"-T2") != 0
+			|| strstr(mapName,"-T3") != 0)
+		{
+			// chop off the -T1 *only when needed!*
+			mapName[strlen(game.map)-3] = 0;		// chop off the -T1 etc..
+		}
 		// chop off the sk- if required.
 		if(strncmp(mapName,"Sk-",3) == 0)
 		{
@@ -1598,48 +1617,66 @@ BOOL recvMapFileRequested()
 		snprintf(mapStr, sizeof(mapStr), "%dc-%s.wz", game.maxPlayers, mapName);
 		snprintf(fixedname, sizeof(fixedname), "maps/%s", mapStr);		//We know maps are in /maps dir...now. fix for linux -Q
 		sstrcpy(mapStr, fixedname);
-		NETsendFile(true,mapStr,0);
-	}
+		debug(LOG_NET, "Map was requested. Looking for %s", mapStr);
 
+		// Checking to see if file is available...
+		pFileHandle = PHYSFS_openRead(mapStr);
+		if (pFileHandle == NULL)
+		{
+			debug(LOG_ERROR, "Failed to open %s for reading: %s", mapStr, PHYSFS_getLastError());
+			debug(LOG_FATAL, "You have a map (%s) that can't be located.\n\nMake sure it is in the correct directory and or format! (No map packs!)", mapStr);
+			// NOTE: if we get here, then the game is basically over, The host can't send the file for whatever reason...
+			// Which also means, that we can't continue.
+			debug(LOG_NET, "***Host has a file issue, and is being forced to quit!***");
+			NETbeginEncode(NET_HOST_DROPPED, NET_ALL_PLAYERS);
+			NETend();
+			abort();
+		}
+
+		// get the file's size.
+		fileSize_64 = PHYSFS_fileLength(pFileHandle);
+		debug(LOG_NET, "File is valid, sending [directory: %s] %s to client %u", PHYSFS_getRealDir(mapStr), mapStr, player);
+
+		NetPlay.players[player].wzFile.pFileHandle = pFileHandle;
+		NetPlay.players[player].wzFile.fileSize_32 = (int32_t) fileSize_64;		//we don't support 64bit int nettypes.
+		NetPlay.players[player].wzFile.currPos = 0;
+
+		NETsendFile(mapStr, player);
+	}
 	return true;
 }
 
 // continue sending the map
-UBYTE sendMap(void)
+void sendMap(void)
 {
+	int i = 0;
 	UBYTE done;
-	static UDWORD lastCall;
 
-
-	if(lastCall > gameTime)lastCall= 0;
-	if ( (gameTime - lastCall) <200)
+	for (i = 0; i < MAX_PLAYERS; i++)
 	{
-		return 0;
+		if (NetPlay.players[i].wzFile.isSending)
+		{
+			done = NETsendFile(game.map, i);
+			if (done == 100)
+			{
+				addConsoleMessage("MAP SENT!",DEFAULT_JUSTIFY, SYSTEM_MESSAGE);
+				debug(LOG_NET, "=== File has been sent to player %d ===", i);
+				NetPlay.players[i].wzFile.isSending = false;
+				NetPlay.players[i].needFile = false;
+			}
+		}
 	}
-	lastCall = gameTime;
-
-
-	done = NETsendFile(false,game.map,0);
-
-	if(done == 100)
-	{
-		addConsoleMessage("MAP SENT!",DEFAULT_JUSTIFY, SYSTEM_MESSAGE);
-		bSendingMap = false;
-	}
-
-	return done;
 }
 
 // Another player is broadcasting a map, recv a chunk. Returns false if not yet done.
 BOOL recvMapFileData()
 {
-	UBYTE done;
-
-	done =  NETrecvFile();
-	if(done == 100)
+	mapDownloadProgress = NETrecvFile();
+	if (mapDownloadProgress == 100)
 	{
 		addConsoleMessage("MAP DOWNLOADED!",DEFAULT_JUSTIFY, SYSTEM_MESSAGE);
 		sendTextMessage("MAP DOWNLOADED",true);					//send
+		debug(LOG_NET, "=== File has been received. ===");
 
 		// clear out the old level list.
 		levShutDown();
@@ -1651,11 +1688,6 @@ BOOL recvMapFileData()
 		}
 		return true;
 	}
-	else
-	{
-		flushConsoleMessages();
-		CONPRINTF(ConsoleString,(ConsoleString,"MAP:%d%%",done));
-	}
 
 	return false;
 }
@@ -1957,24 +1989,6 @@ const char* getPlayerColourName(unsigned int player)
 	return gettext(playerColors[getPlayerColour(player)]);
 }
 
-/*
- * returns player in-game index from a dpid or -1 if player not found (should not happen!)
- */
-SDWORD dpidToPlayer(SDWORD dpid)
-{
-	UDWORD i;
-
-	for(i=0;(i<MAX_PLAYERS) && (dpid != player2dpid[i]); i++);
-
-	if(i >= MAX_PLAYERS)
-	{
-		ASSERT(i< MAX_PLAYERS, "dpidToPlayer: failed to find player with dpid %d", dpid);
-		return -1;
-	}
-
-	return i;
-}
-
 /* Reset ready status for all players */
 void resetReadyStatus(bool bSendOptions)
 {
@@ -1988,6 +2002,7 @@ void resetReadyStatus(bool bSendOptions)
 	// notify all clients if needed
 	if(bSendOptions)
 	{
-		sendOptions(player2dpid[selectedPlayer], selectedPlayer);
+		sendOptions();
 	}
+	netPlayersUpdated = true;
 }
