@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -26,23 +26,12 @@
  */
 
 #include "lib/framework/frame.h"
-#include "lib/framework/strres.h"
 #include "lib/framework/file.h"
-#include "lib/netplay/netplay.h"
-#include "lib/widget/widget.h"
+#include "lib/netplay/nettypes.h"
 
-#include "objmem.h"
-#include "power.h"
-#include "map.h"
-#include "effects.h"	// for discovery flash
-#include "cmddroid.h"
-#include "multiplay.h"
-#include "multirecv.h"
-#include "multistat.h"
-#include "multiint.h"
+#include "main.h"
 #include "mission.h" // for cheats
-
-extern char	MultiPlayersPath[PATH_MAX];
+#include "multistat.h"
 
 // ////////////////////////////////////////////////////////////////////////////
 // STATS STUFF
@@ -51,43 +40,43 @@ static PLAYERSTATS playerStats[MAX_PLAYERS];
 
 // ////////////////////////////////////////////////////////////////////////////
 // Get Player's stats
-PLAYERSTATS getMultiStats(UDWORD player,BOOL bLocal)
+PLAYERSTATS getMultiStats(UDWORD player)
 {
-	static PLAYERSTATS stat;
-	uint32_t playerDPID = player2dpid[player];
-
-	// Copy over the data from our local array
-	memcpy(&stat, &playerStats[playerDPID], sizeof(stat));
-
-	return stat;
+	return playerStats[player];
 }
 
 // ////////////////////////////////////////////////////////////////////////////
 // Set Player's stats
-BOOL setMultiStats(SDWORD dp, PLAYERSTATS plStats, BOOL bLocal)
+// send stats to all players when bLocal is false
+BOOL setMultiStats(SDWORD player, PLAYERSTATS plStats, BOOL bLocal)
 {
-	uint32_t playerDPID = (uint32_t)dp;
+	uint32_t playerIndex = (uint32_t)player;
+
+	if (playerIndex >= MAX_PLAYERS)
+	{
+		return true;
+	}
 
 	// First copy over the data into our local array
-	memcpy(&playerStats[playerDPID], &plStats, sizeof(plStats));
+	memcpy(&playerStats[playerIndex], &plStats, sizeof(plStats));
 
 	if (!bLocal)
 	{
 		// Now send it to all other players
 		NETbeginEncode(NET_PLAYER_STATS, NET_ALL_PLAYERS);
 			// Send the ID of the player's stats we're updating
-			NETuint32_t(&playerDPID);
+			NETuint32_t(&playerIndex);
 
 			// Send over the actual stats
-			NETuint32_t(&playerStats[playerDPID].played);
-			NETuint32_t(&playerStats[playerDPID].wins);
-			NETuint32_t(&playerStats[playerDPID].losses);
-			NETuint32_t(&playerStats[playerDPID].totalKills);
-			NETuint32_t(&playerStats[playerDPID].totalScore);
-			NETuint32_t(&playerStats[playerDPID].recentKills);
-			NETuint32_t(&playerStats[playerDPID].recentScore);
-			NETuint32_t(&playerStats[playerDPID].killsToAdd);
-			NETuint32_t(&playerStats[playerDPID].scoreToAdd);
+			NETuint32_t(&playerStats[playerIndex].played);
+			NETuint32_t(&playerStats[playerIndex].wins);
+			NETuint32_t(&playerStats[playerIndex].losses);
+			NETuint32_t(&playerStats[playerIndex].totalKills);
+			NETuint32_t(&playerStats[playerIndex].totalScore);
+			NETuint32_t(&playerStats[playerIndex].recentKills);
+			NETuint32_t(&playerStats[playerIndex].recentScore);
+			NETuint32_t(&playerStats[playerIndex].killsToAdd);
+			NETuint32_t(&playerStats[playerIndex].scoreToAdd);
 		NETend();
 	}
 
@@ -96,23 +85,32 @@ BOOL setMultiStats(SDWORD dp, PLAYERSTATS plStats, BOOL bLocal)
 
 void recvMultiStats()
 {
-	uint32_t playerDPID;
+	uint32_t playerIndex;
 
 	NETbeginDecode(NET_PLAYER_STATS);
 		// Retrieve the ID number of the player for which we need to
 		// update the stats
-		NETuint32_t(&playerDPID);
+		NETuint32_t(&playerIndex);
 
-		// Retrieve the actual stats
-		NETuint32_t(&playerStats[playerDPID].played);
-		NETuint32_t(&playerStats[playerDPID].wins);
-		NETuint32_t(&playerStats[playerDPID].losses);
-		NETuint32_t(&playerStats[playerDPID].totalKills);
-		NETuint32_t(&playerStats[playerDPID].totalScore);
-		NETuint32_t(&playerStats[playerDPID].recentKills);
-		NETuint32_t(&playerStats[playerDPID].recentScore);
-		NETuint32_t(&playerStats[playerDPID].killsToAdd);
-		NETuint32_t(&playerStats[playerDPID].scoreToAdd);
+		if (playerIndex >= MAX_PLAYERS)
+		{
+			return;
+		}
+
+		// we don't what to update ourselves, we already know our score (FIXME: rewrite setMultiStats())
+		if (!myResponsibility(playerIndex))
+		{
+			// Retrieve the actual stats
+			NETuint32_t(&playerStats[playerIndex].played);
+			NETuint32_t(&playerStats[playerIndex].wins);
+			NETuint32_t(&playerStats[playerIndex].losses);
+			NETuint32_t(&playerStats[playerIndex].totalKills);
+			NETuint32_t(&playerStats[playerIndex].totalScore);
+			NETuint32_t(&playerStats[playerIndex].recentKills);
+			NETuint32_t(&playerStats[playerIndex].recentScore);
+			NETuint32_t(&playerStats[playerIndex].killsToAdd);
+			NETuint32_t(&playerStats[playerIndex].scoreToAdd);
+		}
 	NETend();
 }
 
@@ -210,42 +208,50 @@ void updateMultiStatsDamage(UDWORD attacker, UDWORD defender, UDWORD inflicted)
 	{
 		return;
 	}
-	
-	if(isHumanPlayer(attacker))
+	// FIXME: Why in the world are we using two different structs for stats when we can use only one?
+	// Host controls self + AI, so update the scores for them as well.
+	if (attacker < MAX_PLAYERS)
 	{
-		st = getMultiStats(attacker,true);	// get stats
-		if(NetPlay.bComms)
+		if (myResponsibility(attacker) && NetPlay.bComms)
 		{
-			st.scoreToAdd += (2*inflicted);
+			st = getMultiStats(attacker);	// get stats
+			if (NetPlay.bComms)
+			{
+				st.scoreToAdd += (2 * inflicted);
+			}
+			else
+			{
+				st.recentScore += (2 * inflicted);
+			}
+			setMultiStats(attacker, st, true);
 		}
 		else
 		{
-			st.recentScore += (2*inflicted);
+			ingame.skScores[attacker][0] += (2 * inflicted);	// increment skirmish players rough score.
 		}
-		setMultiStats(player2dpid[attacker], st, true);
-	}
-	else
-	{
-		ingame.skScores[attacker][0] += (2*inflicted);	// increment skirmish players rough score.
 	}
 
-
-	if(isHumanPlayer(defender))
+	// FIXME: Why in the world are we using two different structs for stats when we can use only one?
+	// Host controls self + AI, so update the scores for them as well.
+	if (defender < MAX_PLAYERS)
 	{
-		st = getMultiStats(defender,true);	// get stats
-		if(NetPlay.bComms)
+		if (myResponsibility(defender) && NetPlay.bComms)
 		{
-			st.scoreToAdd  -= inflicted;
+			st = getMultiStats(defender);	// get stats
+			if (NetPlay.bComms)
+			{
+				st.scoreToAdd  -= inflicted;
+			}
+			else
+			{
+				st.recentScore  -= inflicted;
+			}
+			setMultiStats(defender, st, true);
 		}
 		else
 		{
-			st.recentScore  -= inflicted;
+			ingame.skScores[defender][0] -= inflicted;	// increment skirmish players rough score.
 		}
-		setMultiStats(player2dpid[defender], st, true);
-	}
-	else
-	{
-		ingame.skScores[defender][0] -= inflicted;	// increment skirmish players rough score.
 	}
 }
 
@@ -258,9 +264,9 @@ void updateMultiStatsGames(void)
 	{
 		return;
 	}
-	st  = getMultiStats(selectedPlayer,true);
+	st  = getMultiStats(selectedPlayer);
 	st.played ++;
-	setMultiStats(player2dpid[selectedPlayer], st, true);
+	setMultiStats(selectedPlayer, st, true);
 }
 
 // games won
@@ -271,9 +277,9 @@ void updateMultiStatsWins(void)
 	{
 		return;
 	}
-	st  = getMultiStats(selectedPlayer,true);
+	st  = getMultiStats(selectedPlayer);
 	st.wins ++;
-	setMultiStats(player2dpid[selectedPlayer], st, true);
+	setMultiStats(selectedPlayer, st, true);
 }
 
 //games lost.
@@ -284,9 +290,9 @@ void updateMultiStatsLoses(void)
 	{
 		return;
 	}
-	st  = getMultiStats(selectedPlayer,true);
+	st  = getMultiStats(selectedPlayer);
 	++st.losses;
-	setMultiStats(player2dpid[selectedPlayer], st, true);
+	setMultiStats(selectedPlayer, st, true);
 }
 
 // update kills
@@ -298,9 +304,11 @@ void updateMultiStatsKills(BASE_OBJECT *psKilled,UDWORD player)
 	{
 		return;
 	}
-	if(isHumanPlayer(player))
+	// FIXME: Why in the world are we using two different structs for stats when we can use only one?
+	// Host controls self + AI, so update the scores for them as well.
+	if(myResponsibility(player) && NetPlay.bComms)
 	{
-		st  = getMultiStats(player,true);
+		st  = getMultiStats(player);
 
 		if(NetPlay.bComms)
 		{
@@ -310,7 +318,7 @@ void updateMultiStatsKills(BASE_OBJECT *psKilled,UDWORD player)
 		{
 			st.recentKills++;
 		}
-		setMultiStats(player2dpid[player], st, true);
+		setMultiStats(player, st, true);
 	}
 	else
 	{
