@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -43,6 +43,7 @@
 #include "droid.h"
 #include "formation.h"
 #include "mapgrid.h"
+#include "visibility.h"
 
 #ifdef DEBUG
 static SDWORD factoryDeliveryPointCheck[MAX_PLAYERS][NUM_FLAG_TYPES][MAX_FACTORY];
@@ -123,6 +124,8 @@ static void objmemDestroy(BASE_OBJECT *psObj)
 	// Make sure to get rid of some final references in the sound code to this object first
 	audio_RemoveObj(psObj);
 
+	visRemoveVisibility(psObj);
+	free(psObj->watchedTiles);
 	free(psObj);
 	debug(LOG_MEMORY, "BASE_OBJECT* 0x%p is freed.", psObj);
 }
@@ -239,6 +242,8 @@ static inline BASE_OBJECT* createObject(UDWORD player, OBJECT_TYPE objType)
 	newObject->player = (UBYTE)player;
 	newObject->died = 0;
 	newObject->psNextFunc = NULL;
+	newObject->numWatchedTiles = 0;
+	newObject->watchedTiles = NULL;
 
 	return newObject;
 }
@@ -408,7 +413,9 @@ static inline void releaseAllObjectsInList(BASE_OBJECT *list[], OBJECT_DESTRUCTO
 			// Call a specialized destruction function
 			// (will do all cleanup except for releasing memory of object)
 			objectDestructor(psCurr);
-
+			// FIXME: the next call is disabled for now, yes, it will leak memory again.
+			// issue is with campaign games, and the swapping pointers 'trick' Pumpkin uses.
+			//	visRemoveVisibility(psCurr);
 			// Release object's memory
 			free(psCurr);
 		}
