@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -23,42 +23,24 @@
  * Store PlayerPower and other power related stuff!
  *
  */
-#include <string.h>
-#include "objectdef.h"
-#include "power.h"
-#include "hci.h"
-#include "lib/gamelib/gtime.h"
-#include "lib/sound/audio.h"
-#include "objmem.h"
-#include "frontend.h"
 
-#include "lib/netplay/netplay.h"
-#include "multiplay.h"
-#include "multiint.h"
+#include "lib/framework/frame.h"
 
-#include "feature.h"
-#include "structure.h"
-#include "mission.h"
-#include "research.h"
-#include "intdisplay.h"
-#include "action.h"
 #include "difficulty.h"
-
+#include "intdisplay.h"
+#include "mission.h"
+#include "power.h"
+#include "research.h"
 
 #define EXTRACT_POINTS	    1
 #define EASY_POWER_MOD      110
 #define NORMAL_POWER_MOD    100
 #define HARD_POWER_MOD      90
+#define MAX_POWER           100000
 
 //flag used to check for power calculations to be done or not
 BOOL	powerCalculated;
 
-/* Updates the current power based on the extracted power and a Power Generator*/
-static void updateCurrentPower(POWER_GEN *psPowerGen, UDWORD player);
-
-//returns the relevant list based on OffWorld or OnWorld
-static STRUCTURE* powerStructList(UBYTE player);
-
 PLAYER_POWER		asPower[MAX_PLAYERS];
 
 /*allocate the space for the playerPower*/
@@ -80,12 +62,6 @@ void clearPlayerPower(void)
 	}
 }
 
-/*Free the space used for playerPower */
-void releasePlayerPower(void)
-{
-	// nothing now
-}
-
 /*check the current power - if enough return true, else return false */
 BOOL checkPower(UDWORD player, UDWORD quantity)
 {
@@ -123,13 +99,6 @@ BOOL usePower(UDWORD player, UDWORD quantity)
 		asPower[player].currentPower -= quantity;
 		return true;
 	}
-	else if (player == selectedPlayer)
-	{
-		if(titleMode == FORCESELECT) //|| (titleMode == DESIGNSCREEN))
-		{
-			return false;
-		}
-	}
 	return false;
 }
 
@@ -138,57 +107,91 @@ void addPower(UDWORD player, UDWORD quantity)
 {
 	ASSERT(player < MAX_PLAYERS, "addPower: Bad player (%u)", player);
 
+	ASSERT(quantity <= MAX_POWER/2, "Power over or under flow. Tried to add %u.", quantity);
+	if (quantity > MAX_POWER)
+	{
+		debug(LOG_WARNING, "Power over or under flow. Tried to add %u - ignored", quantity);
+		return;
+	}
 	asPower[player].currentPower += quantity;
+	if (asPower[player].currentPower > MAX_POWER)
+	{
+		asPower[player].currentPower = MAX_POWER;
+	}
 }
 
 /*resets the power calc flag for all players*/
 void powerCalc(BOOL on)
 {
-	if (on)
-	{
-		powerCalculated = true;
-	}
-	else
-	{
-		powerCalculated = false;
-	}
+	powerCalculated = on;
 }
 
 /* Each Resource Extractor yields EXTRACT_POINTS per second until there are none
    left in the resource. */
-UDWORD updateExtractedPower(STRUCTURE	*psBuilding)
+static int32_t updateExtractedPower(STRUCTURE *psBuilding)
 {
 	RES_EXTRACTOR		*pResExtractor;
-	UDWORD				pointsToAdd, extractedPoints, timeDiff;
-	UBYTE			modifier;
+	int32_t				pointsToAdd, extractedPoints;
+	int32_t				powmodifier;
 
 	pResExtractor = (RES_EXTRACTOR *) psBuilding->pFunctionality;
 	extractedPoints = 0;
 
 	//only extracts points whilst its active ie associated with a power gen
-	//and has got some power to extract
-	if (pResExtractor->active && pResExtractor->power)
+	if (pResExtractor->active)
 	{
-		timeDiff = gameTime - pResExtractor->timeLastUpdated;
+		int overflowDiff;
 		// Add modifier according to difficulty level
 		if (getDifficultyLevel() == DL_EASY)
 		{
-			modifier = EASY_POWER_MOD;
+			powmodifier = EASY_POWER_MOD/10;
 		}
 		else if (getDifficultyLevel() == DL_HARD)
 		{
-			modifier = HARD_POWER_MOD;
+			powmodifier = HARD_POWER_MOD/10;
 		}
 		else
 		{
-			modifier = NORMAL_POWER_MOD;
+			powmodifier = NORMAL_POWER_MOD/10;
+		}
+		// if the extractor hasn't been updated recently, now would be a good time.
+		if (pResExtractor->timeLastUpdated < 20 && gameTime >= 20)
+		{
+			pResExtractor->timeLastUpdated = gameTime;
 		}
 		// include modifier as a %
-		pointsToAdd = (modifier * EXTRACT_POINTS * timeDiff) / (GAME_TICKS_PER_SEC * 100);
+		// Written this way to prevent rounding errors - do not "simplify"
+		overflowDiff = pResExtractor->timeLastUpdated - (pResExtractor->timeLastUpdated % (GAME_TICKS_PER_SEC*10));
+		pointsToAdd = ((gameTime - overflowDiff)                       * powmodifier * EXTRACT_POINTS) / (GAME_TICKS_PER_SEC * 10)
+		            - ((pResExtractor->timeLastUpdated - overflowDiff) * powmodifier * EXTRACT_POINTS) / (GAME_TICKS_PER_SEC * 10);
+		/*
+		 * If you are thinking about rewriting the preceding section of code, there are a few things
+		 * you should know.
+		 * 
+		 * First of all, division doesn't work intuitively.
+		 * 3 / 2 = 1, not 1.5. These are integers, not floats.
+		 *
+		 * Second of all, timeLastUpdated is NOT necessarily the time you want to base off of.
+		 * timeLastUpdated of an extractor that's just been created is some magic number around 12ms.
+		 * gameTime, on the other hand, could be around 3 hours.
+		 */
+		ASSERT(pointsToAdd > -1 && pointsToAdd < 10, "pointsToAdd not in sensical range");
+
+		if ((int)pResExtractor->timeLastUpdated - (int)gameTime > GAME_TICKS_PER_SEC || (int)gameTime - (int)pResExtractor->timeLastUpdated > GAME_TICKS_PER_SEC)
+		{
+			// extractor is not in the right time zone
+			// we have a maximum time skip of less than a second, so this can't be caused by lag
+			ASSERT(false, "Oil derrick out of sync.");
+			pointsToAdd = 0;
+		}
+		pResExtractor->timeLastUpdated = gameTime;
 		if (pointsToAdd)
 		{
-			// Lose a lot on rounding this way
-			pResExtractor->timeLastUpdated = gameTime;
+			extractedPoints += pointsToAdd;
+
+			// If not having unlimited power, uncomment the following lines.
+
+			/*
 			if (pResExtractor->power > pointsToAdd)
 			{
 				extractedPoints += pointsToAdd;
@@ -202,23 +205,19 @@ UDWORD updateExtractedPower(STRUCTURE	*psBuilding)
 
 			if (pResExtractor->power == 0)
 			{
-				// If not having unlimited power, put the 2 lines below back in
-				//set the extractor to be inactive
-				//pResExtractor->active = false;
-				//break the link between the power gen and the res extractor
-				//releaseResExtractor(psBuilding);
-
-				//for now, when the power = 0 set it back to the max level!
-				pResExtractor->power = ((RESOURCE_FUNCTION*)psBuilding->pStructureType->
-					asFuncList[0])->maxPower;
+				// set the extractor to be inactive
+				pResExtractor->active = false;
+				// break the link between the power gen and the res extractor
+				releaseResExtractor(psBuilding);
 			}
+			*/
 		}
 	}
 	return extractedPoints;
 }
 
 //returns the relevant list based on OffWorld or OnWorld
-STRUCTURE* powerStructList(UBYTE player)
+static STRUCTURE* powerStructList(UBYTE player)
 {
 	ASSERT(player < MAX_PLAYERS, "powerStructList: Bad player");
 	if (offWorldKeepLists)
@@ -231,6 +230,51 @@ STRUCTURE* powerStructList(UBYTE player)
 	}
 }
 
+/* Updates the current power based on the extracted power and a Power Generator*/
+static void updateCurrentPower(POWER_GEN *psPowerGen, UDWORD player)
+{
+	int32_t		power, i, extractedPower;
+
+	ASSERT(player < MAX_PLAYERS, "updateCurrentPower: Bad player");
+
+	//each power gen can cope with its associated resource extractors
+	extractedPower = 0;
+	for (i=0; i < NUM_POWER_MODULES; i++)
+	{
+		if (psPowerGen->apResExtractors[i])
+		{
+			//check not died
+			if (psPowerGen->apResExtractors[i]->died)
+			{
+				psPowerGen->apResExtractors[i] = NULL;
+			}
+			else
+			{
+				extractedPower += updateExtractedPower(psPowerGen->apResExtractors[i]);
+			}
+		}
+	}
+
+	// Written this way to prevent rounding errors - do not "simplify"
+	power = ((asPower[player].extractedPower + extractedPower) * psPowerGen->multiplier) / 100
+	      - (asPower[player].extractedPower * psPowerGen->multiplier) / 100;
+	asPower[player].extractedPower += extractedPower;
+	if (asPower[player].extractedPower > 100)
+	{
+		asPower[player].extractedPower -= 100; // just to prevent integer overflow
+	}
+
+	ASSERT_OR_RETURN(, power < 20 && power > -1, "Power out of sane range");
+	if (power >= 0)
+	{
+		asPower[player].currentPower += power;
+		if (asPower[player].currentPower > MAX_POWER)
+		{
+			asPower[player].currentPower = MAX_POWER;
+		}
+	}
+}
+
 /* Update current power based on what Power Generators exist */
 void updatePlayerPower(UDWORD player)
 {
@@ -255,40 +299,6 @@ void updatePlayerPower(UDWORD player)
 	}
 }
 
-/* Updates the current power based on the extracted power and a Power Generator*/
-void updateCurrentPower(POWER_GEN *psPowerGen, UDWORD player)
-{
-	UDWORD		power, i, extractedPower;
-
-	ASSERT(player < MAX_PLAYERS, "updateCurrentPower: Bad player");
-
-	//each power gen can cope with its associated resource extractors
-	extractedPower = 0;
-	for (i=0; i < NUM_POWER_MODULES; i++)
-	{
-		if (psPowerGen->apResExtractors[i])
-		{
-			//check not died
-			if (psPowerGen->apResExtractors[i]->died)
-			{
-				psPowerGen->apResExtractors[i] = NULL;
-			}
-			else
-			{
-				extractedPower += updateExtractedPower(psPowerGen->apResExtractors[i]);
-			}
-		}
-	}
-
-	asPower[player].extractedPower += extractedPower ;
-	power = (asPower[player].extractedPower * psPowerGen->multiplier) / 100;
-	if (power)
-	{
-		asPower[player].currentPower += power;
-		asPower[player].extractedPower = 0;
-	}
-}
-
 // only used in multiplayer games.
 void setPower(UDWORD player, UDWORD avail)
 {
