@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -38,43 +38,34 @@
 
 typedef struct _player_power
 {
-	UDWORD		currentPower;		/**< The current amount of power avaialble to the player. */
-	UDWORD		extractedPower;		/**< The power extracted but not converted. */
+	int32_t		currentPower;		/**< The current amount of power avaialble to the player. */
+	int32_t		extractedPower;		/**< The power extracted but not converted. */
 	BASE_OBJECT	*psLastPowered;		/**< The last object that received power before it ran out. */
 } PLAYER_POWER;
 
 /** Allocate the space for the playerPower. */
-extern BOOL allocPlayerPower(void);
+BOOL allocPlayerPower(void);
 
 /** Clear the playerPower. */
-extern void clearPlayerPower(void);
-
-/** Reset the power levels when a power_gen or resource_extractor is destroyed. */
-extern BOOL resetPlayerPower(UDWORD player, STRUCTURE *psStruct);
-
-/** Free the space used for playerPower. */
-extern void releasePlayerPower(void);
+void clearPlayerPower(void);
 
 /** Check the available power. */
-extern BOOL checkPower(UDWORD player, UDWORD quantity);
+BOOL checkPower(UDWORD player, UDWORD quantity);
 
 /** Subtract the power required. */
-extern BOOL usePower(UDWORD player, UDWORD quantity);
+BOOL usePower(UDWORD player, UDWORD quantity);
 
 /** Return the power when a structure/droid is deliberately destroyed. */
-extern void addPower(UDWORD player, UDWORD quantity);
-
-/** Each Resource Extractor yields EXTRACT_POINTS per second until there are none left in the resource. */
-extern UDWORD updateExtractedPower(STRUCTURE	*psBuilding);
+void addPower(UDWORD player, UDWORD quantity);
 
 /** Update current power based on what was extracted during the last cycle and what Power Generators exist. */
-extern void updatePlayerPower(UDWORD player);
+void updatePlayerPower(UDWORD player);
 
 /** Used in multiplayer to force power levels. */
-extern void setPower(UDWORD player, UDWORD avail);
+void setPower(UDWORD player, UDWORD avail);
 
 /** Get the amount of power current held by the given player. */
-extern UDWORD getPower(UDWORD player);
+UDWORD getPower(UDWORD player);
 
 /** Resets the power levels for all players when power is turned back on. */
 void powerCalc(BOOL on);
@@ -86,30 +77,30 @@ void setPlayerPower(UDWORD power, UDWORD player);
 void newGameInitPower(void);
 
 /** Informs the power array that a Object has been destroyed. */
-extern void powerDestroyObject(BASE_OBJECT *psObject);
+void powerDestroyObject(BASE_OBJECT *psObject);
 
 /** Accrue the power in the facilities that require it. */
-extern BOOL accruePower(BASE_OBJECT *psObject);
+BOOL accruePower(BASE_OBJECT *psObject);
 
 /** Inform the players power struct that the last Object to receive power has changed. */
-extern void updateLastPowered(BASE_OBJECT *psObject,UBYTE player);
+void updateLastPowered(BASE_OBJECT *psObject,UBYTE player);
 
 /**	Returns the next res. Ext. in the list from the one passed in. returns 1st one
 	in list if passed in is NULL and NULL if there's none?
 */
-extern STRUCTURE *getRExtractor(STRUCTURE *psStruct);
+STRUCTURE *getRExtractor(STRUCTURE *psStruct);
 
 /** Checks if the object to be powered next - returns true if power. */
-extern BOOL getLastPowered(BASE_OBJECT *psStructure);
+BOOL getLastPowered(BASE_OBJECT *psStructure);
 
 /** Defines which structure types draw power - returns true if use power. */
-extern BOOL structUsesPower(STRUCTURE *psStruct);
+BOOL structUsesPower(STRUCTURE *psStruct);
 
 /** Defines which droid types draw power - returns true if use power. */
-extern BOOL droidUsesPower(DROID *psDroid);
+BOOL droidUsesPower(DROID *psDroid);
 
 /** This is a check cos there is a problem with the power but not sure where!! */
-extern void powerCheck(BOOL bBeforePowerUsed, UBYTE player);
+void powerCheck(BOOL bBeforePowerUsed, UBYTE player);
 
 /** @todo Wrap access to this global and make it static for easier sanity checking! */
 extern PLAYER_POWER		asPower[MAX_PLAYERS];
