@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -64,6 +64,11 @@
 #define	DIRECT_PROJ_SPEED		500
 #define VTOL_HITBOX_MODIFICATOR 100
 
+typedef struct _interval
+{
+	int begin, end;  // Time 1 = 0, time 2 = 1024. Or begin >= end if empty.
+} INTERVAL;
+
 // Watermelon:they are from droid.c
 /* The range for neighbouring objects */
 #define PROJ_NAYBOR_RANGE		(TILE_UNITS*4)
@@ -91,8 +96,6 @@ BASE_OBJECT		*g_pProjLastAttacker;
 
 static UDWORD	establishTargetRadius( BASE_OBJECT *psTarget );
 static UDWORD	establishTargetHeight( BASE_OBJECT *psTarget );
-static void	proj_InFlightDirectFunc( PROJECTILE *psObj );
-static void	proj_InFlightIndirectFunc( PROJECTILE *psObj );
 static void	proj_ImpactFunc( PROJECTILE *psObj );
 static void	proj_PostImpactFunc( PROJECTILE *psObj );
 static void	proj_checkBurnDamage( BASE_OBJECT *apsList, PROJECTILE *psProj);
@@ -210,7 +213,7 @@ proj_Shutdown( void )
 static void proj_Free(PROJECTILE *psObj)
 {
 	/* Decrement any reference counts the projectile may have increased */
-	setProjectileDamaged(psObj, NULL);
+	free(psObj->psDamaged);
 	setProjectileSource(psObj, NULL);
 	setProjectileDestination(psObj, NULL);
 
@@ -251,7 +254,7 @@ static float QualityFactor(DROID *psAttacker, DROID *psVictim)
 	CLIP(powerRatio, 0.5, 2.0);
 	CLIP(pointsRatio, 0.5, 2.0);
 
-	return (powerRatio + pointsRatio) / 2;
+	return (powerRatio + pointsRatio) / 2.0;
 }
 
 // update the kills after a target is damaged/destroyed
@@ -291,6 +294,8 @@ static void proj_UpdateKills(PROJECTILE *psObj, float experienceInc)
 			experienceInc *= QualityFactor(psDroid, (DROID *) psObj->psDest);
 		}
 
+		ASSERT_OR_RETURN(, -0.1 < experienceInc && experienceInc < 2.1, "Experience increase out of range");
+
 		psDroid->experience += experienceInc;
 		cmdDroidUpdateKills(psDroid, experienceInc);
 
@@ -303,6 +308,8 @@ static void proj_UpdateKills(PROJECTILE *psObj, float experienceInc)
 	}
 	else if (psObj->psSource->type == OBJ_STRUCTURE)
 	{
+		ASSERT_OR_RETURN(, -0.1 < experienceInc && experienceInc < 2.1, "Experience increase out of range");
+
 		// See if there was a command droid designating this target
 		psDroid = cmdDroidGetDesignator(psObj->psSource->player);
 
@@ -327,9 +334,9 @@ BOOL proj_SendProjectile(WEAPON *psWeap, BASE_OBJECT *psAttacker, int player, Ve
 	SDWORD			iRadSq, iPitchLow, iPitchHigh, iTemp;
 	WEAPON_STATS *psStats = &asWeaponStats[psWeap->nStat];
 
-	ASSERT( psStats != NULL, "proj_SendProjectile: invalid weapon stats" );
-
-	ASSERT( psTarget == NULL || !psTarget->died, "Aiming at dead target!" );
+	ASSERT_OR_RETURN( false, psWeap->nStat < numWeaponStats, "Invalid range referenced for numWeaponStats, %d > %d", psWeap->nStat, numWeaponStats);
+	ASSERT_OR_RETURN( false, psStats != NULL, "Invalid weapon stats" );
+	ASSERT_OR_RETURN( false, psTarget == NULL || !psTarget->died, "Aiming at dead target!" );
 
 	/* get muzzle offset */
 	if (psAttacker == NULL)
@@ -357,7 +364,6 @@ BOOL proj_SendProjectile(WEAPON *psWeap, BASE_OBJECT *psAttacker, int player, Ve
 	/* Initialise the structure */
 	psProj->id			= ProjectileTrackerID |(gameTime2 >>4);		// make unique id
 	psProj->type		    = OBJ_PROJECTILE;
-	psProj->state		= PROJ_INFLIGHT;
 	psProj->psWStats		= psStats;
 
 	psProj->pos = Vector3f_To3uw(muzzle);
@@ -383,14 +389,17 @@ BOOL proj_SendProjectile(WEAPON *psWeap, BASE_OBJECT *psAttacker, int player, Ve
 		psProj->born = psOldProjectile->born;
 
 		setProjectileSource(psProj, psOldProjectile->psSource);
-		setProjectileDamaged(psProj, psOldProjectile->psDamaged);
+		psProj->psDamaged = (BASE_OBJECT **)malloc(psOldProjectile->psNumDamaged*sizeof(BASE_OBJECT *));
+		psProj->psNumDamaged = psOldProjectile->psNumDamaged;
+		memcpy(psProj->psDamaged, psOldProjectile->psDamaged, psOldProjectile->psNumDamaged*sizeof(BASE_OBJECT *));
 	}
 	else
 	{
 		psProj->born = gameTime;
 
 		setProjectileSource(psProj, psAttacker);
-		setProjectileDamaged(psProj, NULL);
+		psProj->psDamaged = NULL;
+		psProj->psNumDamaged = 0;
 	}
 
 	if (psTarget)
@@ -443,7 +452,7 @@ BOOL proj_SendProjectile(WEAPON *psWeap, BASE_OBJECT *psAttacker, int player, Ve
 			fR += 2.0 * M_PI;
 		}
 		psProj->pitch = (SWORD)( RAD_TO_DEG(fR) );
-		psProj->pInFlightFunc = proj_InFlightDirectFunc;
+		psProj->state = PROJ_INFLIGHTDIRECT;
 	}
 	else
 	{
@@ -530,8 +539,7 @@ BOOL proj_SendProjectile(WEAPON *psWeap, BASE_OBJECT *psAttacker, int player, Ve
 		psProj->vXY = iVel * trigCos(psProj->pitch);
 		psProj->vZ  = iVel * trigSin(psProj->pitch);
 
-		/* set function pointer */
-		psProj->pInFlightFunc = proj_InFlightIndirectFunc;
+		psProj->state = PROJ_INFLIGHTINDIRECT;
 	}
 
 	/* put the projectile object first in the global list */
@@ -582,27 +590,113 @@ BOOL proj_SendProjectile(WEAPON *psWeap, BASE_OBJECT *psAttacker, int player, Ve
 
 /***************************************************************************/
 
-static void proj_InFlightDirectFunc(PROJECTILE *psProj)
+static INTERVAL intervalIntersection(INTERVAL i1, INTERVAL i2)
+{
+	INTERVAL ret = {MAX(i1.begin, i2.begin), MIN(i1.end, i2.end)};
+	return ret;
+}
+
+static bool intervalEmpty(INTERVAL i)
+{
+	return i.begin >= i.end;
+}
+
+static INTERVAL collisionZ(int32_t z1, int32_t z2, int32_t height)
+{
+	INTERVAL ret = {-1, -1};
+	if (z1 > z2)
+	{
+		z1 *= -1;
+		z2 *= -1;
+	}
+
+	if (z1 > height || z2 < -height)
+		return ret;  // No collision between time 1 and time 2.
+
+	if (z1 == z2)
+	{
+		if (z1 >= -height && z1 <= height)
+		{
+			ret.begin = 0;
+			ret.end = 1024;
+		}
+		return ret;
+	}
+
+	ret.begin = 1024*(-height - z1)/(z2 - z1);
+	ret.end   = 1024*( height - z1)/(z2 - z1);
+	return ret;
+}
+
+static INTERVAL collisionXY(int32_t x1, int32_t y1, int32_t x2, int32_t y2, int32_t radius)
+{
+	// Solve (1 - t)v1 + t v2 = r.
+	int32_t dx = x2 - x1, dy = y2 - y1;
+	int32_t a = dx*dx + dy*dy;                  // a = (v2 - v1)²
+	float   b = x1*dx + y1*dy;                  // b = v1(v2 - v1)
+	float   c = x1*x1 + y1*y1 - radius*radius;  // c = v1² - r²
+	// Equation to solve is now a t^2 + 2 b t + c = 0.
+	float   d = b*b - a*c;                      // d = b² - a c
+	float sd;
+	// Solution is (-b ± √d)/a.
+	INTERVAL empty = {-1, -1};
+	INTERVAL full = {0, 1024};
+	INTERVAL ret;
+	if (d < 0)
+	{
+		return empty;  // Missed.
+	}
+	if (a == 0)
+	{
+		return c < 0 ? full : empty;  // Not moving. See if inside the target.
+	}
+
+	sd = sqrtf(d);
+	ret.begin = MAX(   0, 1024*(-b - sd)/a);
+	ret.end   = MIN(1024, 1024*(-b + sd)/a);
+	return ret;
+}
+
+static int32_t collisionXYZ(Vector3i v1, Vector3i v2, int32_t radius, int32_t height)
+{
+	INTERVAL iz = collisionZ(v1.z, v2.z, height);
+	if (!intervalEmpty(iz))  // Don't bother checking x and y unless z passes.
+	{
+		INTERVAL i = intervalIntersection(iz, collisionXY(v1.x, v1.y, v2.x, v2.y, radius));
+		if (!intervalEmpty(i))
+		{
+			return MAX(0, i.begin);
+		}
+	}
+	return -1;
+}
+
+static void proj_InFlightFunc(PROJECTILE *psProj, bool bIndirect)
 {
 	/* we want a delay between Las-Sats firing and actually hitting in multiPlayer
 	magic number but that's how long the audio countdown message lasts! */
 	const unsigned int LAS_SAT_DELAY = 4;
-	int timeSoFar;
+	int timeSoFar, nextPosZ;
 	int distancePercent; /* How far we are 0..100 */
 	float distanceRatio; /* How far we are, 1.0==at target */
 	float distanceExtensionFactor; /* Extended lifespan */
 	Vector3i move;
-	unsigned int i;
+	unsigned int i, j;
 	// Projectile is missile:
 	bool bMissile = false;
 	WEAPON_STATS *psStats;
+	Vector3uw prevPos, nextPos;
+	unsigned int targetDistance, currentDistance;
+	int32_t closestCollision = 1<<30;
+	BASE_OBJECT *closestCollisionObject = NULL;
+	Vector3uw closestCollisionPos;
 
 	CHECK_PROJECTILE(psProj);
 
 	timeSoFar = gameTime - psProj->born;
 
 	psStats = psProj->psWStats;
-	ASSERT(psStats != NULL, "proj_InFlightDirectFunc: Invalid weapon stats pointer");
+	ASSERT_OR_RETURN( , psStats != NULL, "Invalid weapon stats pointer");
 
 	/* we want a delay between Las-Sats firing and actually hitting in multiPlayer
 	magic number but that's how long the audio countdown message lasts! */
@@ -651,73 +745,103 @@ static void proj_InFlightDirectFunc(PROJECTILE *psProj)
 			break;
 	}
 
-	/* Do movement */
+	/* Calculate movement vector: */
+	if (psStats->movementModel == MM_HOMINGDIRECT && psProj->psDest)
 	{
-		unsigned int targetDistance, currentDistance;
-
-		/* Calculate movement vector: */
-		if (psStats->movementModel == MM_HOMINGDIRECT && psProj->psDest)
+		/* If it's homing and it has a target (not a miss)... */
+		move.x = psProj->psDest->pos.x - psProj->startX;
+		move.y = psProj->psDest->pos.y - psProj->startY;
+		move.z = psProj->psDest->pos.z + establishTargetHeight(psProj->psDest)/2 - psProj->srcHeight;
+	}
+	else
+	{
+		move.x = psProj->tarX - psProj->startX;
+		move.y = psProj->tarY - psProj->startY;
+		// LASSAT doesn't have a z
+		if(psStats->weaponSubClass == WSC_LAS_SAT)
 		{
-			/* If it's homing and it has a target (not a miss)... */
-			move.x = psProj->psDest->pos.x - psProj->startX;
-			move.y = psProj->psDest->pos.y - psProj->startY;
-			move.z = psProj->psDest->pos.z - psProj->srcHeight;
+			move.z = 0;
+		}
+		else if (!bIndirect)
+		{
+			move.z = psProj->altChange;
 		}
 		else
 		{
-			move.x = psProj->tarX - psProj->startX;
-			move.y = psProj->tarY - psProj->startY;
-			// LASSAT doesn't have a z
-			if(psStats->weaponSubClass == WSC_LAS_SAT)
-			{
-				move.z = 0;
-			}
-			else
-			{
-				move.z = psProj->altChange;
-			}
+			move.z = (psProj->vZ - (timeSoFar * ACC_GRAVITY / (GAME_TICKS_PER_SEC * 2))) * timeSoFar / GAME_TICKS_PER_SEC; // '2' because we reach our highest point in the mid of flight, when "vZ is 0".
 		}
+	}
 
-		targetDistance = sqrtf(move.x*move.x + move.y*move.y);
+	targetDistance = sqrtf(move.x*move.x + move.y*move.y);
+	if (!bIndirect)
+	{
 		currentDistance = timeSoFar * psStats->flightSpeed / GAME_TICKS_PER_SEC;
+	}
+	else
+	{
+		currentDistance = timeSoFar * psProj->vXY / GAME_TICKS_PER_SEC;
+	}
 
-		// Prevent div by zero:
-		if (targetDistance == 0)
-			targetDistance = 1;
+	// Prevent div by zero:
+	if (targetDistance == 0)
+	{
+		targetDistance = 1;
+	}
 
-		distanceRatio = (float)currentDistance / targetDistance;
-		distancePercent = PERCENT(currentDistance, targetDistance);
+	distanceRatio = (float)currentDistance / targetDistance;
+	distancePercent = PERCENT(currentDistance, targetDistance);
 
-		{
-			/* Calculate next position */
-			Vector3uw nextPos = {
-				psProj->startX + (distanceRatio * move.x),
-				psProj->startY + (distanceRatio * move.y),
-				psProj->srcHeight + (distanceRatio * move.z)
-			};
+	/* Calculate next position */
+	nextPos.x = psProj->startX + (distanceRatio * move.x);
+	nextPos.y = psProj->startY + (distanceRatio * move.y);
+	if (!bIndirect)
+	{
+		nextPosZ = (SDWORD)(psProj->srcHeight + (distanceRatio * move.z));  // Save unclamped nextPos.z value.
+	}
+	else
+	{
+		nextPosZ = (SDWORD)(psProj->srcHeight + move.z);  // Save unclamped nextPos.z value.
+	}
+	nextPos.z = MAX(0, nextPosZ);  // nextPos.z is unsigned.
 
-			/* impact if about to go off map else update coordinates */
-			if (!worldOnMap(nextPos.x, nextPos.y))
-			{
-				psProj->state = PROJ_IMPACT;
-				setProjectileDestination(psProj, NULL);
-				debug(LOG_NEVER, "**** projectile(%i) off map - removed ****\n", psProj->id);
-				return;
-			}
+	/* impact if about to go off map else update coordinates */
+	if (!worldOnMap(nextPos.x, nextPos.y))
+	{
+		psProj->state = PROJ_IMPACT;
+		psProj->tarX = psProj->pos.x;
+		psProj->tarY = psProj->pos.y;
+		setProjectileDestination(psProj, NULL);
+		debug(LOG_NEVER, "**** projectile(%i) off map - removed ****\n", psProj->id);
+		return;
+	}
 
-			/* Update position */
-			psProj->pos = nextPos;
-		}
+	/* Update position */
+	prevPos = psProj->pos;
+	psProj->pos = nextPos;
+
+	if (bIndirect)
+	{
+		/* Update pitch */
+		psProj->pitch = rad2degf(atan2f(psProj->vZ - (timeSoFar * ACC_GRAVITY / GAME_TICKS_PER_SEC), psProj->vXY));
 	}
 
 	/* Check nearby objects for possible collisions */
 	for (i = 0; i < numProjNaybors; i++)
 	{
 		BASE_OBJECT *psTempObj = asProjNaybors[i].psObj;
+		bool alreadyDamaged = false;
 
 		CHECK_OBJECT(psTempObj);
 
-		if (psTempObj == psProj->psDamaged)
+		for (j = 0; j != psProj->psNumDamaged; ++j)
+		{
+			if (psTempObj == psProj->psDamaged[j])
+			{
+				alreadyDamaged = true;
+				break;
+			}
+		}
+		if (alreadyDamaged)
 		{
 			// Dont damage one target twice
 			continue;
@@ -743,75 +867,90 @@ static void proj_InFlightDirectFunc(PROJECTILE *psProj)
 			continue;
 		}
 
-		if (psTempObj->player == psProj->player ||
-			aiCheckAlliances(psTempObj->player, psProj->player))
+		if (aiCheckAlliances(psTempObj->player, psProj->player)
+			&& psTempObj != psProj->psDest)
 		{
-			// No friendly fire
+			// No friendly fire unless intentional
 			continue;
 		}
 
 		if (psStats->surfaceToAir == SHOOT_IN_AIR &&
 			(psTempObj->type == OBJ_STRUCTURE ||
 				psTempObj->type == OBJ_FEATURE ||
-				(psTempObj->type == OBJ_DROID && !isVtolDroid((DROID *)psTempObj))
+				(psTempObj->type == OBJ_DROID && !isFlying((DROID *)psTempObj))
 			))
 		{
 			// AA weapons should not hit buildings and non-vtol droids
 			continue;
 		}
 
-		/* Actual collision test */
+		// Actual collision test.
 		{
 			// FIXME HACK Needed since we got those ugly Vector3uw floating around in BASE_OBJECT...
 			Vector3i
-				posProj = Vector3uw_To3i(psProj->pos),
+				posProj = {psProj->pos.x, psProj->pos.y, nextPosZ},  // HACK psProj->pos.z may have been set to 0, since psProj->pos.z can't be negative. So can't use Vector3uw_To3i.
+				prevPosProj = Vector3uw_To3i(prevPos),
 				posTemp = Vector3uw_To3i(psTempObj->pos);
 
 			Vector3i diff = Vector3i_Sub(posProj, posTemp);
+			Vector3i prevDiff = Vector3i_Sub(prevPosProj, posTemp);  // HACK Ignore that target might be moving. The projectile is probably moving faster, so it's better than nothing...
 
 			unsigned int targetHeight = establishTargetHeight(psTempObj);
 			unsigned int targetRadius = establishTargetRadius(psTempObj);
 
-			/* Height is always positive */
-			diff.z = abs(diff.z);
+			int32_t collision = collisionXYZ(prevDiff, diff, targetRadius, targetHeight);
 
-			/* We hit! */
-			if (diff.z < targetHeight &&
-				(diff.x*diff.x + diff.y*diff.y) < targetRadius * targetRadius)
+			if (collision >= 0 && collision < closestCollision)
 			{
-				setProjectileDestination(psProj, psTempObj);
+				// We hit!
+				//exactHitPos = prevPosProj + (posProj - prevPosProj)*collision/1024;
+				Vector3i exactHitPos = Vector3i_Add(prevPosProj, Vector3i_Div(Vector3i_Mult(Vector3i_Sub(posProj, prevPosProj), collision), 1024));
+				exactHitPos.z = MAX(0, exactHitPos.z);  // Clamp before casting to unsigned.
+				closestCollisionPos = Vector3i_To3uw(exactHitPos);
 
-				/* Buildings cannot be penetrated and we need a penetrating weapon */
-				if (psTempObj->type == OBJ_DROID && psStats->penetrate)
-				{
-					WEAPON asWeap = {psStats - asWeaponStats, 0, 0, 0, 0, 0};
-					// Determine position to fire a missile at
-					// (must be at least 0 because we don't use signed integers
-					//  this shouldn't be larger than the height and width of the map either)
-					Vector3i newDest = {
-						psProj->startX + move.x * distanceExtensionFactor,
-						psProj->startY + move.y * distanceExtensionFactor,
-						psProj->srcHeight + move.z * distanceExtensionFactor
-					};
+				closestCollision = collision;
+				closestCollisionObject = psTempObj;
 
-					ASSERT(distanceExtensionFactor != 0.f, "Unitialized variable used! distanceExtensionFactor is not initialized.");
-
-					newDest.x = clip(newDest.x, 0, world_coord(mapWidth - 1));
-					newDest.y = clip(newDest.y, 0, world_coord(mapHeight - 1));
-
-					// Assume we damaged the chosen target
-					setProjectileDamaged(psProj, psTempObj);
-
-					proj_SendProjectile(&asWeap, (BASE_OBJECT*)psProj, psProj->player, newDest, NULL, true, -1);
-				}
-
-				psProj->state = PROJ_IMPACT;
-
-				return;
+				// Keep testing for more collisions, in case there was a closer target.
 			}
 		}
 	}
 
+	if (closestCollisionObject != NULL)
+	{
+		// We hit!
+		psProj->pos = closestCollisionPos;
+		setProjectileDestination(psProj, closestCollisionObject);  // We hit something.
+
+		/* Buildings cannot be penetrated and we need a penetrating weapon */
+		if (closestCollisionObject->type == OBJ_DROID && psStats->penetrate)
+		{
+			WEAPON asWeap = {psStats - asWeaponStats, 0, 0, 0, 0, 0};
+			// Determine position to fire a missile at
+			// (must be at least 0 because we don't use signed integers
+			//  this shouldn't be larger than the height and width of the map either)
+			Vector3i newDest = {
+				psProj->startX + move.x * distanceExtensionFactor,
+				psProj->startY + move.y * distanceExtensionFactor,
+				psProj->srcHeight + move.z * distanceExtensionFactor
+			};
+
+			ASSERT(distanceExtensionFactor != 0.f, "Unitialized variable used! distanceExtensionFactor is not initialized.");
+
+			newDest.x = clip(newDest.x, 0, world_coord(mapWidth - 1));
+			newDest.y = clip(newDest.y, 0, world_coord(mapHeight - 1));
+
+			// Assume we damaged the chosen target
+			setProjectileDamaged(psProj, closestCollisionObject);
+
+			proj_SendProjectile(&asWeap, (BASE_OBJECT*)psProj, psProj->player, newDest, NULL, true, -1);
+		}
+
+		psProj->state = PROJ_IMPACT;
+
+		return;
+	}
+
 	ASSERT(distanceExtensionFactor != 0.f, "Unitialized variable used! distanceExtensionFactor is not initialized.");
 
 	if (distanceRatio > distanceExtensionFactor || /* We've traveled our maximum range */
@@ -851,13 +990,13 @@ static void proj_InFlightDirectFunc(PROJECTILE *psProj)
 				addEffect(&pos, EFFECT_SMOKE, SMOKE_TYPE_TRAIL, false, NULL, 0);
 			} break;
 			default:
-				/* add smoke trail to indirect weapons firing directly */
+				// Add smoke trail to indirect weapons, even if firing directly.
 				if (!proj_Direct(psStats))
 				{
 					Vector3i pos = {psProj->pos.x, psProj->pos.z+4, psProj->pos.y};
 					addEffect(&pos, EFFECT_SMOKE, SMOKE_TYPE_TRAIL, false, NULL, 0);
 				}
-				/* Otherwise no effect */
+				// Otherwise no effect.
 				break;
 		}
 	}
@@ -865,221 +1004,6 @@ static void proj_InFlightDirectFunc(PROJECTILE *psProj)
 
 /***************************************************************************/
 
-static void proj_InFlightIndirectFunc(PROJECTILE *psProj)
-{
-	/* NOTE Main differences to direct projectiles:
-		- Movement vector / pitch update
-		- No extended radius
-		- Some optimisations by leaving out tests which are never true (homing, AA, counter-missile, lassat)
-	*/
-
-	int timeSoFar;
-	int distancePercent; /* How far we are 0..100 */
-	float distanceRatio; /* How far we are, 1.0==at target */
-	float distanceExtensionFactor; /* Extended lifespan */
-	Vector3i move;
-	unsigned int i;
-	WEAPON_STATS *psStats;
-
-	CHECK_PROJECTILE(psProj);
-
-	timeSoFar = gameTime - psProj->born;
-
-	psStats = psProj->psWStats;
-	ASSERT(psStats != NULL, "proj_InFlightIndirectFunc: Invalid weapon stats pointer");
-
-	/* Calculate extended lifespan where appropriate */
-	distanceExtensionFactor = 1.2f;
-
-	/* Do movement */
-	{
-		unsigned int targetDistance, currentDistance;
-
-		/* Calculate movement vector: */
-		move.x = psProj->tarX - psProj->startX;
-		move.y = psProj->tarY - psProj->startY;
-		move.z = (psProj->vZ - (timeSoFar * ACC_GRAVITY / (GAME_TICKS_PER_SEC * 2))) * timeSoFar / GAME_TICKS_PER_SEC; // '2' because we reach our highest point in the mid of flight, when "vZ is 0".
-
-		targetDistance = sqrtf(move.x*move.x + move.y*move.y);
-		currentDistance = timeSoFar * psProj->vXY / GAME_TICKS_PER_SEC; // FIXME ARTILLERY
-
-		// Prevent div by zero:
-		if (targetDistance == 0)
-			targetDistance = 1;
-
-		distanceRatio = (float)currentDistance / targetDistance;
-		distancePercent = PERCENT(currentDistance, targetDistance);
-
-		{
-			/* Calculate next position */
-			Vector3uw nextPos = {
-				psProj->startX + (distanceRatio * move.x),
-				psProj->startY + (distanceRatio * move.y),
-				psProj->srcHeight + move.z
-			};
-			if (nextPos.z > UWORD_MAX / 2)  /* Assume it wrapped around */
-			{
-				/* XXX FIXME Unfortunately, this usually occurs because we skipped past our target. */
-				nextPos.z = 0;
-			}
-
-			/* impact if about to go off map else update coordinates */
-			if (!worldOnMap(nextPos.x, nextPos.y))
-			{
-				psProj->state = PROJ_IMPACT;
-				setProjectileDestination(psProj, NULL);
-				debug(LOG_NEVER, "**** projectile(%i) off map - removed ****\n", psProj->id);
-				return;
-			}
-
-			/* Update position */
-			psProj->pos = nextPos;
-		}
-	}
-
-	/* Update pitch */
-	{
-		float fVVert = psProj->vZ - (timeSoFar * ACC_GRAVITY / GAME_TICKS_PER_SEC);
-		psProj->pitch = rad2degf(atan2f(fVVert, psProj->vXY));
-	}
-
-	/* Check nearby objects for possible collisions */
-	for (i = 0; i < numProjNaybors; i++)
-	{
-		BASE_OBJECT *psTempObj = asProjNaybors[i].psObj;
-
-		CHECK_OBJECT(psTempObj);
-
-		if (psTempObj == psProj->psDamaged)
-		{
-			// Dont damage one target twice
-			continue;
-		}
-
-		if (psTempObj->died)
-		{
-			// Do not damage dead objects further
-			continue;
-		}
-
-		if (psTempObj->type == OBJ_PROJECTILE)
-		{
-			// A projectile should not collide with another projectile unless it's a counter-missile weapon
-			// FIXME Indirectly firing weapons are never counter-missiles?
-			continue;
-		}
-
-		if (psTempObj->type == OBJ_FEATURE &&
-			!((FEATURE*)psTempObj)->psStats->damageable)
-		{
-			// Ignore oil resources, artifacts and other pickups
-			continue;
-		}
-
-		if (psTempObj->player == psProj->player ||
-			aiCheckAlliances(psTempObj->player, psProj->player))
-		{
-			// No friendly fire
-			continue;
-		}
-
-		/* Actual collision test */
-		{
-			// FIXME HACK Needed since we got those ugly Vector3uw floating around in BASE_OBJECT...
-			Vector3i
-				posProj = Vector3uw_To3i(psProj->pos),
-				posTemp = Vector3uw_To3i(psTempObj->pos);
-
-			Vector3i diff = Vector3i_Sub(posProj, posTemp);
-
-			unsigned int targetHeight = establishTargetHeight(psTempObj);
-			unsigned int targetRadius = establishTargetRadius(psTempObj);
-
-			/* Height is always positive */
-			diff.z = abs(diff.z);
-
-			/* We hit! */
-			if (diff.z < targetHeight &&
-				(diff.x*diff.x + diff.y*diff.y) < targetRadius * targetRadius)
-			{
-				setProjectileDestination(psProj, psTempObj);
-
-				/* Buildings cannot be penetrated and we need a penetrating weapon */
-				if (psTempObj->type == OBJ_DROID && psStats->penetrate)
-				{
-					WEAPON asWeap = {psStats - asWeaponStats, 0, 0, 0, 0, 0};
-					// Determine position to fire a missile at
-					// (must be at least 0 because we don't use signed integers
-					//  this shouldn't be larger than the height and width of the map either)
-					Vector3i newDest = {
-						psProj->startX + move.x * distanceExtensionFactor,
-						psProj->startY + move.y * distanceExtensionFactor,
-						psProj->srcHeight + move.z * distanceExtensionFactor
-					};
-
-					newDest.x = clip(newDest.x, 0, world_coord(mapWidth - 1));
-					newDest.y = clip(newDest.y, 0, world_coord(mapHeight - 1));
-
-					// Assume we damaged the chosen target
-					setProjectileDamaged(psProj, psTempObj);
-
-					proj_SendProjectile(&asWeap, (BASE_OBJECT*)psProj, psProj->player, newDest, NULL, true, -1);
-				}
-
-				psProj->state = PROJ_IMPACT;
-
-				return;
-			}
-		}
-	}
-
-	if (distanceRatio > distanceExtensionFactor || /* We've traveled our maximum range */
-		!mapObjIsAboveGround((BASE_OBJECT*)psProj)) /* trying to travel through terrain */
-	{
-		/* Miss due to range or height */
-		psProj->state = PROJ_IMPACT;
-		setProjectileDestination(psProj, NULL); /* miss registered if NULL target */
-		return;
-	}
-
-	/* Paint effects if visible */
-	if (gfxVisible(psProj))
-	{
-		switch (psStats->weaponSubClass)
-		{
-			case WSC_FLAME:
-			{
-				Vector3i pos = {psProj->pos.x, psProj->pos.z-8, psProj->pos.y};
-				effectGiveAuxVar(distancePercent);
-				addEffect(&pos, EFFECT_EXPLOSION, EXPLOSION_TYPE_FLAMETHROWER, false, NULL, 0);
-			} break;
-			case WSC_COMMAND:
-			case WSC_ELECTRONIC:
-			case WSC_EMP:
-			{
-				Vector3i pos = {psProj->pos.x, psProj->pos.z-8, psProj->pos.y};
-				effectGiveAuxVar(distancePercent/2);
-				addEffect(&pos, EFFECT_EXPLOSION, EXPLOSION_TYPE_LASER, false, NULL, 0);
-			} break;
-			case WSC_ROCKET:
-			case WSC_MISSILE:
-			case WSC_SLOWROCKET:
-			case WSC_SLOWMISSILE:
-			{
-				Vector3i pos = {psProj->pos.x, psProj->pos.z+8, psProj->pos.y};
-				addEffect(&pos, EFFECT_SMOKE, SMOKE_TYPE_TRAIL, false, NULL, 0);
-			} break;
-			default:
-			{
-				Vector3i pos = {psProj->pos.x, psProj->pos.z+4, psProj->pos.y};
-				addEffect(&pos, EFFECT_SMOKE, SMOKE_TYPE_TRAIL, false, NULL, 0);
-			} break;
-		}
-	}
-}
-
-/***************************************************************************/
-
 static void proj_ImpactFunc( PROJECTILE *psObj )
 {
 	WEAPON_STATS	*psStats;
@@ -1113,21 +1037,14 @@ static void proj_ImpactFunc( PROJECTILE *psObj )
 		}
 		else
 		{
-			if (psObj->psDest == NULL)
-			{
-				audio_PlayStaticTrack(psObj->tarX, psObj->tarY, psStats->iAudioImpactID);
-			}
-			else
-			{
-				audio_PlayStaticTrack(psObj->psDest->pos.x, psObj->psDest->pos.y, psStats->iAudioImpactID);
-			}
+			audio_PlayStaticTrack(psObj->pos.x, psObj->pos.y, psStats->iAudioImpactID);
 		}
 
 		/* Shouldn't need to do this check but the stats aren't all at a value yet... */ // FIXME
 		if (psStats->incenRadius && psStats->incenTime)
 		{
-			position.x = psObj->tarX;
-			position.z = psObj->tarY;
+			position.x = psObj->pos.x;
+			position.z = psObj->pos.y; // z = y [sic] intentional
 			position.y = map_Height(position.x, position.z);
 			effectGiveAuxVar(psStats->incenRadius);
 			effectGiveAuxVarSec(psStats->incenTime);
@@ -1150,8 +1067,8 @@ static void proj_ImpactFunc( PROJECTILE *psObj )
 
 	// Set the effects position and radius
 	position.x = psObj->pos.x;
-	position.z = psObj->pos.y;
-	position.y = psObj->pos.z;//map_Height(psObj->pos.x, psObj->pos.y) + 24;
+	position.z = psObj->pos.y; // z = y [sic] intentional
+	position.y = psObj->pos.z; // y = z [sic] intentional
 	scatter.x = psStats->radius;
 	scatter.y = 0;
 	scatter.z = psStats->radius;
@@ -1311,8 +1228,12 @@ static void proj_ImpactFunc( PROJECTILE *psObj )
 				/* see if psCurrD is hit (don't hit main target twice) */
 				if ((BASE_OBJECT *)psCurrD != psObj->psDest)
 				{
-					// Check whether it is in hit radius
-					if (Vector3i_InSphere(Vector3uw_To3i(psCurrD->pos), Vector3uw_To3i(psObj->pos), psStats->radius))
+					bool bTargetInAir = (asPropulsionTypes[asPropulsionStats[psCurrD->asBits[COMP_PROPULSION].nStat].propulsionType].travel == AIR && ((DROID *)psCurrD)->sMove.Status != MOVEINACTIVE);
+
+					// Check whether we can hit it and it is in hit radius
+					if (!((psStats->surfaceToAir == SHOOT_IN_AIR && !bTargetInAir) ||
+						 (psStats->surfaceToAir == SHOOT_ON_GROUND && bTargetInAir)) &&
+					    Vector3i_InSphere(Vector3uw_To3i(psCurrD->pos), Vector3uw_To3i(psObj->pos), psStats->radius))
 					{
 						int dice;
 						HIT_ROLL(dice);
@@ -1337,8 +1258,6 @@ static void proj_ImpactFunc( PROJECTILE *psObj )
 							//Watermelon:uses a slightly different check for angle,
 							// since fragment of a project is from the explosion spot not from the projectile start position
 							impactSide = getHitSide(psObj, (BASE_OBJECT *)psCurrD);
-							//  FIXME: This screws us!  A droid *can* die in the function below!
-							// which means we can't send that info to other players since turnOffMultiMsg() is off!
 							relativeDamage = droidDamage(psCurrD, damage, psStats->weaponClass, psStats->weaponSubClass, impactSide);
 
 							turnOffMultiMsg(false);	// multiplay msgs back on.
@@ -1350,6 +1269,7 @@ static void proj_ImpactFunc( PROJECTILE *psObj )
 			}
 
 			// FIXME Check whether we hit above maximum structure height, to skip unnecessary calculations!
+			if (psStats->surfaceToAir != SHOOT_IN_AIR)
 			{
 				STRUCTURE *psCurrS, *psNextS;
 
@@ -1489,6 +1409,7 @@ static void proj_PostImpactFunc( PROJECTILE *psObj )
 
 static void proj_Update(PROJECTILE *psObj)
 {
+	unsigned n, m;
 	CHECK_PROJECTILE(psObj);
 
 	/* See if any of the stored objects have died
@@ -1502,10 +1423,14 @@ static void proj_Update(PROJECTILE *psObj)
 	{
 		setProjectileDestination(psObj, NULL);
 	}
-	if (psObj->psDamaged && psObj->psDamaged->died)
+	for (n = m = 0; n != psObj->psNumDamaged; ++n)
 	{
-		setProjectileDamaged(psObj, NULL);
+		if (!psObj->psDamaged[n]->died)
+		{
+			psObj->psDamaged[m++] = psObj->psDamaged[n];
+		}
 	}
+	psObj->psNumDamaged = m;
 
 	// This extra check fixes a crash in cam2, mission1
 	if (worldOnMap(psObj->pos.x, psObj->pos.y) == false)
@@ -1518,8 +1443,12 @@ static void proj_Update(PROJECTILE *psObj)
 
 	switch (psObj->state)
 	{
-		case PROJ_INFLIGHT:
-			(psObj->pInFlightFunc) ( psObj );
+		case PROJ_INFLIGHTDIRECT:
+			proj_InFlightFunc(psObj, false);
+			break;
+
+		case PROJ_INFLIGHTINDIRECT:
+			proj_InFlightFunc(psObj, true);
 			break;
 
 		case PROJ_IMPACT:
@@ -1581,8 +1510,6 @@ static void proj_checkBurnDamage( BASE_OBJECT *apsList, PROJECTILE *psProj)
 	SDWORD			xDiff,yDiff;
 	WEAPON_STATS	*psStats;
 	UDWORD			radSquared;
-	UDWORD			damageSoFar;
-	SDWORD			damageToDo;
 	float			relativeDamage;
 
 	CHECK_PROJECTILE(psProj);
@@ -1625,19 +1552,25 @@ static void proj_checkBurnDamage( BASE_OBJECT *apsList, PROJECTILE *psProj)
 			{
 				/* Calculate how much damage should have
 				   been done up till now */
-				damageSoFar = (gameTime - psCurr->burnStart)
-							  //* psStats->incenDamage
-							  * weaponIncenDamage(psStats,psProj->player)
-							  / GAME_TICKS_PER_SEC;
-				damageToDo = (SDWORD)damageSoFar
-							 - (SDWORD)psCurr->burnDamage;
-				if (damageToDo > 0)
+				const int timeburned = gameTime - psCurr->burnStart;
+				const int weapondamage = weaponIncenDamage(psStats, psProj->player);
+				const int armourreduceddamage = weapondamage - psCurr->armour[HIT_SIDE_FRONT][WC_HEAT];
+				const int minimaldamage = weapondamage / 3;
+				const int realdamage = MAX(armourreduceddamage, minimaldamage);
+
+				const int damageSoFar = realdamage * timeburned / GAME_TICKS_PER_SEC;
+				int damageToDo = damageSoFar - psCurr->burnDamage;
+
+				if (damageToDo > 20) // maximum DR becomes 95% instead of previous 0%
 				{
+					damageToDo -= (damageToDo % 20); // make deterministic
+
 					debug(LOG_NEVER, "Burn damage of %d to object %d, player %d\n",
 							damageToDo, psCurr->id, psCurr->player);
 
-					//Watermelon:just assume the burn damage is from FRONT
-					relativeDamage = objectDamage(psCurr, damageToDo, psStats->weaponClass,psStats->weaponSubClass, 0);
+					// HIT_SIDE_PIERCE because armor from burn effects is handled externally
+					// To be consistent with vehicle burn, all burn damage is thermal flame damage
+					relativeDamage = objectDamage(psCurr, damageToDo, WC_HEAT, WSC_FLAME, HIT_SIDE_PIERCE);
 
 					psCurr->burnDamage += damageToDo;
 
@@ -1809,15 +1742,15 @@ static float objectDamage(BASE_OBJECT *psObj, UDWORD damage, UDWORD weaponClass,
 			break;
 
 		case OBJ_PROJECTILE:
-			ASSERT(!"invalid object type: bullet", "objectDamage: invalid object type: OBJ_PROJECTILE");
+			ASSERT(!"invalid object type: bullet", "invalid object type: OBJ_PROJECTILE (id=%d)", psObj->id);
 			break;
 
 		case OBJ_TARGET:
-			ASSERT(!"invalid object type: target", "objectDamage: invalid object type: OBJ_TARGET");
+			ASSERT(!"invalid object type: target", "invalid object type: OBJ_TARGET (id=%d)", psObj->id);
 			break;
 
 		default:
-			ASSERT(!"unknown object type", "objectDamage: unknown object type");
+			ASSERT(!"unknown object type", "unknown object type %d, id=%d", psObj->type, psObj->id );
 	}
 
 	return 0;
@@ -2126,6 +2059,7 @@ static UDWORD	establishTargetHeight(BASE_OBJECT *psTarget)
 
 void checkProjectile(const PROJECTILE* psProjectile, const char * const location_description, const char * function, const int recurse)
 {
+	unsigned n;
 	if (recurse < 0)
 		return;
 
@@ -2133,7 +2067,8 @@ void checkProjectile(const PROJECTILE* psProjectile, const char * const location
 	ASSERT_HELPER(psProjectile->psWStats != NULL, location_description, function, "CHECK_PROJECTILE");
 	ASSERT_HELPER(psProjectile->type == OBJ_PROJECTILE, location_description, function, "CHECK_PROJECTILE");
 	ASSERT_HELPER(psProjectile->player < MAX_PLAYERS, location_description, function, "CHECK_PROJECTILE: Out of bound owning player number (%u)", (unsigned int)psProjectile->player);
-	ASSERT_HELPER(psProjectile->state == PROJ_INFLIGHT
+	ASSERT_HELPER(psProjectile->state == PROJ_INFLIGHTDIRECT
+	    || psProjectile->state == PROJ_INFLIGHTINDIRECT
 	    || psProjectile->state == PROJ_IMPACT
 	    || psProjectile->state == PROJ_POSTIMPACT, location_description, function, "CHECK_PROJECTILE: invalid projectile state: %u", (unsigned int)psProjectile->state);
 	ASSERT_HELPER(psProjectile->direction <= 360.0f && psProjectile->direction >= 0.0f, location_description, function, "CHECK_PROJECTILE: out of range direction (%f)", psProjectile->direction);
@@ -2144,6 +2079,6 @@ void checkProjectile(const PROJECTILE* psProjectile, const char * const location
 	if (psProjectile->psSource)
 		checkObject(psProjectile->psSource, location_description, function, recurse - 1);
 
-	if (psProjectile->psDamaged)
-		checkObject(psProjectile->psDamaged, location_description, function, recurse - 1);
+	for (n = 0; n != psProjectile->psNumDamaged; ++n)
+		checkObject(psProjectile->psDamaged[n], location_description, function, recurse - 1);
 }
