@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -28,7 +28,8 @@
 
 typedef enum PROJ_STATE
 {
-	PROJ_INFLIGHT,
+	PROJ_INFLIGHTDIRECT,
+	PROJ_INFLIGHTINDIRECT,
 	PROJ_IMPACT,
 	PROJ_POSTIMPACT
 } PROJ_STATE;
@@ -48,7 +49,8 @@ typedef struct PROJECTILE
 
 	BASE_OBJECT*    psSource;               ///< what fired the projectile
 	BASE_OBJECT*    psDest;                 ///< target of this projectile
-	BASE_OBJECT*    psDamaged;              ///< the target it already dealt damage to (don't damage the same target twice)
+	BASE_OBJECT **  psDamaged;              ///< the targets that have already been dealt damage to (don't damage the same target twice)
+	unsigned        psNumDamaged;
 
 	UDWORD          startX, startY;         ///< Where projectile started
 	UDWORD          tarX, tarY;             ///< The target coordinates
@@ -57,8 +59,6 @@ typedef struct PROJECTILE
 	SDWORD          altChange;              ///< Change in altitude
 	UDWORD          born;
 	UDWORD          died;
-
-	void (*pInFlightFunc)(struct PROJECTILE* psObj);
 } PROJECTILE;
 
 #endif // __INCLUDED_PROJECTILEDEF_H__
