@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -59,17 +59,17 @@ STRUCTURE				*psCBLastResStructure;
 SDWORD					CBResFacilityOwner;
 
 //research is now loaded per campaign - this hopefully is the max there will be in any one campaign!
-#define MAX_RESEARCH        (500)
+#define MAX_RESEARCH        (450 + 50)
 
 //need to define max's for each of the lists associated with the research - these
 //values have been chosen based on the current research stats - 21/12/98
-#define MAX_RESEARCH_PR             (650)
-#define MAX_RESEARCH_STRUCT_PR      (44 + 5)
+#define MAX_RESEARCH_PR             (650 + 50)
+#define MAX_RESEARCH_STRUCT_PR      (44 + 50)
 #define MAX_RESEARCH_FUNC           (250 + 25)
-#define MAX_RESEARCH_STRUCT_RED     (30 + 2)
+#define MAX_RESEARCH_STRUCT_RED     (30 + 25)
 #define MAX_RESEARCH_ARTE_RED       (40 + 5)
-#define MAX_RESEARCH_STRUCT_RES     (84 + 5)
-#define MAX_RESEARCH_ARTE_RES       (125 + 5)
+#define MAX_RESEARCH_STRUCT_RES     (84 + 50)
+#define MAX_RESEARCH_ARTE_RES       (125 + 50)
 
 //need corresponding arrays for the above
 static UWORD*            pResearchPR;
@@ -134,7 +134,7 @@ BOOL researchInitVars(void)
 	asResearch = (RESEARCH *)malloc(sizeof(RESEARCH)* MAX_RESEARCH);
 	if (asResearch == NULL)
 	{
-		debug( LOG_ERROR, "Research Stats - Out of memory" );
+		debug( LOG_FATAL, "Research Stats - Out of memory" );
 		abort();
 		return false;
 	}
@@ -147,7 +147,7 @@ BOOL researchInitVars(void)
 			sizeof(PLAYER_RESEARCH));
 		if (asPlayerResList[i] == NULL)
 		{
-			debug( LOG_ERROR, "Out of memory assigning Player_Research" );
+			debug( LOG_FATAL, "Out of memory assigning Player_Research" );
 			abort();
 			return false;
 		}
@@ -160,7 +160,7 @@ BOOL researchInitVars(void)
 	pResearchPR = (UWORD *) malloc(sizeof(UWORD) * MAX_RESEARCH_PR);
 	if (pResearchPR == NULL)
 	{
-		debug( LOG_ERROR, "Research Stats - Out of memory" );
+		debug( LOG_FATAL, "Research Stats - Out of memory" );
 		abort();
 		return false;
 	}
@@ -169,7 +169,7 @@ BOOL researchInitVars(void)
 	pResearchStructPR = (UWORD *) malloc(sizeof(UWORD) * MAX_RESEARCH_STRUCT_PR);
 	if (pResearchStructPR == NULL)
 	{
-		debug( LOG_ERROR, "Research Stats - Out of memory" );
+		debug( LOG_FATAL, "Research Stats - Out of memory" );
 		abort();
 		return false;
 	}
@@ -178,7 +178,7 @@ BOOL researchInitVars(void)
 	pResearchFunc = (FUNCTION **) malloc(sizeof(FUNCTION *) * MAX_RESEARCH_FUNC);
 	if (pResearchFunc == NULL)
 	{
-		debug( LOG_ERROR, "Research Stats - Out of memory" );
+		debug( LOG_FATAL, "Research Stats - Out of memory" );
 		abort();
 		return false;
 	}
@@ -187,7 +187,7 @@ BOOL researchInitVars(void)
 	pResearchStructRed = (UWORD *) malloc(sizeof(UWORD) * MAX_RESEARCH_STRUCT_RED);
 	if (pResearchStructRed == NULL)
 	{
-		debug( LOG_ERROR, "Research Stats - Out of memory" );
+		debug( LOG_FATAL, "Research Stats - Out of memory" );
 		abort();
 		return false;
 	}
@@ -196,7 +196,7 @@ BOOL researchInitVars(void)
 	pResearchArteRed = (COMPONENT_STATS **) malloc(sizeof(COMPONENT_STATS *) * MAX_RESEARCH_ARTE_RED);
 	if (pResearchArteRed == NULL)
 	{
-		debug( LOG_ERROR, "Research Stats - Out of memory" );
+		debug( LOG_FATAL, "Research Stats - Out of memory" );
 		abort();
 		return false;
 	}
@@ -205,7 +205,7 @@ BOOL researchInitVars(void)
 	pResearchStructRes = (UWORD *) malloc(sizeof(UWORD) * MAX_RESEARCH_STRUCT_RES);
 	if (pResearchStructRes == NULL)
 	{
-		debug( LOG_ERROR, "Research Stats - Out of memory" );
+		debug( LOG_FATAL, "Research Stats - Out of memory" );
 		abort();
 		return false;
 	}
@@ -214,7 +214,7 @@ BOOL researchInitVars(void)
 	pResearchArteRes = (COMPONENT_STATS **) malloc(sizeof(COMPONENT_STATS *) * MAX_RESEARCH_ARTE_RES);
 	if (pResearchArteRes == NULL)
 	{
-		debug( LOG_ERROR, "Research Stats - Out of memory" );
+		debug( LOG_FATAL, "Research Stats - Out of memory" );
 		abort();
 		return false;
 	}
@@ -223,7 +223,7 @@ BOOL researchInitVars(void)
 	pResearchArteRep = (COMPONENT_STATS **) malloc(sizeof(COMPONENT_STATS *) * MAX_RESEARCH_ARTE_RES);
 	if (pResearchArteRep == NULL)
 	{
-		debug( LOG_ERROR, "Research Stats - Out of memory" );
+		debug( LOG_FATAL, "Research Stats - Out of memory" );
 		abort();
 		return false;
 	}
@@ -241,7 +241,7 @@ BOOL researchInitVars(void)
 /*Load the research stats from the file exported from Access*/
 BOOL loadResearch(const char *pResearchData, UDWORD bufferSize)
 {
-	const unsigned int researchCount = numCR(pResearchData, bufferSize);
+	unsigned int researchCount = numCR(pResearchData, bufferSize);
 	RESEARCH *pResearch;
 	COMPONENT_STATS *psComp;
 	SDWORD structID;
@@ -252,6 +252,13 @@ BOOL loadResearch(const char *pResearchData, UDWORD bufferSize)
 	char structName[MAX_STR_LENGTH], compName[MAX_STR_LENGTH],
 		compType[MAX_STR_LENGTH];
 
+	// Skip descriptive header
+	if (strncmp(pResearchData,"Research ",9)==0)
+	{
+		pResearchData = strchr(pResearchData,'\n') + 1;
+		researchCount--;
+	}
+
 	numResearch = researchCount;
 
 	ASSERT(numResearch <= MAX_RESEARCH, "Too many ResearchStats! - max allowed %d", MAX_RESEARCH);
@@ -639,15 +646,6 @@ BOOL loadResearchPR(const char *pPRData, UDWORD bufferSize)
 		PRName[0] = '\0';
 		sscanf(pPRData,"%[^','],%[^','],%*d", ResearchName, PRName);
 
-		if (!getResourceName(ResearchName))
-		{
-			return false;
-		}
-		if (!getResourceName(PRName))
-		{
-			return false;
-		}
-
 		//loop through each Research to compare the name
 		for (incR=0; incR < numResearch; incR++)
 		{
@@ -755,15 +753,6 @@ BOOL loadResearchArtefacts(const char *pArteData, UDWORD bufferSize, UDWORD list
 		//increment the data pointer
 		pArteData += (strlen(ResearchName)+1+strlen(ArteName)+1+strlen(TypeName)+1);
 
-		if (!getResourceName(ResearchName))
-		{
-			return false;
-		}
-		if (!getResourceName(ArteName))
-		{
-			return false;
-		}
-
 		pArtefact = getComponentDetails(TypeName, ArteName);
 		if (pArtefact == NULL)
 		{
@@ -815,10 +804,6 @@ BOOL loadResearchArtefacts(const char *pArteData, UDWORD bufferSize, UDWORD list
 				}
 				else
 				{
-					if (!getResourceName(ArteName))
-					{
-						return false;
-					}
 					pArtefact = getComponentDetails(TypeName, ArteName);
 					if (pArtefact == NULL)
 					{
@@ -913,15 +898,6 @@ BOOL loadResearchStructures(const char *pStructData, UDWORD bufferSize,UDWORD li
 		StructureName[0] = '\0';
 		sscanf(pStructData,"%[^','],%[^','],%*d,%*d", ResearchName, StructureName);
 
-		if (!getResourceName(ResearchName))
-		{
-			return false;
-		}
-		if (!getResourceName(StructureName))
-		{
-			return false;
-		}
-
 		//loop through each Research to compare the name
 		for (incR = 0; incR < numResearch; incR++)
 		{
@@ -958,7 +934,7 @@ BOOL loadResearchStructures(const char *pStructData, UDWORD bufferSize,UDWORD li
 								break;
 							default:
 								/* NO DEFAULT CASE? Alex.... Here ya go - just for you...*/
-								debug( LOG_ERROR, "Unknown research list" );
+								debug( LOG_FATAL, "Unknown research list" );
 								abort();
 								return false;
 						}
@@ -967,7 +943,7 @@ BOOL loadResearchStructures(const char *pStructData, UDWORD bufferSize,UDWORD li
 						if (pResearch[incR].storeCount >
 										(SDWORD)numToFind)
 						{
-							debug( LOG_ERROR, "Trying to allocate more Structures than allowed for research %s", getResearchName(pResearch) );
+							debug( LOG_FATAL, "Trying to allocate more Structures than allowed for research %s", getResearchName(pResearch) );
 							abort();
 							return false;
 						}
@@ -1041,11 +1017,6 @@ BOOL loadResearchFunctions(const char *pFunctionData, UDWORD bufferSize)
 		FunctionName[0] = '\0';
 		sscanf(pFunctionData,"%[^','],%[^','],%*d", ResearchName, FunctionName);
 
-		if (!getResourceName(ResearchName))
-		{
-			return false;
-		}
-
 		//loop through each Research to compare the name
 		for (incR=0; incR < numResearch; incR++)
 		{
@@ -1067,7 +1038,7 @@ BOOL loadResearchFunctions(const char *pFunctionData, UDWORD bufferSize)
 						if (pResearch[incR].storeCount >
 										(SDWORD)pResearch[incR].numFunctions)
 						{
-							debug( LOG_ERROR, "Trying to allocate more Functions than allowed for research %s", ResearchName );
+							debug( LOG_FATAL, "Trying to allocate more Functions than allowed for research %s", ResearchName );
 							abort();
 							return false;
 						}
@@ -1247,13 +1218,16 @@ void researchResult(UDWORD researchIndex, UBYTE player, BOOL bDisplay,
 	//check for structures to be made available
 	for (inc = 0; inc < pResearch->numStructResults; inc++)
 	{
-		apStructTypeLists[player][pResearch->pStructureResults[inc]] = AVAILABLE;
+		if (apStructTypeLists[player][pResearch->pStructureResults[inc]] != REDUNDANT)
+		{
+			apStructTypeLists[player][pResearch->pStructureResults[inc]] = AVAILABLE;
+		}
 	}
 
 	//check for structures to be made redundant
 	for (inc = 0; inc < pResearch->numRedStructs; inc++)
 	{
-		apStructTypeLists[player][pResearch->pRedStructs[inc]] = UNAVAILABLE;
+		apStructTypeLists[player][pResearch->pRedStructs[inc]] = REDUNDANT;
 	}
 
 	//check for artefacts to be made available
@@ -1263,7 +1237,10 @@ void researchResult(UDWORD researchIndex, UBYTE player, BOOL bDisplay,
 		type = statType(pResearch->pArtefactResults[inc]->ref);
 		//set the component state to AVAILABLE
 		compInc = pResearch->pArtefactResults[inc]->ref - statRefStart(type);
-		apCompLists[player][type][compInc] = AVAILABLE;
+		if (apCompLists[player][type][compInc] != REDUNDANT)
+		{
+			apCompLists[player][type][compInc] = AVAILABLE;
+		}
 		//check for default sensor
 		if (type == COMP_SENSOR)
 		{
@@ -1297,7 +1274,7 @@ void researchResult(UDWORD researchIndex, UBYTE player, BOOL bDisplay,
 			type = statType(pResearch->pReplacedArtefacts[inc]->ref);
 			//set the component state to AVAILABLE
 			compInc = pResearch->pReplacedArtefacts[inc]->ref - statRefStart(type);
-			apCompLists[player][type][compInc] = UNAVAILABLE;
+			apCompLists[player][type][compInc] = REDUNDANT;
 		}
 		//check if the component is a brain
 		if (type == COMP_BRAIN)
@@ -1319,9 +1296,9 @@ void researchResult(UDWORD researchIndex, UBYTE player, BOOL bDisplay,
 	{
 		//determine the type of artefact
 		type = statType(pResearch->pRedArtefacts[inc]->ref);
-		//set the component state to UNAVAILABLE
+		//set the component state to REDUNDANT
 		apCompLists[player][type][pResearch->pRedArtefacts[inc]->ref -
-			statRefStart(type)] = UNAVAILABLE;
+			statRefStart(type)] = REDUNDANT;
 	}
 
 	//check for technology effects
@@ -2460,13 +2437,6 @@ RESEARCH * getResearch(const char *pName, BOOL resName)
 {
 	unsigned int inc = 0;
 
-	//need to get the in game name if a resource name has been passed in
-	if (resName && !getResourceName(pName))
-	{
-		debug(LOG_ERROR, "getResearch: resource not found");
-		return NULL;
-	}
-
 	for (inc = 0; inc < numResearch; inc++)
 	{
 		if (!strcasecmp(asResearch[inc].pName, pName))
