@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -43,6 +43,7 @@
 #include "power.h"
 #include "geometry.h"
 #include "src/scriptfuncs.h"
+#include "fpath.h"
 
 static INTERP_VAL	scrFunctionResult;	//function return value to be pushed to stack
 
@@ -240,8 +241,7 @@ BOOL scrIdleGroup(void)
 		return false;
 	}
 
-	ASSERT( psGroup != NULL,
-		"scrIdleGroup: invalid group pointer" );
+	ASSERT_OR_RETURN(false, psGroup != NULL, "Invalid group pointer");
 
 	for(psDroid = psGroup->psList;psDroid; psDroid = psDroid->psGrpNext)
 	{
@@ -511,7 +511,7 @@ BOOL scrOrderDroid(void)
 		order != DORDER_NONE )
 	{
 		ASSERT( false,
-			"scrOrderUnit: Invalid order" );
+			"scrOrderUnit: Invalid order %d", order );
 		return false;
 	}
 
@@ -619,33 +619,26 @@ BOOL scrOrderDroidStatsLoc(void)
 
 	if (statIndex < 0 || statIndex >= (SDWORD)numStructureStats)
 	{
-		ASSERT( false,
-			"scrOrderUnitStatsLoc: invalid structure stat" );
+		ASSERT( false, "Invalid structure stat" );
 		return false;
 	}
+
+	ASSERT_OR_RETURN( false, statIndex < numStructureStats, "Invalid range referenced for numStructureStats, %d > %d", statIndex, numStructureStats);
 	psStats = (BASE_STATS *)(asStructureStats + statIndex);
 
-	ASSERT( psDroid != NULL,
-		"scrOrderUnitStatsLoc: Invalid Unit pointer" );
-	ASSERT( psStats != NULL,
-		"scrOrderUnitStatsLoc: Invalid object pointer" );
-	if (psDroid == NULL)
-	{
-		return false;
-	}
+	ASSERT_OR_RETURN( false, psDroid != NULL, "Invalid Unit pointer" );
+	ASSERT_OR_RETURN( false, psStats != NULL, "Invalid object pointer" );
 
 	if ((x < 0) || (x > (SDWORD)mapWidth*TILE_UNITS) ||
 		(y < 0) || (y > (SDWORD)mapHeight*TILE_UNITS))
 	{
-		ASSERT( false,
-			"scrOrderUnitStatsLoc: Invalid location" );
+		ASSERT( false, "Invalid location" );
 		return false;
 	}
 
 	if (order != DORDER_BUILD)
 	{
-		ASSERT( false,
-			"scrOrderUnitStatsLoc: Invalid order" );
+		ASSERT( false, "Invalid order" );
 		return false;
 	}
 
@@ -1496,7 +1489,7 @@ BOOL scrSkCanBuildTemplate(void)
 	case DROID_DEFAULT:		        // Default droid
 	case DROID_ANY:
 	default:
-		debug( LOG_ERROR, "scrSkCanBuildTemplate: Unhandled template type" );
+		debug( LOG_FATAL, "scrSkCanBuildTemplate: Unhandled template type" );
 		abort();
 		break;
 	}
@@ -1631,13 +1624,13 @@ BOOL skTopicAvail(UWORD inc, UDWORD player)
 	}
 	return false;
 }
+
 // ********************************************************************************************
 BOOL scrSkDoResearch(void)
 {
 	SDWORD				player, bias;//,timeToResearch;//,*x,*y;
 	UWORD				i;
 
-	char				sTemp[128];
 	STRUCTURE			*psBuilding;
 	RESEARCH_FACILITY	*psResFacilty;
 	PLAYER_RESEARCH		*pPlayerRes;
@@ -1659,7 +1652,7 @@ BOOL scrSkDoResearch(void)
 	// choose a topic to complete.
 	for(i=0;i<numResearch;i++)
 	{
-		if( skTopicAvail(i,player) )
+		if (skTopicAvail(i, player) && (!bMultiPlayer || !beingResearchedByAlly(i, player)))
 		{
 			break;
 		}
@@ -1682,17 +1675,19 @@ BOOL scrSkDoResearch(void)
 
 		MakeResearchStarted(pPlayerRes);
 		psResFacilty->timeStarted = ACTION_START_TIME;
-        psResFacilty->timeStartHold = 0;
+		psResFacilty->timeStartHold = 0;
 		psResFacilty->timeToResearch = pResearch->researchPoints / 	psResFacilty->researchPoints;
 		if (psResFacilty->timeToResearch == 0)
 		{
 			psResFacilty->timeToResearch = 1;
 		}
-
-		sprintf(sTemp,"player:%d starts topic: %s",player, asResearch[i].pName );
-		NETlogEntry(sTemp,0,0);
-
-
+#if defined (DEBUG)
+		{
+			char				sTemp[128];
+			sprintf(sTemp,"player:%d starts topic: %s",player, asResearch[i].pName );
+			NETlogEntry(sTemp, SYNC_FLAG, 0);
+		}
+#endif
 	}
 
 	return true;
@@ -1775,9 +1770,9 @@ BOOL scrSkDifficultyModifier(void)
 	}
 
 	/* Skip cheats if difficulty modifier slider is set to minimum.
-	 * (0 - player disabled, 20 - max value)
+	 * (0 - player disabled, 20 - max value, UBYTE_MAX = autogame human)
 	 */
-	if(game.skDiff[player] <= 1)
+	if (game.skDiff[player] <= 1 || game.skDiff[player] == UBYTE_MAX)
 	{
 		return true;
 	}
@@ -1790,10 +1785,6 @@ BOOL scrSkDifficultyModifier(void)
 	{
 		addPower(player,amount);
 	}
-	else
-	{
-		usePower(player,(0-amount));
-	}
 
 	//research modifier.??
 	for(psStr=apsStructLists[player];psStr;psStr=psStr->psNext)
@@ -1853,7 +1844,10 @@ static BOOL defenseLocation(BOOL variantB)
 		return false;
 	}
 
+	ASSERT_OR_RETURN( false, statIndex < numStructureStats, "Invalid range referenced for numStructureStats, %d > %d", statIndex, numStructureStats);
 	psStats = (BASE_STATS *)(asStructureStats + statIndex);
+
+	ASSERT_OR_RETURN( false, statIndex2 < numStructureStats, "Invalid range referenced for numStructureStats, %d > %d", statIndex2, numStructureStats);
 	psWStats = (BASE_STATS *)(asStructureStats + statIndex2);
 
     // check for wacky coords.
@@ -2190,7 +2184,6 @@ BOOL scrIterateGroupB(void)
 	return true;
 }
 
-// Dummy version for 2.2 branch - always returns true
 BOOL scrDroidCanReach(void)
 {
 	DROID			*psDroid;
@@ -2201,14 +2194,21 @@ BOOL scrDroidCanReach(void)
 		debug(LOG_ERROR, "Failed to pop parameters");
 		return false;
 	}
-	scrFunctionResult.v.bval = true;
-
-	if (!stackPushResult(VAL_BOOL, &scrFunctionResult))
+	if (psDroid)
 	{
-		debug(LOG_ERROR, "stackPushResult failed");
-		return false;
+		const PROPULSION_STATS *psPropStats = asPropulsionStats + psDroid->asBits[COMP_PROPULSION].nStat;
+		const Vector2i dPos = { map_coord(psDroid->pos.x), map_coord(psDroid->pos.y) };
+		const Vector2i rPos = { map_coord(x), map_coord(y) };
+
+		scrFunctionResult.v.bval = fpathCheck(dPos, rPos, psPropStats->propulsionType);
+		if (!stackPushResult(VAL_BOOL, &scrFunctionResult))
+		{
+			debug(LOG_ERROR, "stackPushResult failed");
+			return false;
+		}
+		return true;
 	}
-	return true;
+	return false;
 }
 
 // ********************************************************************************************
