@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@
 #include "map.h"
 
 #include "lib/script/script.h"
+#include "lib/netplay/netplay.h"
 #include "scripttabs.h"
 #include "scriptextern.h"
 
@@ -193,6 +194,12 @@ BOOL scrGenExternSet(UDWORD index)
 			return false;
 		}
 		bInTutorial = val;
+		if (val)
+		{
+			// Since tutorial is skirmish
+			NetPlay.players[0].allocated = true;
+debug(LOG_ERROR, "tutorial turned %s", val ? "on" : "off");
+		}
 		break;
 	case EXTID_EXTRAVICTORYFLAG:
 		if (type != VAL_BOOL)
