@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -405,6 +405,7 @@ extern BOOL scrFlushConsoleMessages(void);
 // find and manipulate a position to build a structure.
 extern BOOL scrPickStructLocation(void);
 extern BOOL scrPickStructLocationB(void);
+extern BOOL scrPickStructLocationC(void);
 
 // establish the distance between two points in world coordinates - approximate bounded to 11% out
 extern BOOL scrDistanceTwoPts( void );
@@ -684,4 +685,6 @@ extern BOOL scrLog(void);
 extern BOOL addBeaconBlip(SDWORD locX, SDWORD locY, SDWORD forPlayer, SDWORD sender, char * textMsg);
 extern VIEWDATA *CreateBeaconViewData(SDWORD sender, UDWORD LocX, UDWORD LocY);
 
+extern BOOL scrScavengersActive(void);
+
 #endif // __INCLUDED_SRC_SCRIPTFUNCS_H__
