@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -102,14 +102,14 @@ BOOL scrvAddContext(char *pID, SCRIPT_CONTEXT *psContext, SCRV_TYPE type)
 	psNew = (SCRV_STORE*)malloc(sizeof(SCRV_STORE));
 	if (!psNew)
 	{
-		debug( LOG_ERROR, "scrvAddContext: Out of memory" );
+		debug( LOG_FATAL, "scrvAddContext: Out of memory" );
 		abort();
 		return false;
 	}
 	psNew->pIDString = (char*)malloc(strlen(pID) + 1);
 	if (!psNew->pIDString)
 	{
-		debug( LOG_ERROR, "scrvAddContext: Out of memory" );
+		debug( LOG_FATAL, "scrvAddContext: Out of memory" );
 		abort();
 		return false;
 	}
@@ -229,7 +229,7 @@ BOOL scrvGetContext(char *pID, SCRIPT_CONTEXT **ppsContext)
 		}
 	}
 
-	debug( LOG_ERROR, "scrvGetContext: couldn't find context for id: %s", pID );
+	debug( LOG_FATAL, "scrvGetContext: couldn't find context for id: %s", pID );
 	abort();
 	return false;
 }
