@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -90,7 +90,7 @@ static UDWORD	maxWeaponDamage;
 static UDWORD	maxWeaponROF;
 static UDWORD	maxPropulsionSpeed;
 
-//stores for each players component states - can be either UNAVAILABLE, FOUND or AVAILABLE
+//stores for each players component states - can be either UNAVAILABLE, REDUNDANT, FOUND or AVAILABLE
 UBYTE		*apCompLists[MAX_PLAYERS][COMP_NUMCOMPONENTS];
 
 //store for each players Structure states
@@ -131,10 +131,11 @@ static void updateMaxConstStats(UWORD maxValue);
 #define ALLOC_STATS(numEntries, list, listSize, type) \
 	ASSERT( (numEntries) < REF_RANGE, \
 	"allocStats: number of stats entries too large for " #type );\
+	if ((list))	free((list));	\
 	(list) = (type *)malloc(sizeof(type) * (numEntries)); \
 	if ((list) == NULL) \
 	{ \
-		debug( LOG_ERROR, "Out of memory" ); \
+		debug( LOG_FATAL, "Out of memory" ); \
 		abort(); \
 		return false; \
 	} \
@@ -144,25 +145,12 @@ static void updateMaxConstStats(UWORD maxValue);
 
 /*Macro to Deallocate stats*/
 #define STATS_DEALLOC(list, listSize, type) \
-	statsDealloc((COMPONENT_STATS*)(list), (listSize), sizeof(type))
+	statsDealloc((COMPONENT_STATS*)(list), (listSize), sizeof(type)); \
+	(list) = NULL 
 
 
 void statsInitVars(void)
 {
-	int i,j;
-
-	asBodyStats = NULL;
-	asBrainStats = NULL;
-	asPropulsionStats = NULL;
-	asSensorStats = NULL;
-	asECMStats = NULL;
-	asRepairStats = NULL;
-	asWeaponStats = NULL;
-	asConstructStats = NULL;
-	asPropulsionTypes = NULL;
-	asTerrainTable = NULL;
-	asSpecialAbility = NULL;
-
 	/* The number of different stats stored */
 	numBodyStats = 0;
 	numBrainStats = 0;
@@ -174,18 +162,6 @@ void statsInitVars(void)
 	numConstructStats = 0;
 	numSpecialAbility = 0;
 
-	//stores for each players component states - can be either UNAVAILABLE, FOUND or AVAILABLE
-	for(i=0; i<MAX_PLAYERS; i++) {
-		for(j=0; j<COMP_NUMCOMPONENTS; j++) {
-			apCompLists[i][j] = NULL;
-		}
-	}
-
-	//store for each players Structure states
-	for(i=0; i<MAX_PLAYERS; i++) {
-		apStructTypeLists[i] = NULL;
-	}
-
 	//initialise the upgrade structures
 	memset(asWeaponUpgrade, 0, MAX_PLAYERS * WSC_NUM_WEAPON_SUBCLASSES * sizeof(WEAPON_UPGRADE));
 	memset(asSensorUpgrade, 0, MAX_PLAYERS * sizeof(SENSOR_UPGRADE));
@@ -195,16 +171,19 @@ void statsInitVars(void)
 
 	// init the max values
 	maxComponentWeight = maxBodyArmour = maxBodyPower =
-        maxBodyPoints = maxSensorRange = maxSensorPower = maxECMPower = maxECMRange =
-        maxConstPoints = maxRepairPoints = maxWeaponRange = maxWeaponDamage =
-        maxPropulsionSpeed = 0;
+		maxBodyPoints = maxSensorRange = maxSensorPower = maxECMPower = maxECMRange =
+		maxConstPoints = maxRepairPoints = maxWeaponRange = maxWeaponDamage =
+		maxPropulsionSpeed = 0;
 }
 
 
 /*Deallocate all the stats assigned from input data*/
 void statsDealloc(COMPONENT_STATS* pStats, UDWORD listSize, UDWORD structureSize)
 {
-	free(pStats);
+	if (pStats)
+	{
+		free(pStats);
+	}
 }
 
 
@@ -340,7 +319,7 @@ const char *getStatName(const void * Stat)
 /*Load the weapon stats from the file exported from Access*/
 BOOL loadWeaponStats(const char *pWeaponData, UDWORD bufferSize)
 {
-	const unsigned int NumWeapons = numCR(pWeaponData, bufferSize);
+	unsigned int	NumWeapons = numCR(pWeaponData, bufferSize);
 	WEAPON_STATS	sStats, * const psStats = &sStats;
 	UDWORD			i, rotate, maxElevation, surfaceToAir;
 	SDWORD			minElevation;
@@ -359,6 +338,13 @@ BOOL loadWeaponStats(const char *pWeaponData, UDWORD bufferSize)
 	UDWORD			penetrate;
 	UDWORD dummyVal;
 
+	// Skip descriptive header
+	if (strncmp(pWeaponData,"Weapon ",7)==0)
+	{
+		pWeaponData = strchr(pWeaponData,'\n') + 1;
+		NumWeapons--;
+	}
+
 	if (!statsAllocWeapons(NumWeapons))
 	{
 		return false;
@@ -444,7 +430,7 @@ BOOL loadWeaponStats(const char *pWeaponData, UDWORD bufferSize)
 			if (psStats->pIMD == NULL)
 			{
 
-				debug( LOG_ERROR, "Cannot find the weapon PIE for record %s", getStatName(psStats) );
+				debug( LOG_FATAL, "Cannot find the weapon PIE for record %s", getStatName(psStats) );
 				abort();
 				return false;
 			}
@@ -459,7 +445,7 @@ BOOL loadWeaponStats(const char *pWeaponData, UDWORD bufferSize)
 			psStats->pMountGraphic = (iIMDShape *) resGetData("IMD", mountGfx);
 			if (psStats->pMountGraphic == NULL)
 			{
-				debug( LOG_ERROR, "Cannot find the mount PIE for record %s", getStatName(psStats) );
+				debug( LOG_FATAL, "Cannot find the mount PIE for record %s", getStatName(psStats) );
 				abort();
 				return false;
 			}
@@ -474,7 +460,7 @@ BOOL loadWeaponStats(const char *pWeaponData, UDWORD bufferSize)
 			psStats->pMuzzleGraphic = (iIMDShape *) resGetData("IMD", muzzleGfx);
 			if (psStats->pMuzzleGraphic == NULL)
 			{
-				debug( LOG_ERROR, "Cannot find the muzzle PIE for record %s", getStatName(psStats) );
+				debug( LOG_FATAL, "Cannot find the muzzle PIE for record %s", getStatName(psStats) );
 				abort();
 				return false;
 			}
@@ -483,7 +469,7 @@ BOOL loadWeaponStats(const char *pWeaponData, UDWORD bufferSize)
 			psStats->pInFlightGraphic = (iIMDShape *) resGetData("IMD", flightGfx);
 			if (psStats->pInFlightGraphic == NULL)
 			{
-				debug( LOG_ERROR, "Cannot find the flight PIE for record %s", getStatName(psStats) );
+				debug( LOG_FATAL, "Cannot find the flight PIE for record %s", getStatName(psStats) );
 				abort();
 				return false;
 			}
@@ -491,7 +477,7 @@ BOOL loadWeaponStats(const char *pWeaponData, UDWORD bufferSize)
 			psStats->pTargetHitGraphic = (iIMDShape *) resGetData("IMD", hitGfx);
 			if (psStats->pTargetHitGraphic == NULL)
 			{
-				debug( LOG_ERROR, "Cannot find the target hit PIE for record %s", getStatName(psStats) );
+				debug( LOG_FATAL, "Cannot find the target hit PIE for record %s", getStatName(psStats) );
 				abort();
 				return false;
 			}
@@ -499,7 +485,7 @@ BOOL loadWeaponStats(const char *pWeaponData, UDWORD bufferSize)
 			psStats->pTargetMissGraphic = (iIMDShape *) resGetData("IMD", missGfx);
 			if (psStats->pTargetMissGraphic == NULL)
 			{
-				debug( LOG_ERROR, "Cannot find the target miss PIE for record %s", getStatName(psStats) );
+				debug( LOG_FATAL, "Cannot find the target miss PIE for record %s", getStatName(psStats) );
 				abort();
 				return false;
 			}
@@ -507,7 +493,7 @@ BOOL loadWeaponStats(const char *pWeaponData, UDWORD bufferSize)
 			psStats->pWaterHitGraphic = (iIMDShape *) resGetData("IMD", waterGfx);
 			if (psStats->pWaterHitGraphic == NULL)
 			{
-				debug( LOG_ERROR, "Cannot find the water hit PIE for record %s", getStatName(psStats) );
+				debug( LOG_FATAL, "Cannot find the water hit PIE for record %s", getStatName(psStats) );
 				abort();
 				return false;
 			}
@@ -517,7 +503,7 @@ BOOL loadWeaponStats(const char *pWeaponData, UDWORD bufferSize)
 				psStats->pTrailGraphic = (iIMDShape *) resGetData("IMD", trailGfx);
 				if (psStats->pTrailGraphic == NULL)
 				{
-					debug( LOG_ERROR, "Cannot find the trail PIE for record %s", getStatName(psStats) );
+					debug( LOG_FATAL, "Cannot find the trail PIE for record %s", getStatName(psStats) );
 					abort();
 					return false;
 				}
@@ -587,7 +573,7 @@ BOOL loadWeaponStats(const char *pWeaponData, UDWORD bufferSize)
 		//set the weapon effect
 		if (!getWeaponEffect(weaponEffect, &psStats->weaponEffect))
 		{
-			debug( LOG_ERROR, "loadWepaonStats: Invalid weapon effect for weapon %s", getStatName(psStats) );
+			debug( LOG_FATAL, "loadWepaonStats: Invalid weapon effect for weapon %s", getStatName(psStats) );
 			abort();
 			return false;
 		}
@@ -754,13 +740,20 @@ BOOL loadWeaponStats(const char *pWeaponData, UDWORD bufferSize)
 BOOL loadBodyStats(const char *pBodyData, UDWORD bufferSize)
 {
 	BODY_STATS sStats, * const psStats = &sStats;
-	const unsigned int NumBody = numCR(pBodyData, bufferSize);
+	unsigned int NumBody = numCR(pBodyData, bufferSize);
 	unsigned int i, designable;
 	char BodyName[MAX_STR_LENGTH], size[MAX_STR_LENGTH],
 		GfxFile[MAX_STR_LENGTH], dummy[MAX_STR_LENGTH],
 		flameIMD[MAX_STR_LENGTH];
 	UDWORD dummyVal;
 
+	// Skip descriptive header
+	if (strncmp(pBodyData,"Body ",5)==0)
+	{
+		pBodyData = strchr(pBodyData,'\n') + 1;
+		NumBody--;
+	}
+	
 	if (!statsAllocBody(NumBody))
 	{
 		return false;
@@ -816,7 +809,7 @@ BOOL loadBodyStats(const char *pBodyData, UDWORD bufferSize)
 			psStats->pIMD = (iIMDShape *) resGetData("IMD", GfxFile);
 			if (psStats->pIMD == NULL)
 			{
-				debug( LOG_ERROR, "Cannot find the body PIE for record %s", getStatName(psStats) );
+				debug( LOG_FATAL, "Cannot find the body PIE for record %s", getStatName(psStats) );
 				abort();
 				return false;
 			}
@@ -832,7 +825,7 @@ BOOL loadBodyStats(const char *pBodyData, UDWORD bufferSize)
 			psStats->pFlameIMD = (iIMDShape *) resGetData("IMD", flameIMD);
 			if (psStats->pFlameIMD == NULL)
 			{
-				debug( LOG_ERROR, "Cannot find the flame PIE for record %s", getStatName(psStats) );
+				debug( LOG_FATAL, "Cannot find the flame PIE for record %s", getStatName(psStats) );
 				abort();
 				return false;
 			}
@@ -904,17 +897,12 @@ BOOL loadBrainStats(const char *pBrainData, UDWORD bufferSize)
 		}
 		else
 		{
-			//get the weapon stat
-			if (!getResourceName(weaponName))
-			{
-				return false;
-			}
 			weapon = getCompFromName(COMP_WEAPON, weaponName);
 
 			//if weapon not found - error
 			if (weapon == -1)
 			{
-				debug( LOG_ERROR, "Unable to find Weapon %s for brain %s", weaponName, BrainName );
+				debug( LOG_FATAL, "Unable to find Weapon %s for brain %s", weaponName, BrainName );
 				abort();
 				return false;
 			}
@@ -1038,7 +1026,7 @@ BOOL loadPropulsionStats(const char *pPropulsionData, UDWORD bufferSize)
 			psStats->pIMD = (iIMDShape *) resGetData("IMD", imdName);
 			if (psStats->pIMD == NULL)
 			{
-				debug( LOG_ERROR, "Cannot find the propulsion PIE for record %s", getStatName(psStats) );
+				debug( LOG_FATAL, "Cannot find the propulsion PIE for record %s", getStatName(psStats) );
 				abort();
 				return false;
 			}
@@ -1051,7 +1039,7 @@ BOOL loadPropulsionStats(const char *pPropulsionData, UDWORD bufferSize)
 		//set up the stats type
 		if (!getPropulsionType(type, &psStats->propulsionType))
 		{
-			debug( LOG_ERROR, "loadPropulsionStats: Invalid Propulsion type for %s", getStatName(psStats) );
+			debug( LOG_FATAL, "loadPropulsionStats: Invalid Propulsion type for %s", getStatName(psStats) );
 			abort();
 			return false;
 		}
@@ -1101,7 +1089,7 @@ BOOL loadPropulsionStats(const char *pPropulsionData, UDWORD bufferSize)
 /*Load the Sensor stats from the file exported from Access*/
 BOOL loadSensorStats(const char *pSensorData, UDWORD bufferSize)
 {
-	const unsigned int NumSensor = numCR(pSensorData, bufferSize);
+	unsigned int NumSensor = numCR(pSensorData, bufferSize);
 	SENSOR_STATS sStats, * const psStats = &sStats;
 	unsigned int i = 0, designable;
 	char			SensorName[MAX_STR_LENGTH], location[MAX_STR_LENGTH],
@@ -1109,6 +1097,13 @@ BOOL loadSensorStats(const char *pSensorData, UDWORD bufferSize)
 	char			mountGfx[MAX_STR_LENGTH], dummy[MAX_STR_LENGTH];
 	UDWORD dummyVal;
 
+	// Skip descriptive header
+	if (strncmp(pSensorData,"Sensor ",7)==0)
+	{
+		pSensorData = strchr(pSensorData,'\n') + 1;
+		NumSensor--;
+	}
+	
 	if (!statsAllocSensor(NumSensor))
 	{
 		return false;
@@ -1192,7 +1187,7 @@ BOOL loadSensorStats(const char *pSensorData, UDWORD bufferSize)
 			psStats->pIMD = (iIMDShape *) resGetData("IMD", GfxFile);
 			if (psStats->pIMD == NULL)
 			{
-				debug( LOG_ERROR, "Cannot find the sensor PIE for record %s", getStatName(psStats) );
+				debug( LOG_FATAL, "Cannot find the sensor PIE for record %s", getStatName(psStats) );
 				abort();
 				return false;
 			}
@@ -1207,7 +1202,7 @@ BOOL loadSensorStats(const char *pSensorData, UDWORD bufferSize)
 			psStats->pMountGraphic = (iIMDShape *) resGetData("IMD", mountGfx);
 			if (psStats->pMountGraphic == NULL)
 			{
-				debug( LOG_ERROR, "Cannot find the mount PIE for record %s", getStatName(psStats) );
+				debug( LOG_FATAL, "Cannot find the mount PIE for record %s", getStatName(psStats) );
 				abort();
 				return false;
 			}
@@ -1298,7 +1293,7 @@ BOOL loadECMStats(const char *pECMData, UDWORD bufferSize)
 			psStats->pIMD = (iIMDShape *) resGetData("IMD", GfxFile);
 			if (psStats->pIMD == NULL)
 			{
-				debug( LOG_ERROR, "Cannot find the ECM PIE for record %s", getStatName(psStats) );
+				debug( LOG_FATAL, "Cannot find the ECM PIE for record %s", getStatName(psStats) );
 				abort();
 				return false;
 			}
@@ -1313,7 +1308,7 @@ BOOL loadECMStats(const char *pECMData, UDWORD bufferSize)
 			psStats->pMountGraphic = (iIMDShape *) resGetData("IMD", mountGfx);
 			if (psStats->pMountGraphic == NULL)
 			{
-				debug( LOG_ERROR, "Cannot find the mount PIE for record %s", getStatName(psStats) );
+				debug( LOG_FATAL, "Cannot find the mount PIE for record %s", getStatName(psStats) );
 				abort();
 				return false;
 			}
@@ -1419,7 +1414,7 @@ BOOL loadRepairStats(const char *pRepairData, UDWORD bufferSize)
 			psStats->pIMD = (iIMDShape *) resGetData("IMD", GfxFile);
 			if (psStats->pIMD == NULL)
 			{
-				debug( LOG_ERROR, "Cannot find the Repair PIE for record %s", getStatName(psStats) );
+				debug( LOG_FATAL, "Cannot find the Repair PIE for record %s", getStatName(psStats) );
 				abort();
 				return false;
 			}
@@ -1434,7 +1429,7 @@ BOOL loadRepairStats(const char *pRepairData, UDWORD bufferSize)
 			psStats->pMountGraphic = (iIMDShape *) resGetData("IMD", mountGfx);
 			if (psStats->pMountGraphic == NULL)
 			{
-				debug( LOG_ERROR, "Cannot find the Repair mount PIE for record %s", getStatName(psStats) );
+				debug( LOG_FATAL, "Cannot find the Repair mount PIE for record %s", getStatName(psStats) );
 				abort();
 				return false;
 			}
@@ -1516,7 +1511,7 @@ BOOL loadConstructStats(const char *pConstructData, UDWORD bufferSize)
 			psStats->pIMD = (iIMDShape *) resGetData("IMD", GfxFile);
 			if (psStats->pIMD == NULL)
 			{
-				debug( LOG_ERROR, "Cannot find the constructor PIE for record %s", getStatName(psStats) );
+				debug( LOG_FATAL, "Cannot find the constructor PIE for record %s", getStatName(psStats) );
 				abort();
 				return false;
 			}
@@ -1531,7 +1526,7 @@ BOOL loadConstructStats(const char *pConstructData, UDWORD bufferSize)
 			psStats->pMountGraphic = (iIMDShape *) resGetData("IMD", mountGfx);
 			if (psStats->pMountGraphic == NULL)
 			{
-				debug( LOG_ERROR, "Cannot find the mount PIE for record %s", getStatName(psStats) );
+				debug( LOG_FATAL, "Cannot find the mount PIE for record %s", getStatName(psStats) );
 				abort();
 				return false;
 			}
@@ -1573,7 +1568,7 @@ BOOL loadPropulsionTypes(const char *pPropTypeData, UDWORD bufferSize)
 	asPropulsionTypes = (PROPULSION_TYPES *)malloc(sizeof(PROPULSION_TYPES)*NumTypes);
 	if (asPropulsionTypes == NULL)
 	{
-		debug( LOG_ERROR, "PropulsionTypes - Out of memory" );
+		debug( LOG_FATAL, "PropulsionTypes - Out of memory" );
 		abort();
 		return false;
 	}
@@ -1589,7 +1584,7 @@ BOOL loadPropulsionTypes(const char *pPropTypeData, UDWORD bufferSize)
 		//set the pointer for this record based on the name
 		if (!getPropulsionType(PropulsionName, &type))
 		{
-			debug( LOG_ERROR, "loadPropulsionTypes: Invalid Propulsion type - %s", PropulsionName );
+			debug( LOG_FATAL, "loadPropulsionTypes: Invalid Propulsion type - %s", PropulsionName );
 			abort();
 			return false;
 		}
@@ -1647,7 +1642,7 @@ BOOL loadTerrainTable(const char *pTerrainTableData, UDWORD bufferSize)
 
 	if (asTerrainTable == NULL)
 	{
-		debug( LOG_ERROR, "Terrain Types - Out of memory" );
+		debug( LOG_FATAL, "Terrain Types - Out of memory" );
 		abort();
 		return false;
 	}
@@ -1684,7 +1679,7 @@ BOOL loadTerrainTable(const char *pTerrainTableData, UDWORD bufferSize)
 			TERRAIN_TABLE * const pTerrainTable = asTerrainTable + (i * PROPULSION_TYPE_NUM + j);
 			if (pTerrainTable->speedFactor == 0)
 			{
-				debug( LOG_ERROR, "loadTerrainTable: Invalid propulsion/terrain table entry" );
+				debug( LOG_FATAL, "loadTerrainTable: Invalid propulsion/terrain table entry" );
 				abort();
 				return false;
 			}
@@ -1707,7 +1702,7 @@ BOOL loadSpecialAbility(const char *pSAbilityData, UDWORD bufferSize)
 
 	if (asSpecialAbility == NULL)
 	{
-		debug( LOG_ERROR, "SpecialAbility - Out of memory" );
+		debug( LOG_FATAL, "SpecialAbility - Out of memory" );
 		abort();
 		return false;
 	}
@@ -1726,7 +1721,7 @@ BOOL loadSpecialAbility(const char *pSAbilityData, UDWORD bufferSize)
 		//check that the data is ordered in the way it will be stored
 		if (accessID != i)
 		{
-			debug( LOG_ERROR, "The Special Ability sequence is invalid" );
+			debug( LOG_FATAL, "The Special Ability sequence is invalid" );
 			abort();
 			return false;
 		}
@@ -1734,7 +1729,7 @@ BOOL loadSpecialAbility(const char *pSAbilityData, UDWORD bufferSize)
 		asSpecialAbility->pName = (char *)malloc((strlen(SAbilityName))+1);
 		if (asSpecialAbility->pName == NULL)
 		{
-			debug( LOG_ERROR, "Special Ability Name - Out of memory" );
+			debug( LOG_FATAL, "Special Ability Name - Out of memory" );
 			abort();
 			return false;
 		}
@@ -1774,7 +1769,7 @@ BOOL loadBodyPropulsionIMDs(const char *pData, UDWORD bufferSize)
 		psBodyStat->ppIMDList = (iIMDShape **) malloc(numPropulsionStats * NUM_PROP_SIDES * sizeof(iIMDShape *));
 		if (psBodyStat->ppIMDList == NULL)
 		{
-			debug( LOG_ERROR, "Out of memory" );
+			debug( LOG_FATAL, "Out of memory" );
 			abort();
 		}
 		//initialise the pointer space
@@ -1798,10 +1793,6 @@ BOOL loadBodyPropulsionIMDs(const char *pData, UDWORD bufferSize)
 
 		//get the body stats
 		found = false;
-		if (!getResourceName(bodyName))
-		{
-			return false;
-		}
 
 		for (numStats = 0; numStats < numBodyStats; numStats++)
 		{
@@ -1814,17 +1805,13 @@ BOOL loadBodyPropulsionIMDs(const char *pData, UDWORD bufferSize)
 		}
 		if (!found)
 		{
-			debug( LOG_ERROR, "loadBodyPropulsionPIEs: Invalid body name %s", bodyName );
+			debug( LOG_FATAL, "loadBodyPropulsionPIEs: Invalid body name %s", bodyName );
 			abort();
 			return false;
 		}
 
 		//get the propulsion stats
 		found = false;
-		if (!getResourceName(propulsionName))
-		{
-			return false;
-		}
 
 		for (numStats = 0; numStats < numPropulsionStats; numStats++)
 		{
@@ -1837,7 +1824,7 @@ BOOL loadBodyPropulsionIMDs(const char *pData, UDWORD bufferSize)
 		}
 		if (!found)
 		{
-			debug( LOG_ERROR, "Invalid propulsion name %s", propulsionName );
+			debug( LOG_FATAL, "Invalid propulsion name %s", propulsionName );
 			abort();
 			return false;
 		}
@@ -1850,7 +1837,7 @@ BOOL loadBodyPropulsionIMDs(const char *pData, UDWORD bufferSize)
 			*psBodyStat->ppIMDList = (iIMDShape *) resGetData("IMD", leftIMD);
 			if (*psBodyStat->ppIMDList == NULL)
 			{
-				debug( LOG_ERROR, "Cannot find the left propulsion PIE for body %s", bodyName );
+				debug( LOG_FATAL, "Cannot find the left propulsion PIE for body %s", bodyName );
 				abort();
 				return false;
 			}
@@ -1867,7 +1854,7 @@ BOOL loadBodyPropulsionIMDs(const char *pData, UDWORD bufferSize)
 			*psBodyStat->ppIMDList = (iIMDShape *) resGetData("IMD", rightIMD);
 			if (*psBodyStat->ppIMDList == NULL)
 			{
-				debug( LOG_ERROR, "Cannot find the right propulsion PIE for body %s", bodyName );
+				debug( LOG_FATAL, "Cannot find the right propulsion PIE for body %s", bodyName );
 				abort();
 				return false;
 			}
@@ -1900,7 +1887,7 @@ statsGetAudioIDFromString( char *szStatName, char *szWavName, SDWORD *piWavID )
 	{
 		if ( (*piWavID = audio_GetIDFromStr(szWavName)) == NO_SOUND )
 		{
-			debug( LOG_ERROR, "statsGetAudioIDFromString: couldn't get ID %d for sound %s", *piWavID, szWavName );
+			debug( LOG_FATAL, "statsGetAudioIDFromString: couldn't get ID %d for sound %s", *piWavID, szWavName );
 			abort();
 			return false;
 		}
@@ -1909,7 +1896,7 @@ statsGetAudioIDFromString( char *szStatName, char *szWavName, SDWORD *piWavID )
 	  || *piWavID > ID_MAX_SOUND)
 	 && *piWavID != NO_SOUND)
 	{
-		debug( LOG_ERROR, "statsGetAudioIDFromString: Invalid ID - %d for sound %s", *piWavID, szStatName );
+		debug( LOG_FATAL, "statsGetAudioIDFromString: Invalid ID - %d for sound %s", *piWavID, szStatName );
 		abort();
 		return false;
 	}
@@ -1926,7 +1913,6 @@ BOOL loadWeaponSounds(const char *pSoundData, UDWORD bufferSize)
 	SDWORD i, weaponSoundID, explosionSoundID, inc, iDum;
 	char			WeaponName[MAX_STR_LENGTH];
 	char			szWeaponWav[MAX_STR_LENGTH],	szExplosionWav[MAX_STR_LENGTH];
-	BOOL 	Ok = true;
 
 	ASSERT( asWeaponStats != NULL, "loadWeaponSounds: Weapon stats not loaded" );
 
@@ -1949,12 +1935,6 @@ BOOL loadWeaponSounds(const char *pSoundData, UDWORD bufferSize)
 			return false;
 		}
 
-		//find the weapon stat
-		if (!getResourceName(WeaponName))
-		{
-			return false;
-		}
-
 		for (inc = 0; inc < (SDWORD)numWeaponStats; inc++)
 		{
 			if (!strcmp(asWeaponStats[inc].pName, WeaponName))
@@ -1964,13 +1944,8 @@ BOOL loadWeaponSounds(const char *pSoundData, UDWORD bufferSize)
 				break;
 			}
 		}
-		if (inc == (SDWORD)numWeaponStats)
-		{
-			debug( LOG_ERROR, "loadWeaponSounds: Weapon stat not found - %s", WeaponName );
-			abort();
-			Ok = false;
-//			return false;
-		}
+		ASSERT_OR_RETURN(false, inc != (SDWORD)numWeaponStats, "Weapon stat not found - %s", WeaponName);
+
 		//increment the pointer to the start of the next record
 		pSoundData = strchr(pSoundData,'\n') + 1;
 	}
@@ -2005,21 +1980,21 @@ BOOL loadWeaponModifiers(const char *pWeapModData, UDWORD bufferSize)
 		//get the weapon effect inc
 		if (!getWeaponEffect(weaponEffectName, &effectInc))
 		{
-			debug( LOG_ERROR, "loadWeaponModifiers: Invalid Weapon Effect - %s", weaponEffectName );
+			debug( LOG_FATAL, "loadWeaponModifiers: Invalid Weapon Effect - %s", weaponEffectName );
 			abort();
 			return false;
 		}
 		//get the propulsion inc
 		if (!getPropulsionType(propulsionName, &propInc))
 		{
-			debug( LOG_ERROR, "loadWeaponModifiers: Invalid Propulsion type - %s", propulsionName );
+			debug( LOG_FATAL, "loadWeaponModifiers: Invalid Propulsion type - %s", propulsionName );
 			abort();
 			return false;
 		}
 
 		if (modifier > UWORD_MAX)
 		{
-			debug( LOG_ERROR, "loadWeaponModifiers: modifier for effect %s, prop type %s is too large", weaponEffectName, propulsionName );
+			debug( LOG_FATAL, "loadWeaponModifiers: modifier for effect %s, prop type %s is too large", weaponEffectName, propulsionName );
 			abort();
 			return false;
 		}
@@ -2090,7 +2065,7 @@ BOOL loadPropulsionSounds(const char *pPropSoundData, UDWORD bufferSize)
 
 		if (!getPropulsionType(propulsionName, &type))
 		{
-			debug( LOG_ERROR, "loadPropulsionSounds: Invalid Propulsion type - %s", propulsionName );
+			debug( LOG_FATAL, "loadPropulsionSounds: Invalid Propulsion type - %s", propulsionName );
 			abort();
 			return false;
 		}
@@ -2448,7 +2423,7 @@ UDWORD statRefStart(UDWORD stat)
 		default:
 		{
 			//COMP_UNKNOWN should be an error
-			debug( LOG_ERROR, "Invalid stat type" );
+			debug( LOG_FATAL, "Invalid stat type" );
 			abort();
 			start = 0;
 		}
@@ -2511,7 +2486,7 @@ BOOL compareYes(const char* strToCompare, const char* strOwner)
 	{
 		//set default to false but continue
 		//DBERROR(("Invalid yes/no for record %s", strOwner));
-		debug( LOG_ERROR, "Invalid yes/no for record %s", getName(strOwner) );
+		debug( LOG_FATAL, "Invalid yes/no for record %s", getName(strOwner) );
 		abort();
 		return false;
 	}
@@ -2572,7 +2547,7 @@ static void getStatsDetails(UDWORD compType, BASE_STATS **ppsStats, UDWORD *pnum
 		break;
 	default:
 		//COMP_UNKNOWN should be an error
-		debug( LOG_ERROR, "Invalid component type - game.c" );
+		debug( LOG_FATAL, "Invalid component type - game.c" );
 		abort();
 	}
 }
@@ -2601,13 +2576,6 @@ SDWORD getCompFromName(UDWORD compType, const char *pName)
 	return -1;
 }
 
-
-//converts the name read in from Access into the name which is used in the Stat lists
-BOOL getResourceName(const char *pName)
-{
-	return true;
-}
-
 /*return the name to display for the interface - valid for OBJECTS and STATS*/
 const char* getName(const char *pNameID)
 {
@@ -2792,7 +2760,7 @@ bool getWeaponEffect(const char* weaponEffect, WEAPON_EFFECT* effect)
 	{
 		*effect = WE_FLAMER;
 	}
-	else if (strcmp(weaponEffect, "ANTI AIRCRAFT") == 0)
+	else if (strcmp(weaponEffect, "ANTI AIRCRAFT") == 0 || strcmp(weaponEffect, "ALL ROUNDER") == 0)
 	{
 		*effect = WE_ANTI_AIRCRAFT;
 	}
@@ -2819,7 +2787,7 @@ char* allocateName(const char* name)
 	 */
 	if (!strresGetString(psStringRes, name))
 	{
-		debug(LOG_ERROR, "Unable to find string resource for %s", name);
+		debug(LOG_FATAL, "Unable to find string resource for %s", name);
 		abort();
 		return NULL;
 	}
@@ -2827,7 +2795,7 @@ char* allocateName(const char* name)
 	storeName = strdup(name);
 	if (!storeName)
 	{
-		debug(LOG_ERROR, "Out of memory");
+		debug(LOG_FATAL, "Out of memory");
 		abort();
 		return NULL;
 	}
@@ -3359,6 +3327,7 @@ BOOL objHasWeapon(BASE_OBJECT *psObj)
 SENSOR_STATS *objActiveRadar(BASE_OBJECT *psObj)
 {
 	SENSOR_STATS	*psStats = NULL;
+	int				compIndex;
 
 	switch (psObj->type)
 	{
@@ -3367,7 +3336,9 @@ SENSOR_STATS *objActiveRadar(BASE_OBJECT *psObj)
 		{
 			return NULL;
 		}
-		psStats = asSensorStats + ((DROID *)psObj)->asBits[COMP_SENSOR].nStat;
+		compIndex = ((DROID *)psObj)->asBits[COMP_SENSOR].nStat;
+		ASSERT_OR_RETURN( NULL, compIndex < numSensorStats, "Invalid range referenced for numSensorStats, %d > %d", compIndex, numSensorStats);
+		psStats = asSensorStats + compIndex;
 		break;
 	case OBJ_STRUCTURE:
 		psStats = ((STRUCTURE *)psObj)->pStructureType->pSensor;
