@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -98,6 +98,7 @@ extern UBYTE		*apStructTypeLists[MAX_PLAYERS];
 #define AVAILABLE				0x01		//this item can be used to design droids
 #define UNAVAILABLE				0x02		//the player does not know about this item
 #define FOUND					0x04		//this item has been found, but is unresearched
+#define REDUNDANT				0x0A		//the player no longer needs this item
 
 /*******************************************************************************
 *		Allocate stats functions
@@ -268,8 +269,6 @@ extern SDWORD getCompFromResName(UDWORD compType, const char *pName);
 extern bool getWeaponSubClass(const char* subClass, WEAPON_SUBCLASS* wclass);
 /*either gets the name associated with the resource (if one) or allocates space and copies pName*/
 extern char* allocateName(const char* name);
-//converts the name read in from Access into the name which is used in the Stat lists (or ignores it)
-extern BOOL getResourceName(const char *pName);
 /*return the name to display for the interface - valid for OBJECTS and STATS*/
 extern const char* getName(const char *pNameID);
 /*sets the store to the body size based on the name passed in - returns false
