@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -126,7 +126,8 @@ extern void createTestStructures(void);
 //builds a specified structure at a given location
 extern STRUCTURE* buildStructure(STRUCTURE_STATS* pStructureType, UDWORD x, UDWORD y,
 						  UDWORD player,BOOL FromSave);
-
+/// Create a blueprint structure, with just enough information to render it
+extern STRUCTURE *buildBlueprint(STRUCTURE_STATS *psStats, float x, float y, STRUCT_STATES state);
 /* The main update routine for all Structures */
 void structureUpdate(STRUCTURE *psBuilding);
 
@@ -385,6 +386,9 @@ extern void changeProductionPlayer(UBYTE player);
 // La!
 extern BOOL IsStatExpansionModule(STRUCTURE_STATS *psStats);
 
+/// is this a blueprint and not a real structure?
+extern BOOL structureIsBlueprint(STRUCTURE *psStructure);
+
 /*checks that the structure stats have loaded up as expected - must be done after
 all StructureStats parts have been loaded*/
 extern BOOL checkStructureStats(void);
