@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  * This is where we do texture atlas generation.
  */
 
-#include "lib/ivis_opengl/GLee.h"
+#include <GLee.h>
 #include "lib/framework/frame.h"
 
 
@@ -90,7 +90,7 @@ static int newPage(const char *name, int level, int width, int height, int count
 	if (texPage == _TEX_INDEX)
 	{
 		// We need to create a new texture page; create it and increase texture table to store it
-		glGenTextures(1, (GLuint *) &_TEX_PAGE[texPage].id);
+		glGenTextures(1, &_TEX_PAGE[texPage].id);
 		_TEX_INDEX++;
 	}
 	terrainPage = texPage;
@@ -170,7 +170,7 @@ bool texLoad(const char *fileName)
 	sprintf(fullPath, "%s.radar", fileName);
 	if (!loadFile(fullPath, &buffer, &size))
 	{
-		debug(LOG_ERROR, "texLoad: Could not find radar colours at %s", fullPath);
+		debug(LOG_FATAL, "texLoad: Could not find radar colours at %s", fullPath);
 		abort(); // cannot recover; we could possibly generate a random palette?
 	}
 	i = 0; // tile
