@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -56,7 +56,7 @@
 #include "lib/framework/fixedpoint.h"
 #include "lib/ivis_opengl/piematrix.h"
 #include "mapgrid.h"
-
+#include "visibility.h"
 #include "multiplay.h"
 
 //#define IDTRANS_FORM			9000	//The Transporter base form
@@ -1421,15 +1421,18 @@ void transporterRemoveDroid(UDWORD id)
 			addDroid(psDroid, apsDroidLists);
 
 			//inform all other players about that
-			if (bMultiPlayer)
+			if (bMultiMessages)
 			{
 				sendDroidDisEmbark(psDroid,psCurrTransporter);
 			}
 		}
 
-		// We can update the orders now, since everyone has been
-		// notified of the droid exiting the transporter
-		updateDroidOrientation(psDroid);
+		if (psDroid->pos.x != INVALID_XY)
+		{
+			// We can update the orders now, since everyone has been
+			// notified of the droid exiting the transporter
+			updateDroidOrientation(psDroid);
+		}
 		//initialise the movement data
 		initDroidMovement(psDroid);
 		//reset droid orders
@@ -1519,7 +1522,7 @@ void transporterAddDroid(DROID *psTransporter, DROID *psDroidToAdd)
 		// adding to transporter unit's group list
 		grpJoin(psTransporter->psGroup, psDroidToAdd);
 		
-		if (bMultiPlayer)
+		if (bMultiMessages)
 		{
 			//inform all other players to update their local lists
 			sendDroidEmbark(psDroidToAdd,psTransporter);
@@ -1529,7 +1532,15 @@ void transporterAddDroid(DROID *psTransporter, DROID *psDroidToAdd)
 	{
 		debug(LOG_ERROR,"droid %d not found, so nothing added to transporter!",psDroidToAdd->id);
 	}
-
+	if (onMission)
+	{
+		visRemoveVisibilityOffWorld((BASE_OBJECT *)psDroidToAdd);
+	}
+	else
+	{
+		visRemoveVisibility((BASE_OBJECT *)psDroidToAdd);
+	}
+	
 	//this is called by droidRemove
 	//intRefreshScreen();
 }
@@ -1917,7 +1928,7 @@ BOOL transporterFlying(DROID *psTransporter)
         (bMultiPlayer && psTransporter->order == DORDER_MOVE) ||
         //in multiPlayer mode the Transporter can be moved and emptied!
         (bMultiPlayer && psTransporter->order == DORDER_DISEMBARK) ||
-        //in multiPlayer, cannot select transporter whilst flying
+        //in multiPlayer, descending still counts as flying
         (bMultiPlayer && psTransporter->order == DORDER_NONE &&
         psTransporter->sMove.iVertSpeed != 0))
     {
