@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 2004  Giel van Schijndel
-	Copyright (C) 2007-2009  Warzone Resurrection Project
+	Copyright (C) 2007-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -23,6 +23,10 @@
 
 #include "lib/framework/types.h"
 
+#if defined(__cplusplus)
+extern "C" {
+#endif
+
 /** Retrieve the low revision number
  *  \return the lowest revision number of the working copy from which we built
  */
@@ -101,4 +105,8 @@ extern const char* version_getSvnTime(void);
  */
 extern const char* version_getFormattedVersionString(void);
 
+#if defined(__cplusplus)
+}
+#endif
+
 #endif // __INCLUDED_VERSION_H__
