@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -59,9 +59,10 @@ static float			visLevelIncAcc, visLevelDecAcc;
 // integer amount to change visiblility this turn
 static SDWORD			visLevelInc, visLevelDec;
 
-// alexl's sensor range.
-BOOL bDisplaySensorRange;
-
+// horrible hack because this code is full of them and I ain't rewriting it all - Per
+#define MAX_SEEN_TILES 1024
+static TILEPOS recordTilePos[MAX_SEEN_TILES];
+static int lastRecordTilePos = -1;
 
 typedef struct {
 	bool rayStart; // Whether this is the first point on the ray
@@ -129,9 +130,40 @@ static int visObjHeight(const BASE_OBJECT * psObject)
 	}
 }
 
+/* Record all tiles that some object confers visibility to. Only record each tile
+ * once. Note that there is both a limit to how many objects can watch any given
+ * tile, and a limit to how many tiles each object can watch. Strange but non fatal
+ * things will happen if these limits are exceeded. This function uses icky globals. */
+static inline void visMarkTile(int mapX, int mapY, MAPTILE *psTile)
+{
+	bool alreadySeen = false;
+	int i;
+
+	if (psTile->watchers[rayPlayer] < UBYTE_MAX && lastRecordTilePos < MAX_SEEN_TILES)
+	{
+		for (i = 0; i < lastRecordTilePos; i++)
+		{
+			if (recordTilePos[i].x == mapX && recordTilePos[i].y == mapY)
+			{
+				alreadySeen = true;
+				break;
+			}
+		}
+		if (!alreadySeen)
+		{
+			psTile->watchers[rayPlayer]++;			// we see this tile
+			recordTilePos[lastRecordTilePos].x = mapX;	// record having seen it
+			recordTilePos[lastRecordTilePos].y = mapY;
+			lastRecordTilePos++;
+		}
+	}
+}
+
 /* The terrain revealing ray callback */
 bool rayTerrainCallback(Vector3i pos, int distSq, void * data)
 {
+	const int mapX = map_coord(pos.x);
+	const int mapY = map_coord(pos.y);
 	int dist = sqrtf(distSq);
 	int newH, newG; // The new gradient
 	MAPTILE *psTile;
@@ -140,7 +172,7 @@ bool rayTerrainCallback(Vector3i pos, int distSq, void * data)
 		&& pos.y >= 0 && pos.y < world_coord(mapHeight),
 			"rayTerrainCallback: coords off map" );
 
-	psTile = mapTile(map_coord(pos.x), map_coord(pos.y));
+	psTile = mapTile(mapX, mapY);
 
 	/* Not true visibility - done on sensor range */
 
@@ -164,17 +196,14 @@ bool rayTerrainCallback(Vector3i pos, int distSq, void * data)
 			SET_TILE_VISIBLE(selectedPlayer,psTile);		//reveal radar
 		}
 
-		/* Not true visibility - done on sensor range */
+		visMarkTile(mapX, mapY, psTile);	// Mark this tile as seen by our sensor
+
+		/* Single player visibility system - fix me one day to work properly in MP */
 		if (rayPlayer == selectedPlayer
 		    || (bMultiPlayer && game.alliance == ALLIANCES_TEAMS
 			&& aiCheckAlliances(selectedPlayer, rayPlayer)))
 		{
-			// can see opponent moving
-			if(getRevealStatus())
-			{
-				avInformOfChange(map_coord(pos.x), map_coord(pos.y));		//reveal map
-			}
-			psTile->activeSensor = true;
+			avInformOfChange(map_coord(pos.x), map_coord(pos.y));		//reveal map
 		}
 	}
 
@@ -244,6 +273,35 @@ BOOL visTilesPending(BASE_OBJECT *psObj)
 	return (((DROID*)psObj)->updateFlags & DUPF_SCANTERRAIN);
 }
 
+/* Remove tile visibility from object */
+void visRemoveVisibility(BASE_OBJECT *psObj)
+{
+	if (psObj->watchedTiles && psObj->numWatchedTiles > 0)
+	{
+		int i = 0;
+
+		ASSERT_OR_RETURN(, psObj->player < MAX_PLAYERS, "Player index %d out of bounds for %s", (int)psObj->player, objInfo(psObj));
+		for (i = 0; i < psObj->numWatchedTiles; i++)
+		{
+			const TILEPOS pos = psObj->watchedTiles[i];
+			MAPTILE *psTile = mapTile(pos.x, pos.y);
+
+			ASSERT(psTile->watchers > 0, "Not watching watched tile (%d, %d)", (int)pos.x, (int)pos.y);
+			psTile->watchers[psObj->player]--;
+		}
+		free(psObj->watchedTiles);
+		psObj->watchedTiles = NULL;
+		psObj->numWatchedTiles = 0;
+	}
+}
+
+void visRemoveVisibilityOffWorld(BASE_OBJECT *psObj)
+{
+	free(psObj->watchedTiles);
+	psObj->watchedTiles = NULL;
+	psObj->numWatchedTiles = 0;
+}
+
 /* Check which tiles can be seen by an object */
 void visTilesUpdate(BASE_OBJECT *psObj, RAY_CALLBACK callback)
 {
@@ -253,8 +311,24 @@ void visTilesUpdate(BASE_OBJECT *psObj, RAY_CALLBACK callback)
 
 	ASSERT(psObj->type != OBJ_FEATURE, "visTilesUpdate: visibility updates are not for features!");
 
+	lastRecordTilePos = 0;
+	memset(recordTilePos, 0, sizeof(recordTilePos));
 	rayPlayer = psObj->player;
 
+	// Remove previous map visibility provided by object
+	visRemoveVisibility(psObj);
+
+	if (psObj->type == OBJ_STRUCTURE)
+	{
+		STRUCTURE * psStruct = (STRUCTURE *)psObj;
+		if (psStruct->status != SS_BUILT ||
+		    psStruct->pStructureType->type == REF_WALL || psStruct->pStructureType->type == REF_WALLCORNER)
+		{
+			// unbuilt structures and walls do not confer visibility.
+			return;
+		}
+	}
+
 	// Do the whole circle in 80 steps
 	for (ray = 0; ray < NUM_RAYS; ray += NUM_RAYS / 80)
 	{
@@ -267,6 +341,40 @@ void visTilesUpdate(BASE_OBJECT *psObj, RAY_CALLBACK callback)
 		// Cast the rays from the viewer
 		rayCast(pos, dir, range, callback, NULL);
 	}
+
+	// Make sure we also watch tiles underneath ourselves
+	if (psObj->type == OBJ_STRUCTURE)
+	{
+		int i, j;
+
+		for (i = 0; i <= ((STRUCTURE *)psObj)->pStructureType->baseBreadth; i++)
+		{
+			for (j = 0; j <= ((STRUCTURE *)psObj)->pStructureType->baseWidth; j++)
+			{
+				int	mapX = map_coord(psObj->pos.x) + i;
+				int	mapY = map_coord(psObj->pos.y) + j;
+				MAPTILE	*psTile = mapTile(mapX, mapY);
+
+				visMarkTile(mapX, mapY, psTile);
+			}
+		}
+	}
+	else
+	{
+		MAPTILE	*psTile = mapTile(map_coord(psObj->pos.x), map_coord(psObj->pos.y));
+		int	mapX = map_coord(psObj->pos.x);
+		int	mapY = map_coord(psObj->pos.y);
+
+		visMarkTile(mapX, mapY, psTile);
+	}
+
+	// Record new map visibility provided by object
+	if (lastRecordTilePos > 0)
+	{
+		psObj->watchedTiles = calloc(lastRecordTilePos, sizeof(*psObj->watchedTiles));
+		psObj->numWatchedTiles = lastRecordTilePos;
+		memcpy(psObj->watchedTiles, recordTilePos, lastRecordTilePos * sizeof(*psObj->watchedTiles));
+	}
 }
 
 /* Check whether psViewer can see psTarget.
@@ -401,8 +509,8 @@ bool visibleObject(const BASE_OBJECT* psViewer, const BASE_OBJECT* psTarget, boo
 // Find the wall that is blocking LOS to a target (if any)
 STRUCTURE* visGetBlockingWall(const BASE_OBJECT* psViewer, const BASE_OBJECT* psTarget)
 {
-	int numWalls;
-	Vector2i wall;
+	int numWalls = 0;
+	Vector2i wall = { 0, 0 };
 
 	// HACK Using globals to not clutter visibleObject() interface too much
 	gNumWalls = &numWalls;
@@ -585,45 +693,48 @@ void processVisibility(BASE_OBJECT *psObj)
 		}
 	}
 
-	// if a feature has just become visible set the tile flags
-	if (psObj->type == OBJ_FEATURE && !prevVis[selectedPlayer] && psObj->visible[selectedPlayer])
+	// if a feature has just become visible set the message blips
+	if (psObj->type == OBJ_FEATURE)
 	{
-		/*if this is an oil resource we want to add a proximity message for
-		the selected Player - if there isn't an Resource Extractor on it*/
-		if (((FEATURE *)psObj)->psStats->subType == FEAT_OIL_RESOURCE)
+		for (player = 0; player < MAX_PLAYERS; player++)
 		{
-			if (!TileHasStructure(mapTile(map_coord(psObj->pos.x),
-			                               map_coord(psObj->pos.y))))
+			if (!prevVis[player] && psObj->visible[player])
 			{
-				psMessage = addMessage(MSG_PROXIMITY, true, selectedPlayer);
-				if (psMessage)
+				/* If this is an oil resource we want to add a proximity message for
+				 * the selected Player - if there isn't an Resource Extractor on it. */
+				if (((FEATURE *)psObj)->psStats->subType == FEAT_OIL_RESOURCE)
 				{
-					psMessage->pViewData = (MSG_VIEWDATA *)psObj;
+					if (!TileHasStructure(mapTile(map_coord(psObj->pos.x), map_coord(psObj->pos.y))))
+					{
+						psMessage = addMessage(MSG_PROXIMITY, true, player);
+						if (psMessage)
+						{
+							psMessage->pViewData = (MSG_VIEWDATA *)psObj;
+						}
+						if (!bInTutorial && player == selectedPlayer)
+						{
+							//play message to indicate been seen
+							audio_QueueTrackPos( ID_SOUND_RESOURCE_HERE, psObj->pos.x, psObj->pos.y, psObj->pos.z );
+						}
+						debug(LOG_MSG, "Added message for oil well, pViewData=%p", psMessage->pViewData);
+					}
 				}
-				if (!bInTutorial)
+				else if (((FEATURE *)psObj)->psStats->subType == FEAT_GEN_ARTE)
 				{
-					//play message to indicate been seen
-					audio_QueueTrackPos( ID_SOUND_RESOURCE_HERE,
-										psObj->pos.x, psObj->pos.y, psObj->pos.z );
+					psMessage = addMessage(MSG_PROXIMITY, true, player);
+					if (psMessage)
+					{
+						psMessage->pViewData = (MSG_VIEWDATA *)psObj;
+					}
+					if (!bInTutorial && player == selectedPlayer)
+					{
+						// play message to indicate been seen
+						audio_QueueTrackPos( ID_SOUND_ARTEFACT_DISC, psObj->pos.x, psObj->pos.y, psObj->pos.z );
+					}
+					debug(LOG_MSG, "Added message for artefact, pViewData=%p", psMessage->pViewData);
 				}
-				debug(LOG_MSG, "Added message for oil well, pViewData=%p", psMessage->pViewData);
 			}
 		}
-		else if (((FEATURE *)psObj)->psStats->subType == FEAT_GEN_ARTE)
-		{
-			psMessage = addMessage(MSG_PROXIMITY, true, selectedPlayer);
-			if (psMessage)
-			{
-				psMessage->pViewData = (MSG_VIEWDATA *)psObj;
-			}
-			if (!bInTutorial)
-			{
-				//play message to indicate been seen
-				audio_QueueTrackPos( ID_SOUND_ARTEFACT_DISC,
-								psObj->pos.x, psObj->pos.y, psObj->pos.z );
-			}
-			debug(LOG_MSG, "Added message for artefact, pViewData=%p", psMessage->pViewData);
-		}
 	}
 }
 
@@ -675,39 +786,6 @@ MAPTILE		*psTile;
 	}
 }
 
-void updateSensorDisplay()
-{
-	MAPTILE		*psTile = psMapTiles;
-	int		x;
-	DROID		*psDroid;
-	STRUCTURE	*psStruct;
-
-	// clear sensor info
-	for (x = 0; x < mapWidth * mapHeight; x++)
-	{
-		psTile->activeSensor = false;
-		psTile++;
-	}
-
-	// process the sensor range of all droids/structs.
-
-	// units.
-	for(psDroid = apsDroidLists[selectedPlayer];psDroid;psDroid=psDroid->psNext)
-	{
-		visTilesUpdate((BASE_OBJECT*)psDroid, rayTerrainCallback);
-	}
-
-	// structs.
-	for(psStruct = apsStructLists[selectedPlayer];psStruct;psStruct=psStruct->psNext)
-	{
-		if (psStruct->pStructureType->type != REF_WALL
- 		    && psStruct->pStructureType->type != REF_WALLCORNER)
-		{
-			visTilesUpdate((BASE_OBJECT*)psStruct, rayTerrainCallback);
-		}
-	}
-}
-
 bool scrRayTerrainCallback(Vector3i pos, int distSq, void *data)
 {
 	int dist = sqrtf(distSq);
