@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -58,9 +58,8 @@ extern void visUpdateLevel(void);
 
 extern void setUnderTilesVis(BASE_OBJECT *psObj, UDWORD player);
 
-// sensor range display
-extern BOOL	bDisplaySensorRange;
-extern void updateSensorDisplay(void);
+void visRemoveVisibility(BASE_OBJECT *psObj);
+void visRemoveVisibilityOffWorld(BASE_OBJECT *psObj);
 
 extern bool scrTileIsVisible(SDWORD player, SDWORD x, SDWORD y);
 extern void scrResetPlayerTileVisibility(SDWORD player);
