@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -414,7 +414,7 @@ BOOL Status = true;
 			Status = false;
 		break;
 	default:
-		debug( LOG_ERROR, "Weirdy status for tracking Camera" );
+		debug( LOG_FATAL, "Weirdy status for tracking Camera" );
 		abort();
 		break;
 	}
