@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -46,7 +46,6 @@ typedef struct _warzoneGlobals
 	FMV_MODE	FMVmode;
 	BOOL		bFog;
 	SWORD		effectsLevel;
-	BOOL		allowSubtitles;
 	BOOL		Fullscreen;
 	BOOL		soundEnabled;
 	BOOL		trapCursor;
@@ -93,14 +92,6 @@ void war_SetDefaultStates(void)//Sets all states
 	war_SetMusicEnabled(true);
 }
 
-void war_SetAllowSubtitles(BOOL b) {
-	warGlobs.allowSubtitles = b;
-}
-
-BOOL war_GetAllowSubtitles(void) {
-	return warGlobs.allowSubtitles;
-}
-
 void war_setFullscreen(BOOL b) {
 	warGlobs.Fullscreen = b;
 }
