@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2009  Warzone Resurrection Project
+	Copyright (C) 2005-2010  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -22,85 +22,96 @@
  * Frontend loop & also loading screen & game over screen.
  * AlexL. Pumpkin Studios, EIDOS Interactive, 1997
  */
+
 #include "lib/framework/frame.h"
 #include "lib/framework/frameresource.h"
-#include "lib/framework/strres.h"
-
-#include "lib/ivis_common/piestate.h"
-#include "lib/ivis_common/textdraw.h" //ivis text code
 // FIXME Direct iVis implementation include!
-#include "lib/ivis_opengl/screen.h"
 #include "lib/ivis_common/piemode.h"
-#include "lib/ivis_common/piefunc.h"
-
-#include "hci.h"		// access to widget screen.
-#include "wrappers.h"
-#include "main.h"
-#include "objects.h"
-#include "display.h"
-#include "display3d.h"
-#include "frontend.h"
-#include "frend.h"		// display logo.
-#include "console.h"
-#include "intimage.h"
-#include "intdisplay.h"	//for shutdown
+#include "lib/ivis_common/piestate.h"
+#include "lib/ivis_common/rendmode.h"
+#include "lib/ivis_opengl/screen.h"
+#include "lib/netplay/netplay.h"	// multiplayer
 #include "lib/sound/audio.h"
-#include "lib/gamelib/gtime.h"
-#include "ingameop.h"
+
+#include "frontend.h"
+#include "keyedit.h"
 #include "keymap.h"
 #include "mission.h"
-#include "keyedit.h"
-// FIXME Direct iVis implementation include!
-#include "lib/ivis_common/rendmode.h"
-#include "lib/framework/cursors.h"
-#include "lib/netplay/netplay.h"	// multiplayer
-#include "multiplay.h"
 #include "multiint.h"
-#include "multistat.h"
 #include "multilimit.h"
+#include "multistat.h"
 #include "warzoneconfig.h"
+#include "wrappers.h"
 
 typedef struct _star
 {
-	UWORD	xPos;
-	SDWORD	speed;
+	int      xPos;
+	int      speed;
+	PIELIGHT colour;
 } STAR;
 
-#define MAX_STARS 20
-static STAR	stars[MAX_STARS];	// quick hack for loading stuff
-
 static BOOL		firstcall = false;
-static UDWORD	loadScreenCallNo=0;
 static BOOL		bPlayerHasLost = false;
 static BOOL		bPlayerHasWon = false;
 static UBYTE    scriptWinLoseVideo = PLAY_NONE;
 
-void	startCreditsScreen	( void );
 void	runCreditsScreen	( void );
 
-static	UDWORD	lastTick = 0;
 static	UDWORD	lastChange = 0;
-extern char iptoconnect[PATH_MAX];		// holds our ip/hostname from the command line
 BOOL hostlaunch = false;				// used to detect if we are hosting a game via command line option.
 
-static void initStars(void)
+static uint32_t lastTick = 0;
+static int barLeftX, barLeftY, barRightX, barRightY, boxWidth, boxHeight, starsNum, starHeight;
+static STAR *stars = NULL;
+
+static STAR newStar(void)
+{
+	STAR s;
+	s.xPos = rand() % barRightX;
+	s.speed = (rand() % 30 + 6) * pie_GetVideoBufferWidth() / 640.0;
+	s.colour = pal_Grey(150 + rand() % 100);
+	return s;
+}
+
+static void setupLoadingScreen(void)
 {
 	unsigned int i;
+	int w = pie_GetVideoBufferWidth();
+	int h = pie_GetVideoBufferHeight();
+	int offset;
 
-	for(i = 0; i < MAX_STARS; ++i)
+	boxHeight = h / 40.0;
+	offset = boxHeight;
+	boxWidth = w - 2.0 * offset;
+
+	barRightX = w - offset;
+	barRightY = h - offset;
+
+	barLeftX = barRightX - boxWidth;
+	barLeftY = barRightY - boxHeight;
+
+	starsNum = boxWidth / boxHeight;
+	starHeight = 2.0 * h / 640.0;
+
+	if (!stars)
 	{
-		stars[i].xPos = (UWORD)(rand()%598);		// scatter them
-		stars[i].speed = rand()%10+2;	// always move
+		stars = (STAR *)malloc(sizeof(STAR) * starsNum);
+	}
+
+	for (i = 0; i < starsNum; ++i)
+	{
+		stars[i] = newStar();
 	}
 }
 
+
 // //////////////////////////////////////////////////////////////////
 // Initialise frontend globals and statics.
 //
 BOOL frontendInitVars(void)
 {
 	firstcall = true;
-	initStars();
+	setupLoadingScreen();
 
 	return true;
 }
@@ -126,6 +137,7 @@ TITLECODE titleLoop(void)
 		{
 			ingame.bHostSetup = true;
 			bMultiPlayer = true;
+			bMultiMessages = true;
 			game.type = SKIRMISH;		// needed?
 			changeTitleMode(MULTIOPTION);
 			hostlaunch = false;			// reset the bool to default state.
@@ -142,6 +154,9 @@ TITLECODE titleLoop(void)
 		pie_SetMouse(CURSOR_DEFAULT, war_GetColouredCursor());
 	}
 
+	if (titleMode != MULTIOPTION && titleMode != MULTILIMIT && titleMode != STARTGAME)
+		screen_disableMapPreview();
+
 	switch(titleMode) // run relevant title screen code.
 	{
 		// MULTIPLAYER screens
@@ -199,20 +214,20 @@ TITLECODE titleLoop(void)
 			break;
 
 
-		case GAME2:
-			runGameOptions2Menu();
+		case GRAPHICS_OPTIONS:
+			runGraphicsOptionsMenu();
 			break;
 
-		case GAME3:
-			runGameOptions3Menu();
+		case AUDIO_OPTIONS:
+			runAudioOptionsMenu();
 			break;
 
-		case GAME4:
-			runGameOptions4Menu();
+		case VIDEO_OPTIONS:
+			runVideoOptionsMenu();
 			break;
 
-		case GAME5:
-			runGameOptions5Menu();
+		case MOUSE_OPTIONS:
+			runMouseOptionsMenu();
 			break;
 
 		case QUIT:
@@ -240,7 +255,7 @@ TITLECODE titleLoop(void)
 			break;
 
 		default:
-			debug( LOG_ERROR, "unknown title screen mode" );
+			debug( LOG_FATAL, "unknown title screen mode" );
 			abort();
 	}
 
@@ -263,65 +278,44 @@ TITLECODE titleLoop(void)
 ////////////////////////////////////////////////////////////////////////////////
 // Loading Screen.
 
-
-
-
 //loadbar update
 void loadingScreenCallback(void)
 {
+	const PIELIGHT loadingbar_background = pal_RGBA(0, 0, 0, 24);
+	const uint32_t currTick = SDL_GetTicks();
 	unsigned int i;
-	UDWORD			topX,topY,botX,botY;
-	UDWORD			currTick;
-	PIELIGHT		colour;
 
-	if(SDL_GetTicks()-lastTick < 16)
+	if (currTick - lastTick < 50)
 	{
 		return;
 	}
-	currTick = SDL_GetTicks();
-	if ((currTick - lastTick) > 500)
-	{
-		currTick -= lastTick;
-		debug( LOG_NEVER, "loadingScreenCallback: pause %d\n", currTick );
-	}
-	lastTick = SDL_GetTicks();
-	colour.byte.r = 1;
-	colour.byte.g = 1;
-	colour.byte.b = 1;
-	colour.byte.a = 32;
-	pie_UniTransBoxFill(1, 1, 2, 2, colour);
-	/* Draw the black rectangle at the bottom */
+	lastTick = currTick;
 
-	topX = 10+D_W;
-	topY = 450+D_H-1;
-	botX = 630+D_W;
-	botY = 470+D_H+1;
-	colour.byte.a = 24;
-	pie_UniTransBoxFill(topX, topY, botX, botY, colour);
+	/* Draw the black rectangle at the bottom, with a two pixel border */
+	pie_UniTransBoxFill(barLeftX - 2, barLeftY - 2, barRightX + 2, barRightY + 2, loadingbar_background);
 
-	for(i = 1; i < MAX_STARS; ++i)
+	for (i = 1; i < starsNum; ++i)
 	{
-	   	if(stars[i].xPos + stars[i].speed >=598)
+		stars[i].xPos = stars[i].xPos + stars[i].speed;
+		if (stars[i].xPos >= barRightX)
 		{
+			stars[i] = newStar();
 			stars[i].xPos = 1;
 		}
-		else
 		{
-			stars[i].xPos = (UWORD)(stars[i].xPos + stars[i].speed);
-		}
+		const int topX = barLeftX + stars[i].xPos;
+		const int topY = barLeftY + i * (boxHeight - starHeight) / starsNum;
+		const int botX = MIN(topX + stars[i].speed, barRightX);
+		const int botY = topY + starHeight;
 
-		colour.byte.r = 200;
-		colour.byte.g = 200;
-		colour.byte.b = 200;
-		colour.byte.a = 255;
-		pie_UniTransBoxFill(10 + stars[i].xPos+D_W, 450 + i + D_H, 10 + stars[i].xPos + (2 * stars[i].speed) + D_W, 450 + i + 2 + D_H, colour);
-   	}
+		pie_UniTransBoxFill(topX, topY, botX, botY, stars[i].colour);
+		}
+	}
 
 	pie_ScreenFlip(CLEAR_OFF_AND_NO_BUFFER_DOWNLOAD);//loading callback		// dont clear.
 	audio_Update();
 }
 
-
 // fill buffers with the static screen
 void initLoadingScreen( BOOL drawbdrop )
 {
@@ -333,7 +327,6 @@ void initLoadingScreen( BOOL drawbdrop )
 		pie_SetFogStatus(false);
 		pie_ScreenFlip(CLEAR_BLACK);
 		resSetLoadCallback(loadingScreenCallback);
-		loadScreenCallNo = 0;
 		return;
 	}
 
@@ -342,7 +335,6 @@ void initLoadingScreen( BOOL drawbdrop )
 
 	// setup the callback....
 	resSetLoadCallback(loadingScreenCallback);
-	loadScreenCallNo = 0;
 
 	// NOTE: When this is called, we stop the backdrop, but since the screen
 	// is double buffered, we only have the backdrop on 1 buffer, and not the other.
@@ -382,8 +374,12 @@ void runCreditsScreen( void )
 // shut down the loading screen
 void closeLoadingScreen(void)
 {
+	if (stars)
+	{
+		free(stars);
+		stars = NULL;
+	}
 	resSetLoadCallback(NULL);
-	loadScreenCallNo = 0;
 }
 
 
@@ -393,14 +389,6 @@ void closeLoadingScreen(void)
 
 BOOL displayGameOver(BOOL bDidit)
 {
-// AlexL says take this out......
-//	setConsolePermanence(true,true);
-//	flushConsoleMessages( );
-
-//	addConsoleMessage(" ", CENTRE_JUSTIFY, SYSTEM_MESSAGE);
-//	addConsoleMessage(_("Game Over"), CENTRE_JUSTIFY, SYSTEM_MESSAGE);
-//	addConsoleMessage(" ", CENTRE_JUSTIFY, SYSTEM_MESSAGE);
-
 	if(bDidit)
 	{
 		setPlayerHasWon(true);
